
This is a patch file against 0.2.8.

Change to directory gnupg-0.2.8 (or however you renamed it)
and give this command:

     zcat somepath/gnupg-0.2.9.diff.gz | patch -p1

It is a good idea to rename your current directory to gnupg-0.2.9 now.



Prereq: 0.2.8

diff -urN gnupg-0.2.8/VERSION gnupg-0.2.9/VERSION
--- gnupg-0.2.8/VERSION	Tue Feb 24 17:21:58 1998
+++ gnupg-0.2.9/VERSION	Thu Feb 26 15:34:27 1998
@@ -1 +1 @@
-0.2.8
+0.2.9
diff -urN gnupg-0.2.8/intl/VERSION gnupg-0.2.9/intl/VERSION
--- gnupg-0.2.8/intl/VERSION	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/VERSION	Thu Feb 26 16:27:25 1998
@@ -1 +1 @@
-GNU gettext library from gettext-0.10
+GNU gettext library from gettext-0.10.32
diff -urN gnupg-0.2.8/intl/bindtextdom.c gnupg-0.2.9/intl/bindtextdom.c
--- gnupg-0.2.8/intl/bindtextdom.c	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/bindtextdom.c	Thu Feb 26 16:27:25 1998
@@ -1,19 +1,19 @@
-/* bindtextdom.c -- implementation of the bindtextdomain(3) function
-   Copyright (C) 1995 Free Software Foundation, Inc.
+/* Implementation of the bindtextdomain(3) function
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -33,6 +33,9 @@
 # include <string.h>
 #else
 # include <strings.h>
+# ifndef memcpy
+#  define memcpy(Dst, Src, Num) bcopy (Src, Dst, Num)
+# endif
 #endif
 
 #ifdef _LIBC
@@ -58,6 +61,7 @@
    prefix.  So we have to make a difference here.  */
 #ifdef _LIBC
 # define BINDTEXTDOMAIN __bindtextdomain
+# define strdup(str) __strdup (str)
 #else
 # define BINDTEXTDOMAIN bindtextdomain__
 #endif
@@ -95,25 +99,36 @@
 
   if (binding != NULL)
     {
-      /* The domain is already bound.  Replace the old binding.  */
-      char *new_dirname;
-
-      if (strcmp (dirname, _nl_default_dirname) == 0)
-	new_dirname = (char *) _nl_default_dirname;
-      else
+      /* The domain is already bound.  If the new value and the old
+	 one are equal we simply do nothing.  Otherwise replace the
+	 old binding.  */
+      if (strcmp (dirname, binding->dirname) != 0)
 	{
-	  size_t len = strlen (dirname) + 1;
-	  new_dirname = (char *) malloc (len);
-	  if (new_dirname == NULL)
-	    return NULL;
+	  char *new_dirname;
 
-	  memcpy (new_dirname, dirname, len);
-	}
+	  if (strcmp (dirname, _nl_default_dirname) == 0)
+	    new_dirname = (char *) _nl_default_dirname;
+	  else
+	    {
+#if defined _LIBC || defined HAVE_STRDUP
+	      new_dirname = strdup (dirname);
+	      if (new_dirname == NULL)
+		return NULL;
+#else
+	      size_t len = strlen (dirname) + 1;
+	      new_dirname = (char *) malloc (len);
+	      if (new_dirname == NULL)
+		return NULL;
 
-      if (strcmp (binding->dirname, _nl_default_dirname) != 0)
-        free (binding->dirname);
+	      memcpy (new_dirname, dirname, len);
+#endif
+	    }
 
-      binding->dirname = new_dirname;
+	  if (binding->dirname != _nl_default_dirname)
+	    free (binding->dirname);
+
+	  binding->dirname = new_dirname;
+	}
     }
   else
     {
@@ -125,21 +140,33 @@
       if (new_binding == NULL)
 	return NULL;
 
+#if defined _LIBC || defined HAVE_STRDUP
+      new_binding->domainname = strdup (domainname);
+      if (new_binding->domainname == NULL)
+	return NULL;
+#else
       len = strlen (domainname) + 1;
       new_binding->domainname = (char *) malloc (len);
       if (new_binding->domainname == NULL)
-	  return NULL;
+	return NULL;
       memcpy (new_binding->domainname, domainname, len);
+#endif
 
       if (strcmp (dirname, _nl_default_dirname) == 0)
 	new_binding->dirname = (char *) _nl_default_dirname;
       else
 	{
+#if defined _LIBC || defined HAVE_STRDUP
+	  new_binding->dirname = strdup (dirname);
+	  if (new_binding->dirname == NULL)
+	    return NULL;
+#else
 	  len = strlen (dirname) + 1;
 	  new_binding->dirname = (char *) malloc (len);
 	  if (new_binding->dirname == NULL)
 	    return NULL;
 	  memcpy (new_binding->dirname, dirname, len);
+#endif
 	}
 
       /* Now enqueue it.  */
diff -urN gnupg-0.2.8/intl/cat-compat.c gnupg-0.2.9/intl/cat-compat.c
--- gnupg-0.2.8/intl/cat-compat.c	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/cat-compat.c	Thu Feb 26 16:27:25 1998
@@ -1,20 +1,19 @@
 /* Compatibility code for gettext-using-catgets interface.
-   Copyright (C) 1995 Free Software Foundation, Inc.
+   Copyright (C) 1995, 1997 Free Software Foundation, Inc.
 
-The GNU C Library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public License as
-published by the Free Software Foundation; either version 2 of the
-License, or (at your option) any later version.
-
-The GNU C Library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public
-License along with the GNU C Library; see the file COPYING.LIB.  If
-not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -40,6 +39,16 @@
 
 /* @@ end of prolog @@ */
 
+/* XPG3 defines the result of `setlocale (category, NULL)' as:
+   ``Directs `setlocale()' to query `category' and return the current
+     setting of `local'.''
+   However it does not specify the exact format.  And even worse: POSIX
+   defines this not at all.  So we can use this feature only on selected
+   system (e.g. those using GNU C Library).  */
+#ifdef _LIBC
+# define HAVE_LOCALE_NULL
+#endif
+
 /* The catalog descriptor.  */
 static nl_catd catalog = (nl_catd) -1;
 
@@ -50,11 +59,11 @@
 static const char *catalog_name = default_catalog_name;
 
 /* Get ID for given string.  If not found return -1.  */
-static int msg_to_cat_id __P ((const char *msg));
+static int msg_to_cat_id PARAMS ((const char *msg));
 
 /* Substitution for systems lacking this function in their C library.  */
 #if !_LIBC && !HAVE_STPCPY
-static char *stpcpy __P ((char *dest, const char *src));
+static char *stpcpy PARAMS ((char *dest, const char *src));
 #endif
 
 
@@ -68,7 +77,8 @@
   size_t new_name_len;
   char *lang;
 
-#if HAVE_SETLOCALE && HAVE_LC_MESSAGES && HAVE_SETLOCALE_NULL
+#if defined HAVE_SETLOCALE && defined HAVE_LC_MESSAGES \
+    && defined HAVE_LOCALE_NULL
   lang = setlocale (LC_MESSAGES, NULL);
 #else
   lang = getenv ("LC_ALL");
diff -urN gnupg-0.2.8/intl/dcgettext.c gnupg-0.2.9/intl/dcgettext.c
--- gnupg-0.2.8/intl/dcgettext.c	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/dcgettext.c	Thu Feb 26 16:27:25 1998
@@ -1,19 +1,19 @@
-/* dcgettext.c -- implemenatation of the dcgettext(3) function
-   Copyright (C) 1995 Free Software Foundation, Inc.
+/* Implementation of the dcgettext(3) function
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -23,6 +23,7 @@
 
 #ifdef __GNUC__
 # define alloca __builtin_alloca
+# define HAVE_ALLOCA 1
 #else
 # if defined HAVE_ALLOCA_H || defined _LIBC
 #  include <alloca.h>
@@ -41,6 +42,9 @@
 #ifndef errno
 extern int errno;
 #endif
+#ifndef __set_errno
+# define __set_errno(val) errno = (val)
+#endif
 
 #if defined STDC_HEADERS || defined _LIBC
 # include <stdlib.h>
@@ -54,6 +58,9 @@
 #endif
 
 #if defined HAVE_STRING_H || defined _LIBC
+# ifndef _GNU_SOURCE
+#  define _GNU_SOURCE	1
+# endif
 # include <string.h>
 #else
 # include <strings.h>
@@ -85,13 +92,16 @@
    file and the name space must not be polluted.  */
 # define getcwd __getcwd
 # define stpcpy __stpcpy
-#endif
-
-#if !defined HAVE_GETCWD && !defined _LIBC
-char *getwd ();
-# define getcwd(buf, max) getwd (buf)
 #else
+# if !defined HAVE_GETCWD
+char *getwd ();
+#  define getcwd(buf, max) getwd (buf)
+# else
 char *getcwd ();
+# endif
+# ifndef HAVE_STPCPY
+static char *stpcpy PARAMS ((char *dest, const char *src));
+# endif
 #endif
 
 /* Amount to increase buffer size by in each try.  */
@@ -151,10 +161,47 @@
 struct binding *_nl_domain_bindings;
 
 /* Prototypes for local functions.  */
-static char *find_msg __P ((struct loaded_domain *domain, const char *msgid));
-static const char *category_to_name __P((int category));
-static const char *guess_category_value __P((int category,
-					     const char *categoryname));
+static char *find_msg PARAMS ((struct loaded_l10nfile *domain_file,
+			       const char *msgid));
+static const char *category_to_name PARAMS ((int category));
+static const char *guess_category_value PARAMS ((int category,
+						 const char *categoryname));
+
+
+/* For those loosing systems which don't have `alloca' we have to add
+   some additional code emulating it.  */
+#ifdef HAVE_ALLOCA
+/* Nothing has to be done.  */
+# define ADD_BLOCK(list, address) /* nothing */
+# define FREE_BLOCKS(list) /* nothing */
+#else
+struct block_list
+{
+  void *address;
+  struct block_list *next;
+};
+# define ADD_BLOCK(list, addr)						      \
+  do {									      \
+    struct block_list *newp = (struct block_list *) malloc (sizeof (*newp));  \
+    /* If we cannot get a free block we cannot add the new element to	      \
+       the list.  */							      \
+    if (newp != NULL) {							      \
+      newp->address = (addr);						      \
+      newp->next = (list);						      \
+      (list) = newp;							      \
+    }									      \
+  } while (0)
+# define FREE_BLOCKS(list)						      \
+  do {									      \
+    while (list != NULL) {						      \
+      struct block_list *old = list;					      \
+      list = list->next;						      \
+      free (old);							      \
+    }									      \
+  } while (0)
+# undef alloca
+# define alloca(size) (malloc (size))
+#endif	/* have alloca */
 
 
 /* Names for the libintl functions are a problem.  They must not clash
@@ -175,13 +222,17 @@
      const char *msgid;
      int category;
 {
-  struct loaded_domain *domain;
+#ifndef HAVE_ALLOCA
+  struct block_list *block_list = NULL;
+#endif
+  struct loaded_l10nfile *domain;
   struct binding *binding;
   const char *categoryname;
   const char *categoryvalue;
   char *dirname, *xdomainname;
   char *single_locale;
   char *retval;
+  int saved_errno = errno;
 
   /* If no real MSGID is given return NULL.  */
   if (msgid == NULL)
@@ -223,30 +274,27 @@
       path_max += 2;		/* The getcwd docs say to do this.  */
 
       dirname = (char *) alloca (path_max + dirname_len);
+      ADD_BLOCK (block_list, dirname);
 
-      errno = 0;
+      __set_errno (0);
       while ((ret = getcwd (dirname, path_max)) == NULL && errno == ERANGE)
 	{
 	  path_max += PATH_INCR;
 	  dirname = (char *) alloca (path_max + dirname_len);
-	  errno = 0;
+	  ADD_BLOCK (block_list, dirname);
+	  __set_errno (0);
 	}
 
       if (ret == NULL)
-	/* We cannot get the current working directory.  Don't signal an
-	   error but simply return the default string.  */
-	return (char *) msgid;
-
-      /* We don't want libintl.a to depend on any other library.  So
-	 we avoid the non-standard function stpcpy.  In GNU C Library
-	 this function is available, though.  Also allow the symbol
-	 HAVE_STPCPY to be defined.  */
-#if defined _LIBC || defined HAVE_STPCPY
+	{
+	  /* We cannot get the current working directory.  Don't signal an
+	     error but simply return the default string.  */
+	  FREE_BLOCKS (block_list);
+	  __set_errno (saved_errno);
+	  return (char *) msgid;
+	}
+
       stpcpy (stpcpy (strchr (dirname, '\0'), "/"), binding->dirname);
-#else
-      strcat (dirname, "/");
-      strcat (dirname, binding->dirname);
-#endif
     }
 
   /* Now determine the symbolic name of CATEGORY and its value.  */
@@ -255,23 +303,15 @@
 
   xdomainname = (char *) alloca (strlen (categoryname)
 				 + strlen (domainname) + 5);
-  /* We don't want libintl.a to depend on any other library.  So we
-     avoid the non-standard function stpcpy.  In GNU C Library this
-     function is available, though.  Also allow the symbol HAVE_STPCPY
-     to be defined.  */
-#if defined _LIBC || defined HAVE_STPCPY
+  ADD_BLOCK (block_list, xdomainname);
+
   stpcpy (stpcpy (stpcpy (stpcpy (xdomainname, categoryname), "/"),
 		  domainname),
 	  ".mo");
-#else
-  strcpy (xdomainname, categoryname);
-  strcat (xdomainname, "/");
-  strcat (xdomainname, domainname);
-  strcat (xdomainname, ".mo");
-#endif
 
   /* Creating working area.  */
   single_locale = (char *) alloca (strlen (categoryvalue) + 1);
+  ADD_BLOCK (block_list, single_locale);
 
 
   /* Search for the given string.  This is a loop because we perhaps
@@ -285,7 +325,7 @@
 	{
 	  /* The whole contents of CATEGORYVALUE has been searched but
 	     no valid entry has been found.  We solve this situation
-	     by implicitely appending a "C" entry, i.e. no translation
+	     by implicitly appending a "C" entry, i.e. no translation
 	     will take place.  */
 	  single_locale[0] = 'C';
 	  single_locale[1] = '\0';
@@ -302,7 +342,11 @@
 	 domain.  Return the MSGID.  */
       if (strcmp (single_locale, "C") == 0
 	  || strcmp (single_locale, "POSIX") == 0)
-	return (char *) msgid;
+	{
+	  FREE_BLOCKS (block_list);
+	  __set_errno (saved_errno);
+	  return (char *) msgid;
+	}
 
 
       /* Find structure describing the message catalog matching the
@@ -327,7 +371,11 @@
 	    }
 
 	  if (retval != NULL)
-	    return retval;
+	    {
+	      FREE_BLOCKS (block_list);
+	      __set_errno (saved_errno);
+	      return retval;
+	    }
 	}
     }
   /* NOTREACHED */
@@ -340,18 +388,21 @@
 
 
 static char *
-find_msg (domain, msgid)
-     struct loaded_domain *domain;
+find_msg (domain_file, msgid)
+     struct loaded_l10nfile *domain_file;
      const char *msgid;
 {
   size_t top, act, bottom;
+  struct loaded_domain *domain;
 
-  if (domain->decided == 0)
-    _nl_load_domain (domain);
+  if (domain_file->decided == 0)
+    _nl_load_domain (domain_file);
 
-  if (domain->data == NULL)
+  if (domain_file->data == NULL)
     return NULL;
 
+  domain = (struct loaded_domain *) domain_file->data;
+
   /* Locate the MSGID and its translation.  */
   if (domain->hash_size > 2 && domain->hash_tab != NULL)
     {
@@ -375,8 +426,8 @@
 
       while (1)
 	{
-	  if (idx >= W (domain->must_swap, domain->hash_size) - incr)
-	    idx -= W (domain->must_swap, domain->hash_size) - incr;
+	  if (idx >= domain->hash_size - incr)
+	    idx -= domain->hash_size - incr;
 	  else
 	    idx += incr;
 
@@ -424,7 +475,8 @@
 
 
 /* Return string representation of locale CATEGORY.  */
-static const char *category_to_name (category)
+static const char *
+category_to_name (category)
      int category;
 {
   const char *retval;
@@ -482,7 +534,8 @@
 }
 
 /* Guess value of current locale from value of the environment variables.  */
-static const char *guess_category_value (category, categoryname)
+static const char *
+guess_category_value (category, categoryname)
      int category;
      const char *categoryname;
 {
@@ -520,3 +573,21 @@
   return "C";
 #endif
 }
+
+/* @@ begin of epilog @@ */
+
+/* We don't want libintl.a to depend on any other library.  So we
+   avoid the non-standard function stpcpy.  In GNU C Library this
+   function is available, though.  Also allow the symbol HAVE_STPCPY
+   to be defined.  */
+#if !_LIBC && !HAVE_STPCPY
+static char *
+stpcpy (dest, src)
+     char *dest;
+     const char *src;
+{
+  while ((*dest++ = *src++) != '\0')
+    /* Do nothing. */ ;
+  return dest - 1;
+}
+#endif
diff -urN gnupg-0.2.8/intl/explodename.c gnupg-0.2.9/intl/explodename.c
--- gnupg-0.2.8/intl/explodename.c	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/intl/explodename.c	Thu Feb 26 16:27:25 1998
@@ -0,0 +1,181 @@
+/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
+   Contributed by Ulrich Drepper <drepper@gnu.ai.mit.edu>, 1995.
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#include <stdlib.h>
+#include <string.h>
+#include <sys/types.h>
+
+#include "loadinfo.h"
+
+/* On some strange systems still no definition of NULL is found.  Sigh!  */
+#ifndef NULL
+# if defined __STDC__ && __STDC__
+#  define NULL ((void *) 0)
+# else
+#  define NULL 0
+# endif
+#endif
+
+/* @@ end of prolog @@ */
+
+int
+_nl_explode_name (name, language, modifier, territory, codeset,
+		  normalized_codeset, special, sponsor, revision)
+     char *name;
+     const char **language;
+     const char **modifier;
+     const char **territory;
+     const char **codeset;
+     const char **normalized_codeset;
+     const char **special;
+     const char **sponsor;
+     const char **revision;
+{
+  enum { undecided, xpg, cen } syntax;
+  char *cp;
+  int mask;
+
+  *modifier = NULL;
+  *territory = NULL;
+  *codeset = NULL;
+  *normalized_codeset = NULL;
+  *special = NULL;
+  *sponsor = NULL;
+  *revision = NULL;
+
+  /* Now we determine the single parts of the locale name.  First
+     look for the language.  Termination symbols are `_' and `@' if
+     we use XPG4 style, and `_', `+', and `,' if we use CEN syntax.  */
+  mask = 0;
+  syntax = undecided;
+  *language = cp = name;
+  while (cp[0] != '\0' && cp[0] != '_' && cp[0] != '@'
+	 && cp[0] != '+' && cp[0] != ',')
+    ++cp;
+
+  if (*language == cp)
+    /* This does not make sense: language has to be specified.  Use
+       this entry as it is without exploding.  Perhaps it is an alias.  */
+    cp = strchr (*language, '\0');
+  else if (cp[0] == '_')
+    {
+      /* Next is the territory.  */
+      cp[0] = '\0';
+      *territory = ++cp;
+
+      while (cp[0] != '\0' && cp[0] != '.' && cp[0] != '@'
+	     && cp[0] != '+' && cp[0] != ',' && cp[0] != '_')
+	++cp;
+
+      mask |= TERRITORY;
+
+      if (cp[0] == '.')
+	{
+	  /* Next is the codeset.  */
+	  syntax = xpg;
+	  cp[0] = '\0';
+	  *codeset = ++cp;
+
+	  while (cp[0] != '\0' && cp[0] != '@')
+	    ++cp;
+
+	  mask |= XPG_CODESET;
+
+	  if (*codeset != cp && (*codeset)[0] != '\0')
+	    {
+	      *normalized_codeset = _nl_normalize_codeset (*codeset,
+							   cp - *codeset);
+	      if (strcmp (*codeset, *normalized_codeset) == 0)
+		free ((char *) *normalized_codeset);
+	      else
+		mask |= XPG_NORM_CODESET;
+	    }
+	}
+    }
+
+  if (cp[0] == '@' || (syntax != xpg && cp[0] == '+'))
+    {
+      /* Next is the modifier.  */
+      syntax = cp[0] == '@' ? xpg : cen;
+      cp[0] = '\0';
+      *modifier = ++cp;
+
+      while (syntax == cen && cp[0] != '\0' && cp[0] != '+'
+	     && cp[0] != ',' && cp[0] != '_')
+	++cp;
+
+      mask |= XPG_MODIFIER | CEN_AUDIENCE;
+    }
+
+  if (syntax != xpg && (cp[0] == '+' || cp[0] == ',' || cp[0] == '_'))
+    {
+      syntax = cen;
+
+      if (cp[0] == '+')
+	{
+ 	  /* Next is special application (CEN syntax).  */
+	  cp[0] = '\0';
+	  *special = ++cp;
+
+	  while (cp[0] != '\0' && cp[0] != ',' && cp[0] != '_')
+	    ++cp;
+
+	  mask |= CEN_SPECIAL;
+	}
+
+      if (cp[0] == ',')
+	{
+ 	  /* Next is sponsor (CEN syntax).  */
+	  cp[0] = '\0';
+	  *sponsor = ++cp;
+
+	  while (cp[0] != '\0' && cp[0] != '_')
+	    ++cp;
+
+	  mask |= CEN_SPONSOR;
+	}
+
+      if (cp[0] == '_')
+	{
+ 	  /* Next is revision (CEN syntax).  */
+	  cp[0] = '\0';
+	  *revision = ++cp;
+
+	  mask |= CEN_REVISION;
+	}
+    }
+
+  /* For CEN syntax values it might be important to have the
+     separator character in the file name, not for XPG syntax.  */
+  if (syntax == xpg)
+    {
+      if (*territory != NULL && (*territory)[0] == '\0')
+	mask &= ~TERRITORY;
+
+      if (*codeset != NULL && (*codeset)[0] == '\0')
+	mask &= ~XPG_CODESET;
+
+      if (*modifier != NULL && (*modifier)[0] == '\0')
+	mask &= ~XPG_MODIFIER;
+    }
+
+  return mask;
+}
diff -urN gnupg-0.2.8/intl/finddomain.c gnupg-0.2.9/intl/finddomain.c
--- gnupg-0.2.8/intl/finddomain.c	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/finddomain.c	Thu Feb 26 16:27:25 1998
@@ -1,25 +1,26 @@
-/* finddomain.c -- handle list of needed message catalogs
-   Copyright (C) 1995 Software Foundation, Inc.
+/* Handle list of needed message catalogs
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
    Written by Ulrich Drepper <drepper@gnu.ai.mit.edu>, 1995.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
+#include <ctype.h>
 #include <errno.h>
 #include <stdio.h>
 #include <sys/types.h>
@@ -38,6 +39,9 @@
 # include <string.h>
 #else
 # include <strings.h>
+# ifndef memcpy
+#  define memcpy(Dst, Src, Num) bcopy (Src, Dst, Num)
+# endif
 #endif
 #if !HAVE_STRCHR && !defined _LIBC
 # ifndef strchr
@@ -58,80 +62,38 @@
 #endif
 
 /* @@ end of prolog @@ */
-
-#ifdef _LIBC
-/* Rename the non ANSI C functions.  This is required by the standard
-   because some ANSI C functions will require linking with this object
-   file and the name space must not be polluted.  */
-# define stpcpy __stpcpy
-#endif
-
-/* Encoding of locale name parts.  */
-#define CEN_REVISION	1
-#define CEN_SPONSOR	2
-#define CEN_SPECIAL	4
-#define XPG_CODESET	8
-#define TERRITORY	16
-#define CEN_AUDIENCE	32
-#define XPG_MODIFIER	64
-
-#define CEN_SPECIFIC	(CEN_REVISION|CEN_SPONSOR|CEN_SPECIAL|CEN_AUDIENCE)
-#define XPG_SPECIFIC	(XPG_CODESET|XPG_MODIFIER)
-
-
 /* List of already loaded domains.  */
-static struct loaded_domain *_nl_loaded_domains;
-
-/* Prototypes for local functions.  */
-static struct loaded_domain *make_entry_rec __P ((const char *dirname,
-						  int mask,
-						  const char *language,
-						  const char *territory,
-						  const char *codeset,
-						  const char *modifier,
-						  const char *special,
-						  const char *sponsor,
-						  const char *revision,
-						  const char *domainname,
-						  int do_allocate));
-
-/* Substitution for systems lacking this function in their C library.  */
-#if !_LIBC && !HAVE_STPCPY
-static char *stpcpy __P ((char *dest, const char *src));
-#endif
+static struct loaded_l10nfile *_nl_loaded_domains;
 
 
 /* Return a data structure describing the message catalog described by
    the DOMAINNAME and CATEGORY parameters with respect to the currently
    established bindings.  */
-struct loaded_domain *
+struct loaded_l10nfile *
 _nl_find_domain (dirname, locale, domainname)
      const char *dirname;
      char *locale;
      const char *domainname;
 {
-  enum { undecided, xpg, cen } syntax;
-  struct loaded_domain *retval;
+  struct loaded_l10nfile *retval;
   const char *language;
-  const char *modifier = NULL;
-  const char *territory = NULL;
-  const char *codeset = NULL;
-  const char *special = NULL;
-  const char *sponsor = NULL;
-  const char *revision = NULL;
-  const char *alias_value = NULL;
-  char *cp;
+  const char *modifier;
+  const char *territory;
+  const char *codeset;
+  const char *normalized_codeset;
+  const char *special;
+  const char *sponsor;
+  const char *revision;
+  const char *alias_value;
   int mask;
 
-  /* CATEGORYVALUE now possibly contains a colon separated list of
-     locales.  Each single locale can consist of up to four recognized
-     parts for the XPG syntax:
+  /* LOCALE can consist of up to four recognized parts for the XPG syntax:
 
 		language[_territory[.codeset]][@modifier]
 
      and six parts for the CEN syntax:
 
-	language[_territory][+audience][+special][,sponsor][_revision]
+	language[_territory][+audience][+special][,[sponsor][_revision]]
 
      Beside the first all of them are allowed to be missing.  If the
      full specified locale is not found, the less specific one are
@@ -141,21 +103,23 @@
 		(2) sponsor
 		(3) special
 		(4) codeset
-		(5) territory
-		(6) audience/modifier
+		(5) normalized codeset
+		(6) territory
+		(7) audience/modifier
    */
 
   /* If we have already tested for this locale entry there has to
      be one data set in the list of loaded domains.  */
-  retval = make_entry_rec (dirname, 0, locale, NULL, NULL, NULL,
-			   NULL, NULL, NULL, domainname, 0);
+  retval = _nl_make_l10nflist (&_nl_loaded_domains, dirname,
+			       strlen (dirname) + 1, 0, locale, NULL, NULL,
+			       NULL, NULL, NULL, NULL, NULL, domainname, 0);
   if (retval != NULL)
     {
       /* We know something about this locale.  */
       int cnt;
 
       if (retval->decided == 0)
-	_nl_load_domain (retval); /* @@@ */
+	_nl_load_domain (retval);
 
       if (retval->data != NULL)
 	return retval;
@@ -168,8 +132,6 @@
 	  if (retval->successor[cnt]->data != NULL)
 	    break;
 	}
-
-      /* We really found some usable information.  */
       return cnt >= 0 ? retval : NULL;
       /* NOTREACHED */
     }
@@ -191,114 +153,16 @@
   /* Now we determine the single parts of the locale name.  First
      look for the language.  Termination symbols are `_' and `@' if
      we use XPG4 style, and `_', `+', and `,' if we use CEN syntax.  */
-  mask = 0;
-  syntax = undecided;
-  language = cp = locale;
-  while (cp[0] != '\0' && cp[0] != '_' && cp[0] != '@'
-	 && cp[0] != '+' && cp[0] != ',')
-    ++cp;
-
-  if (language == cp)
-    /* This does not make sense: language has to be specified.  Use
-       this entry as it is without exploding.  Perhaps it is an alias.  */
-    cp = strchr (language, '\0');
-  else if (cp[0] == '_')
-    {
-      /* Next is the territory.  */
-      cp[0] = '\0';
-      territory = ++cp;
-
-      while (cp[0] != '\0' && cp[0] != '.' && cp[0] != '@'
-	     && cp[0] != '+' && cp[0] != ',' && cp[0] != '_')
-	++cp;
-
-      mask |= TERRITORY;
-
-      if (cp[0] == '.')
-	{
-	  /* Next is the codeset.  */
-	  syntax = xpg;
-	  cp[0] = '\0';
-	  codeset = ++cp;
-
-	  while (cp[0] != '\0' && cp[0] != '@')
-	    ++cp;
-
-	  mask |= XPG_CODESET;
-	}
-    }
-
-  if (cp[0] == '@' || (syntax != xpg && cp[0] == '+'))
-    {
-      /* Next is the modifier.  */
-      syntax = cp[0] == '@' ? xpg : cen;
-      cp[0] = '\0';
-      modifier = ++cp;
-
-      while (syntax == cen && cp[0] != '\0' && cp[0] != '+'
-	     && cp[0] != ',' && cp[0] != '_')
-	++cp;
-
-      mask |= XPG_MODIFIER | CEN_AUDIENCE;
-    }
-
-  if (syntax != xpg && (cp[0] == '+' || cp[0] == ',' || cp[0] == '_'))
-    {
-      syntax = cen;
-
-      if (cp[0] == '+')
-	{
- 	  /* Next is special application (CEN syntax).  */
-	  cp[0] = '\0';
-	  special = ++cp;
-
-	  while (cp[0] != '\0' && cp[0] != ',' && cp[0] != '_')
-	    ++cp;
-
-	  mask |= CEN_SPECIAL;
-	}
-
-      if (cp[0] == ',')
-	{
- 	  /* Next is sponsor (CEN syntax).  */
-	  cp[0] = '\0';
-	  sponsor = ++cp;
-
-	  while (cp[0] != '\0' && cp[0] != '_')
-	    ++cp;
-
-	  mask |= CEN_SPONSOR;
-	}
-
-      if (cp[0] == '_')
-	{
- 	  /* Next is revision (CEN syntax).  */
-	  cp[0] = '\0';
-	  revision = ++cp;
-
-	  mask |= CEN_REVISION;
-	}
-    }
-
-  /* For CEN sytnax values it might be important to have the
-     separator character in the file name, not for XPG syntax.  */
-  if (syntax == xpg)
-    {
-      if (territory != NULL && territory[0] == '\0')
-	mask &= ~TERRITORY;
-
-      if (codeset != NULL && codeset[0] == '\0')
-	mask &= ~XPG_CODESET;
-
-      if (modifier != NULL && modifier[0] == '\0')
-	mask &= ~XPG_MODIFIER;
-    }
+  mask = _nl_explode_name (locale, &language, &modifier, &territory,
+			   &codeset, &normalized_codeset, &special,
+			   &sponsor, &revision);
 
   /* Create all possible locale entries which might be interested in
-     generalzation.  */
-  retval = make_entry_rec (dirname, mask, language, territory, codeset,
-			   modifier, special, sponsor, revision,
-			   domainname, 1);
+     generalization.  */
+  retval = _nl_make_l10nflist (&_nl_loaded_domains, dirname,
+			       strlen (dirname) + 1, mask, language, territory,
+			       codeset, normalized_codeset, modifier, special,
+			       sponsor, revision, domainname, 1);
   if (retval == NULL)
     /* This means we are out of core.  */
     return NULL;
@@ -314,12 +178,7 @@
 	    _nl_load_domain (retval->successor[cnt]);
 	  if (retval->successor[cnt]->data != NULL)
 	    break;
-
-	  /* Signal that locale is not available.  */
-	  retval->successor[cnt] = NULL;
 	}
-      if (retval->successor[cnt] == NULL)
-	retval = NULL;
     }
 
   /* The room for an alias was dynamically allocated.  Free it now.  */
@@ -328,176 +187,3 @@
 
   return retval;
 }
-
-
-static struct loaded_domain *
-make_entry_rec (dirname, mask, language, territory, codeset, modifier,
-		special, sponsor, revision, domain, do_allocate)
-     const char *dirname;
-     int mask;
-     const char *language;
-     const char *territory;
-     const char *codeset;
-     const char *modifier;
-     const char *special;
-     const char *sponsor;
-     const char *revision;
-     const char *domain;
-     int do_allocate;
-{
-  char *filename = NULL;
-  struct loaded_domain *last = NULL;
-  struct loaded_domain *retval;
-  char *cp;
-  size_t entries;
-  int cnt;
-
-
-  /* Process the current entry described by the MASK only when it is
-     valid.  Because the mask can have in the first call bits from
-     both syntaces set this is necessary to prevent constructing
-     illegal local names.  */
-  /* FIXME: Rewrite because test is necessary only in first round.  */
-  if ((mask & CEN_SPECIFIC) == 0 || (mask & XPG_SPECIFIC) == 0)
-    {
-      /* Allocate room for the full file name.  */
-      filename = (char *) malloc (strlen (dirname) + 1
-				  + strlen (language)
-				  + ((mask & TERRITORY) != 0
-				     ? strlen (territory) : 0)
-				  + ((mask & XPG_CODESET) != 0
-				     ? strlen (codeset) : 0)
-				  + ((mask & XPG_MODIFIER) != 0 ?
-				     strlen (modifier) : 0)
-				  + ((mask & CEN_SPECIAL) != 0
-				     ? strlen (special) : 0)
-				  + ((mask & CEN_SPONSOR) != 0
-				     ? strlen (sponsor) : 0)
-				  + ((mask & CEN_REVISION) != 0
-				     ? strlen (revision) : 0) + 1
-				  + strlen (domain) + 1);
-
-      if (filename == NULL)
-	return NULL;
-
-      retval = NULL;
-      last = NULL;
-
-      /* Construct file name.  */
-      cp = stpcpy (filename, dirname);
-      *cp++ = '/';
-      cp = stpcpy (cp, language);
-
-      if ((mask & TERRITORY) != 0)
-	{
-	  *cp++ = '_';
-	  cp = stpcpy (cp, territory);
-	}
-      if ((mask & XPG_CODESET) != 0)
-	{
-	  *cp++ = '.';
-      cp = stpcpy (cp, codeset);
-	}
-      if ((mask & (XPG_MODIFIER | CEN_AUDIENCE)) != 0)
-	{
-	  /* This component can be part of both syntaces but has different
-	     leading characters.  For CEN we use `+', else `@'.  */
-	  *cp++ = (mask & CEN_AUDIENCE) != 0 ? '+' : '@';
-	  cp = stpcpy (cp, modifier);
-	}
-      if ((mask & CEN_SPECIAL) != 0)
-	{
-	  *cp++ = '+';
-	  cp = stpcpy (cp, special);
-	}
-      if ((mask & CEN_SPONSOR) != 0)
-	{
-	  *cp++ = ',';
-	  cp = stpcpy (cp, sponsor);
-	}
-      if ((mask & CEN_REVISION) != 0)
-	{
-	  *cp++ = '_';
-	  cp = stpcpy (cp, revision);
-	}
-
-      *cp++ = '/';
-      stpcpy (cp, domain);
-
-      /* Look in list of already loaded domains whether it is already
-	 available.  */
-      last = NULL;
-      for (retval = _nl_loaded_domains; retval != NULL; retval = retval->next)
-	if (retval->filename != NULL)
-	  {
-	    int compare = strcmp (retval->filename, filename);
-	    if (compare == 0)
-	      /* We found it!  */
-	      break;
-	    if (compare < 0)
-	      {
-		/* It's not in the list.  */
-		retval = NULL;
-		break;
-	      }
-
-	    last = retval;
-	  }
-
-      if (retval != NULL || do_allocate == 0)
-	{
-	  free (filename);
-	  return retval;
-	}
-    }
-
-  retval = (struct loaded_domain *) malloc (sizeof (*retval));
-  if (retval == NULL)
-    return NULL;
-
-  retval->filename = filename;
-  retval->decided = 0;
-
-  if (last == NULL)
-    {
-      retval->next = _nl_loaded_domains;
-      _nl_loaded_domains = retval;
-    }
-  else
-    {
-      retval->next = last->next;
-      last->next = retval;
-    }
-
-  entries = 0;
-  for (cnt = 126; cnt >= 0; --cnt)
-    if (cnt < mask && (cnt & ~mask) == 0
-	&& ((cnt & CEN_SPECIFIC) == 0 || (cnt & XPG_SPECIFIC) == 0))
-      retval->successor[entries++] = make_entry_rec (dirname, cnt,
-						     language, territory,
-						     codeset, modifier,
-						     special, sponsor,
-						     revision, domain, 1);
-  retval->successor[entries] = NULL;
-
-  return retval;
-}
-
-
-/* @@ begin of epilog @@ */
-
-/* We don't want libintl.a to depend on any other library.  So we
-   avoid the non-standard function stpcpy.  In GNU C Library this
-   function is available, though.  Also allow the symbol HAVE_STPCPY
-   to be defined.  */
-#if !_LIBC && !HAVE_STPCPY
-static char *
-stpcpy (dest, src)
-     char *dest;
-     const char *src;
-{
-  while ((*dest++ = *src++) != '\0')
-    /* Do nothing. */ ;
-  return dest - 1;
-}
-#endif
diff -urN gnupg-0.2.8/intl/gettext.c gnupg-0.2.9/intl/gettext.c
--- gnupg-0.2.8/intl/gettext.c	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/gettext.c	Thu Feb 26 16:27:25 1998
@@ -1,19 +1,19 @@
-/* gettext.c -- implementation of gettext(3) function
-   Copyright (C) 1995 Software Foundation, Inc.
+/* Implementation of gettext(3) function
+   Copyright (C) 1995, 1997 Free Software Foundation, Inc.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
diff -urN gnupg-0.2.8/intl/gettext.h gnupg-0.2.9/intl/gettext.h
--- gnupg-0.2.8/intl/gettext.h	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/gettext.h	Thu Feb 26 16:27:25 1998
@@ -1,20 +1,20 @@
-/* gettext.h - internal header for GNU gettext internationalization functions
-   Copyright (C) 1995 Software Foundation, Inc.
+/* Internal header for GNU gettext internationalization functions
+   Copyright (C) 1995, 1997 Free Software Foundation, Inc.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-You should have received a copy of the GNU Library General Public
-License along with the GNU C Library; see the file COPYING.LIB.  If
-not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU Library General Public
+   License along with the GNU C Library; see the file COPYING.LIB.  If not,
+   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 #ifndef _GETTEXT_H
 #define _GETTEXT_H 1
diff -urN gnupg-0.2.8/intl/gettextP.h gnupg-0.2.9/intl/gettextP.h
--- gnupg-0.2.8/intl/gettextP.h	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/gettextP.h	Thu Feb 26 16:27:25 1998
@@ -1,30 +1,32 @@
-/* gettextP.h -- header describing internals of gettext library
-   Copyright (C) 1995 Free Software Foundation, Inc.
+/* Header describing internals of gettext library
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifndef _GETTEXTP_H
 #define _GETTEXTP_H
 
+#include "loadinfo.h"
+
 /* @@ end of prolog @@ */
 
-#ifndef __P
+#ifndef PARAMS
 # if __STDC__
-#  define __P(args) args
+#  define PARAMS(args) args
 # else
-#  define __P(args) ()
+#  define PARAMS(args) ()
 # endif
 #endif
 
@@ -33,7 +35,7 @@
 #endif
 
 
-static nls_uint32 SWAP __P ((nls_uint32 i));
+static nls_uint32 SWAP PARAMS ((nls_uint32 i));
 
 static inline nls_uint32
 SWAP (i)
@@ -45,12 +47,6 @@
 
 struct loaded_domain
 {
-  struct loaded_domain *next;
-  struct loaded_domain *successor[31];
-
-  const char *filename;
-  int decided;
-
   const char *data;
   int must_swap;
   nls_uint32 nstrings;
@@ -67,12 +63,10 @@
   char *dirname;
 };
 
-struct loaded_domain *_nl_find_domain __P ((const char *__dirname,
-					    char *__locale,
-					    const char *__domainname));
-void _nl_load_domain __P ((struct loaded_domain *__domain));
-
-const char *_nl_expand_alias __P ((const char *__name));
+struct loaded_l10nfile *_nl_find_domain PARAMS ((const char *__dirname,
+						 char *__locale,
+						 const char *__domainname));
+void _nl_load_domain PARAMS ((struct loaded_l10nfile *__domain));
 
 /* @@ begin of epilog @@ */
 
diff -urN gnupg-0.2.8/intl/hash-string.h gnupg-0.2.9/intl/hash-string.h
--- gnupg-0.2.8/intl/hash-string.h	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/hash-string.h	Thu Feb 26 16:27:25 1998
@@ -1,19 +1,20 @@
-/* hash-string - Implements a string hashing function.
-   Copyright (C) 1995 Free Software Foundation, Inc.
+/* Implements a string hashing function.
+   Copyright (C) 1995, 1997 Free Software Foundation, Inc.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public
+   License along with the GNU C Library; see the file COPYING.LIB.  If not,
+   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_VALUES_H
 # include <values.h>
@@ -21,11 +22,11 @@
 
 /* @@ end of prolog @@ */
 
-#ifndef __P
+#ifndef PARAMS
 # if __STDC__
-#  define __P(Args) Args
+#  define PARAMS(Args) Args
 # else
-#  define __P(Args) ()
+#  define PARAMS(Args) ()
 # endif
 #endif
 
@@ -36,7 +37,7 @@
 /* Defines the so called `hashpjw' function by P.J. Weinberger
    [see Aho/Sethi/Ullman, COMPILERS: Principles, Techniques and Tools,
    1986, 1987 Bell Telephone Laboratories, Inc.]  */
-static unsigned long hash_string __P ((const char *__str_param));
+static unsigned long hash_string PARAMS ((const char *__str_param));
 
 static inline unsigned long
 hash_string (str_param)
diff -urN gnupg-0.2.8/intl/l10nflist.c gnupg-0.2.9/intl/l10nflist.c
--- gnupg-0.2.8/intl/l10nflist.c	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/intl/l10nflist.c	Thu Feb 26 16:27:25 1998
@@ -0,0 +1,409 @@
+/* Handle list of needed message catalogs
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
+   Written by Ulrich Drepper <drepper@gnu.ai.mit.edu>, 1995.
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+
+#if defined HAVE_STRING_H || defined _LIBC
+# ifndef _GNU_SOURCE
+#  define _GNU_SOURCE	1
+# endif
+# include <string.h>
+#else
+# include <strings.h>
+# ifndef memcpy
+#  define memcpy(Dst, Src, Num) bcopy (Src, Dst, Num)
+# endif
+#endif
+#if !HAVE_STRCHR && !defined _LIBC
+# ifndef strchr
+#  define strchr index
+# endif
+#endif
+
+#if defined _LIBC || defined HAVE_ARGZ_H
+# include <argz.h>
+#endif
+#include <ctype.h>
+#include <sys/types.h>
+
+#if defined STDC_HEADERS || defined _LIBC
+# include <stdlib.h>
+#endif
+
+#include "loadinfo.h"
+
+/* On some strange systems still no definition of NULL is found.  Sigh!  */
+#ifndef NULL
+# if defined __STDC__ && __STDC__
+#  define NULL ((void *) 0)
+# else
+#  define NULL 0
+# endif
+#endif
+
+/* @@ end of prolog @@ */
+
+#ifdef _LIBC
+/* Rename the non ANSI C functions.  This is required by the standard
+   because some ANSI C functions will require linking with this object
+   file and the name space must not be polluted.  */
+# define stpcpy(dest, src) __stpcpy(dest, src)
+#else
+# ifndef HAVE_STPCPY
+static char *stpcpy PARAMS ((char *dest, const char *src));
+# endif
+#endif
+
+/* Define function which are usually not available.  */
+
+#if !defined _LIBC && !defined HAVE___ARGZ_COUNT
+/* Returns the number of strings in ARGZ.  */
+static size_t argz_count__ PARAMS ((const char *argz, size_t len));
+
+static size_t
+argz_count__ (argz, len)
+     const char *argz;
+     size_t len;
+{
+  size_t count = 0;
+  while (len > 0)
+    {
+      size_t part_len = strlen (argz);
+      argz += part_len + 1;
+      len -= part_len + 1;
+      count++;
+    }
+  return count;
+}
+# undef __argz_count
+# define __argz_count(argz, len) argz_count__ (argz, len)
+#endif	/* !_LIBC && !HAVE___ARGZ_COUNT */
+
+#if !defined _LIBC && !defined HAVE___ARGZ_STRINGIFY
+/* Make '\0' separated arg vector ARGZ printable by converting all the '\0's
+   except the last into the character SEP.  */
+static void argz_stringify__ PARAMS ((char *argz, size_t len, int sep));
+
+static void
+argz_stringify__ (argz, len, sep)
+     char *argz;
+     size_t len;
+     int sep;
+{
+  while (len > 0)
+    {
+      size_t part_len = strlen (argz);
+      argz += part_len;
+      len -= part_len + 1;
+      if (len > 0)
+	*argz++ = sep;
+    }
+}
+# undef __argz_stringify
+# define __argz_stringify(argz, len, sep) argz_stringify__ (argz, len, sep)
+#endif	/* !_LIBC && !HAVE___ARGZ_STRINGIFY */
+
+#if !defined _LIBC && !defined HAVE___ARGZ_NEXT
+static char *argz_next__ PARAMS ((char *argz, size_t argz_len,
+				  const char *entry));
+
+static char *
+argz_next__ (argz, argz_len, entry)
+     char *argz;
+     size_t argz_len;
+     const char *entry;
+{
+  if (entry)
+    {
+      if (entry < argz + argz_len)
+        entry = strchr (entry, '\0') + 1;
+
+      return entry >= argz + argz_len ? NULL : (char *) entry;
+    }
+  else
+    if (argz_len > 0)
+      return argz;
+    else
+      return 0;
+}
+# undef __argz_next
+# define __argz_next(argz, len, entry) argz_next__ (argz, len, entry)
+#endif	/* !_LIBC && !HAVE___ARGZ_NEXT */
+
+
+/* Return number of bits set in X.  */
+static int pop PARAMS ((int x));
+
+static inline int
+pop (x)
+     int x;
+{
+  /* We assume that no more than 16 bits are used.  */
+  x = ((x & ~0x5555) >> 1) + (x & 0x5555);
+  x = ((x & ~0x3333) >> 2) + (x & 0x3333);
+  x = ((x >> 4) + x) & 0x0f0f;
+  x = ((x >> 8) + x) & 0xff;
+
+  return x;
+}
+
+
+struct loaded_l10nfile *
+_nl_make_l10nflist (l10nfile_list, dirlist, dirlist_len, mask, language,
+		    territory, codeset, normalized_codeset, modifier, special,
+		    sponsor, revision, filename, do_allocate)
+     struct loaded_l10nfile **l10nfile_list;
+     const char *dirlist;
+     size_t dirlist_len;
+     int mask;
+     const char *language;
+     const char *territory;
+     const char *codeset;
+     const char *normalized_codeset;
+     const char *modifier;
+     const char *special;
+     const char *sponsor;
+     const char *revision;
+     const char *filename;
+     int do_allocate;
+{
+  char *abs_filename;
+  struct loaded_l10nfile *last = NULL;
+  struct loaded_l10nfile *retval;
+  char *cp;
+  size_t entries;
+  int cnt;
+
+  /* Allocate room for the full file name.  */
+  abs_filename = (char *) malloc (dirlist_len
+				  + strlen (language)
+				  + ((mask & TERRITORY) != 0
+				     ? strlen (territory) + 1 : 0)
+				  + ((mask & XPG_CODESET) != 0
+				     ? strlen (codeset) + 1 : 0)
+				  + ((mask & XPG_NORM_CODESET) != 0
+				     ? strlen (normalized_codeset) + 1 : 0)
+				  + (((mask & XPG_MODIFIER) != 0
+				      || (mask & CEN_AUDIENCE) != 0)
+				     ? strlen (modifier) + 1 : 0)
+				  + ((mask & CEN_SPECIAL) != 0
+				     ? strlen (special) + 1 : 0)
+				  + (((mask & CEN_SPONSOR) != 0
+				      || (mask & CEN_REVISION) != 0)
+				     ? (1 + ((mask & CEN_SPONSOR) != 0
+					     ? strlen (sponsor) + 1 : 0)
+					+ ((mask & CEN_REVISION) != 0
+					   ? strlen (revision) + 1 : 0)) : 0)
+				  + 1 + strlen (filename) + 1);
+
+  if (abs_filename == NULL)
+    return NULL;
+
+  retval = NULL;
+  last = NULL;
+
+  /* Construct file name.  */
+  memcpy (abs_filename, dirlist, dirlist_len);
+  __argz_stringify (abs_filename, dirlist_len, ':');
+  cp = abs_filename + (dirlist_len - 1);
+  *cp++ = '/';
+  cp = stpcpy (cp, language);
+
+  if ((mask & TERRITORY) != 0)
+    {
+      *cp++ = '_';
+      cp = stpcpy (cp, territory);
+    }
+  if ((mask & XPG_CODESET) != 0)
+    {
+      *cp++ = '.';
+      cp = stpcpy (cp, codeset);
+    }
+  if ((mask & XPG_NORM_CODESET) != 0)
+    {
+      *cp++ = '.';
+      cp = stpcpy (cp, normalized_codeset);
+    }
+  if ((mask & (XPG_MODIFIER | CEN_AUDIENCE)) != 0)
+    {
+      /* This component can be part of both syntaces but has different
+	 leading characters.  For CEN we use `+', else `@'.  */
+      *cp++ = (mask & CEN_AUDIENCE) != 0 ? '+' : '@';
+      cp = stpcpy (cp, modifier);
+    }
+  if ((mask & CEN_SPECIAL) != 0)
+    {
+      *cp++ = '+';
+      cp = stpcpy (cp, special);
+    }
+  if ((mask & (CEN_SPONSOR | CEN_REVISION)) != 0)
+    {
+      *cp++ = ',';
+      if ((mask & CEN_SPONSOR) != 0)
+	cp = stpcpy (cp, sponsor);
+      if ((mask & CEN_REVISION) != 0)
+	{
+	  *cp++ = '_';
+	  cp = stpcpy (cp, revision);
+	}
+    }
+
+  *cp++ = '/';
+  stpcpy (cp, filename);
+
+  /* Look in list of already loaded domains whether it is already
+     available.  */
+  last = NULL;
+  for (retval = *l10nfile_list; retval != NULL; retval = retval->next)
+    if (retval->filename != NULL)
+      {
+	int compare = strcmp (retval->filename, abs_filename);
+	if (compare == 0)
+	  /* We found it!  */
+	  break;
+	if (compare < 0)
+	  {
+	    /* It's not in the list.  */
+	    retval = NULL;
+	    break;
+	  }
+
+	last = retval;
+      }
+
+  if (retval != NULL || do_allocate == 0)
+    {
+      free (abs_filename);
+      return retval;
+    }
+
+  retval = (struct loaded_l10nfile *)
+    malloc (sizeof (*retval) + (__argz_count (dirlist, dirlist_len)
+				* (1 << pop (mask))
+				* sizeof (struct loaded_l10nfile *)));
+  if (retval == NULL)
+    return NULL;
+
+  retval->filename = abs_filename;
+  retval->decided = (__argz_count (dirlist, dirlist_len) != 1
+		     || ((mask & XPG_CODESET) != 0
+			 && (mask & XPG_NORM_CODESET) != 0));
+  retval->data = NULL;
+
+  if (last == NULL)
+    {
+      retval->next = *l10nfile_list;
+      *l10nfile_list = retval;
+    }
+  else
+    {
+      retval->next = last->next;
+      last->next = retval;
+    }
+
+  entries = 0;
+  /* If the DIRLIST is a real list the RETVAL entry corresponds not to
+     a real file.  So we have to use the DIRLIST separation mechanism
+     of the inner loop.  */
+  cnt = __argz_count (dirlist, dirlist_len) == 1 ? mask - 1 : mask;
+  for (; cnt >= 0; --cnt)
+    if ((cnt & ~mask) == 0
+	&& ((cnt & CEN_SPECIFIC) == 0 || (cnt & XPG_SPECIFIC) == 0)
+	&& ((cnt & XPG_CODESET) == 0 || (cnt & XPG_NORM_CODESET) == 0))
+      {
+	/* Iterate over all elements of the DIRLIST.  */
+	char *dir = NULL;
+
+	while ((dir = __argz_next ((char *) dirlist, dirlist_len, dir))
+	       != NULL)
+	  retval->successor[entries++]
+	    = _nl_make_l10nflist (l10nfile_list, dir, strlen (dir) + 1, cnt,
+				  language, territory, codeset,
+				  normalized_codeset, modifier, special,
+				  sponsor, revision, filename, 1);
+      }
+  retval->successor[entries] = NULL;
+
+  return retval;
+}
+
+/* Normalize codeset name.  There is no standard for the codeset
+   names.  Normalization allows the user to use any of the common
+   names.  */
+const char *
+_nl_normalize_codeset (codeset, name_len)
+     const char *codeset;
+     size_t name_len;
+{
+  int len = 0;
+  int only_digit = 1;
+  char *retval;
+  char *wp;
+  size_t cnt;
+
+  for (cnt = 0; cnt < name_len; ++cnt)
+    if (isalnum (codeset[cnt]))
+      {
+	++len;
+
+	if (isalpha (codeset[cnt]))
+	  only_digit = 0;
+      }
+
+  retval = (char *) malloc ((only_digit ? 3 : 0) + len + 1);
+
+  if (retval != NULL)
+    {
+      if (only_digit)
+	wp = stpcpy (retval, "iso");
+      else
+	wp = retval;
+
+      for (cnt = 0; cnt < name_len; ++cnt)
+	if (isalpha (codeset[cnt]))
+	  *wp++ = tolower (codeset[cnt]);
+	else if (isdigit (codeset[cnt]))
+	  *wp++ = codeset[cnt];
+
+      *wp = '\0';
+    }
+
+  return (const char *) retval;
+}
+
+
+/* @@ begin of epilog @@ */
+
+/* We don't want libintl.a to depend on any other library.  So we
+   avoid the non-standard function stpcpy.  In GNU C Library this
+   function is available, though.  Also allow the symbol HAVE_STPCPY
+   to be defined.  */
+#if !_LIBC && !HAVE_STPCPY
+static char *
+stpcpy (dest, src)
+     char *dest;
+     const char *src;
+{
+  while ((*dest++ = *src++) != '\0')
+    /* Do nothing. */ ;
+  return dest - 1;
+}
+#endif
diff -urN gnupg-0.2.8/intl/libgettext.h gnupg-0.2.9/intl/libgettext.h
--- gnupg-0.2.8/intl/libgettext.h	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/libgettext.h	Thu Feb 26 16:27:25 1998
@@ -1,19 +1,19 @@
-/* libgettext.h -- Message catalogs for internationalization.
-   Copyright (C) 1995 Free Software Foundation, Inc.
+/* Message catalogs for internationalization.
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Because on some systems (e.g. Solaris) we sometimes have to include
    the systems libintl.h as well as this file we have more complex
@@ -21,7 +21,7 @@
    define _LIBINTL_H and therefore we have to protect the definition here.  */
 
 #if !defined (_LIBINTL_H) || !defined (_LIBGETTEXT_H)
-#if !_LIBINTL_H
+#if !defined (_LIBINTL_H)
 # define _LIBINTL_H	1
 #endif
 #define _LIBGETTEXT_H	1
@@ -43,11 +43,11 @@
 
 /* @@ end of prolog @@ */
 
-#ifndef __P
+#ifndef PARAMS
 # if __STDC__
-#  define __P(args) args
+#  define PARAMS(args) args
 # else
-#  define __P(args) ()
+#  define PARAMS(args) ()
 # endif
 #endif
 
@@ -91,33 +91,34 @@
 /* Look up MSGID in the current default message catalog for the current
    LC_MESSAGES locale.  If not found, returns MSGID itself (the default
    text).  */
-extern char *gettext __P ((const char *__msgid));
-extern char *gettext__ __P ((const char *__msgid));
+extern char *gettext PARAMS ((const char *__msgid));
+extern char *gettext__ PARAMS ((const char *__msgid));
 
 /* Look up MSGID in the DOMAINNAME message catalog for the current
    LC_MESSAGES locale.  */
-extern char *dgettext __P ((const char *__domainname, const char *__msgid));
-extern char *dgettext__ __P ((const char *__domainname, const char *__msgid));
+extern char *dgettext PARAMS ((const char *__domainname, const char *__msgid));
+extern char *dgettext__ PARAMS ((const char *__domainname,
+				 const char *__msgid));
 
 /* Look up MSGID in the DOMAINNAME message catalog for the current CATEGORY
    locale.  */
-extern char *dcgettext __P ((const char *__domainname, const char *__msgid,
-			     int __category));
-extern char *dcgettext__ __P ((const char *__domainname, const char *__msgid,
-			       int __category));
+extern char *dcgettext PARAMS ((const char *__domainname, const char *__msgid,
+				int __category));
+extern char *dcgettext__ PARAMS ((const char *__domainname,
+				  const char *__msgid, int __category));
 
 
 /* Set the current default message catalog to DOMAINNAME.
    If DOMAINNAME is null, return the current default.
    If DOMAINNAME is "", reset to the default of "messages".  */
-extern char *textdomain __P ((const char *__domainname));
-extern char *textdomain__ __P ((const char *__domainname));
+extern char *textdomain PARAMS ((const char *__domainname));
+extern char *textdomain__ PARAMS ((const char *__domainname));
 
 /* Specify that the DOMAINNAME message catalog will be found
    in DIRNAME rather than in the system locale data base.  */
-extern char *bindtextdomain __P ((const char *__domainname,
+extern char *bindtextdomain PARAMS ((const char *__domainname,
 				  const char *__dirname));
-extern char *bindtextdomain__ __P ((const char *__domainname,
+extern char *bindtextdomain__ PARAMS ((const char *__domainname,
 				    const char *__dirname));
 
 #if ENABLE_NLS
@@ -127,33 +128,37 @@
    has dcgettext.  */
 # if !HAVE_CATGETS && (!HAVE_GETTEXT || HAVE_DCGETTEXT)
 
-#  define gettext(Msgid) \
+#  define gettext(Msgid)						      \
      dgettext (NULL, Msgid)
 
-#  define dgettext(Domainname, Msgid) \
+#  define dgettext(Domainname, Msgid)					      \
      dcgettext (Domainname, Msgid, LC_MESSAGES)
 
 #  if defined __GNUC__ && __GNUC__ == 2 && __GNUC_MINOR__ >= 7
-#   define dcgettext(Domainname, Msgid, Category) \
+/* This global variable is defined in loadmsgcat.c.  We need a sign,
+   whether a new catalog was loaded, which can be associated with all
+   translations.  */
+extern int _nl_msg_cat_cntr;
+
+#   define dcgettext(Domainname, Msgid, Category)			      \
   (__extension__							      \
    ({									      \
-     char *result;							      \
+     char *__result;							      \
      if (__builtin_constant_p (Msgid))					      \
        {								      \
-	 extern int _nl_msg_cat_cntr;					      \
 	 static char *__translation__;					      \
 	 static int __catalog_counter__;				      \
 	 if (! __translation__ || __catalog_counter__ != _nl_msg_cat_cntr)    \
 	   {								      \
 	     __translation__ =						      \
-	       dcgettext__ ((Domainname), (Msgid), (Category));		      \
+	       dcgettext__ (Domainname, Msgid, Category);		      \
 	     __catalog_counter__ = _nl_msg_cat_cntr;			      \
 	   }								      \
-	 result = __translation__;					      \
+	 __result = __translation__;					      \
        }								      \
      else								      \
-       result = dcgettext__ ((Domainname), (Msgid), (Category));	      \
-     result;								      \
+       __result = dcgettext__ (Domainname, Msgid, Category);		      \
+     __result;								      \
     }))
 #  endif
 # endif
diff -urN gnupg-0.2.8/intl/loadinfo.h gnupg-0.2.9/intl/loadinfo.h
--- gnupg-0.2.8/intl/loadinfo.h	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/intl/loadinfo.h	Thu Feb 26 16:27:25 1998
@@ -0,0 +1,58 @@
+#ifndef PARAMS
+# if __STDC__
+#  define PARAMS(args) args
+# else
+#  define PARAMS(args) ()
+# endif
+#endif
+
+/* Encoding of locale name parts.  */
+#define CEN_REVISION		1
+#define CEN_SPONSOR		2
+#define CEN_SPECIAL		4
+#define XPG_NORM_CODESET	8
+#define XPG_CODESET		16
+#define TERRITORY		32
+#define CEN_AUDIENCE		64
+#define XPG_MODIFIER		128
+
+#define CEN_SPECIFIC	(CEN_REVISION|CEN_SPONSOR|CEN_SPECIAL|CEN_AUDIENCE)
+#define XPG_SPECIFIC	(XPG_CODESET|XPG_NORM_CODESET|XPG_MODIFIER)
+
+
+struct loaded_l10nfile
+{
+  const char *filename;
+  int decided;
+
+  const void *data;
+
+  struct loaded_l10nfile *next;
+  struct loaded_l10nfile *successor[1];
+};
+
+
+extern const char *_nl_normalize_codeset PARAMS ((const char *codeset,
+						  size_t name_len));
+
+extern struct loaded_l10nfile *
+_nl_make_l10nflist PARAMS ((struct loaded_l10nfile **l10nfile_list,
+			    const char *dirlist, size_t dirlist_len, int mask,
+			    const char *language, const char *territory,
+			    const char *codeset,
+			    const char *normalized_codeset,
+			    const char *modifier, const char *special,
+			    const char *sponsor, const char *revision,
+			    const char *filename, int do_allocate));
+
+
+extern const char *_nl_expand_alias PARAMS ((const char *name));
+
+extern int _nl_explode_name PARAMS ((char *name, const char **language,
+				     const char **modifier,
+				     const char **territory,
+				     const char **codeset,
+				     const char **normalized_codeset,
+				     const char **special,
+				     const char **sponsor,
+				     const char **revision));
diff -urN gnupg-0.2.8/intl/loadmsgcat.c gnupg-0.2.9/intl/loadmsgcat.c
--- gnupg-0.2.8/intl/loadmsgcat.c	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/loadmsgcat.c	Thu Feb 26 16:27:25 1998
@@ -1,19 +1,19 @@
-/* loadmsgcat.c -- load needed message catalogs
-   Copyright (C) 1995 Software Foundation, Inc.
+/* Load needed message catalogs
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -41,8 +41,8 @@
 /* @@ end of prolog @@ */
 
 #ifdef _LIBC
-/* Rename the non ANSI C functions.  This is required by the standard
-   because some ANSI C functions will require linking with this object
+/* Rename the non ISO C functions.  This is required by the standard
+   because some ISO C functions will require linking with this object
    file and the name space must not be polluted.  */
 # define fstat  __fstat
 # define open   __open
@@ -55,14 +55,14 @@
 /* We need a sign, whether a new catalog was loaded, which can be associated
    with all translations.  This is important if the translations are
    cached by one of GCC's features.  */
-int _nl_msg_cat_cntr;
+int _nl_msg_cat_cntr = 0;
 
 
 /* Load the message catalogs specified by FILENAME.  If it is no valid
    message catalog do nothing.  */
 void
-_nl_load_domain (domain)
-     struct loaded_domain *domain;
+_nl_load_domain (domain_file)
+     struct loaded_l10nfile *domain_file;
 {
   int fd;
   struct stat st;
@@ -71,19 +71,20 @@
     || defined _LIBC
   int use_mmap = 0;
 #endif
+  struct loaded_domain *domain;
 
-  domain->decided = 1;
-  domain->data = NULL;
+  domain_file->decided = 1;
+  domain_file->data = NULL;
 
   /* If the record does not represent a valid locale the FILENAME
      might be NULL.  This can happen when according to the given
      specification the locale file name is different for XPG and CEN
      syntax.  */
-  if (domain->filename == NULL)
+  if (domain_file->filename == NULL)
     return;
 
   /* Try to open the addressed file.  */
-  fd = open (domain->filename, O_RDONLY);
+  fd = open (domain_file->filename, O_RDONLY);
   if (fd == -1)
     return;
 
@@ -156,6 +157,12 @@
       return;
     }
 
+  domain_file->data
+    = (struct loaded_domain *) malloc (sizeof (struct loaded_domain));
+  if (domain_file->data == NULL)
+    return;
+
+  domain = (struct loaded_domain *) domain_file->data;
   domain->data = (char *) data;
   domain->must_swap = data->magic != _MAGIC;
 
@@ -181,11 +188,12 @@
       else
 #endif
 	free (data);
-      domain->data = NULL;
+      free (domain);
+      domain_file->data = NULL;
       return;
     }
 
   /* Show that one domain is changed.  This might make some cached
-     translation invalid.  */
+     translations invalid.  */
   ++_nl_msg_cat_cntr;
 }
diff -urN gnupg-0.2.8/intl/localealias.c gnupg-0.2.9/intl/localealias.c
--- gnupg-0.2.8/intl/localealias.c	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/localealias.c	Thu Feb 26 16:27:25 1998
@@ -1,19 +1,20 @@
-/* localealias.c -- handle aliases for locale names
-   Copyright (C) 1995 Free Software Foundation, Inc.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+/* Handle aliases for locale names
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
+   Written by Ulrich Drepper <drepper@gnu.ai.mit.edu>, 1995.
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -25,6 +26,7 @@
 
 #ifdef __GNUC__
 # define alloca __builtin_alloca
+# define HAVE_ALLOCA 1
 #else
 # if defined HAVE_ALLOCA_H || defined _LIBC
 #  include <alloca.h>
@@ -51,9 +53,15 @@
 #endif
 
 #if defined HAVE_STRING_H || defined _LIBC
+# ifndef _GNU_SOURCE
+#  define _GNU_SOURCE	1
+# endif
 # include <string.h>
 #else
 # include <strings.h>
+# ifndef memcpy
+#  define memcpy(Dst, Src, Num) bcopy (Src, Dst, Num)
+# endif
 #endif
 #if !HAVE_STRCHR && !defined _LIBC
 # ifndef strchr
@@ -73,6 +81,43 @@
 # define strcasecmp __strcasecmp
 #endif
 
+
+/* For those loosing systems which don't have `alloca' we have to add
+   some additional code emulating it.  */
+#ifdef HAVE_ALLOCA
+/* Nothing has to be done.  */
+# define ADD_BLOCK(list, address) /* nothing */
+# define FREE_BLOCKS(list) /* nothing */
+#else
+struct block_list
+{
+  void *address;
+  struct block_list *next;
+};
+# define ADD_BLOCK(list, addr)						      \
+  do {									      \
+    struct block_list *newp = (struct block_list *) malloc (sizeof (*newp));  \
+    /* If we cannot get a free block we cannot add the new element to	      \
+       the list.  */							      \
+    if (newp != NULL) {							      \
+      newp->address = (addr);						      \
+      newp->next = (list);						      \
+      (list) = newp;							      \
+    }									      \
+  } while (0)
+# define FREE_BLOCKS(list)						      \
+  do {									      \
+    while (list != NULL) {						      \
+      struct block_list *old = list;					      \
+      list = list->next;						      \
+      free (old);							      \
+    }									      \
+  } while (0)
+# undef alloca
+# define alloca(size) (malloc (size))
+#endif	/* have alloca */
+
+
 struct alias_map
 {
   const char *alias;
@@ -86,10 +131,10 @@
 
 
 /* Prototypes for local functions.  */
-static size_t read_alias_file __P ((const char *fname, int fname_len));
-static void extend_alias_table __P ((void));
-static int alias_compare __P ((const struct alias_map *map1,
-			       const struct alias_map *map2));
+static size_t read_alias_file PARAMS ((const char *fname, int fname_len));
+static void extend_alias_table PARAMS ((void));
+static int alias_compare PARAMS ((const struct alias_map *map1,
+				  const struct alias_map *map2));
 
 
 const char *
@@ -109,9 +154,9 @@
       if (nmap > 0)
 	retval = (struct alias_map *) bsearch (&item, map, nmap,
 					       sizeof (struct alias_map),
-					       (int (*) __P ((const void *,
-							      const void *)))
-					         alias_compare);
+					       (int (*) PARAMS ((const void *,
+								 const void *))
+						) alias_compare);
       else
 	retval = NULL;
 
@@ -147,18 +192,25 @@
      const char *fname;
      int fname_len;
 {
+#ifndef HAVE_ALLOCA
+  struct block_list *block_list = NULL;
+#endif
   FILE *fp;
   char *full_fname;
   size_t added;
   static const char aliasfile[] = "/locale.alias";
 
   full_fname = (char *) alloca (fname_len + sizeof aliasfile);
+  ADD_BLOCK (block_list, full_fname);
   memcpy (full_fname, fname, fname_len);
   memcpy (&full_fname[fname_len], aliasfile, sizeof aliasfile);
 
   fp = fopen (full_fname, "r");
   if (fp == NULL)
-    return 0;
+    {
+      FREE_BLOCKS (block_list);
+      return 0;
+    }
 
   added = 0;
   while (!feof (fp))
@@ -223,14 +275,20 @@
 	      len = strlen (alias) + 1;
 	      tp = (char *) malloc (len);
 	      if (tp == NULL)
-		return added;
+		{
+		  FREE_BLOCKS (block_list);
+		  return added;
+		}
 	      memcpy (tp, alias, len);
 	      map[nmap].alias = tp;
 
 	      len = strlen (value) + 1;
 	      tp = (char *) malloc (len);
 	      if (tp == NULL)
-		return added;
+		{
+		  FREE_BLOCKS (block_list);
+		  return added;
+		}
 	      memcpy (tp, value, len);
 	      map[nmap].value = tp;
 
@@ -239,7 +297,7 @@
 	    }
 	}
 
-      /* Possibily not the whole line fitted into the buffer.  Ignore
+      /* Possibly not the whole line fits into the buffer.  Ignore
 	 the rest of the line.  */
       while (strchr (cp, '\n') == NULL)
 	{
@@ -257,8 +315,9 @@
 
   if (added > 0)
     qsort (map, nmap, sizeof (struct alias_map),
-	   (int (*) __P ((const void *, const void *))) alias_compare);
+	   (int (*) PARAMS ((const void *, const void *))) alias_compare);
 
+  FREE_BLOCKS (block_list);
   return added;
 }
 
@@ -309,6 +368,8 @@
       c2 = isupper (*p2) ? tolower (*p2) : *p2;
       if (c1 == '\0')
 	break;
+      ++p1;
+      ++p2;
     }
   while (c1 == c2);
 
diff -urN gnupg-0.2.8/intl/textdomain.c gnupg-0.2.9/intl/textdomain.c
--- gnupg-0.2.8/intl/textdomain.c	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/textdomain.c	Thu Feb 26 16:27:25 1998
@@ -1,19 +1,20 @@
-/* textdomain.c -- implementation of the textdomain(3) function
-   Copyright (C) 1995 Software Foundation, Inc.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+/* Implementation of the textdomain(3) function
+   Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
+   Written by Ulrich Drepper <drepper@gnu.ai.mit.edu>, 1995.
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -27,6 +28,9 @@
 # include <string.h>
 #else
 # include <strings.h>
+# ifndef memcpy
+#  define memcpy(Dst, Src, Num) bcopy (Src, Dst, Num)
+# endif
 #endif
 
 #ifdef _LIBC
@@ -50,6 +54,7 @@
    prefix.  So we have to make a difference here.  */
 #ifdef _LIBC
 # define TEXTDOMAIN __textdomain
+# define strdup(str) __strdup (str)
 #else
 # define TEXTDOMAIN textdomain__
 #endif
@@ -78,11 +83,15 @@
       /* If the following malloc fails `_nl_current_default_domain'
 	 will be NULL.  This value will be returned and so signals we
 	 are out of core.  */
+#if defined _LIBC || defined HAVE_STRDUP
+      _nl_current_default_domain = strdup (domainname);
+#else
       size_t len = strlen (domainname) + 1;
       char *cp = (char *) malloc (len);
       if (cp != NULL)
 	memcpy (cp, domainname, len);
       _nl_current_default_domain = cp;
+#endif
     }
 
   if (old != _nl_default_default_domain)
diff -urN gnupg-0.2.8/mpi/ChangeLog gnupg-0.2.9/mpi/ChangeLog
--- gnupg-0.2.8/mpi/ChangeLog	Mon Feb 23 12:22:22 1998
+++ gnupg-0.2.9/mpi/ChangeLog	Thu Feb 26 06:49:23 1998
@@ -1,3 +1,7 @@
+Thu Feb 26 06:48:54 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* config.links (X86_BROKEN_ALIGN): Added for some systems.
+
 Mon Feb 23 12:21:40 1998  Werner Koch  (wk@isil.d.shuttle.de)
 
 	* mpi/m68k/mpih-shift.S (Lspecial): Changed duplicate symbol.
diff -urN gnupg-0.2.8/mpi/Makefile.in gnupg-0.2.9/mpi/Makefile.in
--- gnupg-0.2.8/mpi/Makefile.in	Tue Feb 24 18:11:58 1998
+++ gnupg-0.2.9/mpi/Makefile.in	Thu Feb 26 17:13:22 1998
@@ -1,6 +1,6 @@
-# Makefile.in generated automatically by automake 1.2d from Makefile.am
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
 
-# Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -72,19 +72,25 @@
 GENCAT = @GENCAT@
 GMOFILES = @GMOFILES@
 GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
 INSTOBJEXT = @INSTOBJEXT@
 INTLDEPS = @INTLDEPS@
 INTLLIBS = @INTLLIBS@
 INTLOBJS = @INTLOBJS@
-INTLSUB = @INTLSUB@
+MKINSTALLDIRS = @MKINSTALLDIRS@
 MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
 MSGFMT = @MSGFMT@
 PACKAGE = @PACKAGE@
 POFILES = @POFILES@
 POSUB = @POSUB@
 RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
 VERSION = @VERSION@
 ZLIBS = @ZLIBS@
+l = @l@
 
 INCLUDES =  -I$(top_srcdir)/include
 
@@ -185,7 +191,7 @@
 	$(COMPILE) -c $<
 
 mostlyclean-compile:
-	-rm -f *.o core
+	-rm -f *.o core *.core
 
 clean-compile:
 
@@ -208,8 +214,12 @@
 TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) $(LISP)
 	tags=; \
 	here=`pwd`; \
-	test -z "$(ETAGS_ARGS)$(SOURCES)$(HEADERS)$(LISP)$$tags" \
-	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $(SOURCES) $(HEADERS) $(LISP) -o $$here/TAGS)
+	list='$(SOURCES) $(HEADERS)'; \
+	unique=`for i in $$list; do echo $$i; done | \
+	  awk '    { files[$$0] = 1; } \
+	       END { for (i in files) print i; }'`; \
+	test -z "$(ETAGS_ARGS)$$unique$(LISP)$$tags" \
+	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $$unique $(LISP) -o $$here/TAGS)
 
 mostlyclean-tags:
 
@@ -231,59 +241,57 @@
 	  || ln $$d/$$file $(distdir)/$$file 2> /dev/null \
 	  || cp -p $$d/$$file $(distdir)/$$file; \
 	done
-mpi-add.o mpi-add.lo: mpi-add.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h
-mpi-bit.o mpi-bit.lo: mpi-bit.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h longlong.h
-mpi-cmp.o mpi-cmp.lo: mpi-cmp.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h
-mpi-div.o mpi-div.lo: mpi-div.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h longlong.h
-mpi-gcd.o mpi-gcd.lo: mpi-gcd.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h
-mpi-inv.o mpi-inv.lo: mpi-inv.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h
-mpi-mpow.o mpi-mpow.lo: mpi-mpow.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h longlong.h
-mpi-mul.o mpi-mul.lo: mpi-mul.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h
-mpi-pow.o mpi-pow.lo: mpi-pow.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h longlong.h
-mpi-scan.o mpi-scan.lo: mpi-scan.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h longlong.h
-mpicoder.o mpicoder.lo: mpicoder.c ../config.h ../include/mpi.h \
-	../include/iobuf.h ../include/types.h ../include/memory.h \
-	mpi-internal.h mpi-inline.h ../include/util.h \
-	../include/errors.h
-mpih-add.o mpih-add.lo: mpih-add.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h
-mpih-cmp.o mpih-cmp.lo: mpih-cmp.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h
-mpih-div.o mpih-div.lo: mpih-div.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h longlong.h
-mpih-mul.o mpih-mul.lo: mpih-mul.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h longlong.h
-mpih-sub.o mpih-sub.lo: mpih-sub.c ../config.h mpi-internal.h \
-	../include/mpi.h ../include/iobuf.h ../include/types.h \
-	../include/memory.h mpi-inline.h
-mpiutil.o mpiutil.lo: mpiutil.c ../config.h ../include/mpi.h \
+mpi-add.o: mpi-add.c ../config.h mpi-internal.h ../include/mpi.h \
 	../include/iobuf.h ../include/types.h ../include/memory.h \
-	mpi-internal.h mpi-inline.h ../include/util.h \
-	../include/errors.h
+	mpi-inline.h
+mpi-bit.o: mpi-bit.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h longlong.h
+mpi-cmp.o: mpi-cmp.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h
+mpi-div.o: mpi-div.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h longlong.h
+mpi-gcd.o: mpi-gcd.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h
+mpi-inv.o: mpi-inv.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h
+mpi-mpow.o: mpi-mpow.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h longlong.h
+mpi-mul.o: mpi-mul.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h
+mpi-pow.o: mpi-pow.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h longlong.h
+mpi-scan.o: mpi-scan.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h longlong.h
+mpicoder.o: mpicoder.c ../config.h ../include/mpi.h ../include/iobuf.h \
+	../include/types.h ../include/memory.h mpi-internal.h \
+	mpi-inline.h ../include/util.h ../include/errors.h
+mpih-add.o: mpih-add.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h
+mpih-cmp.o: mpih-cmp.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h
+mpih-div.o: mpih-div.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h longlong.h
+mpih-mul.o: mpih-mul.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h longlong.h
+mpih-sub.o: mpih-sub.c ../config.h mpi-internal.h ../include/mpi.h \
+	../include/iobuf.h ../include/types.h ../include/memory.h \
+	mpi-inline.h
+mpiutil.o: mpiutil.c ../config.h ../include/mpi.h ../include/iobuf.h \
+	../include/types.h ../include/memory.h mpi-internal.h \
+	mpi-inline.h ../include/util.h ../include/errors.h
 
 info:
 dvi:
diff -urN gnupg-0.2.8/mpi/config.links gnupg-0.2.9/mpi/config.links
--- gnupg-0.2.8/mpi/config.links	Mon Feb 16 12:56:58 1998
+++ gnupg-0.2.9/mpi/config.links	Thu Feb 26 06:48:26 1998
@@ -12,11 +12,13 @@
 case "${target}" in
     i[34]86*-*-linuxaout* | i[34]86*-*-linuxoldld* | i[34]86*-*-*bsd*)
 	echo '#define BSD_SYNTAX' >>./mpi/asm-syntax.h
+	echo '#define X86_BROKEN_ALIGN' >>./mpi/asm-syntax.h
 	cat  $srcdir/mpi/i386/syntax.h	    >>./mpi/asm-syntax.h
 	path="i386"
 	;;
     i[56]86*-*-linuxaout* | i[56]86*-*-linuxoldld* | i[56]86*-*-*bsd*)
 	echo '#define BSD_SYNTAX' >>./mpi/asm-syntax.h
+	echo '#define X86_BROKEN_ALIGN' >>./mpi/asm-syntax.h
 	cat  $srcdir/mpi/i386/syntax.h	    >>./mpi/asm-syntax.h
 	path="i586 i386"
 	;;
diff -urN gnupg-0.2.8/po/ChangeLog gnupg-0.2.9/po/ChangeLog
--- gnupg-0.2.8/po/ChangeLog	Fri Feb 13 13:24:34 1998
+++ gnupg-0.2.9/po/ChangeLog	Thu Feb 26 16:30:22 1998
@@ -0,0 +1 @@
+
diff -urN gnupg-0.2.8/po/Makefile.in.in gnupg-0.2.9/po/Makefile.in.in
--- gnupg-0.2.8/po/Makefile.in.in	Wed Jan 28 16:36:50 1998
+++ gnupg-0.2.9/po/Makefile.in.in	Thu Feb 26 16:30:32 1998
@@ -1,19 +1,10 @@
 # Makefile for program source directory in GNU NLS utilities package.
-# Copyright (C) 1995 Free Software Foundation, Inc.
+# Copyright (C) 1995, 1996, 1997 by Ulrich Drepper <drepper@gnu.ai.mit.edu>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
-# any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# This file file be copied and used freely without restrictions.  It can
+# be used in projects which are not available under the GNU Public License
+# but which still want to provide support for the GNU gettext functionality.
+# Please note that the actual code is *not* freely available.
 
 PACKAGE = @PACKAGE@
 VERSION = @VERSION@
@@ -30,18 +21,19 @@
 datadir = $(prefix)/@DATADIRNAME@
 localedir = $(datadir)/locale
 gnulocaledir = $(prefix)/share/locale
-gettextsrcdir = $(prefix)/share/gettext
+gettextsrcdir = $(prefix)/share/gettext/po
 subdir = po
 
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
+MKINSTALLDIRS = $(top_srcdir)/@MKINSTALLDIRS@
 
 CC = @CC@
 GENCAT = @GENCAT@
-GMSGFMT = @GMSGFMT@
+GMSGFMT = PATH=../src:$$PATH @GMSGFMT@
 MSGFMT = @MSGFMT@
-XGETTEXT = @XGETTEXT@
-TUPDATE = tupdate
+XGETTEXT = PATH=../src:$$PATH @XGETTEXT@
+MSGMERGE = PATH=../src:$$PATH msgmerge
 
 DEFS = @DEFS@
 CFLAGS = @CFLAGS@
@@ -55,7 +47,7 @@
 POFILES = @POFILES@
 GMOFILES = @GMOFILES@
 DISTFILES = ChangeLog Makefile.in.in POTFILES.in $(PACKAGE).pot \
-	    $(POFILES) $(SOURCES)
+stamp-cat-id $(POFILES) $(GMOFILES) $(SOURCES)
 
 POTFILES = \
 
@@ -71,7 +63,7 @@
 
 .po.pox:
 	$(MAKE) $(PACKAGE).pot
-	$(TUPDATE) $(srcdir)/$(PACKAGE).pot $< > $*.pox
+	$(MSGMERGE) $< $(srcdir)/$(PACKAGE).pot -o $*.pox
 
 .po.mo:
 	$(MSGFMT) -o $@ $<
@@ -85,68 +77,103 @@
 	  && rm -f $@ && $(GENCAT) $@ $*.msg
 
 
-all: cat-id-tbl.c $(CATALOGS)
+all: all-@USE_NLS@
 
-$(PACKAGE).pot: $(POTFILES)
+all-yes: cat-id-tbl.c $(CATALOGS)
+all-no:
+
+$(srcdir)/$(PACKAGE).pot: $(POTFILES)
 	$(XGETTEXT) --default-domain=$(PACKAGE) --directory=$(top_srcdir) \
 	  --add-comments --keyword=_ --keyword=N_ \
 	  --files-from=$(srcdir)/POTFILES.in
-	if cmp -s $(PACKAGE).po $(srcdir)/$(PACKAGE).pot; then \
-	  rm -f $(PACKAGE).po; \
-	else \
-	  rm -f $(srcdir)/$(PACKAGE).pot \
-	    && mv $(PACKAGE).po $(srcdir)/$(PACKAGE).pot; \
-	fi
+	rm -f $(srcdir)/$(PACKAGE).pot
+	mv $(PACKAGE).po $(srcdir)/$(PACKAGE).pot
 
-cat-id-tbl.c: stamp-cat-id
-stamp-cat-id: $(PACKAGE).pot
-	rm -f cat-id-tbl.tmp.c
+$(srcdir)/cat-id-tbl.c: stamp-cat-id; @:
+$(srcdir)/stamp-cat-id: $(PACKAGE).pot
+	rm -f cat-id-tbl.tmp
 	sed -f ../intl/po2tbl.sed $(srcdir)/$(PACKAGE).pot \
-		| sed -e "s/@PACKAGE NAME@/$(PACKAGE)/" > cat-id-tbl.tmp.c
-	if cmp -s cat-id-tbl.tmp.c $(srcdir)/cat-id-tbl.c; then \
-	  rm cat-id-tbl.tmp.c; \
+		| sed -e "s/@PACKAGE NAME@/$(PACKAGE)/" > cat-id-tbl.tmp
+	if cmp -s cat-id-tbl.tmp $(srcdir)/cat-id-tbl.c; then \
+	  rm cat-id-tbl.tmp; \
 	else \
 	  echo cat-id-tbl.c changed; \
 	  rm -f $(srcdir)/cat-id-tbl.c; \
-	  mv cat-id-tbl.tmp.c $(srcdir)/cat-id-tbl.c; \
+	  mv cat-id-tbl.tmp $(srcdir)/cat-id-tbl.c; \
 	fi
 	cd $(srcdir) && rm -f stamp-cat-id && echo timestamp > stamp-cat-id
 
 
 install: install-exec install-data
 install-exec:
-install-data: all
-	$(top_srcdir)/scripts/mkinstalldirs $(datadir)
-	catalogs='$(CATALOGS)'; \
+install-data: install-data-@USE_NLS@
+install-data-no: all
+install-data-yes: all
+	if test -r $(MKINSTALLDIRS); then \
+	  $(MKINSTALLDIRS) $(datadir); \
+	else \
+	  $(top_srcdir)/mkinstalldirs $(datadir); \
+	fi
+	@catalogs='$(CATALOGS)'; \
 	for cat in $$catalogs; do \
-	  if test "`echo $$cat | sed 's/.*\(\..*\)/\1/'`" = ".gmo"; then \
-	    destdir=$(gnulocaledir); \
+	  cat=`basename $$cat`; \
+	  case "$$cat" in \
+	    *.gmo) destdir=$(gnulocaledir);; \
+	    *)     destdir=$(localedir);; \
+	  esac; \
+	  lang=`echo $$cat | sed 's/\$(CATOBJEXT)$$//'`; \
+	  dir=$$destdir/$$lang/LC_MESSAGES; \
+	  if test -r $(MKINSTALLDIRS); then \
+	    $(MKINSTALLDIRS) $$dir; \
 	  else \
-	    destdir=$(localedir); \
+	    $(top_srcdir)/mkinstalldirs $$dir; \
 	  fi; \
-	  lang=`echo $$cat | sed 's/$(CATOBJEXT)$$//'`; \
-	  dir=$$destdir/$$lang/LC_MESSAGES; \
-	  $(top_srcdir)/scripts/mkinstalldirs $$dir; \
 	  if test -r $$cat; then \
 	    $(INSTALL_DATA) $$cat $$dir/$(PACKAGE)$(INSTOBJEXT); \
+	    echo "installing $$cat as $$dir/$(PACKAGE)$(INSTOBJEXT)"; \
 	  else \
 	    $(INSTALL_DATA) $(srcdir)/$$cat $$dir/$(PACKAGE)$(INSTOBJEXT); \
+	    echo "installing $(srcdir)/$$cat as" \
+		 "$$dir/$(PACKAGE)$(INSTOBJEXT)"; \
+	  fi; \
+	  if test -r $$cat.m; then \
+	    $(INSTALL_DATA) $$cat.m $$dir/$(PACKAGE)$(INSTOBJEXT).m; \
+	    echo "installing $$cat.m as $$dir/$(PACKAGE)$(INSTOBJEXT).m"; \
+	  else \
+	    if test -r $(srcdir)/$$cat.m ; then \
+	      $(INSTALL_DATA) $(srcdir)/$$cat.m \
+		$$dir/$(PACKAGE)$(INSTOBJEXT).m; \
+	      echo "installing $(srcdir)/$$cat as" \
+		   "$$dir/$(PACKAGE)$(INSTOBJEXT).m"; \
+	    else \
+	      true; \
+	    fi; \
 	  fi; \
 	done
+	if test "$(PACKAGE)" = "gettext"; then \
+	  if test -r $(MKINSTALLDIRS); then \
+	    $(MKINSTALLDIRS) $(gettextsrcdir); \
+	  else \
+	    $(top_srcdir)/mkinstalldirs $(gettextsrcdir); \
+	  fi; \
+	  $(INSTALL_DATA) $(srcdir)/Makefile.in.in \
+			  $(gettextsrcdir)/Makefile.in.in; \
+	else \
+	  : ; \
+	fi
 
-# This installation goal is only used in GNU gettext.  Packages which
-# only use the library should use install instead.
-install-src: install
-	$(top_srcdir)/scripts/mkinstalldirs $(gettextsrcdir)
-	cd $(srcdir) && \
-	  $(INSTALL_DATA) Makefile.in.in $(gettextsrcdir)/po-Makefile.in.in
+# Define this as empty until I found a useful application.
+installcheck:
 
 uninstall:
 	catalogs='$(CATALOGS)'; \
 	for cat in $$catalogs; do \
-	  lang=`echo $$cat | sed 's/$(CATOBJEXT)$$//'`; \
+	  cat=`basename $$cat`; \
+	  lang=`echo $$cat | sed 's/\$(CATOBJEXT)$$//'`; \
 	  rm -f $(localedir)/$$lang/LC_MESSAGES/$(PACKAGE)$(INSTOBJEXT); \
+	  rm -f $(localedir)/$$lang/LC_MESSAGES/$(PACKAGE)$(INSTOBJEXT).m; \
 	  rm -f $(gnulocaledir)/$$lang/LC_MESSAGES/$(PACKAGE)$(INSTOBJEXT); \
+	  rm -f $(gnulocaledir)/$$lang/LC_MESSAGES/$(PACKAGE)$(INSTOBJEXT).m; \
 	done
 	rm -f $(gettextsrcdir)/po-Makefile.in.in
 
@@ -154,39 +181,44 @@
 
 cat-id-tbl.o: ../intl/libgettext.h
 
-TAGS ID:
+dvi info tags TAGS ID:
 
 mostlyclean:
-	rm -f core core.* *.pox $(PACKAGE).po *.old.po cat-id-tbl.tmp.c
+	rm -f core core.* *.pox $(PACKAGE).po *.old.po cat-id-tbl.tmp
+	rm -fr *.o
 
 clean: mostlyclean
 
 distclean: clean
-	rm -f Makefile Makefile.in POTFILES *.mo *.msg *.cat
+	rm -f Makefile Makefile.in POTFILES *.mo *.msg *.cat *.cat.m
 
 maintainer-clean: distclean
 	@echo "This command is intended for maintainers to use;"
 	@echo "it deletes files that may require special tools to rebuild."
+	rm -f $(GMOFILES)
 
-distdir = $(top_builddir)/$(PACKAGE)-$(VERSION)/$(subdir)
-distdir: $(DEP_DISTFILES)
-	@for file in `cd $(srcdir) && echo $(DISTFILES)`; do \
-	  test -f $(distdir)/$$file \
-	  || ln $(srcdir)/$$file $(distdir)/$$file 2> /dev/null \
-	  || cp -p $(srcdir)/$$file $(distdir)/$$file; \
+distdir = ../$(PACKAGE)-$(VERSION)/$(subdir)
+dist distdir: update-po $(DISTFILES)
+	dists="$(DISTFILES)"; \
+	for file in $$dists; do \
+	  ln $(srcdir)/$$file $(distdir) 2> /dev/null \
+	    || cp -p $(srcdir)/$$file $(distdir); \
 	done
 
 update-po: Makefile
 	$(MAKE) $(PACKAGE).pot
+	PATH=`pwd`/../src:$$PATH; \
 	cd $(srcdir); \
 	catalogs='$(CATALOGS)'; \
 	for cat in $$catalogs; do \
-	  lang=`echo $$cat | sed 's/$(CATOBJEXT)$$//'`; \
+	  cat=`basename $$cat`; \
+	  lang=`echo $$cat | sed 's/\$(CATOBJEXT)$$//'`; \
 	  mv $$lang.po $$lang.old.po; \
-	  if $(TUPDATE) $(PACKAGE).pot $$lang.old.po > $$lang.po; then \
+	  echo "$$lang:"; \
+	  if $(MSGMERGE) $$lang.old.po $(PACKAGE).pot -o $$lang.po; then \
 	    rm -f $$lang.old.po; \
 	  else \
-	    echo "tupdate for $$cat failed!"; \
+	    echo "msgmerge for $$cat failed!"; \
 	    rm -f $$lang.po; \
 	    mv $$lang.old.po $$lang.po; \
 	  fi; \
@@ -198,12 +230,17 @@
 	  else \
 	    posrcprefix="../"; \
 	  fi; \
-	  sed -e '/^#/d' -e '/^[        ]*$$/d' \
-	      -e "s@.*@ $$posrcprefix& \\\\@" \
-	      -e '$$s/\(.*\) \\/\1/' < $(srcdir)/POTFILES.in > POTFILES )
+	  rm -f $@-t $@ \
+	    && (sed -e '/^#/d' -e '/^[ 	]*$$/d' \
+		    -e "s@.*@	$$posrcprefix& \\\\@" < $(srcdir)/$@.in \
+		| sed -e '$$s/\\$$//') > $@-t \
+	    && chmod a-w $@-t \
+	    && mv $@-t $@ )
 
 Makefile: Makefile.in.in ../config.status POTFILES
-	cd .. && CONFIG_FILES=$(subdir)/$@.in CONFIG_HEADERS= ./config.status
+	cd .. \
+	  && CONFIG_FILES=$(subdir)/$@.in CONFIG_HEADERS= \
+	       $(SHELL) ./config.status
 
 # Tell versions [3.59,3.63) of GNU make not to export all variables.
 # Otherwise a system limit (for SysV at least) may be exceeded.
Binary files gnupg-0.2.8/po/de.gmo and gnupg-0.2.9/po/de.gmo differ
diff -urN gnupg-0.2.8/po/gnupg.pot gnupg-0.2.9/po/gnupg.pot
--- gnupg-0.2.8/po/gnupg.pot	Tue Feb 24 16:12:53 1998
+++ gnupg-0.2.9/po/gnupg.pot	Thu Feb 26 16:49:47 1998
@@ -1,12 +1,12 @@
 msgid ""
 msgstr ""
-"Date: 1998-02-24 16:12:53+0100\n"
-"From: Werner Koch <wk@frodo>\n"
+"Date: 1998-02-26 16:49:47+0100\n"
+"From: root <root@frodo>\n"
 "Content-Type: text/plain; charset=\n"
 "Xgettext-Options: --default-domain=gnupg --directory=.. --add-comments --keyword=_ --keyword=N_ --files-from=./POTFILES.in\n"
 "Files: util/secmem.c cipher/random.c g10/g10.c g10/pkclist.c g10/keygen.c\n"
 
-#: util/secmem.c:176
+#: util/secmem.c:180
 msgid "Warning: using insecure memory!\n"
 msgstr ""
 
diff -urN gnupg-0.2.8/po/stamp-cat-id gnupg-0.2.9/po/stamp-cat-id
--- gnupg-0.2.8/po/stamp-cat-id	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/po/stamp-cat-id	Thu Feb 26 16:49:49 1998
@@ -0,0 +1 @@
+timestamp
diff -urN gnupg-0.2.8/tools/Makefile.in gnupg-0.2.9/tools/Makefile.in
--- gnupg-0.2.8/tools/Makefile.in	Tue Feb 24 18:12:11 1998
+++ gnupg-0.2.9/tools/Makefile.in	Thu Feb 26 17:13:28 1998
@@ -1,6 +1,6 @@
-# Makefile.in generated automatically by automake 1.2d from Makefile.am
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
 
-# Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -72,19 +72,25 @@
 GENCAT = @GENCAT@
 GMOFILES = @GMOFILES@
 GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
 INSTOBJEXT = @INSTOBJEXT@
 INTLDEPS = @INTLDEPS@
 INTLLIBS = @INTLLIBS@
 INTLOBJS = @INTLOBJS@
-INTLSUB = @INTLSUB@
+MKINSTALLDIRS = @MKINSTALLDIRS@
 MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
 MSGFMT = @MSGFMT@
 PACKAGE = @PACKAGE@
 POFILES = @POFILES@
 POSUB = @POSUB@
 RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
 VERSION = @VERSION@
 ZLIBS = @ZLIBS@
+l = @l@
 
 INCLUDES = -I$(top_srcdir)/include
 needed_libs = ../cipher/libcipher.a  ../util/libutil.a ../mpi/libmpi.a ../util/libutil.a
@@ -165,7 +171,7 @@
 	$(COMPILE) -c $<
 
 mostlyclean-compile:
-	-rm -f *.o core
+	-rm -f *.o core *.core
 
 clean-compile:
 
@@ -195,8 +201,12 @@
 TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) $(LISP)
 	tags=; \
 	here=`pwd`; \
-	test -z "$(ETAGS_ARGS)$(SOURCES)$(HEADERS)$(LISP)$$tags" \
-	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $(SOURCES) $(HEADERS) $(LISP) -o $$here/TAGS)
+	list='$(SOURCES) $(HEADERS)'; \
+	unique=`for i in $$list; do echo $$i; done | \
+	  awk '    { files[$$0] = 1; } \
+	       END { for (i in files) print i; }'`; \
+	test -z "$(ETAGS_ARGS)$$unique$(LISP)$$tags" \
+	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $$unique $(LISP) -o $$here/TAGS)
 
 mostlyclean-tags:
 
@@ -218,17 +228,17 @@
 	  || ln $$d/$$file $(distdir)/$$file 2> /dev/null \
 	  || cp -p $$d/$$file $(distdir)/$$file; \
 	done
-bftest.o bftest.lo: bftest.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/cipher.h \
+bftest.o: bftest.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h ../include/i18n.h
 clean-sat.o clean-sat.lo: clean-sat.c
-mpicalc.o mpicalc.lo: mpicalc.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/i18n.h
+mpicalc.o: mpicalc.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/i18n.h
 
 info:
 dvi:
diff -urN gnupg-0.2.8/util/ChangeLog gnupg-0.2.9/util/ChangeLog
--- gnupg-0.2.8/util/ChangeLog	Fri Feb 20 17:43:34 1998
+++ gnupg-0.2.9/util/ChangeLog	Thu Feb 26 14:37:43 1998
@@ -1,3 +1,8 @@
+Thu Feb 26 14:36:51 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* secmem.c (lock_pool): No error if EAGAIN is returned instead
+	of EPERM.
+
 Fri Feb 20 17:43:05 1998  Werner Koch  (wk@isil.d.shuttle.de)
 
 	* ttyio.c [MINGW32]: Add support for mingw32.
diff -urN gnupg-0.2.8/util/Makefile.in gnupg-0.2.9/util/Makefile.in
--- gnupg-0.2.8/util/Makefile.in	Tue Feb 24 18:11:53 1998
+++ gnupg-0.2.9/util/Makefile.in	Thu Feb 26 17:13:19 1998
@@ -1,6 +1,6 @@
-# Makefile.in generated automatically by automake 1.2d from Makefile.am
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
 
-# Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -72,19 +72,25 @@
 GENCAT = @GENCAT@
 GMOFILES = @GMOFILES@
 GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
 INSTOBJEXT = @INSTOBJEXT@
 INTLDEPS = @INTLDEPS@
 INTLLIBS = @INTLLIBS@
 INTLOBJS = @INTLOBJS@
-INTLSUB = @INTLSUB@
+MKINSTALLDIRS = @MKINSTALLDIRS@
 MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
 MSGFMT = @MSGFMT@
 PACKAGE = @PACKAGE@
 POFILES = @POFILES@
 POSUB = @POSUB@
 RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
 VERSION = @VERSION@
 ZLIBS = @ZLIBS@
+l = @l@
 
 INCLUDES = -I$(top_srcdir)/include
 
@@ -150,7 +156,7 @@
 	$(COMPILE) -c $<
 
 mostlyclean-compile:
-	-rm -f *.o core
+	-rm -f *.o core *.core
 
 clean-compile:
 
@@ -173,8 +179,12 @@
 TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) $(LISP)
 	tags=; \
 	here=`pwd`; \
-	test -z "$(ETAGS_ARGS)$(SOURCES)$(HEADERS)$(LISP)$$tags" \
-	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $(SOURCES) $(HEADERS) $(LISP) -o $$here/TAGS)
+	list='$(SOURCES) $(HEADERS)'; \
+	unique=`for i in $$list; do echo $$i; done | \
+	  awk '    { files[$$0] = 1; } \
+	       END { for (i in files) print i; }'`; \
+	test -z "$(ETAGS_ARGS)$$unique$(LISP)$$tags" \
+	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $$unique $(LISP) -o $$here/TAGS)
 
 mostlyclean-tags:
 
@@ -196,34 +206,34 @@
 	  || ln $$d/$$file $(distdir)/$$file 2> /dev/null \
 	  || cp -p $$d/$$file $(distdir)/$$file; \
 	done
-argparse.o argparse.lo: argparse.c ../config.h ../include/util.h \
+argparse.o: argparse.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/i18n.h
+errors.o: errors.c ../config.h ../include/errors.h
+fileutil.o: fileutil.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/ttyio.h
+iobuf.o: iobuf.c ../config.h ../include/memory.h ../include/util.h \
 	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/i18n.h
-errors.o errors.lo: errors.c ../config.h ../include/errors.h
-fileutil.o fileutil.lo: fileutil.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/ttyio.h
-iobuf.o iobuf.lo: iobuf.c ../config.h ../include/memory.h \
-	../include/util.h ../include/types.h ../include/errors.h \
-	../include/mpi.h ../include/iobuf.h
-logger.o logger.lo: logger.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h
-memory.o memory.lo: memory.c ../config.h ../include/types.h \
-	../include/memory.h ../include/util.h ../include/errors.h \
-	../include/mpi.h ../include/iobuf.h
-miscutil.o miscutil.lo: miscutil.c ../config.h ../include/types.h \
+	../include/iobuf.h
+logger.o: logger.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h
+memory.o: memory.c ../config.h ../include/types.h ../include/memory.h \
 	../include/util.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h
-secmem.o secmem.lo: secmem.c ../config.h ../include/types.h \
-	../include/memory.h ../include/util.h ../include/errors.h \
-	../include/mpi.h ../include/iobuf.h ../include/i18n.h
-strgutil.o strgutil.lo: strgutil.c ../config.h ../include/types.h \
+	../include/iobuf.h
+miscutil.o: miscutil.c ../config.h ../include/types.h ../include/util.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h
+secmem.o: secmem.c ../config.h ../include/types.h ../include/memory.h \
 	../include/util.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h
-ttyio.o ttyio.lo: ttyio.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/ttyio.h
+	../include/iobuf.h ../include/i18n.h
+strgutil.o: strgutil.c ../config.h ../include/types.h ../include/util.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h
+ttyio.o: ttyio.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/ttyio.h
 
 info:
 dvi:
diff -urN gnupg-0.2.8/util/secmem.c gnupg-0.2.9/util/secmem.c
--- gnupg-0.2.8/util/secmem.c	Mon Feb 23 13:11:24 1998
+++ gnupg-0.2.9/util/secmem.c	Thu Feb 26 15:34:57 1998
@@ -82,7 +82,11 @@
     }
 
     if( err ) {
-	if( errno != EPERM )
+	if( errno != EPERM
+	  #ifdef EAGAIN  /* OpenBSD returns this */
+	    && errno != EAGAIN
+	  #endif
+	  )
 	    log_error("cant lock memory: %s\n", strerror(err));
 	show_warning = 1;
     }
diff -urN gnupg-0.2.8/zlib/Makefile.in gnupg-0.2.9/zlib/Makefile.in
--- gnupg-0.2.8/zlib/Makefile.in	Tue Feb 24 18:11:47 1998
+++ gnupg-0.2.9/zlib/Makefile.in	Thu Feb 26 17:13:15 1998
@@ -1,6 +1,6 @@
-# Makefile.in generated automatically by automake 1.2d from Makefile.am
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
 
-# Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -77,19 +77,25 @@
 GENCAT = @GENCAT@
 GMOFILES = @GMOFILES@
 GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
 INSTOBJEXT = @INSTOBJEXT@
 INTLDEPS = @INTLDEPS@
 INTLLIBS = @INTLLIBS@
 INTLOBJS = @INTLOBJS@
-INTLSUB = @INTLSUB@
+MKINSTALLDIRS = @MKINSTALLDIRS@
 MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
 MSGFMT = @MSGFMT@
 PACKAGE = @PACKAGE@
 POFILES = @POFILES@
 POSUB = @POSUB@
 RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
 VERSION = @VERSION@
 ZLIBS = @ZLIBS@
+l = @l@
 
 CFLAGS = -O -Wall
 
@@ -166,7 +172,7 @@
 	$(COMPILE) -c $<
 
 mostlyclean-compile:
-	-rm -f *.o core
+	-rm -f *.o core *.core
 
 clean-compile:
 
@@ -189,8 +195,12 @@
 TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) $(LISP)
 	tags=; \
 	here=`pwd`; \
-	test -z "$(ETAGS_ARGS)$(SOURCES)$(HEADERS)$(LISP)$$tags" \
-	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $(SOURCES) $(HEADERS) $(LISP) -o $$here/TAGS)
+	list='$(SOURCES) $(HEADERS)'; \
+	unique=`for i in $$list; do echo $$i; done | \
+	  awk '    { files[$$0] = 1; } \
+	       END { for (i in files) print i; }'`; \
+	test -z "$(ETAGS_ARGS)$$unique$(LISP)$$tags" \
+	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $$unique $(LISP) -o $$here/TAGS)
 
 mostlyclean-tags:
 

diff -urN gnupg-0.2.8/ABOUT-NLS gnupg-0.2.9/ABOUT-NLS
--- gnupg-0.2.8/ABOUT-NLS	Mon Sep 22 11:25:50 1997
+++ gnupg-0.2.9/ABOUT-NLS	Thu Feb 26 17:02:02 1998
@@ -1,16 +1,16 @@
-Notes on the GNU Translation Project
-************************************
+Notes on the Free Translation Project
+*************************************
 
-   GNU is going international!  The GNU Translation Project is a way to
-get maintainers, translators and users all together, so GNU will
-gradually become able to speak many native languages.  A few packages
-already provide native language translation for their messages.
-
-   If you found this `ABOUT-NLS' file inside a GNU distribution, you
-may assume that the distributed package does use GNU `gettext'
-internally, itself available at your nearest GNU archive site.  But you
-do not need to install GNU `gettext' prior to configuring, installing
-or using this package with messages translated.
+   Free software is going international!  The Free Translation Project
+is a way to get maintainers of free software, translators, and users all
+together, so that will gradually become able to speak many languages.
+A few packages already provide translations for their messages.
+
+   If you found this `ABOUT-NLS' file inside a distribution, you may
+assume that the distributed package does use GNU `gettext' internally,
+itself available at your nearest GNU archive site.  But you do *not*
+need to install GNU `gettext' prior to configuring, installing or using
+this package with messages translated.
 
    Installers will find here some useful hints.  These notes also
 explain how users should proceed for getting the programs to use the
@@ -25,60 +25,85 @@
 One advise in advance
 =====================
 
-   If you want to exploit the full power of the GNU `gettext' package
-you should configure it using
+   If you want to exploit the full power of internationalization, you
+should configure it using
 
-             --with-gnu-gettext.
+     ./configure --with-included-gettext
 
-   No existing implementation at this point provides so many useful
-features (such as locale alias or message inheritance).  It is also not
-possible to provide this additional functionality on top of a catgets
-implementation.
-
-   Future versions of GNU `gettext' will very likely provide even more
-functionality.  So it might be a good idea to change to GNU `gettext'
-as soon as possible.
+to force usage of internationalizing routines provided within this
+package, despite the existence of internationalizing capabilities in the
+operating system where this package is being installed.  So far, only
+the `gettext' implementation in the GNU C library version 2 provides as
+many features (such as locale alias or message inheritance) as the
+implementation here.  It is also not possible to offer this additional
+functionality on top of a `catgets' implementation.  Future versions of
+GNU `gettext' will very likely convey even more functionality.  So it
+might be a good idea to change to GNU `gettext' as soon as possible.
+
+   So you need not provide this option if you are using GNU libc 2 or
+you have installed a recent copy of the GNU gettext package with the
+included `libintl'.
 
 INSTALL Matters
 ===============
 
-   Some GNU packages are "localizable" when properly installed; the
+   Some packages are "localizable" when properly installed; the
 programs they contain can be made to speak your own native language.
 Most such packages use GNU `gettext'.  Other packages have their own
 ways to internationalization, predating GNU `gettext'.
 
    By default, this package will be installed to allow translation of
 messages.  It will automatically detect whether the system provides
-usable `catgets' or `gettext' functions.  If neither is available, the
-GNU `gettext' own library will be used.  However, installers may use
-special options at configuration time for changing this behaviour.  The
-commands:
+usable `catgets' (if using this is selected by the installer) or
+`gettext' functions.  If neither is available, the GNU `gettext' own
+library will be used.  This library is wholly contained within this
+package, usually in the `intl/' subdirectory, so prior installation of
+the GNU `gettext' package is *not* required.  Installers may use
+special options at configuration time for changing the default
+behaviour.  The commands:
 
-     ./configure --with-gnu-gettext
+     ./configure --with-included-gettext
+     ./configure --with-catgets
      ./configure --disable-nls
 
-will respectively bypass system `catgets' or `gettext' to use GNU
-`gettext', or else, totally disable translation of messages.
+will respectively bypass any pre-existing `catgets' or `gettext' to use
+the internationalizing routines provided within this package, enable
+the use of the `catgets' functions (if found on the locale system), or
+else, *totally* disable translation of messages.
 
    When you already have GNU `gettext' installed on your system and run
-configure without an option for your new package, configure will
+configure without an option for your new package, `configure' will
 probably detect the previously built and installed `libintl.a' file and
 will decide to use this.  This might be not what is desirable.  You
 should use the more recent version of the GNU `gettext' library.  I.e.
 if the file `intl/VERSION' shows that the library which comes with this
 package is more recent, you should use
 
-     ./configure --with-gnu-gettext
+     ./configure --with-included-gettext
 
 to prevent auto-detection.
 
+   By default the configuration process will not test for the `catgets'
+function and therefore they will not be used.  The reasons are already
+given above: the emulation on top of `catgets' cannot provide all the
+extensions provided by the GNU `gettext' library.  If you nevertheless
+want to use the `catgets' functions use
+
+     ./configure --with-catgets
+
+to enable the test for `catgets' (this causes no harm if `catgets' is
+not available on your system).  If you really select this option we
+would like to hear about the reasons because we cannot think of any
+good one ourself.
+
    Internationalized packages have usually many `po/LL.po' files, where
 LL gives an ISO 639 two-letter code identifying the language.  Unless
-translations are disabled, all those available are installed together
-with the package.  However, the environment variable `LINGUAS' may be
-set, prior to configuration, to limit the installed set.  `LINGUAS'
-should then contain a space separated list of two-letter codes, stating
-which languages are allowed.
+translations have been forbidden at `configure' time by using the
+`--disable-nls' switch, all available translations are installed
+together with the package.  However, the environment variable `LINGUAS'
+may be set, prior to configuration, to limit the installed set.
+`LINGUAS' should then contain a space separated list of two-letter
+codes, stating which languages are allowed.
 
 Using This Package
 ==================
@@ -87,117 +112,115 @@
 only have to set the `LANG' environment variable to the appropriate
 ISO 639 `LL' two-letter code prior to using the programs in the
 package.  For example, let's suppose that you speak German.  At the
-shell prompt, merely execute `setenv LANG de' (in `csh') or
-`export LANG; LANG=de' (in `sh').  This can be done from your `.login'
-or `.profile' file, once and for all.  Packages which are not
-internationalized will merely ignore the setting of this variable.
+shell prompt, merely execute `setenv LANG de' (in `csh'),
+`export LANG; LANG=de' (in `sh') or `export LANG=de' (in `bash').  This
+can be done from your `.login' or `.profile' file, once and for all.
+
+   An operating system might already offer message localization for
+many of its programs, while other programs have been installed locally
+with the full capabilities of GNU `gettext'.  Just using `gettext'
+extended syntax for `LANG' would break proper localization of already
+available operating system programs.  In this case, users should set
+both `LANGUAGE' and `LANG' variables in their environment, as programs
+using GNU `gettext' give preference to `LANGUAGE'.  For example, some
+Swedish users would rather read translations in German than English for
+when Swedish is not available.  This is easily accomplished by setting
+`LANGUAGE' to `sv:de' while leaving `LANG' to `sv'.
 
 Translating Teams
 =================
 
-   The GNU `gettext' tool set contains *everything* maintainers need
-for internationalizing their packages for messages.  It also contains
-quite useful tools for helping translators at localizing messages to
-their native language, once a package has already been
-internationalized.
-
-   To achieve the GNU Translation Project, we need many interested
+   For the Free Translation Project to be a success, we need interested
 people who like their own language and write it well, and who are also
 able to synergize with other translators speaking the same language.
-Each translating team has its own mailing list, courtesy of Linux
-International.  You may reach your translating team at the address
+Each translation team has its own mailing list, courtesy of Linux
+International.  You may reach your translation team at the address
 `LL@li.org', replacing LL by the two-letter ISO 639 code for your
-language.  Language codes are *not* the same as country codes given in
-ISO 3166.  The following translating teams exist, as of November 1995:
+language.  Language codes are *not* the same as the country codes given
+in ISO 3166.  The following translation teams exist, as of December
+1997:
 
      Chinese `zh', Czech `cs', Danish `da', Dutch `nl', English `en',
-     Esperanto `eo', Finnish `fi', French `fr', Irish `ga', German
-     `de', Greek `el', Italian `it', Japanese `ja', Indonesian `in',
-     Norwegian `no', Persian `fa', Polish `pl', Portuguese `pt',
-     Russian `ru', Spanish `es', Swedish `sv', Telugu `te' and Turkish
-     `tr'.
+     Esperanto `eo', Finnish `fi', French `fr', German `de', Hungarian
+     `hu', Irish `ga', Italian `it', Indonesian `id', Japanese `ja',
+     Korean `ko', Latin `la', Norwegian `no', Persian `fa', Polish
+     `pl', Portuguese `pt', Russian `ru', Slovenian `sl', Spanish `es',
+     Swedish `sv', and Turkish `tr'.
 
-For example, you may reach the Chinese translating team by writing to
+For example, you may reach the Chinese translation team by writing to
 `zh@li.org'.
 
    If you'd like to volunteer to *work* at translating messages, you
 should become a member of the translating team for your own language.
 The subscribing address is *not* the same as the list itself, it has
-`-request' appended.  For example, Swedish people can send a message to
-`sv-request@li.org', having this message body:
+`-request' appended.  For example, speakers of Swedish can send a
+message to `sv-request@li.org', having this message body:
 
      subscribe
 
-   Keep in mind that team members should be interested in *working* at
-translations, or at solving translational difficulties, rather than
-merely lurking around.  If your team does not exist yet and you want to
-start one, please write to `gnu-translation@prep.ai.mit.edu'; you will
-then reach the GNU coordinator for all translator teams.
+   Keep in mind that team members are expected to participate
+*actively* in translations, or at solving translational difficulties,
+rather than merely lurking around.  If your team does not exist yet and
+you want to start one, or if you are unsure about what to do or how to
+get started, please write to `translation@iro.umontreal.ca' to reach the
+coordinator for all translator teams.
 
    The English team is special.  It works at improving and uniformizing
-the terminology used in GNU.  Proven linguistic skill are praised more
-than programming skill, here.  For the time being, please avoid
-subscribing to the English team unless explicitely invited to do so.
+the terminology in use.  Proven linguistic skill are praised more than
+programming skill, here.
 
 Available Packages
 ==================
 
-   Languages are not equally supported in all GNU packages.  The
-following matrix shows the current state of GNU internationalization,
-as of November 1995.  Listed are: internationalized packages, and
-languages for which work is in progress, or about to start.
-
-          See note    cs de en fr it ja nl no pt sv
-                \   .-------------------------------.
-     chess      (1) |    X  /                    X  |
-     clisp          |    X  X  X                    |
-     diffutils  (2) |       /  .                    |
-     fileutils      |    .  /                       |
-     flex       (3) |       /  .                    |
-     m4             |    -  /  -  -  .           -  |
-     gettext        |    X  /  X           X     X  |
-     ptx            |    -  /  -                 -  |
-     recode         |    -  /  -        -     -     |
-     sh-utils       |    .  /  .                    |
-     sharutils      |    X  /  X     X  X     X  X  |
-     tar            |    X  /  X           -  X  X  |
-     textutils      |    .  /  .                    |
-     wdiff          | -  -  /  -  -                 |
-                    `-------------------------------'
-                      cs de en fr it ja nl no pt sv
-
-   The interpretation legend and notes are:
-
-`/'
-     There is no PO file, this package merely defaults to this language.
-
-`.'
-     The effort of localizing this package has been undertaken by
-     someone, or by a translating team, and work is, or should be in
-     progress.
-
-`-'
-     A PO file for this package and this language is completed and is
-     currently available in a pretest release, or is all ready for
-     inclusion in the next release of this package.
-
-`X'
-     The localization of this package to this particular language is
-     fully completed, and now distributed through an official release.
-
-(1)
-     This package is translated to specific languages by methods
-     predating GNU `gettext'.  Translations are all kept on disk files,
-     and sources contain numbers where one normally expects strings.
-
-(2)
-     This package is planned to switch to GNU `gettext'.  For the time
-     being, it uses temporary means for internationalization.
-
-(3)
-     This package has its translatable strings marked, but does not use
-     GNU `gettext'.  A convenience patch may be available separately.
+   Languages are not equally supported in all packages.  The following
+matrix shows the current state of internationalization, as of December
+1997.  The matrix shows, in regard of each package, for which languages
+PO files have been submitted to translation coordination.
+
+     Ready PO files    cs da de en es fi fr it ja ko nl no pl pt ru sl sv
+                     .----------------------------------------------------.
+     bash            |       []          []          []                   |  3
+     bison           |       []          []          []                   |  3
+     clisp           |       [] [] []    []                               |  4
+     cpio            |       []    []    []       [] []    []             |  6
+     diffutils       |       []    []    []                []          [] |  5
+     enscript        |       []    [] [] []          []             []    |  6
+     fileutils       | []    []    []    []       [] []    [] []    [] [] | 10
+     findutils       |       []    []    [] []    [] []    []    []    [] |  9
+     flex            |             []    []       []                   [] |  4
+     gcal            |       []          []          []    []          [] |  5
+     gettext         |    [] []    []    []       [] [] [] [] []    [] [] | 12
+     grep            |       []    []    []       [] [] [] []    [] [] [] | 10
+     hello           |       []    []    []       [] [] [] [] []    [] [] | 10
+     id-utils        |       []          []                []             |  3
+     indent          |    [] []                   []       []    []       |  5
+     libc            |       []    []    []       [] []    []          [] |  7
+     m4              |       []          []    []    []          []    [] |  6
+     make            |       []    []    []       [] []    []             |  6
+     music           |                   []                []             |  2
+     ptx             |       []    []    []          [] [] [] []       [] |  8
+     recode          |    [] []    []    []          []    [] []    [] [] |  9
+     sh-utils        |       []    []    []          [] [] [] []       [] |  8
+     sharutils       |       []    []    []          []                [] |  5
+     tar             |       []          [] []    [] [] [] [] []    [] [] | 10
+     texinfo         |       []          []                               |  2
+     textutils       | []    []    []    []       [] [] [] []          [] |  9
+     wdiff           | []    []    []    []          [] [] []          [] |  8
+                     `----------------------------------------------------'
+       17 languages    cs da de en es fi fr it ja ko nl no pl pt ru sl sv
+       27 packages      3  3 25  1 18  1 26  2  1 12 20  9 19  7  4  7 17  175
+
+   Some counters in the preceding matrix are higher than the number of
+visible blocks let us expect.  This is because a few extra PO files are
+used for implementing regional variants of languages, or language
+dialects.
+
+   For a PO file in the matrix above to be effective, the package to
+which it applies should also have been internationalized and
+distributed as such by its maintainer.  There might be an observable
+lag between the mere existence a PO file and its wide availability in a
+distribution.
 
-   If November 1995 seems to be old, you may fetch a more recent copy
+   If December 1997 seems to be old, you may fetch a more recent copy
 of this `ABOUT-NLS' file on most GNU archive sites.
 
diff -urN gnupg-0.2.8/ChangeLog gnupg-0.2.9/ChangeLog
--- gnupg-0.2.8/ChangeLog	Tue Feb 24 15:59:50 1998
+++ gnupg-0.2.9/ChangeLog	Thu Feb 26 17:10:51 1998
@@ -1,3 +1,20 @@
+Thu Feb 26 17:09:27 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* configure.in, acinclude.m4, intl/, po/: New macros taken
+	from GNOME, switched to automake 1.2f
+
+Thu Feb 26 09:05:46 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* configure.in (doc/Makefile): New
+
+Thu Feb 26 07:40:47 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* configure.in: Changed gettext stuff
+
+Wed Feb 25 11:44:10 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* checks/*test : restructured the directory.
+
 Tue Feb 24 15:59:12 1998  Werner Koch  (wk@isil.d.shuttle.de)
 
 	* configure.in: Changed the name of the package to GNUPG and
diff -urN gnupg-0.2.8/INSTALL gnupg-0.2.9/INSTALL
--- gnupg-0.2.8/INSTALL	Tue Feb 24 11:42:52 1998
+++ gnupg-0.2.9/INSTALL	Thu Feb 26 13:39:14 1998
@@ -33,13 +33,36 @@
 Don't forget to delete "config.cache" and run "./config.status --recheck".
 
 
+The Random Device
+=================
+The current version of GNUPG needs the support of a random device.
+If there is no such device, it uses a very simple RNG, which does
+not generate strong random numbers.
+Random devices are available in Linux, FreeBSD and OpenBSD.
+The device files may not exist on your system, please check this
+and create them if needed.
+
+The Linux files should look like this:
+    cr--r--r--	 1 root     sys        1,   8 May 28  1997 /dev/random
+    cr--r--r--	 1 root     sys        1,   9 Feb 16 08:23 /dev/urandom
+You can create them with:
+    mknod /dev/random c 1 8
+    mknod /dev/random c 1 8
+
+The FreeBSD files [from the 970202 snapshot]:
+    crw-r--r--	1 root	wheel	 2,   3 Feb 25 16:54 /dev/random
+    crw-r--r--	1 root	wheel	 2,   4 Feb 25 16:54 /dev/urandom
+You can create them with:
+    mknod /dev/random  c 2 3
+    mknod /dev/urandom c 2 4
+
 
 
 Installation
 ============
-pgp is not installed as suid:root; if you want to do it, do it manually.
+gpg is not installed as suid:root; if you want to do it, do it manually.
 
-The ~/.gpg directory will be created if it does not exist.  Your first
+The ~/.gnupg directory will be created if it does not exist.  Your first
 action should be to create a key pair: "gpg --gen-key".
 
 
diff -urN gnupg-0.2.8/Makefile.am gnupg-0.2.9/Makefile.am
--- gnupg-0.2.8/Makefile.am	Wed Feb 18 17:34:07 1998
+++ gnupg-0.2.9/Makefile.am	Thu Feb 26 14:46:05 1998
@@ -1,6 +1,6 @@
 ## Process this file with automake to produce Makefile.in
 
-SUBDIRS =  intl po zlib util mpi cipher tools g10 checks
+SUBDIRS =  intl po zlib util mpi cipher tools g10 doc checks
 EXTRA_DIST = VERSION
 
 
diff -urN gnupg-0.2.8/Makefile.in gnupg-0.2.9/Makefile.in
--- gnupg-0.2.8/Makefile.in	Tue Feb 24 18:11:38 1998
+++ gnupg-0.2.9/Makefile.in	Thu Feb 26 17:13:08 1998
@@ -1,6 +1,6 @@
-# Makefile.in generated automatically by automake 1.2d from Makefile.am
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
 
-# Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -72,21 +72,27 @@
 GENCAT = @GENCAT@
 GMOFILES = @GMOFILES@
 GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
 INSTOBJEXT = @INSTOBJEXT@
 INTLDEPS = @INTLDEPS@
 INTLLIBS = @INTLLIBS@
 INTLOBJS = @INTLOBJS@
-INTLSUB = @INTLSUB@
+MKINSTALLDIRS = @MKINSTALLDIRS@
 MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
 MSGFMT = @MSGFMT@
 PACKAGE = @PACKAGE@
 POFILES = @POFILES@
 POSUB = @POSUB@
 RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
 VERSION = @VERSION@
 ZLIBS = @ZLIBS@
+l = @l@
 
-SUBDIRS =  intl po zlib util mpi cipher tools g10 checks
+SUBDIRS =  intl po zlib util mpi cipher tools g10 doc checks
 EXTRA_DIST = VERSION
 ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
 mkinstalldirs = $(SHELL) $(top_srcdir)/scripts/mkinstalldirs
@@ -189,8 +195,12 @@
 	list='$(SUBDIRS)'; for subdir in $$list; do \
 	  test -f $$subdir/TAGS && tags="$$tags -i $$here/$$subdir/TAGS"; \
 	done; \
-	test -z "$(ETAGS_ARGS)config.h.in$(SOURCES)$(HEADERS)$(LISP)$$tags" \
-	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags config.h.in $(SOURCES) $(HEADERS) $(LISP) -o $$here/TAGS)
+	list='$(SOURCES) $(HEADERS)'; \
+	unique=`for i in $$list; do echo $$i; done | \
+	  awk '    { files[$$0] = 1; } \
+	       END { for (i in files) print i; }'`; \
+	test -z "$(ETAGS_ARGS)config.h.in$$unique$(LISP)$$tags" \
+	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags config.h.in $$unique $(LISP) -o $$here/TAGS)
 
 mostlyclean-tags:
 
diff -urN gnupg-0.2.8/NEWS gnupg-0.2.9/NEWS
--- gnupg-0.2.8/NEWS	Tue Feb 24 16:12:45 1998
+++ gnupg-0.2.9/NEWS	Thu Feb 26 17:08:43 1998
@@ -1,3 +1,12 @@
+Noteworthy changes in version 0.2.9
+-----------------------------------
+
+    * Fixed FreeBSD bug.
+
+    * Added a simple man page.
+
+    * Switched to automake1.2f and a newer gettext.
+
 Noteworthy changes in version 0.2.8
 -----------------------------------
 
@@ -40,7 +49,7 @@
 -----------------------------------
 
     * Added zlib for systems which don't have it.
-      Use "./configure --with-zlib" to link with thi static version
+      Use "./configure --with-zlib" to link with the static version.
 
     * Generalized some more functions and rewrote the encoding of
       message digests into MPIs.
diff -urN gnupg-0.2.8/README gnupg-0.2.9/README
--- gnupg-0.2.8/README	Tue Feb 24 16:19:48 1998
+++ gnupg-0.2.9/README	Thu Feb 26 08:42:11 1998
@@ -82,11 +82,10 @@
 
     Key generation shows progress by printing different characters to
     stderr:
-	     "."  Miller-Rabin test failed.
+	     "."  Last 10 Miller-Rabin tests failed.
 	     "+"  Miller-Rabin test succeeded.
 	     "!"  Reloading the pool with fresh prime numbers
 	     "^"  Checking a new value for the generator
-	     "~"  Issued during generator checks
 	     "<"  Size of one factor decreased
 	     ">"  Size of one factor increased
 
@@ -204,7 +203,7 @@
     -----------------------
     There are several ways to specify a userID, here are some examples:
 
-    * Only by the short keyid (prepend a zero if it start with A..F):
+    * Only by the short keyid (prepend a zero if it begins with A..F):
 
 	"234567C4"
 	"0F34E556E"
diff -urN gnupg-0.2.8/TODO gnupg-0.2.9/TODO
--- gnupg-0.2.8/TODO	Tue Feb 24 17:15:54 1998
+++ gnupg-0.2.9/TODO	Wed Feb 25 10:24:16 1998
@@ -1,6 +1,7 @@
 
     * improve iobuf by reading more than one byte at once,
       this shoud espceially done for the buffer in the chain.
+      Change the buffering to a mbuf like scheme? Need it for PSST anyway.
     * add a way to difference between errors and eof in the underflow/flush
       function of iobuf.
     * add checking of armor trailers
diff -urN gnupg-0.2.8/acinclude.m4 gnupg-0.2.9/acinclude.m4
--- gnupg-0.2.8/acinclude.m4	Mon Feb  9 12:26:36 1998
+++ gnupg-0.2.9/acinclude.m4	Thu Feb 26 16:37:01 1998
@@ -1,107 +1,306 @@
 dnl macros to configure g10
 
-AC_PREREQ(2.5)
 
-AC_DEFUN(md_TYPE_PTRDIFF_T,
-  [AC_CACHE_CHECK([for ptrdiff_t], ac_cv_type_ptrdiff_t,
-     [AC_TRY_COMPILE(stddef.h, [ptrdiff_t p], ac_cv_type_ptrdiff_t=yes,
-		     ac_cv_type_ptrdiff_t=no)])
-   if test $ac_cv_type_ptrdiff_t = yes; then
-     AC_DEFINE(HAVE_PTRDIFF_T)
-   fi
-])
+dnl WK_MSG_PRINT(STRING)
+dnl print a message
+dnl
+define(WK_MSG_PRINT,
+  [ echo $ac_n "$1"" $ac_c" 1>&AC_FD_MSG
+  ])
 
-AC_DEFUN(md_PATH_PROG,
-  [AC_PATH_PROG($1,$2,$3)dnl
-   if echo $$1 | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's $2.  (Better remove it.) >&AC_FD_MSG"
-     ac_cv_path_$1=$2
-     $1=$2
-   fi
+
+dnl WK_CHECK_TYPEDEF(TYPE, HAVE_NAME)
+dnl Check wether a typedef exists and create a #define $2 if it exists
+dnl
+AC_DEFUN(WK_CHECK_TYPEDEF,
+  [ AC_MSG_CHECKING(for $1 typedef)
+    AC_CACHE_VAL(wk_cv_typedef_$1,
+    [AC_TRY_COMPILE([#include <stdlib.h>
+    #include <sys/types.h>], [
+    #undef $1
+    int a = sizeof($1);
+    ], wk_cv_typedef_$1=yes, wk_cv_typedef_$1=no )])
+    AC_MSG_RESULT($wk_cv_typedef_$1)
+    if test "$wk_cv_typedef_$1" = yes; then
+	AC_DEFINE($2)
+    fi
+  ])
+
+
+
+dnl WK_LINK_FILES( SRC, DEST )
+dnl same as AC_LINK_FILES, but collect the files to link in
+dnl some special variables and do the link
+dnl when WK_DO_LINK_FILES is called
+dnl This is a workaround for AC_LINK_FILES, because it does not work
+dnl correct when using a caching scheme
+dnl
+define(WK_LINK_FILES,
+  [ if test "x$wk_link_files_src" = "x"; then
+	wk_link_files_src="$1"
+	wk_link_files_dst="$2"
+    else
+	wk_link_files_src="$wk_link_files_src $1"
+	wk_link_files_dst="$wk_link_files_dst $2"
+    fi
+  ])
+define(WK_DO_LINK_FILES,
+  [ AC_LINK_FILES( $wk_link_files_src, $wk_link_files_dst )
+  ])
+
+
+dnl WK_CHECK_ENDIAN
+dnl define either LITTLE_ENDIAN_HOST or BIG_ENDIAN_HOST
+dnl
+define(WK_CHECK_ENDIAN,
+  [ if test "$cross_compiling" = yes; then
+	AC_MSG_WARN(cross compiling; assuming little endianess)
+    fi
+    AC_MSG_CHECKING(endianess)
+    AC_CACHE_VAL(wk_cv_c_endian,
+      [ wk_cv_c_endian=unknown
+	# See if sys/param.h defines the BYTE_ORDER macro.
+	AC_TRY_COMPILE([#include <sys/types.h>
+	#include <sys/param.h>], [
+	#if !BYTE_ORDER || !BIG_ENDIAN || !LITTLE_ENDIAN
+	 bogus endian macros
+	#endif], [# It does; now see whether it defined to BIG_ENDIAN or not.
+	AC_TRY_COMPILE([#include <sys/types.h>
+	#include <sys/param.h>], [
+	#if BYTE_ORDER != BIG_ENDIAN
+	 not big endian
+	#endif], wk_cv_c_endian=big, wk_cv_c_endian=little)])
+	if test "$wk_cv_c_endian" = unknown; then
+	    AC_TRY_RUN([main () {
+	      /* Are we little or big endian?  From Harbison&Steele.  */
+	      union
+	      {
+		long l;
+		char c[sizeof (long)];
+	      } u;
+	      u.l = 1;
+	      exit (u.c[sizeof (long) - 1] == 1);
+	      }],
+	      wk_cv_c_endian=little,
+	      wk_cv_c_endian=big,
+	      wk_cv_c_endian=little
+	    )
+	fi
+      ])
+    AC_MSG_RESULT([$wk_cv_c_endian])
+    if test "$wk_cv_c_endian" = little; then
+      AC_DEFINE(LITTLE_ENDIAN_HOST)
+    else
+      AC_DEFINE(BIG_ENDIAN_HOST)
+    fi
+  ])
+
+dnl WK_CHECK_CACHE
+dnl
+define(WK_CHECK_CACHE,
+  [ AC_MSG_CHECKING(cached information)
+    wk_hostcheck="$target"
+    AC_CACHE_VAL(wk_cv_hostcheck, [ wk_cv_hostcheck="$wk_hostcheck" ])
+    if test "$wk_cv_hostcheck" != "$wk_hostcheck"; then
+	AC_MSG_RESULT(changed)
+	AC_MSG_WARN(config.cache exists!)
+	AC_MSG_ERROR(you must do 'make distclean' first to compile for
+		 different target or different parameters.)
+    else
+	AC_MSG_RESULT(ok)
+    fi
+  ])
+
+
+######################################################################
+# progtest.m4 from gettext 0.32
+######################################################################
+# Search path for a program which passes the given test.
+# Ulrich Drepper <drepper@cygnus.com>, 1996.
+#
+# This file file be copied and used freely without restrictions.  It can
+# be used in projects which are not available under the GNU Public License
+# but which still want to provide support for the GNU gettext functionality.
+# Please note that the actual code is *not* freely available.
+
+# serial 1
+
+dnl AM_PATH_PROG_WITH_TEST(VARIABLE, PROG-TO-CHECK-FOR,
+dnl   TEST-PERFORMED-ON-FOUND_PROGRAM [, VALUE-IF-NOT-FOUND [, PATH]])
+AC_DEFUN(AM_PATH_PROG_WITH_TEST,
+[# Extract the first word of "$2", so it can be a program name with args.
+set dummy $2; ac_word=[$]2
+AC_MSG_CHECKING([for $ac_word])
+AC_CACHE_VAL(ac_cv_path_$1,
+[case "[$]$1" in
+  /*)
+  ac_cv_path_$1="[$]$1" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS=   }"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in ifelse([$5], , $PATH, [$5]); do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if [$3]; then
+	ac_cv_path_$1="$ac_dir/$ac_word"
+	break
+      fi
+    fi
+  done
+  IFS="$ac_save_ifs"
+dnl If no 4th arg is given, leave the cache variable unset,
+dnl so AC_PATH_PROGS will keep looking.
+ifelse([$4], , , [  test -z "[$]ac_cv_path_$1" && ac_cv_path_$1="$4"
+])dnl
+  ;;
+esac])dnl
+$1="$ac_cv_path_$1"
+if test -n "[$]$1"; then
+  AC_MSG_RESULT([$]$1)
+else
+  AC_MSG_RESULT(no)
+fi
+AC_SUBST($1)dnl
 ])
 
-dnl Check NLS options
 
-AC_DEFUN(ud_LC_MESSAGES,
+######################################################################
+# lcmessage.m4 from gettext 0.32
+######################################################################
+# Check whether LC_MESSAGES is available in <locale.h>.
+# Ulrich Drepper <drepper@cygnus.com>, 1995.
+#
+# This file file be copied and used freely without restrictions.  It can
+# be used in projects which are not available under the GNU Public License
+# but which still want to provide support for the GNU gettext functionality.
+# Please note that the actual code is *not* freely available.
+
+# serial 1
+
+AC_DEFUN(AM_LC_MESSAGES,
   [if test $ac_cv_header_locale_h = yes; then
-    AC_CACHE_CHECK([for LC_MESSAGES], ud_cv_val_LC_MESSAGES,
+    AC_CACHE_CHECK([for LC_MESSAGES], am_cv_val_LC_MESSAGES,
       [AC_TRY_LINK([#include <locale.h>], [return LC_MESSAGES],
-       ud_cv_val_LC_MESSAGES=yes, ud_cv_val_LC_MESSAGES=no)])
-    if test $ud_cv_val_LC_MESSAGES = yes; then
+       am_cv_val_LC_MESSAGES=yes, am_cv_val_LC_MESSAGES=no)])
+    if test $am_cv_val_LC_MESSAGES = yes; then
       AC_DEFINE(HAVE_LC_MESSAGES)
     fi
   fi])
 
-AC_DEFUN(ud_WITH_NLS,
+
+
+######################################################################
+# gettext.m4 from gettext 0.32
+######################################################################
+# Macro to add for using GNU gettext.
+# Ulrich Drepper <drepper@cygnus.com>, 1995.
+#
+# This file file be copied and used freely without restrictions.  It can
+# be used in projects which are not available under the GNU Public License
+# but which still want to provide support for the GNU gettext functionality.
+# Please note that the actual code is *not* freely available.
+
+# serial 3
+
+AC_DEFUN(AM_WITH_NLS,
   [AC_MSG_CHECKING([whether NLS is requested])
     dnl Default is enabled NLS
     AC_ARG_ENABLE(nls,
       [  --disable-nls		 do not use Native Language Support],
-      nls_cv_use_nls=$enableval, nls_cv_use_nls=yes)
-    AC_MSG_RESULT($nls_cv_use_nls)
+      USE_NLS=$enableval, USE_NLS=yes)
+    AC_MSG_RESULT($USE_NLS)
+    AC_SUBST(USE_NLS)
+
+    USE_INCLUDED_LIBINTL=no
 
     dnl If we use NLS figure out what method
-    if test "$nls_cv_use_nls" = "yes"; then
+    if test "$USE_NLS" = "yes"; then
       AC_DEFINE(ENABLE_NLS)
-      AC_MSG_CHECKING([for explicitly using GNU gettext])
-      AC_ARG_WITH(gnu-gettext,
-	[  --with-gnu-gettext	   use the GNU gettext library],
+      AC_MSG_CHECKING([whether included gettext is requested])
+      AC_ARG_WITH(included-gettext,
+	[  --with-included-gettext use the GNU gettext library included here],
 	nls_cv_force_use_gnu_gettext=$withval,
 	nls_cv_force_use_gnu_gettext=no)
       AC_MSG_RESULT($nls_cv_force_use_gnu_gettext)
 
-      if test "$nls_cv_force_use_gnu_gettext" = "yes"; then
-	nls_cv_use_gnu_gettext=yes
-      else
+      nls_cv_use_gnu_gettext="$nls_cv_force_use_gnu_gettext"
+      if test "$nls_cv_force_use_gnu_gettext" != "yes"; then
 	dnl User does not insist on using GNU NLS library.  Figure out what
 	dnl to use.  If gettext or catgets are available (in this order) we
 	dnl use this.  Else we have to fall back to GNU NLS library.
-	AC_CHECK_LIB(intl, main)
-	AC_CHECK_LIB(i, main)
+	dnl catgets is only used if permitted by option --with-catgets.
+	nls_cv_header_intl=
+	nls_cv_header_libgt=
 	CATOBJEXT=NONE
 
-	dnl Debian 1.3.1 does not have libintl.h but libintl.a
-	AC_CHECK_HEADER(libintl.h, [ AC_DEFINE(HAVE_LIBINTL_H) ])
-	if    test "$ac_cv_lib_intl_main" = yes \
-	   && test "$ac_cv_header_libintl_h" != "yes" ; then
-	    nls_cv_use_gnu_gettext=yes
-	else
-	    AC_CHECK_FUNC(gettext,
-	      [AC_DEFINE(HAVE_GETTEXT)
-	       md_PATH_PROG(MSGFMT, msgfmt, no)dnl
-	       if test "$MSGFMT" != "no"; then
-		 AC_CHECK_FUNCS(dcgettext)
-		 md_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
-		 md_PATH_PROG(XGETTEXT, xgettext, xgettext)
-		 CATOBJEXT=.mo
-		 INSTOBJEXT=.mo
-		 DATADIRNAME=lib
-		 if test "$ac_cv_lib_intl[_]main" = yes; then
-		   INTLLIBS=-lintl
-		 elif test "$ac_cv_lib_i[_]main" = yes; then
-		   INTLLIBS=-li
+	AC_CHECK_HEADER(libintl.h,
+	  [AC_CACHE_CHECK([for gettext in libc], gt_cv_func_gettext_libc,
+	    [AC_TRY_LINK([#include <libintl.h>], [return (int) gettext ("")],
+	       gt_cv_func_gettext_libc=yes, gt_cv_func_gettext_libc=no)])
+
+	   if test "$gt_cv_func_gettext_libc" != "yes"; then
+	     AC_CHECK_LIB(intl, bindtextdomain,
+	       [AC_CACHE_CHECK([for gettext in libintl],
+		 gt_cv_func_gettext_libintl,
+		 [AC_TRY_LINK([], [return (int) gettext ("")],
+		 gt_cv_func_gettext_libintl=yes,
+		 gt_cv_func_gettext_libintl=no)])])
+	   fi
+
+	   if test "$gt_cv_func_gettext_libc" = "yes" \
+	      || test "$gt_cv_func_gettext_libintl" = "yes"; then
+	      AC_DEFINE(HAVE_GETTEXT)
+	      AM_PATH_PROG_WITH_TEST(MSGFMT, msgfmt,
+		[test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"], no)dnl
+	      if test "$MSGFMT" != "no"; then
+		AC_CHECK_FUNCS(dcgettext)
+		AC_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
+		AM_PATH_PROG_WITH_TEST(XGETTEXT, xgettext,
+		  [test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"], :)
+		AC_TRY_LINK(, [extern int _nl_msg_cat_cntr;
+			       return _nl_msg_cat_cntr],
+		  [CATOBJEXT=.gmo
+		   DATADIRNAME=share],
+		  [CATOBJEXT=.mo
+		   DATADIRNAME=lib])
+		INSTOBJEXT=.mo
+	      fi
+	    fi
+	])
+
+	if test "$CATOBJEXT" = "NONE"; then
+	  AC_MSG_CHECKING([whether catgets can be used])
+	  AC_ARG_WITH(catgets,
+	    [  --with-catgets	       use catgets functions if available],
+	    nls_cv_use_catgets=$withval, nls_cv_use_catgets=no)
+	  AC_MSG_RESULT($nls_cv_use_catgets)
+
+	  if test "$nls_cv_use_catgets" = "yes"; then
+	    dnl No gettext in C library.  Try catgets next.
+	    AC_CHECK_LIB(i, main)
+	    AC_CHECK_FUNC(catgets,
+	      [AC_DEFINE(HAVE_CATGETS)
+	       INTLOBJS="\$(CATOBJS)"
+	       AC_PATH_PROG(GENCAT, gencat, no)dnl
+	       if test "$GENCAT" != "no"; then
+		 AC_PATH_PROG(GMSGFMT, gmsgfmt, no)
+		 if test "$GMSGFMT" = "no"; then
+		   AM_PATH_PROG_WITH_TEST(GMSGFMT, msgfmt,
+		    [test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"], no)
 		 fi
+		 AM_PATH_PROG_WITH_TEST(XGETTEXT, xgettext,
+		   [test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"], :)
+		 USE_INCLUDED_LIBINTL=yes
+		 CATOBJEXT=.cat
+		 INSTOBJEXT=.cat
+		 DATADIRNAME=lib
+		 INTLDEPS='$(top_builddir)/intl/libintl.a'
+		 INTLLIBS=$INTLDEPS
+		 LIBS=`echo $LIBS | sed -e 's/-lintl//'`
+		 nls_cv_header_intl=intl/libintl.h
+		 nls_cv_header_libgt=intl/libgettext.h
 	       fi])
-
-	    if test "$CATOBJEXT" = "NONE"; then
-	      dnl No gettext in C library.  Try catgets next.
-	      AC_CHECK_FUNC(catgets,
-		[AC_DEFINE(HAVE_CATGETS)
-		 INTLOBJS="\$(CATOBJS)"
-		 AC_PATH_PROG(GENCAT, gencat, no)dnl
-		 if test "$GENCAT" != "no"; then
-		   AC_PATH_PROGS(GMSGFMT, [gmsgfmt msgfmt], msgfmt)
-		   md_PATH_PROG(XGETTEXT, xgettext, xgettext)
-		   CATOBJEXT=.cat
-		   INSTOBJEXT=.cat
-		   DATADIRNAME=lib
-		   INTLDEPS="\${top_srcdir}/intl/libintl.a"
-		   INTLLIBS=$INTLDEPS
-		   LIBS=`echo $LIBS | sed -e 's/-lintl//'`
-		   nls_cv_header_intl=libintl.h
-		   nls_cv_header_libgt=intl/libgettext.h
-		 fi])
-	    fi
+	  fi
 	fi
 
 	if test "$CATOBJEXT" = "NONE"; then
@@ -114,29 +313,51 @@
       if test "$nls_cv_use_gnu_gettext" = "yes"; then
 	dnl Mark actions used to generate GNU NLS library.
 	INTLOBJS="\$(GETTOBJS)"
-	md_PATH_PROG(MSGFMT, msgfmt, msgfmt)
-	md_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
-	md_PATH_PROG(XGETTEXT, xgettext, xgettext)
+	AM_PATH_PROG_WITH_TEST(MSGFMT, msgfmt,
+	  [test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"], msgfmt)
+	AC_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
+	AM_PATH_PROG_WITH_TEST(XGETTEXT, xgettext,
+	  [test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"], :)
 	AC_SUBST(MSGFMT)
+	USE_INCLUDED_LIBINTL=yes
 	CATOBJEXT=.gmo
 	INSTOBJEXT=.mo
 	DATADIRNAME=share
-	INTLDEPS="\${top_srcdir}/intl/libintl.a"
+	INTLDEPS='$(top_builddir)/intl/libintl.a'
 	INTLLIBS=$INTLDEPS
 	LIBS=`echo $LIBS | sed -e 's/-lintl//'`
-	nls_cv_header_intl=libintl.h
+	nls_cv_header_intl=intl/libintl.h
 	nls_cv_header_libgt=intl/libgettext.h
       fi
 
-      # We need to process the intl/ and po/ directory.
-      INTLSUB=intl
+      dnl Test whether we really found GNU xgettext.
+      if test "$XGETTEXT" != ":"; then
+	dnl If it is no GNU xgettext we define it as : so that the
+	dnl Makefiles still can work.
+	if $XGETTEXT --omit-header /dev/null 2> /dev/null; then
+	  : ;
+	else
+	  AC_MSG_RESULT(
+	    [found xgettext programs is not GNU xgettext; ignore it])
+	  XGETTEXT=":"
+	fi
+      fi
+
+      # We need to process the po/ directory.
       POSUB=po
     else
       DATADIRNAME=share
-      nls_cv_header_intl=libintl.h
+      nls_cv_header_intl=intl/libintl.h
       nls_cv_header_libgt=intl/libgettext.h
     fi
 
+    # If this is used in GNU gettext we have to set USE_NLS to `yes'
+    # because some of the sources are only built for this goal.
+    if test "$PACKAGE" = gettext; then
+      USE_NLS=yes
+      USE_INCLUDED_LIBINTL=yes
+    fi
+
     dnl These rules are solely for the distribution goal.  While doing this
     dnl we only have to keep exactly one list of the available catalogs
     dnl in configure.in.
@@ -146,6 +367,7 @@
     done
 
     dnl Make all variables we use known to autoconf.
+    AC_SUBST(USE_INCLUDED_LIBINTL)
     AC_SUBST(CATALOGS)
     AC_SUBST(CATOBJEXT)
     AC_SUBST(DATADIRNAME)
@@ -154,7 +376,6 @@
     AC_SUBST(INTLDEPS)
     AC_SUBST(INTLLIBS)
     AC_SUBST(INTLOBJS)
-    AC_SUBST(INTLSUB)
     AC_SUBST(POFILES)
     AC_SUBST(POSUB)
   ])
@@ -163,6 +384,7 @@
   [AC_REQUIRE([AC_PROG_MAKE_SET])dnl
    AC_REQUIRE([AC_PROG_CC])dnl
    AC_REQUIRE([AC_PROG_RANLIB])dnl
+   AC_REQUIRE([AC_ISC_POSIX])dnl
    AC_REQUIRE([AC_HEADER_STDC])dnl
    AC_REQUIRE([AC_C_CONST])dnl
    AC_REQUIRE([AC_C_INLINE])dnl
@@ -171,8 +393,10 @@
    AC_REQUIRE([AC_FUNC_ALLOCA])dnl
    AC_REQUIRE([AC_FUNC_MMAP])dnl
 
-   AC_CHECK_HEADERS([limits.h locale.h nl_types.h malloc.h string.h unistd.h values.h])
-   AC_CHECK_FUNCS([getcwd munmap putenv setenv setlocale strchr strcasecmp])
+   AC_CHECK_HEADERS([argz.h limits.h locale.h nl_types.h malloc.h string.h \
+unistd.h values.h sys/param.h])
+   AC_CHECK_FUNCS([getcwd munmap putenv setenv setlocale strchr strcasecmp \
+__argz_count __argz_stringify __argz_next])
 
    if test "${ac_cv_func_stpcpy+set}" != "set"; then
      AC_CHECK_FUNCS(stpcpy)
@@ -181,8 +405,8 @@
      AC_DEFINE(HAVE_STPCPY)
    fi
 
-   ud_LC_MESSAGES
-   ud_WITH_NLS
+   AM_LC_MESSAGES
+   AM_WITH_NLS
 
    if test "x$CATOBJEXT" != "x"; then
      if test "x$ALL_LINGUAS" = "x"; then
@@ -205,9 +429,20 @@
      fi
    fi
 
+   dnl The reference to <locale.h> in the installed <libintl.h> file
+   dnl must be resolved because we cannot expect the users of this
+   dnl to define HAVE_LOCALE_H.
+   if test $ac_cv_header_locale_h = yes; then
+     INCLUDE_LOCALE_H="#include <locale.h>"
+   else
+     INCLUDE_LOCALE_H="\
+/* The system does not provide the header <locale.h>.  Take care yourself.  */"
+   fi
+   AC_SUBST(INCLUDE_LOCALE_H)
+
    dnl Determine which catalog format we have (if any is needed)
    dnl For now we know about two different formats:
-   dnl	 Linux and the normal X/Open format
+   dnl	 Linux libc-5 and the normal X/Open format
    test -d intl || mkdir intl
    if test "$CATOBJEXT" = ".cat"; then
      AC_CHECK_HEADER(linux/version.h, msgformat=linux, msgformat=xopen)
@@ -220,6 +455,35 @@
    sed -e '/^#.*[^\\]$/d' -e '/^#$/d' \
      $srcdir/intl/po2tbl.sed.in > intl/po2tbl.sed
 
+   dnl In the intl/Makefile.in we have a special dependency which makes
+   dnl only sense for gettext.	We comment this out for non-gettext
+   dnl packages.
+   if test "$PACKAGE" = "gettext"; then
+     GT_NO="#NO#"
+     GT_YES=
+   else
+     GT_NO=
+     GT_YES="#YES#"
+   fi
+   AC_SUBST(GT_NO)
+   AC_SUBST(GT_YES)
+
+   dnl If the AC_CONFIG_AUX_DIR macro for autoconf is used we possibly
+   dnl find the mkinstalldirs script in another subdir but ($top_srcdir).
+   dnl Try to locate is.
+   MKINSTALLDIRS=
+   if test -n "$ac_aux_dir"; then
+     MKINSTALLDIRS="$ac_aux_dir/mkinstalldirs"
+   fi
+   if test -z "$MKINSTALLDIRS"; then
+     MKINSTALLDIRS="\$(top_srcdir)/mkinstalldirs"
+   fi
+   AC_SUBST(MKINSTALLDIRS)
+
+   dnl *** For now the libtool support in intl/Makefile is not for real.
+   l=
+   AC_SUBST(l)
+
    dnl Generate list of files to be processed by xgettext which will
    dnl be included in po/Makefile.
    test -d po || mkdir po
@@ -232,125 +496,10 @@
    else
      posrcprefix="../"
    fi
+   rm -f po/POTFILES
    sed -e "/^#/d" -e "/^\$/d" -e "s,.*, $posrcprefix& \\\\," -e "\$s/\(.*\) \\\\/\1/" \
 	< $srcdir/po/POTFILES.in > po/POTFILES
   ])
 
-
-
-dnl --------------------------------------------------
-dnl G10 stuff
-dnl --------------------------------------------------
-
-
-dnl WK_MSG_PRINT(STRING)
-dnl print a message
-dnl
-define(WK_MSG_PRINT,
-  [ echo $ac_n "$1"" $ac_c" 1>&AC_FD_MSG
-  ])
-
-
-dnl WK_CHECK_TYPEDEF(TYPE, HAVE_NAME)
-dnl Check wether a typedef exists and create a #define $2 if it exists
-dnl
-AC_DEFUN(WK_CHECK_TYPEDEF,
-  [ AC_MSG_CHECKING(for $1 typedef)
-    AC_CACHE_VAL(wk_cv_typedef_$1,
-    [AC_TRY_COMPILE([#include <stdlib.h>
-    #include <sys/types.h>], [
-    #undef $1
-    int a = sizeof($1);
-    ], wk_cv_typedef_$1=yes, wk_cv_typedef_$1=no )])
-    AC_MSG_RESULT($wk_cv_typedef_$1)
-    if test "$wk_cv_typedef_$1" = yes; then
-	AC_DEFINE($2)
-    fi
-  ])
-
-
-
-dnl WK_LINK_FILES( SRC, DEST )
-dnl same as AC_LINK_FILES, but collect the files to link in
-dnl some special variables and do the link
-dnl when WK_DO_LINK_FILES is called
-dnl This is a workaround for AC_LINK_FILES, because it does not work
-dnl correct when using a caching scheme
-dnl
-define(WK_LINK_FILES,
-  [ if test "x$wk_link_files_src" = "x"; then
-	wk_link_files_src="$1"
-	wk_link_files_dst="$2"
-    else
-	wk_link_files_src="$wk_link_files_src $1"
-	wk_link_files_dst="$wk_link_files_dst $2"
-    fi
-  ])
-define(WK_DO_LINK_FILES,
-  [ AC_LINK_FILES( $wk_link_files_src, $wk_link_files_dst )
-  ])
-
-
-dnl WK_CHECK_ENDIAN
-dnl define either LITTLE_ENDIAN_HOST or BIG_ENDIAN_HOST
-dnl
-define(WK_CHECK_ENDIAN,
-  [ if test "$cross_compiling" = yes; then
-	AC_MSG_WARN(cross compiling; assuming little endianess)
-    fi
-    AC_MSG_CHECKING(endianess)
-    AC_CACHE_VAL(wk_cv_c_endian,
-      [ wk_cv_c_endian=unknown
-	# See if sys/param.h defines the BYTE_ORDER macro.
-	AC_TRY_COMPILE([#include <sys/types.h>
-	#include <sys/param.h>], [
-	#if !BYTE_ORDER || !BIG_ENDIAN || !LITTLE_ENDIAN
-	 bogus endian macros
-	#endif], [# It does; now see whether it defined to BIG_ENDIAN or not.
-	AC_TRY_COMPILE([#include <sys/types.h>
-	#include <sys/param.h>], [
-	#if BYTE_ORDER != BIG_ENDIAN
-	 not big endian
-	#endif], wk_cv_c_endian=big, wk_cv_c_endian=little)])
-	if test "$wk_cv_c_endian" = unknown; then
-	    AC_TRY_RUN([main () {
-	      /* Are we little or big endian?  From Harbison&Steele.  */
-	      union
-	      {
-		long l;
-		char c[sizeof (long)];
-	      } u;
-	      u.l = 1;
-	      exit (u.c[sizeof (long) - 1] == 1);
-	      }],
-	      wk_cv_c_endian=little,
-	      wk_cv_c_endian=big,
-	      wk_cv_c_endian=little
-	    )
-	fi
-      ])
-    AC_MSG_RESULT([$wk_cv_c_endian])
-    if test "$wk_cv_c_endian" = little; then
-      AC_DEFINE(LITTLE_ENDIAN_HOST)
-    else
-      AC_DEFINE(BIG_ENDIAN_HOST)
-    fi
-  ])
-
-dnl WK_CHECK_CACHE
-dnl
-define(WK_CHECK_CACHE,
-  [ AC_MSG_CHECKING(cached information)
-    wk_hostcheck="$target"
-    AC_CACHE_VAL(wk_cv_hostcheck, [ wk_cv_hostcheck="$wk_hostcheck" ])
-    if test "$wk_cv_hostcheck" != "$wk_hostcheck"; then
-	AC_MSG_RESULT(changed)
-	AC_MSG_WARN(config.cache exists!)
-	AC_MSG_ERROR(you must do 'make distclean' first to compile for
-		 different target or different parameters.)
-    else
-	AC_MSG_RESULT(ok)
-    fi
-  ])
 
 
diff -urN gnupg-0.2.8/aclocal.m4 gnupg-0.2.9/aclocal.m4
--- gnupg-0.2.8/aclocal.m4	Mon Feb 23 13:25:08 1998
+++ gnupg-0.2.9/aclocal.m4	Thu Feb 26 16:40:36 1998
@@ -1,6 +1,6 @@
-dnl aclocal.m4 generated automatically by aclocal 1.2d
+dnl aclocal.m4 generated automatically by aclocal 1.2f
 
-dnl Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+dnl Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 dnl This Makefile.in is free software; the Free Software Foundation
 dnl gives unlimited permission to copy and/or distribute it,
 dnl with or without modifications, as long as this notice is preserved.
@@ -12,108 +12,301 @@
 
 dnl macros to configure g10
 
-AC_PREREQ(2.5)
 
-AC_DEFUN(md_TYPE_PTRDIFF_T,
-  [AC_CACHE_CHECK([for ptrdiff_t], ac_cv_type_ptrdiff_t,
-     [AC_TRY_COMPILE(stddef.h, [ptrdiff_t p], ac_cv_type_ptrdiff_t=yes,
-		     ac_cv_type_ptrdiff_t=no)])
-   if test $ac_cv_type_ptrdiff_t = yes; then
-     AC_DEFINE(HAVE_PTRDIFF_T)
-   fi
-])
+dnl WK_MSG_PRINT(STRING)
+dnl print a message
+dnl
+define(WK_MSG_PRINT,
+  [ echo $ac_n "$1"" $ac_c" 1>&AC_FD_MSG
+  ])
 
-AC_DEFUN(md_PATH_PROG,
-  [AC_PATH_PROG($1,$2,$3)dnl
-   if echo $$1 | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's $2.  (Better remove it.) >&AC_FD_MSG"
-     ac_cv_path_$1=$2
-     $1=$2
-   fi
+
+dnl WK_CHECK_TYPEDEF(TYPE, HAVE_NAME)
+dnl Check wether a typedef exists and create a #define $2 if it exists
+dnl
+AC_DEFUN(WK_CHECK_TYPEDEF,
+  [ AC_MSG_CHECKING(for $1 typedef)
+    AC_CACHE_VAL(wk_cv_typedef_$1,
+    [AC_TRY_COMPILE([#include <stdlib.h>
+    #include <sys/types.h>], [
+    #undef $1
+    int a = sizeof($1);
+    ], wk_cv_typedef_$1=yes, wk_cv_typedef_$1=no )])
+    AC_MSG_RESULT($wk_cv_typedef_$1)
+    if test "$wk_cv_typedef_$1" = yes; then
+	AC_DEFINE($2)
+    fi
+  ])
+
+
+
+dnl WK_LINK_FILES( SRC, DEST )
+dnl same as AC_LINK_FILES, but collect the files to link in
+dnl some special variables and do the link
+dnl when WK_DO_LINK_FILES is called
+dnl This is a workaround for AC_LINK_FILES, because it does not work
+dnl correct when using a caching scheme
+dnl
+define(WK_LINK_FILES,
+  [ if test "x$wk_link_files_src" = "x"; then
+	wk_link_files_src="$1"
+	wk_link_files_dst="$2"
+    else
+	wk_link_files_src="$wk_link_files_src $1"
+	wk_link_files_dst="$wk_link_files_dst $2"
+    fi
+  ])
+define(WK_DO_LINK_FILES,
+  [ AC_LINK_FILES( $wk_link_files_src, $wk_link_files_dst )
+  ])
+
+
+dnl WK_CHECK_ENDIAN
+dnl define either LITTLE_ENDIAN_HOST or BIG_ENDIAN_HOST
+dnl
+define(WK_CHECK_ENDIAN,
+  [ if test "$cross_compiling" = yes; then
+	AC_MSG_WARN(cross compiling; assuming little endianess)
+    fi
+    AC_MSG_CHECKING(endianess)
+    AC_CACHE_VAL(wk_cv_c_endian,
+      [ wk_cv_c_endian=unknown
+	# See if sys/param.h defines the BYTE_ORDER macro.
+	AC_TRY_COMPILE([#include <sys/types.h>
+	#include <sys/param.h>], [
+	#if !BYTE_ORDER || !BIG_ENDIAN || !LITTLE_ENDIAN
+	 bogus endian macros
+	#endif], [# It does; now see whether it defined to BIG_ENDIAN or not.
+	AC_TRY_COMPILE([#include <sys/types.h>
+	#include <sys/param.h>], [
+	#if BYTE_ORDER != BIG_ENDIAN
+	 not big endian
+	#endif], wk_cv_c_endian=big, wk_cv_c_endian=little)])
+	if test "$wk_cv_c_endian" = unknown; then
+	    AC_TRY_RUN([main () {
+	      /* Are we little or big endian?  From Harbison&Steele.  */
+	      union
+	      {
+		long l;
+		char c[sizeof (long)];
+	      } u;
+	      u.l = 1;
+	      exit (u.c[sizeof (long) - 1] == 1);
+	      }],
+	      wk_cv_c_endian=little,
+	      wk_cv_c_endian=big,
+	      wk_cv_c_endian=little
+	    )
+	fi
+      ])
+    AC_MSG_RESULT([$wk_cv_c_endian])
+    if test "$wk_cv_c_endian" = little; then
+      AC_DEFINE(LITTLE_ENDIAN_HOST)
+    else
+      AC_DEFINE(BIG_ENDIAN_HOST)
+    fi
+  ])
+
+dnl WK_CHECK_CACHE
+dnl
+define(WK_CHECK_CACHE,
+  [ AC_MSG_CHECKING(cached information)
+    wk_hostcheck="$target"
+    AC_CACHE_VAL(wk_cv_hostcheck, [ wk_cv_hostcheck="$wk_hostcheck" ])
+    if test "$wk_cv_hostcheck" != "$wk_hostcheck"; then
+	AC_MSG_RESULT(changed)
+	AC_MSG_WARN(config.cache exists!)
+	AC_MSG_ERROR(you must do 'make distclean' first to compile for
+		 different target or different parameters.)
+    else
+	AC_MSG_RESULT(ok)
+    fi
+  ])
+
+
+# progtest.m4 from gettext 0.32
+# Search path for a program which passes the given test.
+# Ulrich Drepper <drepper@cygnus.com>, 1996.
+#
+# This file file be copied and used freely without restrictions.  It can
+# be used in projects which are not available under the GNU Public License
+# but which still want to provide support for the GNU gettext functionality.
+# Please note that the actual code is *not* freely available.
+
+# serial 1
+
+dnl AM_PATH_PROG_WITH_TEST(VARIABLE, PROG-TO-CHECK-FOR,
+dnl   TEST-PERFORMED-ON-FOUND_PROGRAM [, VALUE-IF-NOT-FOUND [, PATH]])
+AC_DEFUN(AM_PATH_PROG_WITH_TEST,
+[# Extract the first word of "$2", so it can be a program name with args.
+set dummy $2; ac_word=[$]2
+AC_MSG_CHECKING([for $ac_word])
+AC_CACHE_VAL(ac_cv_path_$1,
+[case "[$]$1" in
+  /*)
+  ac_cv_path_$1="[$]$1" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS=   }"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in ifelse([$5], , $PATH, [$5]); do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if [$3]; then
+	ac_cv_path_$1="$ac_dir/$ac_word"
+	break
+      fi
+    fi
+  done
+  IFS="$ac_save_ifs"
+dnl If no 4th arg is given, leave the cache variable unset,
+dnl so AC_PATH_PROGS will keep looking.
+ifelse([$4], , , [  test -z "[$]ac_cv_path_$1" && ac_cv_path_$1="$4"
+])dnl
+  ;;
+esac])dnl
+$1="$ac_cv_path_$1"
+if test -n "[$]$1"; then
+  AC_MSG_RESULT([$]$1)
+else
+  AC_MSG_RESULT(no)
+fi
+AC_SUBST($1)dnl
 ])
 
-dnl Check NLS options
 
-AC_DEFUN(ud_LC_MESSAGES,
+# lcmessage.m4 from gettext 0.32
+# Check whether LC_MESSAGES is available in <locale.h>.
+# Ulrich Drepper <drepper@cygnus.com>, 1995.
+#
+# This file file be copied and used freely without restrictions.  It can
+# be used in projects which are not available under the GNU Public License
+# but which still want to provide support for the GNU gettext functionality.
+# Please note that the actual code is *not* freely available.
+
+# serial 1
+
+AC_DEFUN(AM_LC_MESSAGES,
   [if test $ac_cv_header_locale_h = yes; then
-    AC_CACHE_CHECK([for LC_MESSAGES], ud_cv_val_LC_MESSAGES,
+    AC_CACHE_CHECK([for LC_MESSAGES], am_cv_val_LC_MESSAGES,
       [AC_TRY_LINK([#include <locale.h>], [return LC_MESSAGES],
-       ud_cv_val_LC_MESSAGES=yes, ud_cv_val_LC_MESSAGES=no)])
-    if test $ud_cv_val_LC_MESSAGES = yes; then
+       am_cv_val_LC_MESSAGES=yes, am_cv_val_LC_MESSAGES=no)])
+    if test $am_cv_val_LC_MESSAGES = yes; then
       AC_DEFINE(HAVE_LC_MESSAGES)
     fi
   fi])
 
-AC_DEFUN(ud_WITH_NLS,
+
+
+# gettext.m4 from gettext 0.32
+# Macro to add for using GNU gettext.
+# Ulrich Drepper <drepper@cygnus.com>, 1995.
+#
+# This file file be copied and used freely without restrictions.  It can
+# be used in projects which are not available under the GNU Public License
+# but which still want to provide support for the GNU gettext functionality.
+# Please note that the actual code is *not* freely available.
+
+# serial 3
+
+AC_DEFUN(AM_WITH_NLS,
   [AC_MSG_CHECKING([whether NLS is requested])
     dnl Default is enabled NLS
     AC_ARG_ENABLE(nls,
       [  --disable-nls		 do not use Native Language Support],
-      nls_cv_use_nls=$enableval, nls_cv_use_nls=yes)
-    AC_MSG_RESULT($nls_cv_use_nls)
+      USE_NLS=$enableval, USE_NLS=yes)
+    AC_MSG_RESULT($USE_NLS)
+    AC_SUBST(USE_NLS)
+
+    USE_INCLUDED_LIBINTL=no
 
     dnl If we use NLS figure out what method
-    if test "$nls_cv_use_nls" = "yes"; then
+    if test "$USE_NLS" = "yes"; then
       AC_DEFINE(ENABLE_NLS)
-      AC_MSG_CHECKING([for explicitly using GNU gettext])
-      AC_ARG_WITH(gnu-gettext,
-	[  --with-gnu-gettext	   use the GNU gettext library],
+      AC_MSG_CHECKING([whether included gettext is requested])
+      AC_ARG_WITH(included-gettext,
+	[  --with-included-gettext use the GNU gettext library included here],
 	nls_cv_force_use_gnu_gettext=$withval,
 	nls_cv_force_use_gnu_gettext=no)
       AC_MSG_RESULT($nls_cv_force_use_gnu_gettext)
 
-      if test "$nls_cv_force_use_gnu_gettext" = "yes"; then
-	nls_cv_use_gnu_gettext=yes
-      else
+      nls_cv_use_gnu_gettext="$nls_cv_force_use_gnu_gettext"
+      if test "$nls_cv_force_use_gnu_gettext" != "yes"; then
 	dnl User does not insist on using GNU NLS library.  Figure out what
 	dnl to use.  If gettext or catgets are available (in this order) we
 	dnl use this.  Else we have to fall back to GNU NLS library.
-	AC_CHECK_LIB(intl, main)
-	AC_CHECK_LIB(i, main)
+	dnl catgets is only used if permitted by option --with-catgets.
+	nls_cv_header_intl=
+	nls_cv_header_libgt=
 	CATOBJEXT=NONE
 
-	dnl Debian 1.3.1 does not have libintl.h but libintl.a
-	AC_CHECK_HEADER(libintl.h, [ AC_DEFINE(HAVE_LIBINTL_H) ])
-	if    test "$ac_cv_lib_intl_main" = yes \
-	   && test "$ac_cv_header_libintl_h" != "yes" ; then
-	    nls_cv_use_gnu_gettext=yes
-	else
-	    AC_CHECK_FUNC(gettext,
-	      [AC_DEFINE(HAVE_GETTEXT)
-	       md_PATH_PROG(MSGFMT, msgfmt, no)dnl
-	       if test "$MSGFMT" != "no"; then
-		 AC_CHECK_FUNCS(dcgettext)
-		 md_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
-		 md_PATH_PROG(XGETTEXT, xgettext, xgettext)
-		 CATOBJEXT=.mo
-		 INSTOBJEXT=.mo
-		 DATADIRNAME=lib
-		 if test "$ac_cv_lib_intl[_]main" = yes; then
-		   INTLLIBS=-lintl
-		 elif test "$ac_cv_lib_i[_]main" = yes; then
-		   INTLLIBS=-li
+	AC_CHECK_HEADER(libintl.h,
+	  [AC_CACHE_CHECK([for gettext in libc], gt_cv_func_gettext_libc,
+	    [AC_TRY_LINK([#include <libintl.h>], [return (int) gettext ("")],
+	       gt_cv_func_gettext_libc=yes, gt_cv_func_gettext_libc=no)])
+
+	   if test "$gt_cv_func_gettext_libc" != "yes"; then
+	     AC_CHECK_LIB(intl, bindtextdomain,
+	       [AC_CACHE_CHECK([for gettext in libintl],
+		 gt_cv_func_gettext_libintl,
+		 [AC_TRY_LINK([], [return (int) gettext ("")],
+		 gt_cv_func_gettext_libintl=yes,
+		 gt_cv_func_gettext_libintl=no)])])
+	   fi
+
+	   if test "$gt_cv_func_gettext_libc" = "yes" \
+	      || test "$gt_cv_func_gettext_libintl" = "yes"; then
+	      AC_DEFINE(HAVE_GETTEXT)
+	      AM_PATH_PROG_WITH_TEST(MSGFMT, msgfmt,
+		[test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"], no)dnl
+	      if test "$MSGFMT" != "no"; then
+		AC_CHECK_FUNCS(dcgettext)
+		AC_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
+		AM_PATH_PROG_WITH_TEST(XGETTEXT, xgettext,
+		  [test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"], :)
+		AC_TRY_LINK(, [extern int _nl_msg_cat_cntr;
+			       return _nl_msg_cat_cntr],
+		  [CATOBJEXT=.gmo
+		   DATADIRNAME=share],
+		  [CATOBJEXT=.mo
+		   DATADIRNAME=lib])
+		INSTOBJEXT=.mo
+	      fi
+	    fi
+	])
+
+	if test "$CATOBJEXT" = "NONE"; then
+	  AC_MSG_CHECKING([whether catgets can be used])
+	  AC_ARG_WITH(catgets,
+	    [  --with-catgets	       use catgets functions if available],
+	    nls_cv_use_catgets=$withval, nls_cv_use_catgets=no)
+	  AC_MSG_RESULT($nls_cv_use_catgets)
+
+	  if test "$nls_cv_use_catgets" = "yes"; then
+	    dnl No gettext in C library.  Try catgets next.
+	    AC_CHECK_LIB(i, main)
+	    AC_CHECK_FUNC(catgets,
+	      [AC_DEFINE(HAVE_CATGETS)
+	       INTLOBJS="\$(CATOBJS)"
+	       AC_PATH_PROG(GENCAT, gencat, no)dnl
+	       if test "$GENCAT" != "no"; then
+		 AC_PATH_PROG(GMSGFMT, gmsgfmt, no)
+		 if test "$GMSGFMT" = "no"; then
+		   AM_PATH_PROG_WITH_TEST(GMSGFMT, msgfmt,
+		    [test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"], no)
 		 fi
+		 AM_PATH_PROG_WITH_TEST(XGETTEXT, xgettext,
+		   [test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"], :)
+		 USE_INCLUDED_LIBINTL=yes
+		 CATOBJEXT=.cat
+		 INSTOBJEXT=.cat
+		 DATADIRNAME=lib
+		 INTLDEPS='$(top_builddir)/intl/libintl.a'
+		 INTLLIBS=$INTLDEPS
+		 LIBS=`echo $LIBS | sed -e 's/-lintl//'`
+		 nls_cv_header_intl=intl/libintl.h
+		 nls_cv_header_libgt=intl/libgettext.h
 	       fi])
-
-	    if test "$CATOBJEXT" = "NONE"; then
-	      dnl No gettext in C library.  Try catgets next.
-	      AC_CHECK_FUNC(catgets,
-		[AC_DEFINE(HAVE_CATGETS)
-		 INTLOBJS="\$(CATOBJS)"
-		 AC_PATH_PROG(GENCAT, gencat, no)dnl
-		 if test "$GENCAT" != "no"; then
-		   AC_PATH_PROGS(GMSGFMT, [gmsgfmt msgfmt], msgfmt)
-		   md_PATH_PROG(XGETTEXT, xgettext, xgettext)
-		   CATOBJEXT=.cat
-		   INSTOBJEXT=.cat
-		   DATADIRNAME=lib
-		   INTLDEPS="\${top_srcdir}/intl/libintl.a"
-		   INTLLIBS=$INTLDEPS
-		   LIBS=`echo $LIBS | sed -e 's/-lintl//'`
-		   nls_cv_header_intl=libintl.h
-		   nls_cv_header_libgt=intl/libgettext.h
-		 fi])
-	    fi
+	  fi
 	fi
 
 	if test "$CATOBJEXT" = "NONE"; then
@@ -126,29 +319,51 @@
       if test "$nls_cv_use_gnu_gettext" = "yes"; then
 	dnl Mark actions used to generate GNU NLS library.
 	INTLOBJS="\$(GETTOBJS)"
-	md_PATH_PROG(MSGFMT, msgfmt, msgfmt)
-	md_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
-	md_PATH_PROG(XGETTEXT, xgettext, xgettext)
+	AM_PATH_PROG_WITH_TEST(MSGFMT, msgfmt,
+	  [test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"], msgfmt)
+	AC_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
+	AM_PATH_PROG_WITH_TEST(XGETTEXT, xgettext,
+	  [test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"], :)
 	AC_SUBST(MSGFMT)
+	USE_INCLUDED_LIBINTL=yes
 	CATOBJEXT=.gmo
 	INSTOBJEXT=.mo
 	DATADIRNAME=share
-	INTLDEPS="\${top_srcdir}/intl/libintl.a"
+	INTLDEPS='$(top_builddir)/intl/libintl.a'
 	INTLLIBS=$INTLDEPS
 	LIBS=`echo $LIBS | sed -e 's/-lintl//'`
-	nls_cv_header_intl=libintl.h
+	nls_cv_header_intl=intl/libintl.h
 	nls_cv_header_libgt=intl/libgettext.h
       fi
 
-      # We need to process the intl/ and po/ directory.
-      INTLSUB=intl
+      dnl Test whether we really found GNU xgettext.
+      if test "$XGETTEXT" != ":"; then
+	dnl If it is no GNU xgettext we define it as : so that the
+	dnl Makefiles still can work.
+	if $XGETTEXT --omit-header /dev/null 2> /dev/null; then
+	  : ;
+	else
+	  AC_MSG_RESULT(
+	    [found xgettext programs is not GNU xgettext; ignore it])
+	  XGETTEXT=":"
+	fi
+      fi
+
+      # We need to process the po/ directory.
       POSUB=po
     else
       DATADIRNAME=share
-      nls_cv_header_intl=libintl.h
+      nls_cv_header_intl=intl/libintl.h
       nls_cv_header_libgt=intl/libgettext.h
     fi
 
+    # If this is used in GNU gettext we have to set USE_NLS to `yes'
+    # because some of the sources are only built for this goal.
+    if test "$PACKAGE" = gettext; then
+      USE_NLS=yes
+      USE_INCLUDED_LIBINTL=yes
+    fi
+
     dnl These rules are solely for the distribution goal.  While doing this
     dnl we only have to keep exactly one list of the available catalogs
     dnl in configure.in.
@@ -158,6 +373,7 @@
     done
 
     dnl Make all variables we use known to autoconf.
+    AC_SUBST(USE_INCLUDED_LIBINTL)
     AC_SUBST(CATALOGS)
     AC_SUBST(CATOBJEXT)
     AC_SUBST(DATADIRNAME)
@@ -166,7 +382,6 @@
     AC_SUBST(INTLDEPS)
     AC_SUBST(INTLLIBS)
     AC_SUBST(INTLOBJS)
-    AC_SUBST(INTLSUB)
     AC_SUBST(POFILES)
     AC_SUBST(POSUB)
   ])
@@ -175,6 +390,7 @@
   [AC_REQUIRE([AC_PROG_MAKE_SET])dnl
    AC_REQUIRE([AC_PROG_CC])dnl
    AC_REQUIRE([AC_PROG_RANLIB])dnl
+   AC_REQUIRE([AC_ISC_POSIX])dnl
    AC_REQUIRE([AC_HEADER_STDC])dnl
    AC_REQUIRE([AC_C_CONST])dnl
    AC_REQUIRE([AC_C_INLINE])dnl
@@ -183,8 +399,10 @@
    AC_REQUIRE([AC_FUNC_ALLOCA])dnl
    AC_REQUIRE([AC_FUNC_MMAP])dnl
 
-   AC_CHECK_HEADERS([limits.h locale.h nl_types.h malloc.h string.h unistd.h values.h])
-   AC_CHECK_FUNCS([getcwd munmap putenv setenv setlocale strchr strcasecmp])
+   AC_CHECK_HEADERS([argz.h limits.h locale.h nl_types.h malloc.h string.h \
+unistd.h values.h sys/param.h])
+   AC_CHECK_FUNCS([getcwd munmap putenv setenv setlocale strchr strcasecmp \
+__argz_count __argz_stringify __argz_next])
 
    if test "${ac_cv_func_stpcpy+set}" != "set"; then
      AC_CHECK_FUNCS(stpcpy)
@@ -193,8 +411,8 @@
      AC_DEFINE(HAVE_STPCPY)
    fi
 
-   ud_LC_MESSAGES
-   ud_WITH_NLS
+   AM_LC_MESSAGES
+   AM_WITH_NLS
 
    if test "x$CATOBJEXT" != "x"; then
      if test "x$ALL_LINGUAS" = "x"; then
@@ -217,9 +435,20 @@
      fi
    fi
 
+   dnl The reference to <locale.h> in the installed <libintl.h> file
+   dnl must be resolved because we cannot expect the users of this
+   dnl to define HAVE_LOCALE_H.
+   if test $ac_cv_header_locale_h = yes; then
+     INCLUDE_LOCALE_H="#include <locale.h>"
+   else
+     INCLUDE_LOCALE_H="\
+/* The system does not provide the header <locale.h>.  Take care yourself.  */"
+   fi
+   AC_SUBST(INCLUDE_LOCALE_H)
+
    dnl Determine which catalog format we have (if any is needed)
    dnl For now we know about two different formats:
-   dnl	 Linux and the normal X/Open format
+   dnl	 Linux libc-5 and the normal X/Open format
    test -d intl || mkdir intl
    if test "$CATOBJEXT" = ".cat"; then
      AC_CHECK_HEADER(linux/version.h, msgformat=linux, msgformat=xopen)
@@ -232,6 +461,35 @@
    sed -e '/^#.*[^\\]$/d' -e '/^#$/d' \
      $srcdir/intl/po2tbl.sed.in > intl/po2tbl.sed
 
+   dnl In the intl/Makefile.in we have a special dependency which makes
+   dnl only sense for gettext.	We comment this out for non-gettext
+   dnl packages.
+   if test "$PACKAGE" = "gettext"; then
+     GT_NO="#NO#"
+     GT_YES=
+   else
+     GT_NO=
+     GT_YES="#YES#"
+   fi
+   AC_SUBST(GT_NO)
+   AC_SUBST(GT_YES)
+
+   dnl If the AC_CONFIG_AUX_DIR macro for autoconf is used we possibly
+   dnl find the mkinstalldirs script in another subdir but ($top_srcdir).
+   dnl Try to locate is.
+   MKINSTALLDIRS=
+   if test -n "$ac_aux_dir"; then
+     MKINSTALLDIRS="$ac_aux_dir/mkinstalldirs"
+   fi
+   if test -z "$MKINSTALLDIRS"; then
+     MKINSTALLDIRS="\$(top_srcdir)/mkinstalldirs"
+   fi
+   AC_SUBST(MKINSTALLDIRS)
+
+   dnl *** For now the libtool support in intl/Makefile is not for real.
+   l=
+   AC_SUBST(l)
+
    dnl Generate list of files to be processed by xgettext which will
    dnl be included in po/Makefile.
    test -d po || mkdir po
@@ -244,126 +502,11 @@
    else
      posrcprefix="../"
    fi
+   rm -f po/POTFILES
    sed -e "/^#/d" -e "/^\$/d" -e "s,.*, $posrcprefix& \\\\," -e "\$s/\(.*\) \\\\/\1/" \
 	< $srcdir/po/POTFILES.in > po/POTFILES
   ])
 
-
-
-dnl --------------------------------------------------
-dnl G10 stuff
-dnl --------------------------------------------------
-
-
-dnl WK_MSG_PRINT(STRING)
-dnl print a message
-dnl
-define(WK_MSG_PRINT,
-  [ echo $ac_n "$1"" $ac_c" 1>&AC_FD_MSG
-  ])
-
-
-dnl WK_CHECK_TYPEDEF(TYPE, HAVE_NAME)
-dnl Check wether a typedef exists and create a #define $2 if it exists
-dnl
-AC_DEFUN(WK_CHECK_TYPEDEF,
-  [ AC_MSG_CHECKING(for $1 typedef)
-    AC_CACHE_VAL(wk_cv_typedef_$1,
-    [AC_TRY_COMPILE([#include <stdlib.h>
-    #include <sys/types.h>], [
-    #undef $1
-    int a = sizeof($1);
-    ], wk_cv_typedef_$1=yes, wk_cv_typedef_$1=no )])
-    AC_MSG_RESULT($wk_cv_typedef_$1)
-    if test "$wk_cv_typedef_$1" = yes; then
-	AC_DEFINE($2)
-    fi
-  ])
-
-
-
-dnl WK_LINK_FILES( SRC, DEST )
-dnl same as AC_LINK_FILES, but collect the files to link in
-dnl some special variables and do the link
-dnl when WK_DO_LINK_FILES is called
-dnl This is a workaround for AC_LINK_FILES, because it does not work
-dnl correct when using a caching scheme
-dnl
-define(WK_LINK_FILES,
-  [ if test "x$wk_link_files_src" = "x"; then
-	wk_link_files_src="$1"
-	wk_link_files_dst="$2"
-    else
-	wk_link_files_src="$wk_link_files_src $1"
-	wk_link_files_dst="$wk_link_files_dst $2"
-    fi
-  ])
-define(WK_DO_LINK_FILES,
-  [ AC_LINK_FILES( $wk_link_files_src, $wk_link_files_dst )
-  ])
-
-
-dnl WK_CHECK_ENDIAN
-dnl define either LITTLE_ENDIAN_HOST or BIG_ENDIAN_HOST
-dnl
-define(WK_CHECK_ENDIAN,
-  [ if test "$cross_compiling" = yes; then
-	AC_MSG_WARN(cross compiling; assuming little endianess)
-    fi
-    AC_MSG_CHECKING(endianess)
-    AC_CACHE_VAL(wk_cv_c_endian,
-      [ wk_cv_c_endian=unknown
-	# See if sys/param.h defines the BYTE_ORDER macro.
-	AC_TRY_COMPILE([#include <sys/types.h>
-	#include <sys/param.h>], [
-	#if !BYTE_ORDER || !BIG_ENDIAN || !LITTLE_ENDIAN
-	 bogus endian macros
-	#endif], [# It does; now see whether it defined to BIG_ENDIAN or not.
-	AC_TRY_COMPILE([#include <sys/types.h>
-	#include <sys/param.h>], [
-	#if BYTE_ORDER != BIG_ENDIAN
-	 not big endian
-	#endif], wk_cv_c_endian=big, wk_cv_c_endian=little)])
-	if test "$wk_cv_c_endian" = unknown; then
-	    AC_TRY_RUN([main () {
-	      /* Are we little or big endian?  From Harbison&Steele.  */
-	      union
-	      {
-		long l;
-		char c[sizeof (long)];
-	      } u;
-	      u.l = 1;
-	      exit (u.c[sizeof (long) - 1] == 1);
-	      }],
-	      wk_cv_c_endian=little,
-	      wk_cv_c_endian=big,
-	      wk_cv_c_endian=little
-	    )
-	fi
-      ])
-    AC_MSG_RESULT([$wk_cv_c_endian])
-    if test "$wk_cv_c_endian" = little; then
-      AC_DEFINE(LITTLE_ENDIAN_HOST)
-    else
-      AC_DEFINE(BIG_ENDIAN_HOST)
-    fi
-  ])
-
-dnl WK_CHECK_CACHE
-dnl
-define(WK_CHECK_CACHE,
-  [ AC_MSG_CHECKING(cached information)
-    wk_hostcheck="$target"
-    AC_CACHE_VAL(wk_cv_hostcheck, [ wk_cv_hostcheck="$wk_hostcheck" ])
-    if test "$wk_cv_hostcheck" != "$wk_hostcheck"; then
-	AC_MSG_RESULT(changed)
-	AC_MSG_WARN(config.cache exists!)
-	AC_MSG_ERROR(you must do 'make distclean' first to compile for
-		 different target or different parameters.)
-    else
-	AC_MSG_RESULT(ok)
-    fi
-  ])
 
 
 
diff -urN gnupg-0.2.8/checks/Makefile.am gnupg-0.2.9/checks/Makefile.am
--- gnupg-0.2.8/checks/Makefile.am	Tue Feb 24 16:46:44 1998
+++ gnupg-0.2.9/checks/Makefile.am	Wed Feb 25 14:33:12 1998
@@ -1,9 +1,43 @@
 ## Process this file with automake to create Makefile.in
 
-TESTS = checkit
+TESTS = version.test decrypt.test clearsig.test armsigs.test \
+	sigs.test armencrypt.test armencryptp.test \
+	encrypt.test encryptp.test signencrypt.test \
+	armsignencrypt.test armdetach.test detach.test \
+	armdetachm.test detachm.test genkey1024.test
+
 
 TEST_FILES = pubring.asc secring.asc gnupg.asc plain-1 plain-2 plain-3o.asc \
 	     plain-1.asc plain-2.asc plain-3.asc
 
+DATA_FILES = data-500 data-9000 data-32000 data-80000
+
 EXTRA_DIST = $(TESTS) $(TEST_FILES)
+CLEANFILES = prepared.stamp x y z out err  $(DATA_FILES)
+
+check: prepared.stamp
+
+prepared.stamp: pubring.gpg secring.gpg gnupg.sig plain-3 $(DATA_FILES)
+	@set -x; \
+	echo "def" | ../g10/gpg -v --no-operation; \
+	echo timestamp >./prepared.stamp
+
+pubring.gpg: pubring.asc
+	../g10/gpgm --yes --dearmor -o pubring.gpg pubring.asc
+secring.gpg: secring.asc
+	../g10/gpgm --yes --dearmor -o secring.gpg secring.asc
+gnupg.sig: gnupg.asc
+	../g10/gpgm --yes --dearmor -o gnupg.sig gnupg.asc
+plain-3: plain-3o.asc
+	../g10/gpgm --yes --dearmor -o plain-3 plain-3o.asc
+
+data-500:
+	head -c 500 /dev/urandom >data-500
+data-9000:
+	head -c 9000 /dev/urandom >data-9000
+data-32000:
+	head -c 32000 /dev/urandom >data-32000
+data-80000:
+	head -c 80000 /dev/urandom >data-80000
+
 
diff -urN gnupg-0.2.8/checks/Makefile.in gnupg-0.2.9/checks/Makefile.in
--- gnupg-0.2.8/checks/Makefile.in	Tue Feb 24 18:12:24 1998
+++ gnupg-0.2.9/checks/Makefile.in	Thu Feb 26 17:13:37 1998
@@ -1,6 +1,6 @@
-# Makefile.in generated automatically by automake 1.2d from Makefile.am
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
 
-# Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -72,26 +72,39 @@
 GENCAT = @GENCAT@
 GMOFILES = @GMOFILES@
 GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
 INSTOBJEXT = @INSTOBJEXT@
 INTLDEPS = @INTLDEPS@
 INTLLIBS = @INTLLIBS@
 INTLOBJS = @INTLOBJS@
-INTLSUB = @INTLSUB@
+MKINSTALLDIRS = @MKINSTALLDIRS@
 MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
 MSGFMT = @MSGFMT@
 PACKAGE = @PACKAGE@
 POFILES = @POFILES@
 POSUB = @POSUB@
 RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
 VERSION = @VERSION@
 ZLIBS = @ZLIBS@
+l = @l@
 
-TESTS = checkit
+TESTS = version.test decrypt.test clearsig.test armsigs.test \
+	sigs.test armencrypt.test armencryptp.test \
+	encrypt.test encryptp.test signencrypt.test \
+	armsignencrypt.test armdetach.test detach.test \
+	armdetachm.test detachm.test genkey1024.test
 
 TEST_FILES = pubring.asc secring.asc gnupg.asc plain-1 plain-2 plain-3o.asc \
 	     plain-1.asc plain-2.asc plain-3.asc
 
+DATA_FILES = data-500 data-9000 data-32000 data-80000
+
 EXTRA_DIST = $(TESTS) $(TEST_FILES)
+CLEANFILES = prepared.stamp x y z out err  $(DATA_FILES)
 mkinstalldirs = $(SHELL) $(top_srcdir)/scripts/mkinstalldirs
 CONFIG_HEADER = ../config.h
 CONFIG_CLEAN_FILES = 
@@ -205,6 +218,31 @@
 mostlyclean-generic distclean-generic clean-generic \
 maintainer-clean-generic clean mostlyclean distclean maintainer-clean
 
+
+check: prepared.stamp
+
+prepared.stamp: pubring.gpg secring.gpg gnupg.sig plain-3 $(DATA_FILES)
+	@set -x; \
+	echo "def" | ../g10/gpg -v --no-operation; \
+	echo timestamp >./prepared.stamp
+
+pubring.gpg: pubring.asc
+	../g10/gpgm --yes --dearmor -o pubring.gpg pubring.asc
+secring.gpg: secring.asc
+	../g10/gpgm --yes --dearmor -o secring.gpg secring.asc
+gnupg.sig: gnupg.asc
+	../g10/gpgm --yes --dearmor -o gnupg.sig gnupg.asc
+plain-3: plain-3o.asc
+	../g10/gpgm --yes --dearmor -o plain-3 plain-3o.asc
+
+data-500:
+	head -c 500 /dev/urandom >data-500
+data-9000:
+	head -c 9000 /dev/urandom >data-9000
+data-32000:
+	head -c 32000 /dev/urandom >data-32000
+data-80000:
+	head -c 80000 /dev/urandom >data-80000
 
 # Tell versions [3.59,3.63) of GNU make to not export all variables.
 # Otherwise a system limit (for SysV at least) may be exceeded.
diff -urN gnupg-0.2.8/checks/armdetach.test gnupg-0.2.9/checks/armdetach.test
--- gnupg-0.2.8/checks/armdetach.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/armdetach.test	Wed Feb 25 11:33:59 1998
@@ -0,0 +1,11 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+
+#info Checking armored detached signatures
+for i in $plain_files $data_files ; do
+    echo "$usrpass1" | run_gpg --passphrase-fd 0 -sab -o x --yes $i
+    run_gpg -o /dev/null --yes x  <$i || error "$i: bad signature"
+done
+
diff -urN gnupg-0.2.8/checks/armdetachm.test gnupg-0.2.9/checks/armdetachm.test
--- gnupg-0.2.8/checks/armdetachm.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/armdetachm.test	Wed Feb 25 11:35:41 1998
@@ -0,0 +1,9 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking armored detached signatures of multiple files
+i="$plain_files $data_files"
+echo "$usrpass1" | run_gpg --passphrase-fd 0 -sab -o x --yes $i
+cat $i | run_gpg -o /dev/null --yes x || error "$i: bad signature"
+
diff -urN gnupg-0.2.8/checks/armencrypt.test gnupg-0.2.9/checks/armencrypt.test
--- gnupg-0.2.8/checks/armencrypt.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/armencrypt.test	Wed Feb 25 11:20:16 1998
@@ -0,0 +1,11 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking armored encryption
+for i in $plain_files $data_files ; do
+    run_gpg -ea -o x --yes -r "$usrname2" $i
+    run_gpg -o y --yes x
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/armencryptp.test gnupg-0.2.9/checks/armencryptp.test
--- gnupg-0.2.8/checks/armencryptp.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/armencryptp.test	Wed Feb 25 11:30:20 1998
@@ -0,0 +1,12 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking armored encryption with a pipe
+for i in $plain_files $data_files ; do
+    run_gpg -ea --yes -r "$usrname2" < $i | tee x | run_gpg -o y --yes
+    cmp $i y || error "$i: mismatch"
+    run_gpg --yes < x > y
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/armsignencrypt.test gnupg-0.2.9/checks/armsignencrypt.test
--- gnupg-0.2.8/checks/armsignencrypt.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/armsignencrypt.test	Wed Feb 25 11:33:13 1998
@@ -0,0 +1,13 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+
+#info Checking armored signing and encryption
+for i in $plain_files $data_files ; do
+    echo "$usrpass1" \
+    | run_gpg --passphrase-fd 0 -sae -o x --yes -r "$usrname2" $i
+    run_gpg -o y --yes x
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/armsigs.test gnupg-0.2.9/checks/armsigs.test
--- gnupg-0.2.8/checks/armsigs.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/armsigs.test	Wed Feb 25 11:18:14 1998
@@ -0,0 +1,11 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking armored signatures
+for i in $plain_files $data_files ; do
+    echo "$usrpass1" | run_gpg --passphrase-fd 0 -sa -o x --yes $i
+    run_gpg -o y --yes x
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/checkit gnupg-0.2.9/checks/checkit
--- gnupg-0.2.8/checks/checkit	Tue Feb 24 16:42:51 1998
+++ gnupg-0.2.9/checks/checkit	Thu Jan  1 01:00:00 1970
@@ -1,213 +0,0 @@
-#!/bin/bash
-#  Script for G10 testing
-#---------------------------------------------------------
-
-#--------------------------------
-#------ constants ---------------
-#--------------------------------
-
-usrname1="one"
-usrpass1="def"
-usrname2="two"
-usrpass2=""
-plain_files="plain-1 plain-2"
-data_files=""
-exp_files=""
-
-
-#--------------------------------
-#------ utility functions -------
-#--------------------------------
-
-fatal () {
-    echo "$pgmname: fatal:" $* >&2
-    exit 1;
-}
-
-error () {
-    echo "$pgmname:" $* >&2
-    exit 1
-}
-
-info () {
-    echo "$pgmname:" $* >&2
-}
-
-chdir () {
-    cd $1 || fatal "cannot cd to $1"
-}
-
-cleanup () {
-    rm $data_files x y z 2>/dev/null
-    echo "#empty" >./options
-}
-
-
-run_g10 () {
-    if ! eval ../g10/gpg --homedir . $* ; then
-	echo "(../g10/gpg --homedir . $*) failed" >&2
-	exit 1
-    fi
-}
-
-run_g10maint () {
-    if ! eval ../g10/gpgm --homedir . $* ; then
-	echo "(../g10/gpgm --homedir . $*) failed" >&2
-	exit 1
-    fi
-}
-
-#--------------------------------
-#-------- main program ----------
-#--------------------------------
-
-set -e
-pgmname=$(basename $0)
-trap cleanup SIGHUP SIGINT SIGQUIT
-
-
-# some checks
-for i in $plain_files plain-3o.asc ; do
-    [ -f $i ] || fatal "$i: missing"
-done
-for i in $exp_files; do
-    [ -f $i ] || fatal "$i: script missing"
-done
-# create the keyrings
-
-cat <<EOF  >./options
-no-greeting
-no-secmem-warning
-batch
-EOF
-
-# print the G10 version
-run_g10 --version
-
-info Unpacking some material
-run_g10maint --yes --dearmor -o pubring.gpg pubring.asc
-run_g10maint --yes --dearmor -o secring.gpg secring.asc
-run_g10maint --yes --dearmor -o gnupg.sig gnupg.asc
-run_g10maint --yes --dearmor -o plain-3 plain-3o.asc
-plain_files="$plain_files plain-3"
-# make sure all files are created
-echo "$usrpass1" | run_g10 --no-operation
-
-info Checking decryption
-for i in $plain_files ; do
-    echo "$usrpass1" | run_g10 --passphrase-fd 0 -o y --yes $i.asc
-    cmp $i y || error "$i: mismatch"
-done
-
-info Checking cleartext signatures
-# There is a minor glitch, which appends a lf to the cleartext.
-# I do not consider that a bug, but I have to use the head .. mimic.
-# It is not clear what should happen to leading LFs, we must
-# change the defintion of cleartext, so that only 1 empty line
-# must follow the headers, but some specs say: any number of empty lines ..
-# clean-sat removes leading LFs
-# I know that this does not work for random data files (due to large lines
-# or what ever) - I hope we can live with it.
-for i in $plain_files; do
-    echo "$usrpass1" | run_g10 --passphrase-fd 0 -sat -o x --yes $i
-    run_g10 -o y --yes x
-    ../tools/clean-sat < $i > z
-    head -c $[ $(cat y | wc -c) - 1 ] y | diff - z || error "$i: mismatch"
-done
-
-info Creating some random data files
-for i in 500 9000 32000 80000; do
-    head -c $i /dev/urandom >data-$i
-    data_files="$data_files data-$i"
-done
-
-info Checking armored signatures
-for i in $plain_files $data_files ; do
-    echo "$usrpass1" | run_g10 --passphrase-fd 0 -sa -o x --yes $i
-    run_g10 -o y --yes x
-    cmp $i y || error "$i: mismatch"
-done
-
-info Checking signatures
-for i in $plain_files $data_files; do
-    echo "$usrpass1" | run_g10 --passphrase-fd 0 -s -o x --yes $i
-    run_g10 -o y --yes x
-    cmp $i y || error "$i: mismatch"
-done
-
-
-info Checking armored encryption
-for i in $plain_files $data_files ; do
-    run_g10 -ea -o x --yes -r "$usrname2" $i
-    run_g10 -o y --yes x
-    cmp $i y || error "$i: mismatch"
-done
-
-info Checking armored encryption with a pipe
-for i in $plain_files $data_files ; do
-    run_g10 -ea --yes -r "$usrname2" < $i | tee x \
-    | run_g10 -o y --yes
-    cmp $i y || error "$i: mismatch"
-    run_g10 --yes < x > y
-    cmp $i y || error "$i: mismatch"
-done
-
-info Checking encryption
-for i in $plain_files $data_files ; do
-    run_g10 -e -o x --yes -r "$usrname2" $i
-    run_g10 -o y --yes x
-    cmp $i y || error "$i: mismatch"
-done
-
-info Checking encryption with a pipe
-for i in $plain_files $data_files ; do
-    run_g10 -e --yes -r "$usrname2" < $i \
-    | run_g10 --yes > y
-    cmp $i y || error "$i: mismatch"
-done
-
-
-info Checking signing and encryption
-for i in $plain_files $data_files ; do
-    echo "$usrpass1" \
-    | run_g10 --passphrase-fd 0 -se -o x --yes -r "$usrname2" $i
-    run_g10 -o y --yes x
-    cmp $i y || error "$i: mismatch"
-done
-
-info Checking armored signing and encryption
-for i in $plain_files $data_files ; do
-    echo "$usrpass1" \
-    | run_g10 --passphrase-fd 0 -sae -o x --yes -r "$usrname2" $i
-    run_g10 -o y --yes x
-    cmp $i y || error "$i: mismatch"
-done
-
-
-info Checking armored detached signatures
-for i in $plain_files $data_files ; do
-    echo "$usrpass1" | run_g10 --passphrase-fd 0 -sab -o x --yes $i
-    run_g10 -o /dev/null --yes x  <$i || error "$i: bad signature"
-done
-
-info Checking detached signatures
-for i in $plain_files $data_files ; do
-    echo "$usrpass1" | run_g10 --passphrase-fd 0 -sb -o x --yes $i
-    run_g10 -o /dev/null --yes x  <$i || error "$i: bad signature"
-done
-
-
-info Checking detached signatures of multiple files
-i="$plain_files $data_files"
-echo "$usrpass1" | run_g10 --passphrase-fd 0 -sb -o x --yes $i
-cat $i | run_g10 -o /dev/null --yes x || error "$i: bad signature"
-
-info Checking armored detached signatures of multiple files
-i="$plain_files $data_files"
-echo "$usrpass1" | run_g10 --passphrase-fd 0 -sab -o x --yes $i
-cat $i | run_g10 -o /dev/null --yes x || error "$i: bad signature"
-
-
-info "All tests passed."
-exit 0
-
diff -urN gnupg-0.2.8/checks/clearsig.test gnupg-0.2.9/checks/clearsig.test
--- gnupg-0.2.8/checks/clearsig.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/clearsig.test	Wed Feb 25 11:17:23 1998
@@ -0,0 +1,20 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking cleartext signatures
+# There is a minor glitch, which appends a lf to the cleartext.
+# I do not consider that a bug, but I have to use the head .. mimic.
+# It is not clear what should happen to leading LFs, we must
+# change the defintion of cleartext, so that only 1 empty line
+# must follow the headers, but some specs say: any number of empty lines ..
+# clean-sat removes leading LFs
+# I know that this does not work for random data files (due to large lines
+# or what ever) - I hope we can live with it.
+for i in $plain_files; do
+    echo "$usrpass1" | run_gpg --passphrase-fd 0 -sat -o x --yes $i
+    run_gpg -o y --yes x
+    ../tools/clean-sat < $i > z
+    head -c $[ $(cat y | wc -c) - 1 ] y | diff - z || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/decrypt.test gnupg-0.2.9/checks/decrypt.test
--- gnupg-0.2.8/checks/decrypt.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/decrypt.test	Wed Feb 25 11:28:01 1998
@@ -0,0 +1,10 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking decryption of supplied files
+for i in $plain_files ; do
+    echo "$usrpass1" | run_gpg --passphrase-fd 0 -o y --yes $i.asc
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/detach.test gnupg-0.2.9/checks/detach.test
--- gnupg-0.2.8/checks/detach.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/detach.test	Wed Feb 25 11:34:57 1998
@@ -0,0 +1,10 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking detached signatures
+for i in $plain_files $data_files ; do
+    echo "$usrpass1" | run_gpg --passphrase-fd 0 -sb -o x --yes $i
+    run_gpg -o /dev/null --yes x  <$i || error "$i: bad signature"
+done
+
diff -urN gnupg-0.2.8/checks/detachm.test gnupg-0.2.9/checks/detachm.test
--- gnupg-0.2.8/checks/detachm.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/detachm.test	Wed Feb 25 11:36:28 1998
@@ -0,0 +1,9 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking detached signatures of multiple files
+i="$plain_files $data_files"
+echo "$usrpass1" | run_gpg --passphrase-fd 0 -sb -o x --yes $i
+cat $i | run_gpg -o /dev/null --yes x || error "$i: bad signature"
+
diff -urN gnupg-0.2.8/checks/encrypt.test gnupg-0.2.9/checks/encrypt.test
--- gnupg-0.2.8/checks/encrypt.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/encrypt.test	Wed Feb 25 11:30:55 1998
@@ -0,0 +1,11 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking encryption
+for i in $plain_files $data_files ; do
+    run_gpg -e -o x --yes -r "$usrname2" $i
+    run_gpg -o y --yes x
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/encryptp.test gnupg-0.2.9/checks/encryptp.test
--- gnupg-0.2.8/checks/encryptp.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/encryptp.test	Wed Feb 25 11:31:42 1998
@@ -0,0 +1,10 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking encryption with a pipe
+for i in $plain_files $data_files ; do
+    run_gpg -e --yes -r "$usrname2" < $i | run_gpg --yes > y
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/genkey1024.test gnupg-0.2.9/checks/genkey1024.test
--- gnupg-0.2.8/checks/genkey1024.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/genkey1024.test	Wed Feb 25 14:32:46 1998
@@ -0,0 +1,59 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+info "This expect script does yet work"
+exit 0
+
+expect - <<EOF
+set timeout -1
+match_max 100000
+spawn ../g10/gpg --no-batch --quick-random --homedir . --gen-key
+expect -exact "Please select the algorithm to use:\r
+   (1) ElGamal is the suggested one.\r
+   (2) DSA can only be used for signatures.\r
+Your selection? (1,2) "
+send -- "1\r"
+expect -exact "1\r
+\r                       \rAbout to generate a new ElGamal keypair.\r
+              minimum keysize is  768 bits\r
+              default keysize is 1024 bits\r
+    highest suggested keysize is 2048 bits\r
+What keysize do you want? (1024) "
+send -- "\r"
+expect -exact "\r
+\r                                 \rRequested keysize is 1024 bits\r
+\r
+You need a User-ID to identify your key; the software constructs the user id\r
+from Real Name, Comment and Email Address in this form:\r
+    \"Heinrich Heine (Der Dichter) <heinrichh@uni-duesseldorf.de>\"\r
+\r
+Real name: "
+send -- "Harry H.\r"
+expect -exact "Harry H.\r
+\r                   \rEmail address: "
+send -- "hh@ddorf.de\r"
+expect -exact "hh@ddorf.de\r
+\r                          \rComment: "
+send -- "a test\r"
+expect -exact "a test\r
+\r               \rYou selected this USER-ID:\r
+    \"Harry H. (a test) <hh@ddorf.de> (INSECURE!)\"\r
+\r
+Edit (N)ame, (C)omment, (E)mail or (O)kay? "
+send -- "o\r"
+expect -exact "o\r
+\r                                            \rYou need a Passphrase to protect your secret key.\r
+\r
+Enter pass phrase: "
+send -- "abc\r"
+expect -ex "abc\r\n"
+expect -ex "\r                   \rRepeat pass phrase:\ "
+send -- "abc\r"
+expect -ex "abc\r\n"
+expect {
+    -ex "public and secret key created and signed.\r"
+    eof  abort
+}
+EOF
+
diff -urN gnupg-0.2.8/checks/signencrypt.test gnupg-0.2.9/checks/signencrypt.test
--- gnupg-0.2.8/checks/signencrypt.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/signencrypt.test	Wed Feb 25 11:32:31 1998
@@ -0,0 +1,13 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+
+#info Checking signing and encryption
+for i in $plain_files $data_files ; do
+    echo "$usrpass1" \
+    | run_gpg --passphrase-fd 0 -se -o x --yes -r "$usrname2" $i
+    run_gpg -o y --yes x
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/sigs.test gnupg-0.2.9/checks/sigs.test
--- gnupg-0.2.8/checks/sigs.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/sigs.test	Wed Feb 25 11:19:38 1998
@@ -0,0 +1,11 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+#info Checking signatures
+for i in $plain_files $data_files; do
+    echo "$usrpass1" | run_gpg --passphrase-fd 0 -s -o x --yes $i
+    run_gpg -o y --yes x
+    cmp $i y || error "$i: mismatch"
+done
+
diff -urN gnupg-0.2.8/checks/version.test gnupg-0.2.9/checks/version.test
--- gnupg-0.2.8/checks/version.test	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/checks/version.test	Wed Feb 25 11:27:46 1998
@@ -0,0 +1,10 @@
+#!/bin/sh
+
+. defs.inc || exit 3
+
+# print the GPG version
+run_gpg --version
+cat err
+
+#fixme: check that the output is correct
+
diff -urN gnupg-0.2.8/cipher/ChangeLog gnupg-0.2.9/cipher/ChangeLog
--- gnupg-0.2.8/cipher/ChangeLog	Tue Feb 24 12:29:43 1998
+++ gnupg-0.2.9/cipher/ChangeLog	Thu Feb 26 07:57:46 1998
@@ -1,3 +1,8 @@
+Thu Feb 26 07:57:02 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* primegen.c (generate_elg_prime): Changed the progress printing.
+	(gen_prime): Ditto.
+
 Tue Feb 24 12:28:42 1998  Werner Koch  (wk@isil.d.shuttle.de)
 
 	* md5.c, md.5 : Replaced by a modified version of md5.c from
diff -urN gnupg-0.2.8/cipher/Makefile.in gnupg-0.2.9/cipher/Makefile.in
--- gnupg-0.2.8/cipher/Makefile.in	Tue Feb 24 18:12:04 1998
+++ gnupg-0.2.9/cipher/Makefile.in	Thu Feb 26 17:13:25 1998
@@ -1,6 +1,6 @@
-# Makefile.in generated automatically by automake 1.2d from Makefile.am
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
 
-# Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -72,19 +72,25 @@
 GENCAT = @GENCAT@
 GMOFILES = @GMOFILES@
 GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
 INSTOBJEXT = @INSTOBJEXT@
 INTLDEPS = @INTLDEPS@
 INTLLIBS = @INTLLIBS@
 INTLOBJS = @INTLOBJS@
-INTLSUB = @INTLSUB@
+MKINSTALLDIRS = @MKINSTALLDIRS@
 MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
 MSGFMT = @MSGFMT@
 PACKAGE = @PACKAGE@
 POFILES = @POFILES@
 POSUB = @POSUB@
 RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
 VERSION = @VERSION@
 ZLIBS = @ZLIBS@
+l = @l@
 
 INCLUDES =  -I$(top_srcdir)/include
 EXTRA_DIST = @CIPHER_EXTRA_DIST@
@@ -171,7 +177,7 @@
 	$(COMPILE) -c $<
 
 mostlyclean-compile:
-	-rm -f *.o core
+	-rm -f *.o core *.core
 
 clean-compile:
 
@@ -194,8 +200,12 @@
 TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) $(LISP)
 	tags=; \
 	here=`pwd`; \
-	test -z "$(ETAGS_ARGS)$(SOURCES)$(HEADERS)$(LISP)$$tags" \
-	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $(SOURCES) $(HEADERS) $(LISP) -o $$here/TAGS)
+	list='$(SOURCES) $(HEADERS)'; \
+	unique=`for i in $$list; do echo $$i; done | \
+	  awk '    { files[$$0] = 1; } \
+	       END { for (i in files) print i; }'`; \
+	test -z "$(ETAGS_ARGS)$$unique$(LISP)$$tags" \
+	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $$unique $(LISP) -o $$here/TAGS)
 
 mostlyclean-tags:
 
@@ -217,65 +227,65 @@
 	  || ln $$d/$$file $(distdir)/$$file 2> /dev/null \
 	  || cp -p $$d/$$file $(distdir)/$$file; \
 	done
-blowfish.o blowfish.lo: blowfish.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h blowfish.h
-dsa.o dsa.lo: dsa.c ../config.h ../include/util.h ../include/types.h \
+blowfish.o: blowfish.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h blowfish.h
+dsa.o: dsa.c ../config.h ../include/util.h ../include/types.h \
 	../include/errors.h ../include/mpi.h ../include/iobuf.h \
 	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h dsa.h
-elgamal.o elgamal.lo: elgamal.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/cipher.h \
+elgamal.o: elgamal.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h elgamal.h
-gost.o gost.lo: gost.c ../config.h ../include/util.h ../include/types.h \
+gost.o: gost.c ../config.h ../include/util.h ../include/types.h \
 	../include/errors.h ../include/mpi.h ../include/iobuf.h \
 	../include/memory.h gost.h
-md.o md.lo: md.c ../config.h ../include/util.h ../include/types.h \
+md.o: md.c ../config.h ../include/util.h ../include/types.h \
 	../include/errors.h ../include/mpi.h ../include/iobuf.h \
 	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h
-md5.o md5.lo: md5.c ../config.h ../include/util.h ../include/types.h \
+md5.o: md5.c ../config.h ../include/util.h ../include/types.h \
 	../include/errors.h ../include/mpi.h ../include/iobuf.h \
 	../include/memory.h md5.h
-misc.o misc.lo: misc.c ../config.h ../include/util.h ../include/types.h \
+misc.o: misc.c ../config.h ../include/util.h ../include/types.h \
 	../include/errors.h ../include/mpi.h ../include/iobuf.h \
 	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h
-primegen.o primegen.lo: primegen.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/cipher.h \
+primegen.o: primegen.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h
-random.o random.lo: random.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/cipher.h \
+random.o: random.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h ../include/ttyio.h \
 	../include/i18n.h
-rmd160.o rmd160.lo: rmd160.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h rmd.h
-sha1.o sha1.lo: sha1.c ../config.h ../include/util.h ../include/types.h \
+rmd160.o: rmd160.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h rmd.h
+sha1.o: sha1.c ../config.h ../include/util.h ../include/types.h \
 	../include/errors.h ../include/mpi.h ../include/iobuf.h \
 	../include/memory.h sha1.h
-smallprime.o smallprime.lo: smallprime.c ../config.h ../include/util.h \
+smallprime.o: smallprime.c ../config.h ../include/util.h \
 	../include/types.h ../include/errors.h ../include/mpi.h \
 	../include/iobuf.h ../include/memory.h
 
diff -urN gnupg-0.2.8/cipher/primegen.c gnupg-0.2.9/cipher/primegen.c
--- gnupg-0.2.8/cipher/primegen.c	Mon Feb 23 13:12:57 1998
+++ gnupg-0.2.9/cipher/primegen.c	Thu Feb 26 07:57:48 1998
@@ -203,7 +203,7 @@
 	    else
 		fputc('^', stderr);
 	    for(i=0; i < n+2; i++ ) {
-		fputc('~', stderr);
+		/*fputc('~', stderr);*/
 		mpi_fdiv_q(tmp, pmin1, factors[i] );
 		/* (no mpi_pow(), but it is okay to use this with mod prime) */
 		mpi_powm(b, g, tmp, prime );
@@ -260,6 +260,8 @@
     count1 = count2 = 0;
     /* enter (endless) loop */
     for(;;) {
+	int dotcount=0;
+
 	/* generate a random number */
 	mpi_set_bytes( prime, nbits, get_random_byte, randomlevel );
 	/* set high order bit to 1, set low order bit to 1 */
@@ -315,7 +317,10 @@
 		m_free(mods);
 		return prime;
 	    }
-	    fputc('.', stderr);
+	    if( ++dotcount == 10 ) {
+		fputc('.', stderr);
+		dotcount = 0;
+	    }
 	}
 	fputc(':', stderr); /* restart with a new random value */
     }
diff -urN gnupg-0.2.8/config.h.in gnupg-0.2.9/config.h.in
--- gnupg-0.2.8/config.h.in	Mon Feb 23 13:24:20 1998
+++ gnupg-0.2.9/config.h.in	Thu Feb 26 16:38:26 1998
@@ -58,6 +58,9 @@
 /* Define to `long' if <sys/types.h> doesn't define.  */
 #undef off_t
 
+/* Define if you need to in order for stat and other things to work.  */
+#undef _POSIX_SOURCE
+
 /* Define to `unsigned' if <sys/types.h> doesn't define.  */
 #undef size_t
 
@@ -91,10 +94,6 @@
 /* Define as 1 if you have gettext and don't want to use GNU gettext.  */
 #undef HAVE_GETTEXT
 
-/* libintl.h is available; this is obsolete because if we don't have
- * this header we use a symlink to the one in intl/ */
-#undef HAVE_LIBINTL_H
-
 #undef HAVE_STPCPY
 
 #undef BIG_ENDIAN_HOST
@@ -124,6 +123,15 @@
 /* The number of bytes in a unsigned short.  */
 #undef SIZEOF_UNSIGNED_SHORT
 
+/* Define if you have the __argz_count function.  */
+#undef HAVE___ARGZ_COUNT
+
+/* Define if you have the __argz_next function.  */
+#undef HAVE___ARGZ_NEXT
+
+/* Define if you have the __argz_stringify function.  */
+#undef HAVE___ARGZ_STRINGIFY
+
 /* Define if you have the dcgettext function.  */
 #undef HAVE_DCGETTEXT
 
@@ -175,6 +183,9 @@
 /* Define if you have the tcgetattr function.  */
 #undef HAVE_TCGETATTR
 
+/* Define if you have the <argz.h> header file.  */
+#undef HAVE_ARGZ_H
+
 /* Define if you have the <limits.h> header file.  */
 #undef HAVE_LIMITS_H
 
@@ -190,6 +201,9 @@
 /* Define if you have the <string.h> header file.  */
 #undef HAVE_STRING_H
 
+/* Define if you have the <sys/param.h> header file.  */
+#undef HAVE_SYS_PARAM_H
+
 /* Define if you have the <unistd.h> header file.  */
 #undef HAVE_UNISTD_H
 
@@ -201,9 +215,6 @@
 
 /* Define if you have the i library (-li).  */
 #undef HAVE_LIBI
-
-/* Define if you have the intl library (-lintl).  */
-#undef HAVE_LIBINTL
 
 
 /* The AC_CHECK_SIZEOF() fails for some machines.
diff -urN gnupg-0.2.8/configure gnupg-0.2.9/configure
--- gnupg-0.2.8/configure	Tue Feb 24 17:22:42 1998
+++ gnupg-0.2.9/configure	Thu Feb 26 16:41:22 1998
@@ -18,7 +18,9 @@
 ac_help="$ac_help
   --disable-nls		 do not use Native Language Support"
 ac_help="$ac_help
-  --with-gnu-gettext	   use the GNU gettext library"
+  --with-included-gettext use the GNU gettext library included here"
+ac_help="$ac_help
+  --with-catgets	       use catgets functions if available"
 
 # Initialize some variables set by options.
 # The variables have the same names as the options, with
@@ -629,7 +631,7 @@
 fi
 
 echo $ac_n "checking host system type""... $ac_c" 1>&6
-echo "configure:633: checking host system type" >&5
+echo "configure:635: checking host system type" >&5
 
 host_alias=$host
 case "$host_alias" in
@@ -650,7 +652,7 @@
 echo "$ac_t""$host" 1>&6
 
 echo $ac_n "checking target system type""... $ac_c" 1>&6
-echo "configure:654: checking target system type" >&5
+echo "configure:656: checking target system type" >&5
 
 target_alias=$target
 case "$target_alias" in
@@ -668,7 +670,7 @@
 echo "$ac_t""$target" 1>&6
 
 echo $ac_n "checking build system type""... $ac_c" 1>&6
-echo "configure:672: checking build system type" >&5
+echo "configure:674: checking build system type" >&5
 
 build_alias=$build
 case "$build_alias" in
@@ -691,7 +693,7 @@
   program_prefix=${target_alias}-
 
  echo $ac_n "checking cached information""... $ac_c" 1>&6
-echo "configure:695: checking cached information" >&5
+echo "configure:697: checking cached information" >&5
     wk_hostcheck="$target"
     if eval "test \"`echo '$''{'wk_cv_hostcheck'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -711,7 +713,7 @@
 
 
 echo $ac_n "checking whether ${MAKE-make} sets \${MAKE}""... $ac_c" 1>&6
-echo "configure:715: checking whether ${MAKE-make} sets \${MAKE}" >&5
+echo "configure:717: checking whether ${MAKE-make} sets \${MAKE}" >&5
 set dummy ${MAKE-make}; ac_make=`echo "$2" | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_prog_make_${ac_make}_set'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -759,7 +761,7 @@
 
 missing_dir=`cd $ac_aux_dir && pwd`
 echo $ac_n "checking for working aclocal""... $ac_c" 1>&6
-echo "configure:763: checking for working aclocal" >&5
+echo "configure:765: checking for working aclocal" >&5
 # Run test in a subshell; some versions of sh will print an error if
 # an executable is not found, even if stderr is redirected.
 # Redirect stdin to placate older versions of autoconf.  Sigh.
@@ -772,7 +774,7 @@
 fi
 
 echo $ac_n "checking for working autoconf""... $ac_c" 1>&6
-echo "configure:776: checking for working autoconf" >&5
+echo "configure:778: checking for working autoconf" >&5
 # Run test in a subshell; some versions of sh will print an error if
 # an executable is not found, even if stderr is redirected.
 # Redirect stdin to placate older versions of autoconf.  Sigh.
@@ -785,7 +787,7 @@
 fi
 
 echo $ac_n "checking for working automake""... $ac_c" 1>&6
-echo "configure:789: checking for working automake" >&5
+echo "configure:791: checking for working automake" >&5
 # Run test in a subshell; some versions of sh will print an error if
 # an executable is not found, even if stderr is redirected.
 # Redirect stdin to placate older versions of autoconf.  Sigh.
@@ -798,7 +800,7 @@
 fi
 
 echo $ac_n "checking for working autoheader""... $ac_c" 1>&6
-echo "configure:802: checking for working autoheader" >&5
+echo "configure:804: checking for working autoheader" >&5
 # Run test in a subshell; some versions of sh will print an error if
 # an executable is not found, even if stderr is redirected.
 # Redirect stdin to placate older versions of autoconf.  Sigh.
@@ -810,6 +812,197 @@
    echo "$ac_t""missing" 1>&6
 fi
 
+# Extract the first word of "gcc", so it can be a program name with args.
+set dummy gcc; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:819: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_prog_CC'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  if test -n "$CC"; then
+  ac_cv_prog_CC="$CC" # Let the user override the test.
+else
+  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      ac_cv_prog_CC="gcc"
+      break
+    fi
+  done
+  IFS="$ac_save_ifs"
+fi
+fi
+CC="$ac_cv_prog_CC"
+if test -n "$CC"; then
+  echo "$ac_t""$CC" 1>&6
+else
+  echo "$ac_t""no" 1>&6
+fi
+
+if test -z "$CC"; then
+  # Extract the first word of "cc", so it can be a program name with args.
+set dummy cc; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:848: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_prog_CC'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  if test -n "$CC"; then
+  ac_cv_prog_CC="$CC" # Let the user override the test.
+else
+  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  ac_prog_rejected=no
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if test "$ac_dir/$ac_word" = "/usr/ucb/cc"; then
+        ac_prog_rejected=yes
+	continue
+      fi
+      ac_cv_prog_CC="cc"
+      break
+    fi
+  done
+  IFS="$ac_save_ifs"
+if test $ac_prog_rejected = yes; then
+  # We found a bogon in the path, so make sure we never use it.
+  set dummy $ac_cv_prog_CC
+  shift
+  if test $# -gt 0; then
+    # We chose a different compiler from the bogus one.
+    # However, it has the same basename, so the bogon will be chosen
+    # first if we set CC to just the basename; use the full file name.
+    shift
+    set dummy "$ac_dir/$ac_word" "$@"
+    shift
+    ac_cv_prog_CC="$@"
+  fi
+fi
+fi
+fi
+CC="$ac_cv_prog_CC"
+if test -n "$CC"; then
+  echo "$ac_t""$CC" 1>&6
+else
+  echo "$ac_t""no" 1>&6
+fi
+
+  test -z "$CC" && { echo "configure: error: no acceptable cc found in \$PATH" 1>&2; exit 1; }
+fi
+
+echo $ac_n "checking whether the C compiler ($CC $CFLAGS $LDFLAGS) works""... $ac_c" 1>&6
+echo "configure:896: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) works" >&5
+
+ac_ext=c
+# CFLAGS is not in ac_cpp because -g, -O, etc. are not valid cpp options.
+ac_cpp='$CPP $CPPFLAGS'
+ac_compile='${CC-cc} -c $CFLAGS $CPPFLAGS conftest.$ac_ext 1>&5'
+ac_link='${CC-cc} -o conftest $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS 1>&5'
+cross_compiling=$ac_cv_prog_cc_cross
+
+cat > conftest.$ac_ext <<EOF
+#line 906 "configure"
+#include "confdefs.h"
+main(){return(0);}
+EOF
+if { (eval echo configure:910: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+  ac_cv_prog_cc_works=yes
+  # If we can't run a trivial program, we are probably using a cross compiler.
+  if (./conftest; exit) 2>/dev/null; then
+    ac_cv_prog_cc_cross=no
+  else
+    ac_cv_prog_cc_cross=yes
+  fi
+else
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
+  ac_cv_prog_cc_works=no
+fi
+rm -fr conftest*
+
+echo "$ac_t""$ac_cv_prog_cc_works" 1>&6
+if test $ac_cv_prog_cc_works = no; then
+  { echo "configure: error: installation or configuration problem: C compiler cannot create executables." 1>&2; exit 1; }
+fi
+echo $ac_n "checking whether the C compiler ($CC $CFLAGS $LDFLAGS) is a cross-compiler""... $ac_c" 1>&6
+echo "configure:930: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) is a cross-compiler" >&5
+echo "$ac_t""$ac_cv_prog_cc_cross" 1>&6
+cross_compiling=$ac_cv_prog_cc_cross
+
+echo $ac_n "checking whether we are using GNU C""... $ac_c" 1>&6
+echo "configure:935: checking whether we are using GNU C" >&5
+if eval "test \"`echo '$''{'ac_cv_prog_gcc'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  cat > conftest.c <<EOF
+#ifdef __GNUC__
+  yes;
+#endif
+EOF
+if { ac_try='${CC-cc} -E conftest.c'; { (eval echo configure:944: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }; } | egrep yes >/dev/null 2>&1; then
+  ac_cv_prog_gcc=yes
+else
+  ac_cv_prog_gcc=no
+fi
+fi
+
+echo "$ac_t""$ac_cv_prog_gcc" 1>&6
+
+if test $ac_cv_prog_gcc = yes; then
+  GCC=yes
+  ac_test_CFLAGS="${CFLAGS+set}"
+  ac_save_CFLAGS="$CFLAGS"
+  CFLAGS=
+  echo $ac_n "checking whether ${CC-cc} accepts -g""... $ac_c" 1>&6
+echo "configure:959: checking whether ${CC-cc} accepts -g" >&5
+if eval "test \"`echo '$''{'ac_cv_prog_cc_g'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  echo 'void f(){}' > conftest.c
+if test -z "`${CC-cc} -g -c conftest.c 2>&1`"; then
+  ac_cv_prog_cc_g=yes
+else
+  ac_cv_prog_cc_g=no
+fi
+rm -f conftest*
+
+fi
+
+echo "$ac_t""$ac_cv_prog_cc_g" 1>&6
+  if test "$ac_test_CFLAGS" = set; then
+    CFLAGS="$ac_save_CFLAGS"
+  elif test $ac_cv_prog_cc_g = yes; then
+    CFLAGS="-g -O2"
+  else
+    CFLAGS="-O2"
+  fi
+else
+  GCC=
+  test "${CFLAGS+set}" = set || CFLAGS="-g"
+fi
+
+echo $ac_n "checking for POSIXized ISC""... $ac_c" 1>&6
+echo "configure:987: checking for POSIXized ISC" >&5
+if test -d /etc/conf/kconfig.d &&
+  grep _POSIX_VERSION /usr/include/sys/unistd.h >/dev/null 2>&1
+then
+  echo "$ac_t""yes" 1>&6
+  ISC=yes # If later tests want to check for ISC.
+  cat >> confdefs.h <<\EOF
+#define _POSIX_SOURCE 1
+EOF
+
+  if test "$GCC" = yes; then
+    CC="$CC -posix"
+  else
+    CC="$CC -Xp"
+  fi
+else
+  echo "$ac_t""no" 1>&6
+  ISC=
+fi
+
 
 case "${target}" in
     i386--mingw32)
@@ -825,7 +1018,7 @@
 # Extract the first word of "ranlib", so it can be a program name with args.
 set dummy ranlib; ac_word=$2
 echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:829: checking for $ac_word" >&5
+echo "configure:1022: checking for $ac_word" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_RANLIB'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -862,7 +1055,7 @@
 # SVR4 /usr/ucb/install, which tries to use the nonexistent group "staff"
 # ./install, which can be erroneously created by make from ./install.sh.
 echo $ac_n "checking for a BSD compatible install""... $ac_c" 1>&6
-echo "configure:866: checking for a BSD compatible install" >&5
+echo "configure:1059: checking for a BSD compatible install" >&5
 if test -z "$INSTALL"; then
 if eval "test \"`echo '$''{'ac_cv_path_install'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -914,7 +1107,7 @@
 # Extract the first word of "gcc", so it can be a program name with args.
 set dummy gcc; ac_word=$2
 echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:918: checking for $ac_word" >&5
+echo "configure:1111: checking for $ac_word" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_CC'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -943,7 +1136,7 @@
   # Extract the first word of "cc", so it can be a program name with args.
 set dummy cc; ac_word=$2
 echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:947: checking for $ac_word" >&5
+echo "configure:1140: checking for $ac_word" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_CC'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -991,7 +1184,7 @@
 fi
 
 echo $ac_n "checking whether the C compiler ($CC $CFLAGS $LDFLAGS) works""... $ac_c" 1>&6
-echo "configure:995: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) works" >&5
+echo "configure:1188: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) works" >&5
 
 ac_ext=c
 # CFLAGS is not in ac_cpp because -g, -O, etc. are not valid cpp options.
@@ -1001,11 +1194,11 @@
 cross_compiling=$ac_cv_prog_cc_cross
 
 cat > conftest.$ac_ext <<EOF
-#line 1005 "configure"
+#line 1198 "configure"
 #include "confdefs.h"
 main(){return(0);}
 EOF
-if { (eval echo configure:1009: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1202: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   ac_cv_prog_cc_works=yes
   # If we can't run a trivial program, we are probably using a cross compiler.
   if (./conftest; exit) 2>/dev/null; then
@@ -1025,12 +1218,12 @@
   { echo "configure: error: installation or configuration problem: C compiler cannot create executables." 1>&2; exit 1; }
 fi
 echo $ac_n "checking whether the C compiler ($CC $CFLAGS $LDFLAGS) is a cross-compiler""... $ac_c" 1>&6
-echo "configure:1029: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) is a cross-compiler" >&5
+echo "configure:1222: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) is a cross-compiler" >&5
 echo "$ac_t""$ac_cv_prog_cc_cross" 1>&6
 cross_compiling=$ac_cv_prog_cc_cross
 
 echo $ac_n "checking whether we are using GNU C""... $ac_c" 1>&6
-echo "configure:1034: checking whether we are using GNU C" >&5
+echo "configure:1227: checking whether we are using GNU C" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_gcc'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -1039,7 +1232,7 @@
   yes;
 #endif
 EOF
-if { ac_try='${CC-cc} -E conftest.c'; { (eval echo configure:1043: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }; } | egrep yes >/dev/null 2>&1; then
+if { ac_try='${CC-cc} -E conftest.c'; { (eval echo configure:1236: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }; } | egrep yes >/dev/null 2>&1; then
   ac_cv_prog_gcc=yes
 else
   ac_cv_prog_gcc=no
@@ -1054,7 +1247,7 @@
   ac_save_CFLAGS="$CFLAGS"
   CFLAGS=
   echo $ac_n "checking whether ${CC-cc} accepts -g""... $ac_c" 1>&6
-echo "configure:1058: checking whether ${CC-cc} accepts -g" >&5
+echo "configure:1251: checking whether ${CC-cc} accepts -g" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_cc_g'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -1082,7 +1275,7 @@
 fi
 
 echo $ac_n "checking how to run the C preprocessor""... $ac_c" 1>&6
-echo "configure:1086: checking how to run the C preprocessor" >&5
+echo "configure:1279: checking how to run the C preprocessor" >&5
 # On Suns, sometimes $CPP names a directory.
 if test -n "$CPP" && test -d "$CPP"; then
   CPP=
@@ -1097,13 +1290,13 @@
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp.
   cat > conftest.$ac_ext <<EOF
-#line 1101 "configure"
+#line 1294 "configure"
 #include "confdefs.h"
 #include <assert.h>
 Syntax Error
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1107: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:1300: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   :
@@ -1114,13 +1307,13 @@
   rm -rf conftest*
   CPP="${CC-cc} -E -traditional-cpp"
   cat > conftest.$ac_ext <<EOF
-#line 1118 "configure"
+#line 1311 "configure"
 #include "confdefs.h"
 #include <assert.h>
 Syntax Error
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1124: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:1317: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   :
@@ -1152,12 +1345,12 @@
 
 
 echo $ac_n "checking for ANSI C header files""... $ac_c" 1>&6
-echo "configure:1156: checking for ANSI C header files" >&5
+echo "configure:1349: checking for ANSI C header files" >&5
 if eval "test \"`echo '$''{'ac_cv_header_stdc'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1161 "configure"
+#line 1354 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 #include <stdarg.h>
@@ -1165,7 +1358,7 @@
 #include <float.h>
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1169: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:1362: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   rm -rf conftest*
@@ -1182,7 +1375,7 @@
 if test $ac_cv_header_stdc = yes; then
   # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
 cat > conftest.$ac_ext <<EOF
-#line 1186 "configure"
+#line 1379 "configure"
 #include "confdefs.h"
 #include <string.h>
 EOF
@@ -1200,7 +1393,7 @@
 if test $ac_cv_header_stdc = yes; then
   # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
 cat > conftest.$ac_ext <<EOF
-#line 1204 "configure"
+#line 1397 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 EOF
@@ -1221,7 +1414,7 @@
   :
 else
   cat > conftest.$ac_ext <<EOF
-#line 1225 "configure"
+#line 1418 "configure"
 #include "confdefs.h"
 #include <ctype.h>
 #define ISLOWER(c) ('a' <= (c) && (c) <= 'z')
@@ -1232,7 +1425,7 @@
 exit (0); }
 
 EOF
-if { (eval echo configure:1236: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:1429: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   :
 else
@@ -1259,17 +1452,17 @@
 do
 ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
 echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
-echo "configure:1263: checking for $ac_hdr" >&5
+echo "configure:1456: checking for $ac_hdr" >&5
 if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1268 "configure"
+#line 1461 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1273: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:1466: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   rm -rf conftest*
@@ -1296,13 +1489,21 @@
 done
 
 
+G10_LOCALEDIR="$g10_prefix/$DATADIRNAME/locale"
+
+cat >> confdefs.h <<EOF
+#define G10_LOCALEDIR "$G10_LOCALEDIR"
+EOF
+
+
+
 echo $ac_n "checking for working const""... $ac_c" 1>&6
-echo "configure:1301: checking for working const" >&5
+echo "configure:1502: checking for working const" >&5
 if eval "test \"`echo '$''{'ac_cv_c_const'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1306 "configure"
+#line 1507 "configure"
 #include "confdefs.h"
 
 int main() {
@@ -1351,7 +1552,7 @@
 
 ; return 0; }
 EOF
-if { (eval echo configure:1355: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:1556: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   ac_cv_c_const=yes
 else
@@ -1372,21 +1573,21 @@
 fi
 
 echo $ac_n "checking for inline""... $ac_c" 1>&6
-echo "configure:1376: checking for inline" >&5
+echo "configure:1577: checking for inline" >&5
 if eval "test \"`echo '$''{'ac_cv_c_inline'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   ac_cv_c_inline=no
 for ac_kw in inline __inline__ __inline; do
   cat > conftest.$ac_ext <<EOF
-#line 1383 "configure"
+#line 1584 "configure"
 #include "confdefs.h"
 
 int main() {
 } $ac_kw foo() {
 ; return 0; }
 EOF
-if { (eval echo configure:1390: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:1591: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   ac_cv_c_inline=$ac_kw; break
 else
@@ -1411,46 +1612,13 @@
  ;;
 esac
 
-echo $ac_n "checking for off_t""... $ac_c" 1>&6
-echo "configure:1416: checking for off_t" >&5
-if eval "test \"`echo '$''{'ac_cv_type_off_t'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  cat > conftest.$ac_ext <<EOF
-#line 1421 "configure"
-#include "confdefs.h"
-#include <sys/types.h>
-#if STDC_HEADERS
-#include <stdlib.h>
-#include <stddef.h>
-#endif
-EOF
-if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
-  egrep "off_t[^a-zA-Z_0-9]" >/dev/null 2>&1; then
-  rm -rf conftest*
-  ac_cv_type_off_t=yes
-else
-  rm -rf conftest*
-  ac_cv_type_off_t=no
-fi
-rm -f conftest*
-
-fi
-echo "$ac_t""$ac_cv_type_off_t" 1>&6
-if test $ac_cv_type_off_t = no; then
-  cat >> confdefs.h <<\EOF
-#define off_t long
-EOF
-
-fi
-
 echo $ac_n "checking for size_t""... $ac_c" 1>&6
-echo "configure:1449: checking for size_t" >&5
+echo "configure:1617: checking for size_t" >&5
 if eval "test \"`echo '$''{'ac_cv_type_size_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1454 "configure"
+#line 1622 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #if STDC_HEADERS
@@ -1477,608 +1645,535 @@
 
 fi
 
-# The Ultrix 4.2 mips builtin alloca declared by alloca.h only works
-# for constant arguments.  Useless!
-echo $ac_n "checking for working alloca.h""... $ac_c" 1>&6
-echo "configure:1484: checking for working alloca.h" >&5
-if eval "test \"`echo '$''{'ac_cv_header_alloca_h'+set}'`\" = set"; then
+
+ if test "$cross_compiling" = yes; then
+	echo "configure: warning: cross compiling; assuming little endianess" 1>&2
+    fi
+    echo $ac_n "checking endianess""... $ac_c" 1>&6
+echo "configure:1654: checking endianess" >&5
+    if eval "test \"`echo '$''{'wk_cv_c_endian'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  cat > conftest.$ac_ext <<EOF
-#line 1489 "configure"
+   wk_cv_c_endian=unknown
+	# See if sys/param.h defines the BYTE_ORDER macro.
+	cat > conftest.$ac_ext <<EOF
+#line 1661 "configure"
 #include "confdefs.h"
-#include <alloca.h>
+#include <sys/types.h>
+	#include <sys/param.h>
 int main() {
-char *p = alloca(2 * sizeof(int));
+
+	#if !BYTE_ORDER || !BIG_ENDIAN || !LITTLE_ENDIAN
+	 bogus endian macros
+	#endif
 ; return 0; }
 EOF
-if { (eval echo configure:1496: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1672: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
-  ac_cv_header_alloca_h=yes
+  # It does; now see whether it defined to BIG_ENDIAN or not.
+	cat > conftest.$ac_ext <<EOF
+#line 1676 "configure"
+#include "confdefs.h"
+#include <sys/types.h>
+	#include <sys/param.h>
+int main() {
+
+	#if BYTE_ORDER != BIG_ENDIAN
+	 not big endian
+	#endif
+; return 0; }
+EOF
+if { (eval echo configure:1687: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+  rm -rf conftest*
+  wk_cv_c_endian=big
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  ac_cv_header_alloca_h=no
+  wk_cv_c_endian=little
 fi
 rm -f conftest*
+else
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
 fi
-
-echo "$ac_t""$ac_cv_header_alloca_h" 1>&6
-if test $ac_cv_header_alloca_h = yes; then
-  cat >> confdefs.h <<\EOF
-#define HAVE_ALLOCA_H 1
-EOF
-
-fi
-
-echo $ac_n "checking for alloca""... $ac_c" 1>&6
-echo "configure:1517: checking for alloca" >&5
-if eval "test \"`echo '$''{'ac_cv_func_alloca_works'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
+rm -f conftest*
+	if test "$wk_cv_c_endian" = unknown; then
+	    if test "$cross_compiling" = yes; then
+  wk_cv_c_endian=little
+	    
 else
   cat > conftest.$ac_ext <<EOF
-#line 1522 "configure"
+#line 1708 "configure"
 #include "confdefs.h"
-
-#ifdef __GNUC__
-# define alloca __builtin_alloca
-#else
-# if HAVE_ALLOCA_H
-#  include <alloca.h>
-# else
-#  ifdef _AIX
- #pragma alloca
-#  else
-#   ifndef alloca /* predefined by HP cc +Olibcalls */
-char *alloca ();
-#   endif
-#  endif
-# endif
-#endif
-
-int main() {
-char *p = (char *) alloca(1);
-; return 0; }
+main () {
+	      /* Are we little or big endian?  From Harbison&Steele.  */
+	      union
+	      {
+		long l;
+		char c[sizeof (long)];
+	      } u;
+	      u.l = 1;
+	      exit (u.c[sizeof (long) - 1] == 1);
+	      }
 EOF
-if { (eval echo configure:1545: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
-  rm -rf conftest*
-  ac_cv_func_alloca_works=yes
+if { (eval echo configure:1721: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+then
+  wk_cv_c_endian=little
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
-  rm -rf conftest*
-  ac_cv_func_alloca_works=no
+  rm -fr conftest*
+  wk_cv_c_endian=big
 fi
-rm -f conftest*
+rm -fr conftest*
 fi
 
-echo "$ac_t""$ac_cv_func_alloca_works" 1>&6
-if test $ac_cv_func_alloca_works = yes; then
-  cat >> confdefs.h <<\EOF
-#define HAVE_ALLOCA 1
-EOF
-
+	fi
+      
 fi
 
-if test $ac_cv_func_alloca_works = no; then
-  # The SVR3 libPW and SVR4 libucb both contain incompatible functions
-  # that cause trouble.  Some versions do not even contain alloca or
-  # contain a buggy version.  If you still want to use their alloca,
-  # use ar to extract alloca.o from them instead of compiling alloca.c.
-  ALLOCA=alloca.o
-  cat >> confdefs.h <<\EOF
-#define C_ALLOCA 1
+    echo "$ac_t""$wk_cv_c_endian" 1>&6
+    if test "$wk_cv_c_endian" = little; then
+      cat >> confdefs.h <<\EOF
+#define LITTLE_ENDIAN_HOST 1
 EOF
 
+    else
+      cat >> confdefs.h <<\EOF
+#define BIG_ENDIAN_HOST 1
+EOF
 
-echo $ac_n "checking whether alloca needs Cray hooks""... $ac_c" 1>&6
-echo "configure:1577: checking whether alloca needs Cray hooks" >&5
-if eval "test \"`echo '$''{'ac_cv_os_cray'+set}'`\" = set"; then
+    fi
+  
+
+
+ echo $ac_n "checking for byte typedef""... $ac_c" 1>&6
+echo "configure:1753: checking for byte typedef" >&5
+    if eval "test \"`echo '$''{'wk_cv_typedef_byte'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1582 "configure"
+#line 1758 "configure"
 #include "confdefs.h"
-#if defined(CRAY) && ! defined(CRAY2)
-webecray
-#else
-wenotbecray
-#endif
+#include <stdlib.h>
+    #include <sys/types.h>
+int main() {
 
+    #undef byte
+    int a = sizeof(byte);
+    
+; return 0; }
 EOF
-if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
-  egrep "webecray" >/dev/null 2>&1; then
+if { (eval echo configure:1769: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
-  ac_cv_os_cray=yes
+  wk_cv_typedef_byte=yes
 else
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
   rm -rf conftest*
-  ac_cv_os_cray=no
+  wk_cv_typedef_byte=no 
 fi
 rm -f conftest*
-
 fi
 
-echo "$ac_t""$ac_cv_os_cray" 1>&6
-if test $ac_cv_os_cray = yes; then
-for ac_func in _getb67 GETB67 getb67; do
-  echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:1607: checking for $ac_func" >&5
-if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
+    echo "$ac_t""$wk_cv_typedef_byte" 1>&6
+    if test "$wk_cv_typedef_byte" = yes; then
+	cat >> confdefs.h <<\EOF
+#define HAVE_BYTE_TYPEDEF 1
+EOF
+
+    fi
+  
+ echo $ac_n "checking for ushort typedef""... $ac_c" 1>&6
+echo "configure:1790: checking for ushort typedef" >&5
+    if eval "test \"`echo '$''{'wk_cv_typedef_ushort'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1612 "configure"
+#line 1795 "configure"
 #include "confdefs.h"
-/* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char $ac_func(); below.  */
-#include <assert.h>
-/* Override any gcc2 internal prototype to avoid an error.  */
-/* We use char because int might match the return type of a gcc2
-    builtin and then its argument prototype would still apply.  */
-char $ac_func();
-
+#include <stdlib.h>
+    #include <sys/types.h>
 int main() {
 
-/* The GNU C library defines this for functions which it implements
-    to always fail with ENOSYS.  Some functions are actually named
-    something starting with __ and the normal name is an alias.  */
-#if defined (__stub_$ac_func) || defined (__stub___$ac_func)
-choke me
-#else
-$ac_func();
-#endif
-
+    #undef ushort
+    int a = sizeof(ushort);
+    
 ; return 0; }
 EOF
-if { (eval echo configure:1635: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1806: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
-  eval "ac_cv_func_$ac_func=yes"
+  wk_cv_typedef_ushort=yes
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_func_$ac_func=no"
+  wk_cv_typedef_ushort=no 
 fi
 rm -f conftest*
 fi
 
-if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
-  cat >> confdefs.h <<EOF
-#define CRAY_STACKSEG_END $ac_func
+    echo "$ac_t""$wk_cv_typedef_ushort" 1>&6
+    if test "$wk_cv_typedef_ushort" = yes; then
+	cat >> confdefs.h <<\EOF
+#define HAVE_USHORT_TYPEDEF 1
 EOF
 
-  break
-else
-  echo "$ac_t""no" 1>&6
-fi
-
-done
-fi
-
-echo $ac_n "checking stack direction for C alloca""... $ac_c" 1>&6
-echo "configure:1662: checking stack direction for C alloca" >&5
-if eval "test \"`echo '$''{'ac_cv_c_stack_direction'+set}'`\" = set"; then
+    fi
+  
+ echo $ac_n "checking for ulong typedef""... $ac_c" 1>&6
+echo "configure:1827: checking for ulong typedef" >&5
+    if eval "test \"`echo '$''{'wk_cv_typedef_ulong'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  if test "$cross_compiling" = yes; then
-  ac_cv_c_stack_direction=0
-else
   cat > conftest.$ac_ext <<EOF
-#line 1670 "configure"
+#line 1832 "configure"
 #include "confdefs.h"
-find_stack_direction ()
-{
-  static char *addr = 0;
-  auto char dummy;
-  if (addr == 0)
-    {
-      addr = &dummy;
-      return find_stack_direction ();
-    }
-  else
-    return (&dummy > addr) ? 1 : -1;
-}
-main ()
-{
-  exit (find_stack_direction() < 0);
-}
+#include <stdlib.h>
+    #include <sys/types.h>
+int main() {
+
+    #undef ulong
+    int a = sizeof(ulong);
+    
+; return 0; }
 EOF
-if { (eval echo configure:1689: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
-then
-  ac_cv_c_stack_direction=1
+if { (eval echo configure:1843: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+  rm -rf conftest*
+  wk_cv_typedef_ulong=yes
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
-  rm -fr conftest*
-  ac_cv_c_stack_direction=-1
-fi
-rm -fr conftest*
+  rm -rf conftest*
+  wk_cv_typedef_ulong=no 
 fi
-
+rm -f conftest*
 fi
 
-echo "$ac_t""$ac_cv_c_stack_direction" 1>&6
-cat >> confdefs.h <<EOF
-#define STACK_DIRECTION $ac_cv_c_stack_direction
+    echo "$ac_t""$wk_cv_typedef_ulong" 1>&6
+    if test "$wk_cv_typedef_ulong" = yes; then
+	cat >> confdefs.h <<\EOF
+#define HAVE_ULONG_TYPEDEF 1
 EOF
 
-fi
-
-for ac_hdr in unistd.h
-do
-ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
-echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
-echo "configure:1714: checking for $ac_hdr" >&5
-if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
+    fi
+  
+ echo $ac_n "checking for u16 typedef""... $ac_c" 1>&6
+echo "configure:1864: checking for u16 typedef" >&5
+    if eval "test \"`echo '$''{'wk_cv_typedef_u16'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1719 "configure"
+#line 1869 "configure"
 #include "confdefs.h"
-#include <$ac_hdr>
+#include <stdlib.h>
+    #include <sys/types.h>
+int main() {
+
+    #undef u16
+    int a = sizeof(u16);
+    
+; return 0; }
 EOF
-ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1724: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
-ac_err=`grep -v '^ *+' conftest.out`
-if test -z "$ac_err"; then
+if { (eval echo configure:1880: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
-  eval "ac_cv_header_$ac_safe=yes"
+  wk_cv_typedef_u16=yes
 else
-  echo "$ac_err" >&5
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_header_$ac_safe=no"
+  wk_cv_typedef_u16=no 
 fi
 rm -f conftest*
 fi
-if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
-    ac_tr_hdr=HAVE_`echo $ac_hdr | sed 'y%abcdefghijklmnopqrstuvwxyz./-%ABCDEFGHIJKLMNOPQRSTUVWXYZ___%'`
-  cat >> confdefs.h <<EOF
-#define $ac_tr_hdr 1
-EOF
- 
-else
-  echo "$ac_t""no" 1>&6
-fi
-done
 
-for ac_func in getpagesize
-do
-echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:1753: checking for $ac_func" >&5
-if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
+    echo "$ac_t""$wk_cv_typedef_u16" 1>&6
+    if test "$wk_cv_typedef_u16" = yes; then
+	cat >> confdefs.h <<\EOF
+#define HAVE_U16_TYPEDEF 1
+EOF
+
+    fi
+  
+ echo $ac_n "checking for u32 typedef""... $ac_c" 1>&6
+echo "configure:1901: checking for u32 typedef" >&5
+    if eval "test \"`echo '$''{'wk_cv_typedef_u32'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1758 "configure"
+#line 1906 "configure"
 #include "confdefs.h"
-/* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char $ac_func(); below.  */
-#include <assert.h>
-/* Override any gcc2 internal prototype to avoid an error.  */
-/* We use char because int might match the return type of a gcc2
-    builtin and then its argument prototype would still apply.  */
-char $ac_func();
-
+#include <stdlib.h>
+    #include <sys/types.h>
 int main() {
 
-/* The GNU C library defines this for functions which it implements
-    to always fail with ENOSYS.  Some functions are actually named
-    something starting with __ and the normal name is an alias.  */
-#if defined (__stub_$ac_func) || defined (__stub___$ac_func)
-choke me
-#else
-$ac_func();
-#endif
-
+    #undef u32
+    int a = sizeof(u32);
+    
 ; return 0; }
 EOF
-if { (eval echo configure:1781: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1917: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
-  eval "ac_cv_func_$ac_func=yes"
+  wk_cv_typedef_u32=yes
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_func_$ac_func=no"
+  wk_cv_typedef_u32=no 
 fi
 rm -f conftest*
 fi
 
-if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
-    ac_tr_func=HAVE_`echo $ac_func | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`
-  cat >> confdefs.h <<EOF
-#define $ac_tr_func 1
+    echo "$ac_t""$wk_cv_typedef_u32" 1>&6
+    if test "$wk_cv_typedef_u32" = yes; then
+	cat >> confdefs.h <<\EOF
+#define HAVE_U32_TYPEDEF 1
 EOF
- 
-else
-  echo "$ac_t""no" 1>&6
-fi
-done
 
-echo $ac_n "checking for working mmap""... $ac_c" 1>&6
-echo "configure:1806: checking for working mmap" >&5
-if eval "test \"`echo '$''{'ac_cv_func_mmap_fixed_mapped'+set}'`\" = set"; then
+    fi
+  
+
+echo $ac_n "checking size of unsigned short""... $ac_c" 1>&6
+echo "configure:1939: checking size of unsigned short" >&5
+if eval "test \"`echo '$''{'ac_cv_sizeof_unsigned_short'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   if test "$cross_compiling" = yes; then
-  ac_cv_func_mmap_fixed_mapped=no
+  ac_cv_sizeof_unsigned_short=2
 else
   cat > conftest.$ac_ext <<EOF
-#line 1814 "configure"
+#line 1947 "configure"
 #include "confdefs.h"
-
-/* Thanks to Mike Haertel and Jim Avera for this test.
-   Here is a matrix of mmap possibilities:
-	mmap private not fixed
-	mmap private fixed at somewhere currently unmapped
-	mmap private fixed at somewhere already mapped
-	mmap shared not fixed
-	mmap shared fixed at somewhere currently unmapped
-	mmap shared fixed at somewhere already mapped
-   For private mappings, we should verify that changes cannot be read()
-   back from the file, nor mmap's back from the file at a different
-   address.  (There have been systems where private was not correctly
-   implemented like the infamous i386 svr4.0, and systems where the
-   VM page cache was not coherent with the filesystem buffer cache
-   like early versions of FreeBSD and possibly contemporary NetBSD.)
-   For shared mappings, we should conversely verify that changes get
-   propogated back to all the places they're supposed to be.
-
-   Grep wants private fixed already mapped.
-   The main things grep needs to know about mmap are:
-   * does it exist and is it safe to write into the mmap'd area
-   * how to use it (BSD variants)  */
-#include <sys/types.h>
-#include <fcntl.h>
-#include <sys/mman.h>
-
-/* This mess was copied from the GNU getpagesize.h.  */
-#ifndef HAVE_GETPAGESIZE
-# ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-# endif
-
-/* Assume that all systems that can run configure have sys/param.h.  */
-# ifndef HAVE_SYS_PARAM_H
-#  define HAVE_SYS_PARAM_H 1
-# endif
-
-# ifdef _SC_PAGESIZE
-#  define getpagesize() sysconf(_SC_PAGESIZE)
-# else /* no _SC_PAGESIZE */
-#  ifdef HAVE_SYS_PARAM_H
-#   include <sys/param.h>
-#   ifdef EXEC_PAGESIZE
-#    define getpagesize() EXEC_PAGESIZE
-#   else /* no EXEC_PAGESIZE */
-#    ifdef NBPG
-#     define getpagesize() NBPG * CLSIZE
-#     ifndef CLSIZE
-#      define CLSIZE 1
-#     endif /* no CLSIZE */
-#    else /* no NBPG */
-#     ifdef NBPC
-#      define getpagesize() NBPC
-#     else /* no NBPC */
-#      ifdef PAGESIZE
-#       define getpagesize() PAGESIZE
-#      endif /* PAGESIZE */
-#     endif /* no NBPC */
-#    endif /* no NBPG */
-#   endif /* no EXEC_PAGESIZE */
-#  else /* no HAVE_SYS_PARAM_H */
-#   define getpagesize() 8192	/* punt totally */
-#  endif /* no HAVE_SYS_PARAM_H */
-# endif /* no _SC_PAGESIZE */
-
-#endif /* no HAVE_GETPAGESIZE */
-
-#ifdef __cplusplus
-extern "C" { void *malloc(unsigned); }
-#else
-char *malloc();
-#endif
-
-int
+#include <stdio.h>
 main()
 {
-	char *data, *data2, *data3;
-	int i, pagesize;
-	int fd;
-
-	pagesize = getpagesize();
-
-	/*
-	 * First, make a file with some known garbage in it.
-	 */
-	data = malloc(pagesize);
-	if (!data)
-		exit(1);
-	for (i = 0; i < pagesize; ++i)
-		*(data + i) = rand();
-	umask(0);
-	fd = creat("conftestmmap", 0600);
-	if (fd < 0)
-		exit(1);
-	if (write(fd, data, pagesize) != pagesize)
-		exit(1);
-	close(fd);
-
-	/*
-	 * Next, try to mmap the file at a fixed address which
-	 * already has something else allocated at it.  If we can,
-	 * also make sure that we see the same garbage.
-	 */
-	fd = open("conftestmmap", O_RDWR);
-	if (fd < 0)
-		exit(1);
-	data2 = malloc(2 * pagesize);
-	if (!data2)
-		exit(1);
-	data2 += (pagesize - ((int) data2 & (pagesize - 1))) & (pagesize - 1);
-	if (data2 != mmap(data2, pagesize, PROT_READ | PROT_WRITE,
-	    MAP_PRIVATE | MAP_FIXED, fd, 0L))
-		exit(1);
-	for (i = 0; i < pagesize; ++i)
-		if (*(data + i) != *(data2 + i))
-			exit(1);
-
-	/*
-	 * Finally, make sure that changes to the mapped area
-	 * do not percolate back to the file as seen by read().
-	 * (This is a bug on some variants of i386 svr4.0.)
-	 */
-	for (i = 0; i < pagesize; ++i)
-		*(data2 + i) = *(data2 + i) + 1;
-	data3 = malloc(pagesize);
-	if (!data3)
-		exit(1);
-	if (read(fd, data3, pagesize) != pagesize)
-		exit(1);
-	for (i = 0; i < pagesize; ++i)
-		if (*(data + i) != *(data3 + i))
-			exit(1);
-	close(fd);
-	unlink("conftestmmap");
-	exit(0);
+  FILE *f=fopen("conftestval", "w");
+  if (!f) exit(1);
+  fprintf(f, "%d\n", sizeof(unsigned short));
+  exit(0);
 }
-
 EOF
-if { (eval echo configure:1954: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:1958: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
-  ac_cv_func_mmap_fixed_mapped=yes
+  ac_cv_sizeof_unsigned_short=`cat conftestval`
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -fr conftest*
-  ac_cv_func_mmap_fixed_mapped=no
+  ac_cv_sizeof_unsigned_short=0
 fi
 rm -fr conftest*
 fi
 
 fi
-
-echo "$ac_t""$ac_cv_func_mmap_fixed_mapped" 1>&6
-if test $ac_cv_func_mmap_fixed_mapped = yes; then
-  cat >> confdefs.h <<\EOF
-#define HAVE_MMAP 1
+echo "$ac_t""$ac_cv_sizeof_unsigned_short" 1>&6
+cat >> confdefs.h <<EOF
+#define SIZEOF_UNSIGNED_SHORT $ac_cv_sizeof_unsigned_short
 EOF
 
-fi
 
-                           
-   for ac_hdr in limits.h locale.h nl_types.h malloc.h string.h unistd.h values.h
-do
-ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
-echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
-echo "configure:1981: checking for $ac_hdr" >&5
-if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
+echo $ac_n "checking size of unsigned int""... $ac_c" 1>&6
+echo "configure:1978: checking size of unsigned int" >&5
+if eval "test \"`echo '$''{'ac_cv_sizeof_unsigned_int'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
+  if test "$cross_compiling" = yes; then
+  ac_cv_sizeof_unsigned_int=4
+else
   cat > conftest.$ac_ext <<EOF
 #line 1986 "configure"
 #include "confdefs.h"
-#include <$ac_hdr>
+#include <stdio.h>
+main()
+{
+  FILE *f=fopen("conftestval", "w");
+  if (!f) exit(1);
+  fprintf(f, "%d\n", sizeof(unsigned int));
+  exit(0);
+}
 EOF
-ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1991: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
-ac_err=`grep -v '^ *+' conftest.out`
-if test -z "$ac_err"; then
-  rm -rf conftest*
-  eval "ac_cv_header_$ac_safe=yes"
+if { (eval echo configure:1997: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+then
+  ac_cv_sizeof_unsigned_int=`cat conftestval`
 else
-  echo "$ac_err" >&5
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
-  rm -rf conftest*
-  eval "ac_cv_header_$ac_safe=no"
+  rm -fr conftest*
+  ac_cv_sizeof_unsigned_int=0
 fi
-rm -f conftest*
+rm -fr conftest*
 fi
-if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
-    ac_tr_hdr=HAVE_`echo $ac_hdr | sed 'y%abcdefghijklmnopqrstuvwxyz./-%ABCDEFGHIJKLMNOPQRSTUVWXYZ___%'`
-  cat >> confdefs.h <<EOF
-#define $ac_tr_hdr 1
-EOF
- 
-else
-  echo "$ac_t""no" 1>&6
+
 fi
-done
+echo "$ac_t""$ac_cv_sizeof_unsigned_int" 1>&6
+cat >> confdefs.h <<EOF
+#define SIZEOF_UNSIGNED_INT $ac_cv_sizeof_unsigned_int
+EOF
 
-   for ac_func in getcwd munmap putenv setenv setlocale strchr strcasecmp
-do
-echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:2020: checking for $ac_func" >&5
-if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
+
+echo $ac_n "checking size of unsigned long""... $ac_c" 1>&6
+echo "configure:2017: checking size of unsigned long" >&5
+if eval "test \"`echo '$''{'ac_cv_sizeof_unsigned_long'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
+  if test "$cross_compiling" = yes; then
+  ac_cv_sizeof_unsigned_long=4
+else
   cat > conftest.$ac_ext <<EOF
 #line 2025 "configure"
 #include "confdefs.h"
+#include <stdio.h>
+main()
+{
+  FILE *f=fopen("conftestval", "w");
+  if (!f) exit(1);
+  fprintf(f, "%d\n", sizeof(unsigned long));
+  exit(0);
+}
+EOF
+if { (eval echo configure:2036: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+then
+  ac_cv_sizeof_unsigned_long=`cat conftestval`
+else
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
+  rm -fr conftest*
+  ac_cv_sizeof_unsigned_long=0
+fi
+rm -fr conftest*
+fi
+
+fi
+echo "$ac_t""$ac_cv_sizeof_unsigned_long" 1>&6
+cat >> confdefs.h <<EOF
+#define SIZEOF_UNSIGNED_LONG $ac_cv_sizeof_unsigned_long
+EOF
+
+
+
+if test "$ac_cv_sizeof_unsigned_short" = "0" \
+   || test "$ac_cv_sizeof_unsigned_int" = "0" \
+   || test "$ac_cv_sizeof_unsigned_long" = "0"; then
+    echo "configure: warning: Hmmm, something is wrong with the sizes - using defaults" 1>&2;
+fi
+
+
+
+echo $ac_n "checking for vprintf""... $ac_c" 1>&6
+echo "configure:2065: checking for vprintf" >&5
+if eval "test \"`echo '$''{'ac_cv_func_vprintf'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  cat > conftest.$ac_ext <<EOF
+#line 2070 "configure"
+#include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char $ac_func(); below.  */
+    which can conflict with char vprintf(); below.  */
 #include <assert.h>
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
     builtin and then its argument prototype would still apply.  */
-char $ac_func();
+char vprintf();
 
 int main() {
 
 /* The GNU C library defines this for functions which it implements
     to always fail with ENOSYS.  Some functions are actually named
     something starting with __ and the normal name is an alias.  */
-#if defined (__stub_$ac_func) || defined (__stub___$ac_func)
+#if defined (__stub_vprintf) || defined (__stub___vprintf)
 choke me
 #else
-$ac_func();
+vprintf();
 #endif
 
 ; return 0; }
 EOF
-if { (eval echo configure:2048: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2093: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  eval "ac_cv_func_$ac_func=yes"
+  eval "ac_cv_func_vprintf=yes"
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_func_$ac_func=no"
+  eval "ac_cv_func_vprintf=no"
 fi
 rm -f conftest*
 fi
 
-if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
+if eval "test \"`echo '$ac_cv_func_'vprintf`\" = yes"; then
   echo "$ac_t""yes" 1>&6
-    ac_tr_func=HAVE_`echo $ac_func | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`
-  cat >> confdefs.h <<EOF
-#define $ac_tr_func 1
+  cat >> confdefs.h <<\EOF
+#define HAVE_VPRINTF 1
 EOF
- 
+
 else
   echo "$ac_t""no" 1>&6
 fi
-done
 
+if test "$ac_cv_func_vprintf" != yes; then
+echo $ac_n "checking for _doprnt""... $ac_c" 1>&6
+echo "configure:2117: checking for _doprnt" >&5
+if eval "test \"`echo '$''{'ac_cv_func__doprnt'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  cat > conftest.$ac_ext <<EOF
+#line 2122 "configure"
+#include "confdefs.h"
+/* System header to define __stub macros and hopefully few prototypes,
+    which can conflict with char _doprnt(); below.  */
+#include <assert.h>
+/* Override any gcc2 internal prototype to avoid an error.  */
+/* We use char because int might match the return type of a gcc2
+    builtin and then its argument prototype would still apply.  */
+char _doprnt();
 
-   if test "${ac_cv_func_stpcpy+set}" != "set"; then
-     for ac_func in stpcpy
+int main() {
+
+/* The GNU C library defines this for functions which it implements
+    to always fail with ENOSYS.  Some functions are actually named
+    something starting with __ and the normal name is an alias.  */
+#if defined (__stub__doprnt) || defined (__stub____doprnt)
+choke me
+#else
+_doprnt();
+#endif
+
+; return 0; }
+EOF
+if { (eval echo configure:2145: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+  rm -rf conftest*
+  eval "ac_cv_func__doprnt=yes"
+else
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
+  rm -rf conftest*
+  eval "ac_cv_func__doprnt=no"
+fi
+rm -f conftest*
+fi
+
+if eval "test \"`echo '$ac_cv_func_'_doprnt`\" = yes"; then
+  echo "$ac_t""yes" 1>&6
+  cat >> confdefs.h <<\EOF
+#define HAVE_DOPRNT 1
+EOF
+
+else
+  echo "$ac_t""no" 1>&6
+fi
+
+fi
+
+for ac_func in strerror stpcpy strlwr tcgetattr rand strtoul mlock mmap
 do
 echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:2077: checking for $ac_func" >&5
+echo "configure:2172: checking for $ac_func" >&5
 if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2082 "configure"
+#line 2177 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -2101,7 +2196,7 @@
 
 ; return 0; }
 EOF
-if { (eval echo configure:2105: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2200: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_func_$ac_func=yes"
 else
@@ -2125,301 +2220,360 @@
 fi
 done
 
-   fi
-   if test "${ac_cv_func_stpcpy}" = "yes"; then
-     cat >> confdefs.h <<\EOF
-#define HAVE_STPCPY 1
-EOF
 
-   fi
 
-   if test $ac_cv_header_locale_h = yes; then
-    echo $ac_n "checking for LC_MESSAGES""... $ac_c" 1>&6
-echo "configure:2139: checking for LC_MESSAGES" >&5
-if eval "test \"`echo '$''{'ud_cv_val_LC_MESSAGES'+set}'`\" = set"; then
+
+
+echo $ac_n "checking for random device""... $ac_c" 1>&6
+echo "configure:2229: checking for random device" >&5
+if eval "test \"`echo '$''{'ac_cv_have_dev_random'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  cat > conftest.$ac_ext <<EOF
-#line 2144 "configure"
-#include "confdefs.h"
-#include <locale.h>
-int main() {
-return LC_MESSAGES
-; return 0; }
-EOF
-if { (eval echo configure:2151: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
-  rm -rf conftest*
-  ud_cv_val_LC_MESSAGES=yes
-else
-  echo "configure: failed program was:" >&5
-  cat conftest.$ac_ext >&5
-  rm -rf conftest*
-  ud_cv_val_LC_MESSAGES=no
-fi
-rm -f conftest*
+  if test -c /dev/random && test -c /dev/urandom ; then
+  ac_cv_have_dev_random=yes; else ac_cv_have_dev_random=no; fi
 fi
 
-echo "$ac_t""$ud_cv_val_LC_MESSAGES" 1>&6
-    if test $ud_cv_val_LC_MESSAGES = yes; then
-      cat >> confdefs.h <<\EOF
-#define HAVE_LC_MESSAGES 1
+echo "$ac_t""$ac_cv_have_dev_random" 1>&6
+if test "$ac_cv_have_dev_random" = yes; then
+    cat >> confdefs.h <<\EOF
+#define HAVE_DEV_RANDOM 1
 EOF
 
+fi
+
+
+echo $ac_n "checking for mpi assembler functions""... $ac_c" 1>&6
+echo "configure:2247: checking for mpi assembler functions" >&5
+if test -f $srcdir/mpi/config.links ; then
+    . $srcdir/mpi/config.links
+     if test "x$wk_link_files_src" = "x"; then
+	wk_link_files_src="$mpi_ln_src"
+	wk_link_files_dst="$mpi_ln_dst"
+    else
+	wk_link_files_src="$wk_link_files_src $mpi_ln_src"
+	wk_link_files_dst="$wk_link_files_dst $mpi_ln_dst"
     fi
-  fi
-   echo $ac_n "checking whether NLS is requested""... $ac_c" 1>&6
-echo "configure:2172: checking whether NLS is requested" >&5
-        # Check whether --enable-nls or --disable-nls was given.
-if test "${enable_nls+set}" = set; then
-  enableval="$enable_nls"
-  nls_cv_use_nls=$enableval
+  
+    ac_cv_mpi_extra_asm_modules="$mpi_extra_modules"
+    ac_cv_mpi_config_done="yes"
+    echo "$ac_t""done" 1>&6
 else
-  nls_cv_use_nls=yes
+    echo "$ac_t""failed" 1>&6
+    { echo "configure: error: mpi/config.links missing!" 1>&2; exit 1; }
+fi
+MPI_EXTRA_ASM_OBJS=""
+if test "$ac_cv_mpi_extra_asm_modules" != ""; then
+ echo $ac_n "mpi extra asm functions:"" $ac_c" 1>&6
+  
+for i in $ac_cv_mpi_extra_asm_modules; do
+     echo $ac_n "$i"" $ac_c" 1>&6
+  
+    MPI_EXTRA_ASM_OBJS="$MPI_EXTRA_ASM_OBJS $i.o"
+done
+echo "$ac_t""" 1>&6
 fi
 
-    echo "$ac_t""$nls_cv_use_nls" 1>&6
 
-        if test "$nls_cv_use_nls" = "yes"; then
-      cat >> confdefs.h <<\EOF
-#define ENABLE_NLS 1
-EOF
+if test "$g10_force_zlib" = "yes"; then
+    ZLIBS="../zlib/libzlib.a"
+    
 
-      echo $ac_n "checking for explicitly using GNU gettext""... $ac_c" 1>&6
-echo "configure:2189: checking for explicitly using GNU gettext" >&5
-      # Check whether --with-gnu-gettext or --without-gnu-gettext was given.
-if test "${with_gnu_gettext+set}" = set; then
-  withval="$with_gnu_gettext"
-  nls_cv_force_use_gnu_gettext=$withval
+if true; then
+  ENABLE_LOCAL_ZLIB_TRUE=
+  ENABLE_LOCAL_ZLIB_FALSE='#'
 else
-  nls_cv_force_use_gnu_gettext=no
+  ENABLE_LOCAL_ZLIB_TRUE='#'
+  ENABLE_LOCAL_ZLIB_FALSE=
 fi
-
-      echo "$ac_t""$nls_cv_force_use_gnu_gettext" 1>&6
-
-      if test "$nls_cv_force_use_gnu_gettext" = "yes"; then
-	nls_cv_use_gnu_gettext=yes
-      else
-				echo $ac_n "checking for main in -lintl""... $ac_c" 1>&6
-echo "configure:2204: checking for main in -lintl" >&5
-ac_lib_var=`echo intl'_'main | sed 'y%./+-%__p_%'`
-if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
+     if test "x$wk_link_files_src" = "x"; then
+	wk_link_files_src="zlib/zlib.h"
+	wk_link_files_dst="zlib.h "
+    else
+	wk_link_files_src="$wk_link_files_src zlib/zlib.h"
+	wk_link_files_dst="$wk_link_files_dst zlib.h "
+    fi
+  
+     if test "x$wk_link_files_src" = "x"; then
+	wk_link_files_src="zlib/zconf.h"
+	wk_link_files_dst="zconf.h "
+    else
+	wk_link_files_src="$wk_link_files_src zlib/zconf.h"
+	wk_link_files_dst="$wk_link_files_dst zconf.h "
+    fi
+  
+else
+for ac_hdr in zlib.h
+do
+ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
+echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
+echo "configure:2310: checking for $ac_hdr" >&5
+if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  ac_save_LIBS="$LIBS"
-LIBS="-lintl  $LIBS"
-cat > conftest.$ac_ext <<EOF
-#line 2212 "configure"
+  cat > conftest.$ac_ext <<EOF
+#line 2315 "configure"
 #include "confdefs.h"
-
-int main() {
-main()
-; return 0; }
+#include <$ac_hdr>
 EOF
-if { (eval echo configure:2219: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
+{ (eval echo configure:2320: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+ac_err=`grep -v '^ *+' conftest.out`
+if test -z "$ac_err"; then
   rm -rf conftest*
-  eval "ac_cv_lib_$ac_lib_var=yes"
+  eval "ac_cv_header_$ac_safe=yes"
 else
+  echo "$ac_err" >&5
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_lib_$ac_lib_var=no"
+  eval "ac_cv_header_$ac_safe=no"
 fi
 rm -f conftest*
-LIBS="$ac_save_LIBS"
-
 fi
-if eval "test \"`echo '$ac_cv_lib_'$ac_lib_var`\" = yes"; then
+if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
   echo "$ac_t""yes" 1>&6
-    ac_tr_lib=HAVE_LIB`echo intl | sed -e 's/[^a-zA-Z0-9_]/_/g' \
-    -e 'y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/'`
+    ac_tr_hdr=HAVE_`echo $ac_hdr | sed 'y%abcdefghijklmnopqrstuvwxyz./-%ABCDEFGHIJKLMNOPQRSTUVWXYZ___%'`
   cat >> confdefs.h <<EOF
-#define $ac_tr_lib 1
+#define $ac_tr_hdr 1
 EOF
+ 
+else
+  echo "$ac_t""no" 1>&6
+fi
+done
 
-  LIBS="-lintl $LIBS"
+if test "$ac_cv_header_zlib_h" = yes ; then
+    LIBS="$LIBS -lz"
+    ZLIBS=
+    
 
+if false; then
+  ENABLE_LOCAL_ZLIB_TRUE=
+  ENABLE_LOCAL_ZLIB_FALSE='#'
 else
-  echo "$ac_t""no" 1>&6
+  ENABLE_LOCAL_ZLIB_TRUE='#'
+  ENABLE_LOCAL_ZLIB_FALSE=
 fi
+else
+    ZLIBS="../zlib/libzlib.a"
+    
 
-	echo $ac_n "checking for main in -li""... $ac_c" 1>&6
-echo "configure:2247: checking for main in -li" >&5
-ac_lib_var=`echo i'_'main | sed 'y%./+-%__p_%'`
-if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
+if true; then
+  ENABLE_LOCAL_ZLIB_TRUE=
+  ENABLE_LOCAL_ZLIB_FALSE='#'
+else
+  ENABLE_LOCAL_ZLIB_TRUE='#'
+  ENABLE_LOCAL_ZLIB_FALSE=
+fi
+     if test "x$wk_link_files_src" = "x"; then
+	wk_link_files_src="zlib/zlib.h"
+	wk_link_files_dst="zlib.h "
+    else
+	wk_link_files_src="$wk_link_files_src zlib/zlib.h"
+	wk_link_files_dst="$wk_link_files_dst zlib.h "
+    fi
+  
+     if test "x$wk_link_files_src" = "x"; then
+	wk_link_files_src="zlib/zconf.h"
+	wk_link_files_dst="zconf.h "
+    else
+	wk_link_files_src="$wk_link_files_src zlib/zconf.h"
+	wk_link_files_dst="$wk_link_files_dst zconf.h "
+    fi
+  
+fi
+fi
+
+
+
+CIPHER_EXTRA_OBJS=""
+CIPHER_EXTRA_DIST=""
+echo $ac_n "checking for extra cipher modules""... $ac_c" 1>&6
+echo "configure:2393: checking for extra cipher modules" >&5
+if eval "test \"`echo '$''{'ac_cv_have_rsa_cipher'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  ac_save_LIBS="$LIBS"
-LIBS="-li  $LIBS"
-cat > conftest.$ac_ext <<EOF
-#line 2255 "configure"
-#include "confdefs.h"
+  if test -f $srcdir/cipher/rsa.c && test -f $srcdir/cipher/rsa.h; then
+  ac_cv_have_rsa_cipher=yes; else ac_cv_have_rsa_cipher=no; fi
+fi
 
-int main() {
-main()
-; return 0; }
+echo "$ac_t""$ac_cv_have_rsa_cipher" 1>&6
+if test $ac_cv_have_rsa_cipher = yes; then
+    cat >> confdefs.h <<\EOF
+#define HAVE_RSA_CIPHER 1
+EOF
+
+    CIPHER_EXTRA_OBJS="rsa.o"
+    CIPHER_EXTRA_DIST="rsa.c rsa.h"
+fi
+
+
+
+echo $ac_n "checking for off_t""... $ac_c" 1>&6
+echo "configure:2414: checking for off_t" >&5
+if eval "test \"`echo '$''{'ac_cv_type_off_t'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  cat > conftest.$ac_ext <<EOF
+#line 2419 "configure"
+#include "confdefs.h"
+#include <sys/types.h>
+#if STDC_HEADERS
+#include <stdlib.h>
+#include <stddef.h>
+#endif
 EOF
-if { (eval echo configure:2262: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
+  egrep "off_t[^a-zA-Z_0-9]" >/dev/null 2>&1; then
   rm -rf conftest*
-  eval "ac_cv_lib_$ac_lib_var=yes"
+  ac_cv_type_off_t=yes
 else
-  echo "configure: failed program was:" >&5
-  cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_lib_$ac_lib_var=no"
+  ac_cv_type_off_t=no
 fi
 rm -f conftest*
-LIBS="$ac_save_LIBS"
 
 fi
-if eval "test \"`echo '$ac_cv_lib_'$ac_lib_var`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
-    ac_tr_lib=HAVE_LIB`echo i | sed -e 's/[^a-zA-Z0-9_]/_/g' \
-    -e 'y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/'`
-  cat >> confdefs.h <<EOF
-#define $ac_tr_lib 1
+echo "$ac_t""$ac_cv_type_off_t" 1>&6
+if test $ac_cv_type_off_t = no; then
+  cat >> confdefs.h <<\EOF
+#define off_t long
 EOF
 
-  LIBS="-li $LIBS"
-
-else
-  echo "$ac_t""no" 1>&6
 fi
 
-	CATOBJEXT=NONE
-
-		ac_safe=`echo "libintl.h" | sed 'y%./+-%__p_%'`
-echo $ac_n "checking for libintl.h""... $ac_c" 1>&6
-echo "configure:2293: checking for libintl.h" >&5
-if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
+# The Ultrix 4.2 mips builtin alloca declared by alloca.h only works
+# for constant arguments.  Useless!
+echo $ac_n "checking for working alloca.h""... $ac_c" 1>&6
+echo "configure:2449: checking for working alloca.h" >&5
+if eval "test \"`echo '$''{'ac_cv_header_alloca_h'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2298 "configure"
+#line 2454 "configure"
 #include "confdefs.h"
-#include <libintl.h>
+#include <alloca.h>
+int main() {
+char *p = alloca(2 * sizeof(int));
+; return 0; }
 EOF
-ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:2303: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
-ac_err=`grep -v '^ *+' conftest.out`
-if test -z "$ac_err"; then
+if { (eval echo configure:2461: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  eval "ac_cv_header_$ac_safe=yes"
+  ac_cv_header_alloca_h=yes
 else
-  echo "$ac_err" >&5
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_header_$ac_safe=no"
+  ac_cv_header_alloca_h=no
 fi
 rm -f conftest*
 fi
-if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
-   cat >> confdefs.h <<\EOF
-#define HAVE_LIBINTL_H 1
+
+echo "$ac_t""$ac_cv_header_alloca_h" 1>&6
+if test $ac_cv_header_alloca_h = yes; then
+  cat >> confdefs.h <<\EOF
+#define HAVE_ALLOCA_H 1
 EOF
- 
-else
-  echo "$ac_t""no" 1>&6
+
 fi
 
-	if    test "$ac_cv_lib_intl_main" = yes \
-	   && test "$ac_cv_header_libintl_h" != "yes" ; then
-	    nls_cv_use_gnu_gettext=yes
-	else
-	    echo $ac_n "checking for gettext""... $ac_c" 1>&6
-echo "configure:2332: checking for gettext" >&5
-if eval "test \"`echo '$''{'ac_cv_func_gettext'+set}'`\" = set"; then
+echo $ac_n "checking for alloca""... $ac_c" 1>&6
+echo "configure:2482: checking for alloca" >&5
+if eval "test \"`echo '$''{'ac_cv_func_alloca_works'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2337 "configure"
+#line 2487 "configure"
 #include "confdefs.h"
-/* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char gettext(); below.  */
-#include <assert.h>
-/* Override any gcc2 internal prototype to avoid an error.  */
-/* We use char because int might match the return type of a gcc2
-    builtin and then its argument prototype would still apply.  */
-char gettext();
-
-int main() {
 
-/* The GNU C library defines this for functions which it implements
-    to always fail with ENOSYS.  Some functions are actually named
-    something starting with __ and the normal name is an alias.  */
-#if defined (__stub_gettext) || defined (__stub___gettext)
-choke me
+#ifdef __GNUC__
+# define alloca __builtin_alloca
 #else
-gettext();
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else
+#  ifdef _AIX
+ #pragma alloca
+#  else
+#   ifndef alloca /* predefined by HP cc +Olibcalls */
+char *alloca ();
+#   endif
+#  endif
+# endif
 #endif
 
+int main() {
+char *p = (char *) alloca(1);
 ; return 0; }
 EOF
-if { (eval echo configure:2360: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2510: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  eval "ac_cv_func_gettext=yes"
+  ac_cv_func_alloca_works=yes
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_func_gettext=no"
+  ac_cv_func_alloca_works=no
 fi
 rm -f conftest*
 fi
 
-if eval "test \"`echo '$ac_cv_func_'gettext`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
+echo "$ac_t""$ac_cv_func_alloca_works" 1>&6
+if test $ac_cv_func_alloca_works = yes; then
   cat >> confdefs.h <<\EOF
-#define HAVE_GETTEXT 1
+#define HAVE_ALLOCA 1
 EOF
 
-	       # Extract the first word of "msgfmt", so it can be a program name with args.
-set dummy msgfmt; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2381: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_MSGFMT'+set}'`\" = set"; then
+fi
+
+if test $ac_cv_func_alloca_works = no; then
+  # The SVR3 libPW and SVR4 libucb both contain incompatible functions
+  # that cause trouble.  Some versions do not even contain alloca or
+  # contain a buggy version.  If you still want to use their alloca,
+  # use ar to extract alloca.o from them instead of compiling alloca.c.
+  ALLOCA=alloca.o
+  cat >> confdefs.h <<\EOF
+#define C_ALLOCA 1
+EOF
+
+
+echo $ac_n "checking whether alloca needs Cray hooks""... $ac_c" 1>&6
+echo "configure:2542: checking whether alloca needs Cray hooks" >&5
+if eval "test \"`echo '$''{'ac_cv_os_cray'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  case "$MSGFMT" in
-  /*)
-  ac_cv_path_MSGFMT="$MSGFMT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_MSGFMT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  test -z "$ac_cv_path_MSGFMT" && ac_cv_path_MSGFMT="no"
-  ;;
-esac
-fi
-MSGFMT="$ac_cv_path_MSGFMT"
-if test -n "$MSGFMT"; then
-  echo "$ac_t""$MSGFMT" 1>&6
+  cat > conftest.$ac_ext <<EOF
+#line 2547 "configure"
+#include "confdefs.h"
+#if defined(CRAY) && ! defined(CRAY2)
+webecray
+#else
+wenotbecray
+#endif
+
+EOF
+if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
+  egrep "webecray" >/dev/null 2>&1; then
+  rm -rf conftest*
+  ac_cv_os_cray=yes
 else
-  echo "$ac_t""no" 1>&6
+  rm -rf conftest*
+  ac_cv_os_cray=no
 fi
-   if echo $MSGFMT | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's msgfmt.  (Better remove it.) >&6"
-     ac_cv_path_MSGFMT=msgfmt
-     MSGFMT=msgfmt
-   fi
-	       if test "$MSGFMT" != "no"; then
-		 for ac_func in dcgettext
-do
-echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:2418: checking for $ac_func" >&5
+rm -f conftest*
+
+fi
+
+echo "$ac_t""$ac_cv_os_cray" 1>&6
+if test $ac_cv_os_cray = yes; then
+for ac_func in _getb67 GETB67 getb67; do
+  echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
+echo "configure:2572: checking for $ac_func" >&5
 if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2423 "configure"
+#line 2577 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -2442,7 +2596,7 @@
 
 ; return 0; }
 EOF
-if { (eval echo configure:2446: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2600: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_func_$ac_func=yes"
 else
@@ -2456,1343 +2610,1343 @@
 
 if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
   echo "$ac_t""yes" 1>&6
-    ac_tr_func=HAVE_`echo $ac_func | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`
   cat >> confdefs.h <<EOF
-#define $ac_tr_func 1
+#define CRAY_STACKSEG_END $ac_func
 EOF
- 
+
+  break
 else
   echo "$ac_t""no" 1>&6
 fi
+
 done
+fi
 
-		 # Extract the first word of "gmsgfmt", so it can be a program name with args.
-set dummy gmsgfmt; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2473: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_GMSGFMT'+set}'`\" = set"; then
+echo $ac_n "checking stack direction for C alloca""... $ac_c" 1>&6
+echo "configure:2627: checking stack direction for C alloca" >&5
+if eval "test \"`echo '$''{'ac_cv_c_stack_direction'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  case "$GMSGFMT" in
-  /*)
-  ac_cv_path_GMSGFMT="$GMSGFMT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_GMSGFMT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  test -z "$ac_cv_path_GMSGFMT" && ac_cv_path_GMSGFMT="$MSGFMT"
-  ;;
-esac
-fi
-GMSGFMT="$ac_cv_path_GMSGFMT"
-if test -n "$GMSGFMT"; then
-  echo "$ac_t""$GMSGFMT" 1>&6
+  if test "$cross_compiling" = yes; then
+  ac_cv_c_stack_direction=0
 else
-  echo "$ac_t""no" 1>&6
+  cat > conftest.$ac_ext <<EOF
+#line 2635 "configure"
+#include "confdefs.h"
+find_stack_direction ()
+{
+  static char *addr = 0;
+  auto char dummy;
+  if (addr == 0)
+    {
+      addr = &dummy;
+      return find_stack_direction ();
+    }
+  else
+    return (&dummy > addr) ? 1 : -1;
+}
+main ()
+{
+  exit (find_stack_direction() < 0);
+}
+EOF
+if { (eval echo configure:2654: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+then
+  ac_cv_c_stack_direction=1
+else
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
+  rm -fr conftest*
+  ac_cv_c_stack_direction=-1
+fi
+rm -fr conftest*
 fi
-   if echo $GMSGFMT | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's gmsgfmt.  (Better remove it.) >&6"
-     ac_cv_path_GMSGFMT=gmsgfmt
-     GMSGFMT=gmsgfmt
-   fi
 
-		 # Extract the first word of "xgettext", so it can be a program name with args.
-set dummy xgettext; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2510: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_XGETTEXT'+set}'`\" = set"; then
+fi
+
+echo "$ac_t""$ac_cv_c_stack_direction" 1>&6
+cat >> confdefs.h <<EOF
+#define STACK_DIRECTION $ac_cv_c_stack_direction
+EOF
+
+fi
+
+for ac_hdr in unistd.h
+do
+ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
+echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
+echo "configure:2679: checking for $ac_hdr" >&5
+if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  case "$XGETTEXT" in
-  /*)
-  ac_cv_path_XGETTEXT="$XGETTEXT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_XGETTEXT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  test -z "$ac_cv_path_XGETTEXT" && ac_cv_path_XGETTEXT="xgettext"
-  ;;
-esac
-fi
-XGETTEXT="$ac_cv_path_XGETTEXT"
-if test -n "$XGETTEXT"; then
-  echo "$ac_t""$XGETTEXT" 1>&6
+  cat > conftest.$ac_ext <<EOF
+#line 2684 "configure"
+#include "confdefs.h"
+#include <$ac_hdr>
+EOF
+ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
+{ (eval echo configure:2689: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+ac_err=`grep -v '^ *+' conftest.out`
+if test -z "$ac_err"; then
+  rm -rf conftest*
+  eval "ac_cv_header_$ac_safe=yes"
 else
-  echo "$ac_t""no" 1>&6
+  echo "$ac_err" >&5
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
+  rm -rf conftest*
+  eval "ac_cv_header_$ac_safe=no"
 fi
-   if echo $XGETTEXT | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's xgettext.  (Better remove it.) >&6"
-     ac_cv_path_XGETTEXT=xgettext
-     XGETTEXT=xgettext
-   fi
-
-		 CATOBJEXT=.mo
-		 INSTOBJEXT=.mo
-		 DATADIRNAME=lib
-		 if test "$ac_cv_lib_intl_main" = yes; then
-		   INTLLIBS=-lintl
-		 elif test "$ac_cv_lib_i_main" = yes; then
-		   INTLLIBS=-li
-		 fi
-	       fi
+rm -f conftest*
+fi
+if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
+  echo "$ac_t""yes" 1>&6
+    ac_tr_hdr=HAVE_`echo $ac_hdr | sed 'y%abcdefghijklmnopqrstuvwxyz./-%ABCDEFGHIJKLMNOPQRSTUVWXYZ___%'`
+  cat >> confdefs.h <<EOF
+#define $ac_tr_hdr 1
+EOF
+ 
 else
   echo "$ac_t""no" 1>&6
 fi
+done
 
-
-	    if test "$CATOBJEXT" = "NONE"; then
-	      	      echo $ac_n "checking for catgets""... $ac_c" 1>&6
-echo "configure:2560: checking for catgets" >&5
-if eval "test \"`echo '$''{'ac_cv_func_catgets'+set}'`\" = set"; then
+for ac_func in getpagesize
+do
+echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
+echo "configure:2718: checking for $ac_func" >&5
+if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2565 "configure"
+#line 2723 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char catgets(); below.  */
+    which can conflict with char $ac_func(); below.  */
 #include <assert.h>
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
     builtin and then its argument prototype would still apply.  */
-char catgets();
+char $ac_func();
 
 int main() {
 
 /* The GNU C library defines this for functions which it implements
     to always fail with ENOSYS.  Some functions are actually named
     something starting with __ and the normal name is an alias.  */
-#if defined (__stub_catgets) || defined (__stub___catgets)
+#if defined (__stub_$ac_func) || defined (__stub___$ac_func)
 choke me
 #else
-catgets();
+$ac_func();
 #endif
 
 ; return 0; }
 EOF
-if { (eval echo configure:2588: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2746: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  eval "ac_cv_func_catgets=yes"
+  eval "ac_cv_func_$ac_func=yes"
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_func_catgets=no"
+  eval "ac_cv_func_$ac_func=no"
 fi
 rm -f conftest*
 fi
 
-if eval "test \"`echo '$ac_cv_func_'catgets`\" = yes"; then
+if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
   echo "$ac_t""yes" 1>&6
-  cat >> confdefs.h <<\EOF
-#define HAVE_CATGETS 1
+    ac_tr_func=HAVE_`echo $ac_func | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`
+  cat >> confdefs.h <<EOF
+#define $ac_tr_func 1
 EOF
-
-		 INTLOBJS="\$(CATOBJS)"
-		 # Extract the first word of "gencat", so it can be a program name with args.
-set dummy gencat; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2610: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_GENCAT'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  case "$GENCAT" in
-  /*)
-  ac_cv_path_GENCAT="$GENCAT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_GENCAT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  test -z "$ac_cv_path_GENCAT" && ac_cv_path_GENCAT="no"
-  ;;
-esac
-fi
-GENCAT="$ac_cv_path_GENCAT"
-if test -n "$GENCAT"; then
-  echo "$ac_t""$GENCAT" 1>&6
-else
-  echo "$ac_t""no" 1>&6
-fi
-		 if test "$GENCAT" != "no"; then
-		   for ac_prog in gmsgfmt msgfmt
-do
-# Extract the first word of "$ac_prog", so it can be a program name with args.
-set dummy $ac_prog; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2644: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_GMSGFMT'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  case "$GMSGFMT" in
-  /*)
-  ac_cv_path_GMSGFMT="$GMSGFMT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_GMSGFMT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  ;;
-esac
-fi
-GMSGFMT="$ac_cv_path_GMSGFMT"
-if test -n "$GMSGFMT"; then
-  echo "$ac_t""$GMSGFMT" 1>&6
+ 
 else
   echo "$ac_t""no" 1>&6
 fi
-
-test -n "$GMSGFMT" && break
 done
-test -n "$GMSGFMT" || GMSGFMT="msgfmt"
 
-		   # Extract the first word of "xgettext", so it can be a program name with args.
-set dummy xgettext; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2679: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_XGETTEXT'+set}'`\" = set"; then
+echo $ac_n "checking for working mmap""... $ac_c" 1>&6
+echo "configure:2771: checking for working mmap" >&5
+if eval "test \"`echo '$''{'ac_cv_func_mmap_fixed_mapped'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  case "$XGETTEXT" in
-  /*)
-  ac_cv_path_XGETTEXT="$XGETTEXT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_XGETTEXT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  test -z "$ac_cv_path_XGETTEXT" && ac_cv_path_XGETTEXT="xgettext"
-  ;;
-esac
-fi
-XGETTEXT="$ac_cv_path_XGETTEXT"
-if test -n "$XGETTEXT"; then
-  echo "$ac_t""$XGETTEXT" 1>&6
-else
-  echo "$ac_t""no" 1>&6
-fi
-   if echo $XGETTEXT | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's xgettext.  (Better remove it.) >&6"
-     ac_cv_path_XGETTEXT=xgettext
-     XGETTEXT=xgettext
-   fi
-
-		   CATOBJEXT=.cat
-		   INSTOBJEXT=.cat
-		   DATADIRNAME=lib
-		   INTLDEPS="\${top_srcdir}/intl/libintl.a"
-		   INTLLIBS=$INTLDEPS
-		   LIBS=`echo $LIBS | sed -e 's/-lintl//'`
-		   nls_cv_header_intl=libintl.h
-		   nls_cv_header_libgt=intl/libgettext.h
-		 fi
+  if test "$cross_compiling" = yes; then
+  ac_cv_func_mmap_fixed_mapped=no
 else
-  echo "$ac_t""no" 1>&6
-fi
-
-	    fi
-	fi
-
-	if test "$CATOBJEXT" = "NONE"; then
-	  	  	  nls_cv_use_gnu_gettext=yes
-	fi
-      fi
+  cat > conftest.$ac_ext <<EOF
+#line 2779 "configure"
+#include "confdefs.h"
 
-      if test "$nls_cv_use_gnu_gettext" = "yes"; then
-		INTLOBJS="\$(GETTOBJS)"
-	# Extract the first word of "msgfmt", so it can be a program name with args.
-set dummy msgfmt; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2739: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_MSGFMT'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  case "$MSGFMT" in
-  /*)
-  ac_cv_path_MSGFMT="$MSGFMT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_MSGFMT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  test -z "$ac_cv_path_MSGFMT" && ac_cv_path_MSGFMT="msgfmt"
-  ;;
-esac
-fi
-MSGFMT="$ac_cv_path_MSGFMT"
-if test -n "$MSGFMT"; then
-  echo "$ac_t""$MSGFMT" 1>&6
-else
-  echo "$ac_t""no" 1>&6
-fi
-   if echo $MSGFMT | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's msgfmt.  (Better remove it.) >&6"
-     ac_cv_path_MSGFMT=msgfmt
-     MSGFMT=msgfmt
-   fi
-
-	# Extract the first word of "gmsgfmt", so it can be a program name with args.
-set dummy gmsgfmt; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2776: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_GMSGFMT'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  case "$GMSGFMT" in
-  /*)
-  ac_cv_path_GMSGFMT="$GMSGFMT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_GMSGFMT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  test -z "$ac_cv_path_GMSGFMT" && ac_cv_path_GMSGFMT="$MSGFMT"
-  ;;
-esac
-fi
-GMSGFMT="$ac_cv_path_GMSGFMT"
-if test -n "$GMSGFMT"; then
-  echo "$ac_t""$GMSGFMT" 1>&6
-else
-  echo "$ac_t""no" 1>&6
-fi
-   if echo $GMSGFMT | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's gmsgfmt.  (Better remove it.) >&6"
-     ac_cv_path_GMSGFMT=gmsgfmt
-     GMSGFMT=gmsgfmt
-   fi
-
-	# Extract the first word of "xgettext", so it can be a program name with args.
-set dummy xgettext; ac_word=$2
-echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:2813: checking for $ac_word" >&5
-if eval "test \"`echo '$''{'ac_cv_path_XGETTEXT'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  case "$XGETTEXT" in
-  /*)
-  ac_cv_path_XGETTEXT="$XGETTEXT" # Let the user override the test with a path.
-  ;;
-  *)
-  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
-  for ac_dir in $PATH; do
-    test -z "$ac_dir" && ac_dir=.
-    if test -f $ac_dir/$ac_word; then
-      ac_cv_path_XGETTEXT="$ac_dir/$ac_word"
-      break
-    fi
-  done
-  IFS="$ac_save_ifs"
-  test -z "$ac_cv_path_XGETTEXT" && ac_cv_path_XGETTEXT="xgettext"
-  ;;
-esac
-fi
-XGETTEXT="$ac_cv_path_XGETTEXT"
-if test -n "$XGETTEXT"; then
-  echo "$ac_t""$XGETTEXT" 1>&6
-else
-  echo "$ac_t""no" 1>&6
-fi
-   if echo $XGETTEXT | grep openwin > /dev/null; then
-     echo "WARNING: Do not use OpenWin's xgettext.  (Better remove it.) >&6"
-     ac_cv_path_XGETTEXT=xgettext
-     XGETTEXT=xgettext
-   fi
-
-	
-	CATOBJEXT=.gmo
-	INSTOBJEXT=.mo
-	DATADIRNAME=share
-	INTLDEPS="\${top_srcdir}/intl/libintl.a"
-	INTLLIBS=$INTLDEPS
-	LIBS=`echo $LIBS | sed -e 's/-lintl//'`
-	nls_cv_header_intl=libintl.h
-	nls_cv_header_libgt=intl/libgettext.h
-      fi
-
-      # We need to process the intl/ and po/ directory.
-      INTLSUB=intl
-      POSUB=po
-    else
-      DATADIRNAME=share
-      nls_cv_header_intl=libintl.h
-      nls_cv_header_libgt=intl/libgettext.h
-    fi
-
-                for lang in $ALL_LINGUAS; do
-      GMOFILES="$GMOFILES $lang.gmo"
-      POFILES="$POFILES $lang.po"
-    done
-
-        
-    
-    
-    
-    
-    
-    
-    
-    
-    
-    
-  
-
-   if test "x$CATOBJEXT" != "x"; then
-     if test "x$ALL_LINGUAS" = "x"; then
-       LINGUAS=
-     else
-       echo $ac_n "checking for catalogs to be installed""... $ac_c" 1>&6
-echo "configure:2890: checking for catalogs to be installed" >&5
-       NEW_LINGUAS=
-       for lang in ${LINGUAS=$ALL_LINGUAS}; do
-	 case "$ALL_LINGUAS" in
-	  *$lang*) NEW_LINGUAS="$NEW_LINGUAS $lang" ;;
-	 esac
-       done
-       LINGUAS=$NEW_LINGUAS
-       echo "$ac_t""$LINGUAS" 1>&6
-     fi
-
-          if test -n "$LINGUAS"; then
-       for lang in $LINGUAS; do CATALOGS="$CATALOGS $lang$CATOBJEXT"; done
-     fi
-   fi
-
-            test -d intl || mkdir intl
-   if test "$CATOBJEXT" = ".cat"; then
-     ac_safe=`echo "linux/version.h" | sed 'y%./+-%__p_%'`
-echo $ac_n "checking for linux/version.h""... $ac_c" 1>&6
-echo "configure:2910: checking for linux/version.h" >&5
-if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  cat > conftest.$ac_ext <<EOF
-#line 2915 "configure"
-#include "confdefs.h"
-#include <linux/version.h>
-EOF
-ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:2920: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
-ac_err=`grep -v '^ *+' conftest.out`
-if test -z "$ac_err"; then
-  rm -rf conftest*
-  eval "ac_cv_header_$ac_safe=yes"
-else
-  echo "$ac_err" >&5
-  echo "configure: failed program was:" >&5
-  cat conftest.$ac_ext >&5
-  rm -rf conftest*
-  eval "ac_cv_header_$ac_safe=no"
-fi
-rm -f conftest*
-fi
-if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
-  msgformat=linux
-else
-  echo "$ac_t""no" 1>&6
-msgformat=xopen
-fi
-
-
-               sed -e '/^#/d' $srcdir/intl/$msgformat-msg.sed > intl/po2msg.sed
-   fi
-      sed -e '/^#.*[^\\]$/d' -e '/^#$/d' \
-     $srcdir/intl/po2tbl.sed.in > intl/po2tbl.sed
-
-         test -d po || mkdir po
-   if test "x$srcdir" != "x."; then
-     if test "x`echo $srcdir | sed 's@/.*@@'`" = "x"; then
-       posrcprefix="$srcdir/"
-     else
-       posrcprefix="../$srcdir/"
-     fi
-   else
-     posrcprefix="../"
-   fi
-   sed -e "/^#/d" -e "/^\$/d" -e "s,.*, $posrcprefix& \\\\," -e "\$s/\(.*\) \\\\/\1/" \
-	< $srcdir/po/POTFILES.in > po/POTFILES
-  
-G10_LOCALEDIR="$g10_prefix/$DATADIRNAME/locale"
-
-cat >> confdefs.h <<EOF
-#define G10_LOCALEDIR "$G10_LOCALEDIR"
-EOF
-
-
- if test "x$wk_link_files_src" = "x"; then
-	wk_link_files_src="$nls_cv_header_libgt"
-	wk_link_files_dst="$nls_cv_header_intl "
-    else
-	wk_link_files_src="$wk_link_files_src $nls_cv_header_libgt"
-	wk_link_files_dst="$wk_link_files_dst $nls_cv_header_intl "
-    fi
-  
-
-echo $ac_n "checking for working const""... $ac_c" 1>&6
-echo "configure:2978: checking for working const" >&5
-if eval "test \"`echo '$''{'ac_cv_c_const'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  cat > conftest.$ac_ext <<EOF
-#line 2983 "configure"
-#include "confdefs.h"
-
-int main() {
-
-/* Ultrix mips cc rejects this.  */
-typedef int charset[2]; const charset x;
-/* SunOS 4.1.1 cc rejects this.  */
-char const *const *ccp;
-char **p;
-/* NEC SVR4.0.2 mips cc rejects this.  */
-struct point {int x, y;};
-static struct point const zero = {0,0};
-/* AIX XL C 1.02.0.0 rejects this.
-   It does not let you subtract one const X* pointer from another in an arm
-   of an if-expression whose if-part is not a constant expression */
-const char *g = "string";
-ccp = &g + (g ? g-g : 0);
-/* HPUX 7.0 cc rejects these. */
-++ccp;
-p = (char**) ccp;
-ccp = (char const *const *) p;
-{ /* SCO 3.2v4 cc rejects this.  */
-  char *t;
-  char const *s = 0 ? (char *) 0 : (char const *) 0;
-
-  *t++ = 0;
-}
-{ /* Someone thinks the Sun supposedly-ANSI compiler will reject this.  */
-  int x[] = {25, 17};
-  const int *foo = &x[0];
-  ++foo;
-}
-{ /* Sun SC1.0 ANSI compiler rejects this -- but not the above. */
-  typedef const int *iptr;
-  iptr p = 0;
-  ++p;
-}
-{ /* AIX XL C 1.02.0.0 rejects this saying
-     "k.c", line 2.27: 1506-025 (S) Operand must be a modifiable lvalue. */
-  struct s { int j; const int *ap[3]; };
-  struct s *b; b->j = 5;
-}
-{ /* ULTRIX-32 V3.1 (Rev 9) vcc rejects this */
-  const int foo = 10;
-}
-
-; return 0; }
-EOF
-if { (eval echo configure:3032: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
-  rm -rf conftest*
-  ac_cv_c_const=yes
-else
-  echo "configure: failed program was:" >&5
-  cat conftest.$ac_ext >&5
-  rm -rf conftest*
-  ac_cv_c_const=no
-fi
-rm -f conftest*
-fi
-
-echo "$ac_t""$ac_cv_c_const" 1>&6
-if test $ac_cv_c_const = no; then
-  cat >> confdefs.h <<\EOF
-#define const 
-EOF
+/* Thanks to Mike Haertel and Jim Avera for this test.
+   Here is a matrix of mmap possibilities:
+	mmap private not fixed
+	mmap private fixed at somewhere currently unmapped
+	mmap private fixed at somewhere already mapped
+	mmap shared not fixed
+	mmap shared fixed at somewhere currently unmapped
+	mmap shared fixed at somewhere already mapped
+   For private mappings, we should verify that changes cannot be read()
+   back from the file, nor mmap's back from the file at a different
+   address.  (There have been systems where private was not correctly
+   implemented like the infamous i386 svr4.0, and systems where the
+   VM page cache was not coherent with the filesystem buffer cache
+   like early versions of FreeBSD and possibly contemporary NetBSD.)
+   For shared mappings, we should conversely verify that changes get
+   propogated back to all the places they're supposed to be.
 
-fi
+   Grep wants private fixed already mapped.
+   The main things grep needs to know about mmap are:
+   * does it exist and is it safe to write into the mmap'd area
+   * how to use it (BSD variants)  */
+#include <sys/types.h>
+#include <fcntl.h>
+#include <sys/mman.h>
 
-echo $ac_n "checking for inline""... $ac_c" 1>&6
-echo "configure:3053: checking for inline" >&5
-if eval "test \"`echo '$''{'ac_cv_c_inline'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  ac_cv_c_inline=no
-for ac_kw in inline __inline__ __inline; do
-  cat > conftest.$ac_ext <<EOF
-#line 3060 "configure"
-#include "confdefs.h"
+/* This mess was copied from the GNU getpagesize.h.  */
+#ifndef HAVE_GETPAGESIZE
+# ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+# endif
 
-int main() {
-} $ac_kw foo() {
-; return 0; }
-EOF
-if { (eval echo configure:3067: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
-  rm -rf conftest*
-  ac_cv_c_inline=$ac_kw; break
-else
-  echo "configure: failed program was:" >&5
-  cat conftest.$ac_ext >&5
-fi
-rm -f conftest*
-done
+/* Assume that all systems that can run configure have sys/param.h.  */
+# ifndef HAVE_SYS_PARAM_H
+#  define HAVE_SYS_PARAM_H 1
+# endif
 
-fi
+# ifdef _SC_PAGESIZE
+#  define getpagesize() sysconf(_SC_PAGESIZE)
+# else /* no _SC_PAGESIZE */
+#  ifdef HAVE_SYS_PARAM_H
+#   include <sys/param.h>
+#   ifdef EXEC_PAGESIZE
+#    define getpagesize() EXEC_PAGESIZE
+#   else /* no EXEC_PAGESIZE */
+#    ifdef NBPG
+#     define getpagesize() NBPG * CLSIZE
+#     ifndef CLSIZE
+#      define CLSIZE 1
+#     endif /* no CLSIZE */
+#    else /* no NBPG */
+#     ifdef NBPC
+#      define getpagesize() NBPC
+#     else /* no NBPC */
+#      ifdef PAGESIZE
+#       define getpagesize() PAGESIZE
+#      endif /* PAGESIZE */
+#     endif /* no NBPC */
+#    endif /* no NBPG */
+#   endif /* no EXEC_PAGESIZE */
+#  else /* no HAVE_SYS_PARAM_H */
+#   define getpagesize() 8192	/* punt totally */
+#  endif /* no HAVE_SYS_PARAM_H */
+# endif /* no _SC_PAGESIZE */
 
-echo "$ac_t""$ac_cv_c_inline" 1>&6
-case "$ac_cv_c_inline" in
-  inline | yes) ;;
-  no) cat >> confdefs.h <<\EOF
-#define inline 
-EOF
- ;;
-  *)  cat >> confdefs.h <<EOF
-#define inline $ac_cv_c_inline
-EOF
- ;;
-esac
+#endif /* no HAVE_GETPAGESIZE */
 
-echo $ac_n "checking for size_t""... $ac_c" 1>&6
-echo "configure:3093: checking for size_t" >&5
-if eval "test \"`echo '$''{'ac_cv_type_size_t'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  cat > conftest.$ac_ext <<EOF
-#line 3098 "configure"
-#include "confdefs.h"
-#include <sys/types.h>
-#if STDC_HEADERS
-#include <stdlib.h>
-#include <stddef.h>
+#ifdef __cplusplus
+extern "C" { void *malloc(unsigned); }
+#else
+char *malloc();
 #endif
-EOF
-if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
-  egrep "size_t[^a-zA-Z_0-9]" >/dev/null 2>&1; then
-  rm -rf conftest*
-  ac_cv_type_size_t=yes
-else
-  rm -rf conftest*
-  ac_cv_type_size_t=no
-fi
-rm -f conftest*
 
-fi
-echo "$ac_t""$ac_cv_type_size_t" 1>&6
-if test $ac_cv_type_size_t = no; then
-  cat >> confdefs.h <<\EOF
-#define size_t unsigned
-EOF
+int
+main()
+{
+	char *data, *data2, *data3;
+	int i, pagesize;
+	int fd;
 
-fi
+	pagesize = getpagesize();
 
+	/*
+	 * First, make a file with some known garbage in it.
+	 */
+	data = malloc(pagesize);
+	if (!data)
+		exit(1);
+	for (i = 0; i < pagesize; ++i)
+		*(data + i) = rand();
+	umask(0);
+	fd = creat("conftestmmap", 0600);
+	if (fd < 0)
+		exit(1);
+	if (write(fd, data, pagesize) != pagesize)
+		exit(1);
+	close(fd);
 
- if test "$cross_compiling" = yes; then
-	echo "configure: warning: cross compiling; assuming little endianess" 1>&2
-    fi
-    echo $ac_n "checking endianess""... $ac_c" 1>&6
-echo "configure:3130: checking endianess" >&5
-    if eval "test \"`echo '$''{'wk_cv_c_endian'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-   wk_cv_c_endian=unknown
-	# See if sys/param.h defines the BYTE_ORDER macro.
-	cat > conftest.$ac_ext <<EOF
-#line 3137 "configure"
-#include "confdefs.h"
-#include <sys/types.h>
-	#include <sys/param.h>
-int main() {
+	/*
+	 * Next, try to mmap the file at a fixed address which
+	 * already has something else allocated at it.  If we can,
+	 * also make sure that we see the same garbage.
+	 */
+	fd = open("conftestmmap", O_RDWR);
+	if (fd < 0)
+		exit(1);
+	data2 = malloc(2 * pagesize);
+	if (!data2)
+		exit(1);
+	data2 += (pagesize - ((int) data2 & (pagesize - 1))) & (pagesize - 1);
+	if (data2 != mmap(data2, pagesize, PROT_READ | PROT_WRITE,
+	    MAP_PRIVATE | MAP_FIXED, fd, 0L))
+		exit(1);
+	for (i = 0; i < pagesize; ++i)
+		if (*(data + i) != *(data2 + i))
+			exit(1);
 
-	#if !BYTE_ORDER || !BIG_ENDIAN || !LITTLE_ENDIAN
-	 bogus endian macros
-	#endif
-; return 0; }
-EOF
-if { (eval echo configure:3148: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
-  rm -rf conftest*
-  # It does; now see whether it defined to BIG_ENDIAN or not.
-	cat > conftest.$ac_ext <<EOF
-#line 3152 "configure"
-#include "confdefs.h"
-#include <sys/types.h>
-	#include <sys/param.h>
-int main() {
+	/*
+	 * Finally, make sure that changes to the mapped area
+	 * do not percolate back to the file as seen by read().
+	 * (This is a bug on some variants of i386 svr4.0.)
+	 */
+	for (i = 0; i < pagesize; ++i)
+		*(data2 + i) = *(data2 + i) + 1;
+	data3 = malloc(pagesize);
+	if (!data3)
+		exit(1);
+	if (read(fd, data3, pagesize) != pagesize)
+		exit(1);
+	for (i = 0; i < pagesize; ++i)
+		if (*(data + i) != *(data3 + i))
+			exit(1);
+	close(fd);
+	unlink("conftestmmap");
+	exit(0);
+}
 
-	#if BYTE_ORDER != BIG_ENDIAN
-	 not big endian
-	#endif
-; return 0; }
-EOF
-if { (eval echo configure:3163: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
-  rm -rf conftest*
-  wk_cv_c_endian=big
-else
-  echo "configure: failed program was:" >&5
-  cat conftest.$ac_ext >&5
-  rm -rf conftest*
-  wk_cv_c_endian=little
-fi
-rm -f conftest*
-else
-  echo "configure: failed program was:" >&5
-  cat conftest.$ac_ext >&5
-fi
-rm -f conftest*
-	if test "$wk_cv_c_endian" = unknown; then
-	    if test "$cross_compiling" = yes; then
-  wk_cv_c_endian=little
-	    
-else
-  cat > conftest.$ac_ext <<EOF
-#line 3184 "configure"
-#include "confdefs.h"
-main () {
-	      /* Are we little or big endian?  From Harbison&Steele.  */
-	      union
-	      {
-		long l;
-		char c[sizeof (long)];
-	      } u;
-	      u.l = 1;
-	      exit (u.c[sizeof (long) - 1] == 1);
-	      }
 EOF
-if { (eval echo configure:3197: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:2919: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
-  wk_cv_c_endian=little
+  ac_cv_func_mmap_fixed_mapped=yes
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -fr conftest*
-  wk_cv_c_endian=big
+  ac_cv_func_mmap_fixed_mapped=no
 fi
 rm -fr conftest*
 fi
 
-	fi
-      
-fi
-
-    echo "$ac_t""$wk_cv_c_endian" 1>&6
-    if test "$wk_cv_c_endian" = little; then
-      cat >> confdefs.h <<\EOF
-#define LITTLE_ENDIAN_HOST 1
-EOF
-
-    else
-      cat >> confdefs.h <<\EOF
-#define BIG_ENDIAN_HOST 1
-EOF
+fi
 
-    fi
-  
+echo "$ac_t""$ac_cv_func_mmap_fixed_mapped" 1>&6
+if test $ac_cv_func_mmap_fixed_mapped = yes; then
+  cat >> confdefs.h <<\EOF
+#define HAVE_MMAP 1
+EOF
 
+fi
 
- echo $ac_n "checking for byte typedef""... $ac_c" 1>&6
-echo "configure:3229: checking for byte typedef" >&5
-    if eval "test \"`echo '$''{'wk_cv_typedef_byte'+set}'`\" = set"; then
+                              
+   for ac_hdr in argz.h limits.h locale.h nl_types.h malloc.h string.h \
+unistd.h values.h sys/param.h
+do
+ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
+echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
+echo "configure:2947: checking for $ac_hdr" >&5
+if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3234 "configure"
+#line 2952 "configure"
 #include "confdefs.h"
-#include <stdlib.h>
-    #include <sys/types.h>
-int main() {
-
-    #undef byte
-    int a = sizeof(byte);
-    
-; return 0; }
+#include <$ac_hdr>
 EOF
-if { (eval echo configure:3245: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
+{ (eval echo configure:2957: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+ac_err=`grep -v '^ *+' conftest.out`
+if test -z "$ac_err"; then
   rm -rf conftest*
-  wk_cv_typedef_byte=yes
+  eval "ac_cv_header_$ac_safe=yes"
 else
+  echo "$ac_err" >&5
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  wk_cv_typedef_byte=no 
+  eval "ac_cv_header_$ac_safe=no"
 fi
 rm -f conftest*
 fi
-
-    echo "$ac_t""$wk_cv_typedef_byte" 1>&6
-    if test "$wk_cv_typedef_byte" = yes; then
-	cat >> confdefs.h <<\EOF
-#define HAVE_BYTE_TYPEDEF 1
+if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
+  echo "$ac_t""yes" 1>&6
+    ac_tr_hdr=HAVE_`echo $ac_hdr | sed 'y%abcdefghijklmnopqrstuvwxyz./-%ABCDEFGHIJKLMNOPQRSTUVWXYZ___%'`
+  cat >> confdefs.h <<EOF
+#define $ac_tr_hdr 1
 EOF
+ 
+else
+  echo "$ac_t""no" 1>&6
+fi
+done
 
-    fi
-  
- echo $ac_n "checking for ushort typedef""... $ac_c" 1>&6
-echo "configure:3266: checking for ushort typedef" >&5
-    if eval "test \"`echo '$''{'wk_cv_typedef_ushort'+set}'`\" = set"; then
+   for ac_func in getcwd munmap putenv setenv setlocale strchr strcasecmp \
+__argz_count __argz_stringify __argz_next
+do
+echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
+echo "configure:2987: checking for $ac_func" >&5
+if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3271 "configure"
+#line 2992 "configure"
 #include "confdefs.h"
-#include <stdlib.h>
-    #include <sys/types.h>
+/* System header to define __stub macros and hopefully few prototypes,
+    which can conflict with char $ac_func(); below.  */
+#include <assert.h>
+/* Override any gcc2 internal prototype to avoid an error.  */
+/* We use char because int might match the return type of a gcc2
+    builtin and then its argument prototype would still apply.  */
+char $ac_func();
+
 int main() {
 
-    #undef ushort
-    int a = sizeof(ushort);
-    
+/* The GNU C library defines this for functions which it implements
+    to always fail with ENOSYS.  Some functions are actually named
+    something starting with __ and the normal name is an alias.  */
+#if defined (__stub_$ac_func) || defined (__stub___$ac_func)
+choke me
+#else
+$ac_func();
+#endif
+
 ; return 0; }
 EOF
-if { (eval echo configure:3282: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3015: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  wk_cv_typedef_ushort=yes
+  eval "ac_cv_func_$ac_func=yes"
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  wk_cv_typedef_ushort=no 
+  eval "ac_cv_func_$ac_func=no"
 fi
 rm -f conftest*
 fi
 
-    echo "$ac_t""$wk_cv_typedef_ushort" 1>&6
-    if test "$wk_cv_typedef_ushort" = yes; then
-	cat >> confdefs.h <<\EOF
-#define HAVE_USHORT_TYPEDEF 1
+if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
+  echo "$ac_t""yes" 1>&6
+    ac_tr_func=HAVE_`echo $ac_func | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`
+  cat >> confdefs.h <<EOF
+#define $ac_tr_func 1
 EOF
+ 
+else
+  echo "$ac_t""no" 1>&6
+fi
+done
 
-    fi
-  
- echo $ac_n "checking for ulong typedef""... $ac_c" 1>&6
-echo "configure:3303: checking for ulong typedef" >&5
-    if eval "test \"`echo '$''{'wk_cv_typedef_ulong'+set}'`\" = set"; then
+
+   if test "${ac_cv_func_stpcpy+set}" != "set"; then
+     for ac_func in stpcpy
+do
+echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
+echo "configure:3044: checking for $ac_func" >&5
+if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3308 "configure"
+#line 3049 "configure"
 #include "confdefs.h"
-#include <stdlib.h>
-    #include <sys/types.h>
+/* System header to define __stub macros and hopefully few prototypes,
+    which can conflict with char $ac_func(); below.  */
+#include <assert.h>
+/* Override any gcc2 internal prototype to avoid an error.  */
+/* We use char because int might match the return type of a gcc2
+    builtin and then its argument prototype would still apply.  */
+char $ac_func();
+
 int main() {
 
-    #undef ulong
-    int a = sizeof(ulong);
-    
+/* The GNU C library defines this for functions which it implements
+    to always fail with ENOSYS.  Some functions are actually named
+    something starting with __ and the normal name is an alias.  */
+#if defined (__stub_$ac_func) || defined (__stub___$ac_func)
+choke me
+#else
+$ac_func();
+#endif
+
 ; return 0; }
 EOF
-if { (eval echo configure:3319: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3072: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  wk_cv_typedef_ulong=yes
+  eval "ac_cv_func_$ac_func=yes"
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  wk_cv_typedef_ulong=no 
+  eval "ac_cv_func_$ac_func=no"
 fi
 rm -f conftest*
 fi
 
-    echo "$ac_t""$wk_cv_typedef_ulong" 1>&6
-    if test "$wk_cv_typedef_ulong" = yes; then
-	cat >> confdefs.h <<\EOF
-#define HAVE_ULONG_TYPEDEF 1
+if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
+  echo "$ac_t""yes" 1>&6
+    ac_tr_func=HAVE_`echo $ac_func | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`
+  cat >> confdefs.h <<EOF
+#define $ac_tr_func 1
+EOF
+ 
+else
+  echo "$ac_t""no" 1>&6
+fi
+done
+
+   fi
+   if test "${ac_cv_func_stpcpy}" = "yes"; then
+     cat >> confdefs.h <<\EOF
+#define HAVE_STPCPY 1
 EOF
 
-    fi
-  
- echo $ac_n "checking for u16 typedef""... $ac_c" 1>&6
-echo "configure:3340: checking for u16 typedef" >&5
-    if eval "test \"`echo '$''{'wk_cv_typedef_u16'+set}'`\" = set"; then
+   fi
+
+   if test $ac_cv_header_locale_h = yes; then
+    echo $ac_n "checking for LC_MESSAGES""... $ac_c" 1>&6
+echo "configure:3106: checking for LC_MESSAGES" >&5
+if eval "test \"`echo '$''{'am_cv_val_LC_MESSAGES'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3345 "configure"
+#line 3111 "configure"
 #include "confdefs.h"
-#include <stdlib.h>
-    #include <sys/types.h>
+#include <locale.h>
 int main() {
-
-    #undef u16
-    int a = sizeof(u16);
-    
+return LC_MESSAGES
 ; return 0; }
 EOF
-if { (eval echo configure:3356: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3118: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  wk_cv_typedef_u16=yes
+  am_cv_val_LC_MESSAGES=yes
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  wk_cv_typedef_u16=no 
+  am_cv_val_LC_MESSAGES=no
 fi
 rm -f conftest*
 fi
 
-    echo "$ac_t""$wk_cv_typedef_u16" 1>&6
-    if test "$wk_cv_typedef_u16" = yes; then
-	cat >> confdefs.h <<\EOF
-#define HAVE_U16_TYPEDEF 1
+echo "$ac_t""$am_cv_val_LC_MESSAGES" 1>&6
+    if test $am_cv_val_LC_MESSAGES = yes; then
+      cat >> confdefs.h <<\EOF
+#define HAVE_LC_MESSAGES 1
 EOF
 
     fi
-  
- echo $ac_n "checking for u32 typedef""... $ac_c" 1>&6
-echo "configure:3377: checking for u32 typedef" >&5
-    if eval "test \"`echo '$''{'wk_cv_typedef_u32'+set}'`\" = set"; then
+  fi
+   echo $ac_n "checking whether NLS is requested""... $ac_c" 1>&6
+echo "configure:3139: checking whether NLS is requested" >&5
+        # Check whether --enable-nls or --disable-nls was given.
+if test "${enable_nls+set}" = set; then
+  enableval="$enable_nls"
+  USE_NLS=$enableval
+else
+  USE_NLS=yes
+fi
+
+    echo "$ac_t""$USE_NLS" 1>&6
+    
+
+    USE_INCLUDED_LIBINTL=no
+
+        if test "$USE_NLS" = "yes"; then
+      cat >> confdefs.h <<\EOF
+#define ENABLE_NLS 1
+EOF
+
+      echo $ac_n "checking whether included gettext is requested""... $ac_c" 1>&6
+echo "configure:3159: checking whether included gettext is requested" >&5
+      # Check whether --with-included-gettext or --without-included-gettext was given.
+if test "${with_included_gettext+set}" = set; then
+  withval="$with_included_gettext"
+  nls_cv_force_use_gnu_gettext=$withval
+else
+  nls_cv_force_use_gnu_gettext=no
+fi
+
+      echo "$ac_t""$nls_cv_force_use_gnu_gettext" 1>&6
+
+      nls_cv_use_gnu_gettext="$nls_cv_force_use_gnu_gettext"
+      if test "$nls_cv_force_use_gnu_gettext" != "yes"; then
+					nls_cv_header_intl=
+	nls_cv_header_libgt=
+	CATOBJEXT=NONE
+
+	ac_safe=`echo "libintl.h" | sed 'y%./+-%__p_%'`
+echo $ac_n "checking for libintl.h""... $ac_c" 1>&6
+echo "configure:3178: checking for libintl.h" >&5
+if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3382 "configure"
+#line 3183 "configure"
 #include "confdefs.h"
-#include <stdlib.h>
-    #include <sys/types.h>
-int main() {
-
-    #undef u32
-    int a = sizeof(u32);
-    
-; return 0; }
+#include <libintl.h>
 EOF
-if { (eval echo configure:3393: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
+{ (eval echo configure:3188: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+ac_err=`grep -v '^ *+' conftest.out`
+if test -z "$ac_err"; then
   rm -rf conftest*
-  wk_cv_typedef_u32=yes
+  eval "ac_cv_header_$ac_safe=yes"
 else
+  echo "$ac_err" >&5
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  wk_cv_typedef_u32=no 
+  eval "ac_cv_header_$ac_safe=no"
 fi
 rm -f conftest*
 fi
-
-    echo "$ac_t""$wk_cv_typedef_u32" 1>&6
-    if test "$wk_cv_typedef_u32" = yes; then
-	cat >> confdefs.h <<\EOF
-#define HAVE_U32_TYPEDEF 1
-EOF
-
-    fi
-  
-
-echo $ac_n "checking size of unsigned short""... $ac_c" 1>&6
-echo "configure:3415: checking size of unsigned short" >&5
-if eval "test \"`echo '$''{'ac_cv_sizeof_unsigned_short'+set}'`\" = set"; then
+if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
+  echo "$ac_t""yes" 1>&6
+  echo $ac_n "checking for gettext in libc""... $ac_c" 1>&6
+echo "configure:3205: checking for gettext in libc" >&5
+if eval "test \"`echo '$''{'gt_cv_func_gettext_libc'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  if test "$cross_compiling" = yes; then
-  ac_cv_sizeof_unsigned_short=2
-else
   cat > conftest.$ac_ext <<EOF
-#line 3423 "configure"
+#line 3210 "configure"
 #include "confdefs.h"
-#include <stdio.h>
-main()
-{
-  FILE *f=fopen("conftestval", "w");
-  if (!f) exit(1);
-  fprintf(f, "%d\n", sizeof(unsigned short));
-  exit(0);
-}
+#include <libintl.h>
+int main() {
+return (int) gettext ("")
+; return 0; }
 EOF
-if { (eval echo configure:3434: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
-then
-  ac_cv_sizeof_unsigned_short=`cat conftestval`
+if { (eval echo configure:3217: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+  rm -rf conftest*
+  gt_cv_func_gettext_libc=yes
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
-  rm -fr conftest*
-  ac_cv_sizeof_unsigned_short=0
-fi
-rm -fr conftest*
+  rm -rf conftest*
+  gt_cv_func_gettext_libc=no
 fi
-
+rm -f conftest*
 fi
-echo "$ac_t""$ac_cv_sizeof_unsigned_short" 1>&6
-cat >> confdefs.h <<EOF
-#define SIZEOF_UNSIGNED_SHORT $ac_cv_sizeof_unsigned_short
-EOF
 
+echo "$ac_t""$gt_cv_func_gettext_libc" 1>&6
 
-echo $ac_n "checking size of unsigned int""... $ac_c" 1>&6
-echo "configure:3454: checking size of unsigned int" >&5
-if eval "test \"`echo '$''{'ac_cv_sizeof_unsigned_int'+set}'`\" = set"; then
+	   if test "$gt_cv_func_gettext_libc" != "yes"; then
+	     echo $ac_n "checking for bindtextdomain in -lintl""... $ac_c" 1>&6
+echo "configure:3233: checking for bindtextdomain in -lintl" >&5
+ac_lib_var=`echo intl'_'bindtextdomain | sed 'y%./+-%__p_%'`
+if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  if test "$cross_compiling" = yes; then
-  ac_cv_sizeof_unsigned_int=4
-else
-  cat > conftest.$ac_ext <<EOF
-#line 3462 "configure"
+  ac_save_LIBS="$LIBS"
+LIBS="-lintl  $LIBS"
+cat > conftest.$ac_ext <<EOF
+#line 3241 "configure"
 #include "confdefs.h"
-#include <stdio.h>
-main()
-{
-  FILE *f=fopen("conftestval", "w");
-  if (!f) exit(1);
-  fprintf(f, "%d\n", sizeof(unsigned int));
-  exit(0);
-}
+/* Override any gcc2 internal prototype to avoid an error.  */
+/* We use char because int might match the return type of a gcc2
+    builtin and then its argument prototype would still apply.  */
+char bindtextdomain();
+
+int main() {
+bindtextdomain()
+; return 0; }
 EOF
-if { (eval echo configure:3473: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
-then
-  ac_cv_sizeof_unsigned_int=`cat conftestval`
+if { (eval echo configure:3252: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+  rm -rf conftest*
+  eval "ac_cv_lib_$ac_lib_var=yes"
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
-  rm -fr conftest*
-  ac_cv_sizeof_unsigned_int=0
-fi
-rm -fr conftest*
+  rm -rf conftest*
+  eval "ac_cv_lib_$ac_lib_var=no"
 fi
+rm -f conftest*
+LIBS="$ac_save_LIBS"
 
 fi
-echo "$ac_t""$ac_cv_sizeof_unsigned_int" 1>&6
-cat >> confdefs.h <<EOF
-#define SIZEOF_UNSIGNED_INT $ac_cv_sizeof_unsigned_int
-EOF
-
-
-echo $ac_n "checking size of unsigned long""... $ac_c" 1>&6
-echo "configure:3493: checking size of unsigned long" >&5
-if eval "test \"`echo '$''{'ac_cv_sizeof_unsigned_long'+set}'`\" = set"; then
+if eval "test \"`echo '$ac_cv_lib_'$ac_lib_var`\" = yes"; then
+  echo "$ac_t""yes" 1>&6
+  echo $ac_n "checking for gettext in libintl""... $ac_c" 1>&6
+echo "configure:3268: checking for gettext in libintl" >&5
+if eval "test \"`echo '$''{'gt_cv_func_gettext_libintl'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  if test "$cross_compiling" = yes; then
-  ac_cv_sizeof_unsigned_long=4
-else
   cat > conftest.$ac_ext <<EOF
-#line 3501 "configure"
+#line 3273 "configure"
 #include "confdefs.h"
-#include <stdio.h>
-main()
-{
-  FILE *f=fopen("conftestval", "w");
-  if (!f) exit(1);
-  fprintf(f, "%d\n", sizeof(unsigned long));
-  exit(0);
-}
+
+int main() {
+return (int) gettext ("")
+; return 0; }
 EOF
-if { (eval echo configure:3512: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
-then
-  ac_cv_sizeof_unsigned_long=`cat conftestval`
+if { (eval echo configure:3280: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+  rm -rf conftest*
+  gt_cv_func_gettext_libintl=yes
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
-  rm -fr conftest*
-  ac_cv_sizeof_unsigned_long=0
+  rm -rf conftest*
+  gt_cv_func_gettext_libintl=no
 fi
-rm -fr conftest*
+rm -f conftest*
 fi
 
+echo "$ac_t""$gt_cv_func_gettext_libintl" 1>&6
+else
+  echo "$ac_t""no" 1>&6
 fi
-echo "$ac_t""$ac_cv_sizeof_unsigned_long" 1>&6
-cat >> confdefs.h <<EOF
-#define SIZEOF_UNSIGNED_LONG $ac_cv_sizeof_unsigned_long
-EOF
 
+	   fi
 
+	   if test "$gt_cv_func_gettext_libc" = "yes" \
+	      || test "$gt_cv_func_gettext_libintl" = "yes"; then
+	      cat >> confdefs.h <<\EOF
+#define HAVE_GETTEXT 1
+EOF
 
-if test "$ac_cv_sizeof_unsigned_short" = "0" \
-   || test "$ac_cv_sizeof_unsigned_int" = "0" \
-   || test "$ac_cv_sizeof_unsigned_long" = "0"; then
-    echo "configure: warning: Hmmm, something is wrong with the sizes - using defaults" 1>&2;
+	      # Extract the first word of "msgfmt", so it can be a program name with args.
+set dummy msgfmt; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3308: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_MSGFMT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  case "$MSGFMT" in
+  /*)
+  ac_cv_path_MSGFMT="$MSGFMT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS=   }"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"; then
+	ac_cv_path_MSGFMT="$ac_dir/$ac_word"
+	break
+      fi
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_MSGFMT" && ac_cv_path_MSGFMT="no"
+  ;;
+esac
 fi
-
-
-
-echo $ac_n "checking for vprintf""... $ac_c" 1>&6
-echo "configure:3541: checking for vprintf" >&5
-if eval "test \"`echo '$''{'ac_cv_func_vprintf'+set}'`\" = set"; then
+MSGFMT="$ac_cv_path_MSGFMT"
+if test -n "$MSGFMT"; then
+  echo "$ac_t""$MSGFMT" 1>&6
+else
+  echo "$ac_t""no" 1>&6
+fi
+	      if test "$MSGFMT" != "no"; then
+		for ac_func in dcgettext
+do
+echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
+echo "configure:3342: checking for $ac_func" >&5
+if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3546 "configure"
+#line 3347 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char vprintf(); below.  */
+    which can conflict with char $ac_func(); below.  */
 #include <assert.h>
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
     builtin and then its argument prototype would still apply.  */
-char vprintf();
+char $ac_func();
 
 int main() {
 
 /* The GNU C library defines this for functions which it implements
     to always fail with ENOSYS.  Some functions are actually named
     something starting with __ and the normal name is an alias.  */
-#if defined (__stub_vprintf) || defined (__stub___vprintf)
+#if defined (__stub_$ac_func) || defined (__stub___$ac_func)
 choke me
 #else
-vprintf();
+$ac_func();
 #endif
 
 ; return 0; }
 EOF
-if { (eval echo configure:3569: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:3370: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  eval "ac_cv_func_vprintf=yes"
+  eval "ac_cv_func_$ac_func=yes"
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_func_vprintf=no"
+  eval "ac_cv_func_$ac_func=no"
 fi
 rm -f conftest*
 fi
 
-if eval "test \"`echo '$ac_cv_func_'vprintf`\" = yes"; then
+if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
   echo "$ac_t""yes" 1>&6
-  cat >> confdefs.h <<\EOF
-#define HAVE_VPRINTF 1
+    ac_tr_func=HAVE_`echo $ac_func | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`
+  cat >> confdefs.h <<EOF
+#define $ac_tr_func 1
+EOF
+ 
+else
+  echo "$ac_t""no" 1>&6
+fi
+done
+
+		# Extract the first word of "gmsgfmt", so it can be a program name with args.
+set dummy gmsgfmt; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3397: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_GMSGFMT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  case "$GMSGFMT" in
+  /*)
+  ac_cv_path_GMSGFMT="$GMSGFMT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      ac_cv_path_GMSGFMT="$ac_dir/$ac_word"
+      break
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_GMSGFMT" && ac_cv_path_GMSGFMT="$MSGFMT"
+  ;;
+esac
+fi
+GMSGFMT="$ac_cv_path_GMSGFMT"
+if test -n "$GMSGFMT"; then
+  echo "$ac_t""$GMSGFMT" 1>&6
+else
+  echo "$ac_t""no" 1>&6
+fi
+
+		# Extract the first word of "xgettext", so it can be a program name with args.
+set dummy xgettext; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3429: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_XGETTEXT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  case "$XGETTEXT" in
+  /*)
+  ac_cv_path_XGETTEXT="$XGETTEXT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS=   }"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"; then
+	ac_cv_path_XGETTEXT="$ac_dir/$ac_word"
+	break
+      fi
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_XGETTEXT" && ac_cv_path_XGETTEXT=":"
+  ;;
+esac
+fi
+XGETTEXT="$ac_cv_path_XGETTEXT"
+if test -n "$XGETTEXT"; then
+  echo "$ac_t""$XGETTEXT" 1>&6
+else
+  echo "$ac_t""no" 1>&6
+fi
+
+		cat > conftest.$ac_ext <<EOF
+#line 3461 "configure"
+#include "confdefs.h"
+
+int main() {
+extern int _nl_msg_cat_cntr;
+			       return _nl_msg_cat_cntr
+; return 0; }
+EOF
+if { (eval echo configure:3469: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+  rm -rf conftest*
+  CATOBJEXT=.gmo
+		   DATADIRNAME=share
+else
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
+  rm -rf conftest*
+  CATOBJEXT=.mo
+		   DATADIRNAME=lib
+fi
+rm -f conftest*
+		INSTOBJEXT=.mo
+	      fi
+	    fi
+	
+else
+  echo "$ac_t""no" 1>&6
+fi
+
+
+	if test "$CATOBJEXT" = "NONE"; then
+	  echo $ac_n "checking whether catgets can be used""... $ac_c" 1>&6
+echo "configure:3492: checking whether catgets can be used" >&5
+	  # Check whether --with-catgets or --without-catgets was given.
+if test "${with_catgets+set}" = set; then
+  withval="$with_catgets"
+  nls_cv_use_catgets=$withval
+else
+  nls_cv_use_catgets=no
+fi
+
+	  echo "$ac_t""$nls_cv_use_catgets" 1>&6
+
+	  if test "$nls_cv_use_catgets" = "yes"; then
+	    	    echo $ac_n "checking for main in -li""... $ac_c" 1>&6
+echo "configure:3505: checking for main in -li" >&5
+ac_lib_var=`echo i'_'main | sed 'y%./+-%__p_%'`
+if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  ac_save_LIBS="$LIBS"
+LIBS="-li  $LIBS"
+cat > conftest.$ac_ext <<EOF
+#line 3513 "configure"
+#include "confdefs.h"
+
+int main() {
+main()
+; return 0; }
+EOF
+if { (eval echo configure:3520: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+  rm -rf conftest*
+  eval "ac_cv_lib_$ac_lib_var=yes"
+else
+  echo "configure: failed program was:" >&5
+  cat conftest.$ac_ext >&5
+  rm -rf conftest*
+  eval "ac_cv_lib_$ac_lib_var=no"
+fi
+rm -f conftest*
+LIBS="$ac_save_LIBS"
+
+fi
+if eval "test \"`echo '$ac_cv_lib_'$ac_lib_var`\" = yes"; then
+  echo "$ac_t""yes" 1>&6
+    ac_tr_lib=HAVE_LIB`echo i | sed -e 's/[^a-zA-Z0-9_]/_/g' \
+    -e 'y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/'`
+  cat >> confdefs.h <<EOF
+#define $ac_tr_lib 1
 EOF
 
+  LIBS="-li $LIBS"
+
 else
   echo "$ac_t""no" 1>&6
 fi
 
-if test "$ac_cv_func_vprintf" != yes; then
-echo $ac_n "checking for _doprnt""... $ac_c" 1>&6
-echo "configure:3593: checking for _doprnt" >&5
-if eval "test \"`echo '$''{'ac_cv_func__doprnt'+set}'`\" = set"; then
+	    echo $ac_n "checking for catgets""... $ac_c" 1>&6
+echo "configure:3548: checking for catgets" >&5
+if eval "test \"`echo '$''{'ac_cv_func_catgets'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3598 "configure"
+#line 3553 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char _doprnt(); below.  */
+    which can conflict with char catgets(); below.  */
 #include <assert.h>
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
     builtin and then its argument prototype would still apply.  */
-char _doprnt();
+char catgets();
 
 int main() {
 
 /* The GNU C library defines this for functions which it implements
     to always fail with ENOSYS.  Some functions are actually named
     something starting with __ and the normal name is an alias.  */
-#if defined (__stub__doprnt) || defined (__stub____doprnt)
+#if defined (__stub_catgets) || defined (__stub___catgets)
 choke me
 #else
-_doprnt();
+catgets();
 #endif
 
 ; return 0; }
 EOF
-if { (eval echo configure:3621: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:3576: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
-  eval "ac_cv_func__doprnt=yes"
+  eval "ac_cv_func_catgets=yes"
 else
   echo "configure: failed program was:" >&5
   cat conftest.$ac_ext >&5
   rm -rf conftest*
-  eval "ac_cv_func__doprnt=no"
+  eval "ac_cv_func_catgets=no"
 fi
 rm -f conftest*
 fi
 
-if eval "test \"`echo '$ac_cv_func_'_doprnt`\" = yes"; then
+if eval "test \"`echo '$ac_cv_func_'catgets`\" = yes"; then
   echo "$ac_t""yes" 1>&6
   cat >> confdefs.h <<\EOF
-#define HAVE_DOPRNT 1
+#define HAVE_CATGETS 1
 EOF
 
+	       INTLOBJS="\$(CATOBJS)"
+	       # Extract the first word of "gencat", so it can be a program name with args.
+set dummy gencat; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3598: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_GENCAT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  case "$GENCAT" in
+  /*)
+  ac_cv_path_GENCAT="$GENCAT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      ac_cv_path_GENCAT="$ac_dir/$ac_word"
+      break
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_GENCAT" && ac_cv_path_GENCAT="no"
+  ;;
+esac
+fi
+GENCAT="$ac_cv_path_GENCAT"
+if test -n "$GENCAT"; then
+  echo "$ac_t""$GENCAT" 1>&6
+else
+  echo "$ac_t""no" 1>&6
+fi
+	       if test "$GENCAT" != "no"; then
+		 # Extract the first word of "gmsgfmt", so it can be a program name with args.
+set dummy gmsgfmt; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3630: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_GMSGFMT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  case "$GMSGFMT" in
+  /*)
+  ac_cv_path_GMSGFMT="$GMSGFMT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      ac_cv_path_GMSGFMT="$ac_dir/$ac_word"
+      break
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_GMSGFMT" && ac_cv_path_GMSGFMT="no"
+  ;;
+esac
+fi
+GMSGFMT="$ac_cv_path_GMSGFMT"
+if test -n "$GMSGFMT"; then
+  echo "$ac_t""$GMSGFMT" 1>&6
 else
   echo "$ac_t""no" 1>&6
 fi
 
+		 if test "$GMSGFMT" = "no"; then
+		   # Extract the first word of "msgfmt", so it can be a program name with args.
+set dummy msgfmt; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3663: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_GMSGFMT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  case "$GMSGFMT" in
+  /*)
+  ac_cv_path_GMSGFMT="$GMSGFMT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS=   }"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"; then
+	ac_cv_path_GMSGFMT="$ac_dir/$ac_word"
+	break
+      fi
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_GMSGFMT" && ac_cv_path_GMSGFMT="no"
+  ;;
+esac
+fi
+GMSGFMT="$ac_cv_path_GMSGFMT"
+if test -n "$GMSGFMT"; then
+  echo "$ac_t""$GMSGFMT" 1>&6
+else
+  echo "$ac_t""no" 1>&6
 fi
 
-for ac_func in strerror stpcpy strlwr tcgetattr rand strtoul mlock mmap
-do
-echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:3648: checking for $ac_func" >&5
-if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
+		 fi
+		 # Extract the first word of "xgettext", so it can be a program name with args.
+set dummy xgettext; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3698: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_XGETTEXT'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
-  cat > conftest.$ac_ext <<EOF
-#line 3653 "configure"
-#include "confdefs.h"
-/* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char $ac_func(); below.  */
-#include <assert.h>
-/* Override any gcc2 internal prototype to avoid an error.  */
-/* We use char because int might match the return type of a gcc2
-    builtin and then its argument prototype would still apply.  */
-char $ac_func();
+  case "$XGETTEXT" in
+  /*)
+  ac_cv_path_XGETTEXT="$XGETTEXT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS=   }"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"; then
+	ac_cv_path_XGETTEXT="$ac_dir/$ac_word"
+	break
+      fi
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_XGETTEXT" && ac_cv_path_XGETTEXT=":"
+  ;;
+esac
+fi
+XGETTEXT="$ac_cv_path_XGETTEXT"
+if test -n "$XGETTEXT"; then
+  echo "$ac_t""$XGETTEXT" 1>&6
+else
+  echo "$ac_t""no" 1>&6
+fi
 
-int main() {
+		 USE_INCLUDED_LIBINTL=yes
+		 CATOBJEXT=.cat
+		 INSTOBJEXT=.cat
+		 DATADIRNAME=lib
+		 INTLDEPS='$(top_builddir)/intl/libintl.a'
+		 INTLLIBS=$INTLDEPS
+		 LIBS=`echo $LIBS | sed -e 's/-lintl//'`
+		 nls_cv_header_intl=intl/libintl.h
+		 nls_cv_header_libgt=intl/libgettext.h
+	       fi
+else
+  echo "$ac_t""no" 1>&6
+fi
 
-/* The GNU C library defines this for functions which it implements
-    to always fail with ENOSYS.  Some functions are actually named
-    something starting with __ and the normal name is an alias.  */
-#if defined (__stub_$ac_func) || defined (__stub___$ac_func)
-choke me
-#else
-$ac_func();
-#endif
+	  fi
+	fi
 
-; return 0; }
-EOF
-if { (eval echo configure:3676: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
-  rm -rf conftest*
-  eval "ac_cv_func_$ac_func=yes"
+	if test "$CATOBJEXT" = "NONE"; then
+	  	  	  nls_cv_use_gnu_gettext=yes
+	fi
+      fi
+
+      if test "$nls_cv_use_gnu_gettext" = "yes"; then
+		INTLOBJS="\$(GETTOBJS)"
+	# Extract the first word of "msgfmt", so it can be a program name with args.
+set dummy msgfmt; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3756: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_MSGFMT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
 else
-  echo "configure: failed program was:" >&5
-  cat conftest.$ac_ext >&5
-  rm -rf conftest*
-  eval "ac_cv_func_$ac_func=no"
+  case "$MSGFMT" in
+  /*)
+  ac_cv_path_MSGFMT="$MSGFMT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS=   }"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"; then
+	ac_cv_path_MSGFMT="$ac_dir/$ac_word"
+	break
+      fi
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_MSGFMT" && ac_cv_path_MSGFMT="msgfmt"
+  ;;
+esac
 fi
-rm -f conftest*
+MSGFMT="$ac_cv_path_MSGFMT"
+if test -n "$MSGFMT"; then
+  echo "$ac_t""$MSGFMT" 1>&6
+else
+  echo "$ac_t""no" 1>&6
 fi
 
-if eval "test \"`echo '$ac_cv_func_'$ac_func`\" = yes"; then
-  echo "$ac_t""yes" 1>&6
-    ac_tr_func=HAVE_`echo $ac_func | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'`
-  cat >> confdefs.h <<EOF
-#define $ac_tr_func 1
-EOF
- 
+	# Extract the first word of "gmsgfmt", so it can be a program name with args.
+set dummy gmsgfmt; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3790: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_GMSGFMT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  case "$GMSGFMT" in
+  /*)
+  ac_cv_path_GMSGFMT="$GMSGFMT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      ac_cv_path_GMSGFMT="$ac_dir/$ac_word"
+      break
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_GMSGFMT" && ac_cv_path_GMSGFMT="$MSGFMT"
+  ;;
+esac
+fi
+GMSGFMT="$ac_cv_path_GMSGFMT"
+if test -n "$GMSGFMT"; then
+  echo "$ac_t""$GMSGFMT" 1>&6
+else
+  echo "$ac_t""no" 1>&6
+fi
+
+	# Extract the first word of "xgettext", so it can be a program name with args.
+set dummy xgettext; ac_word=$2
+echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
+echo "configure:3822: checking for $ac_word" >&5
+if eval "test \"`echo '$''{'ac_cv_path_XGETTEXT'+set}'`\" = set"; then
+  echo $ac_n "(cached) $ac_c" 1>&6
+else
+  case "$XGETTEXT" in
+  /*)
+  ac_cv_path_XGETTEXT="$XGETTEXT" # Let the user override the test with a path.
+  ;;
+  *)
+  IFS="${IFS=   }"; ac_save_ifs="$IFS"; IFS="${IFS}:"
+  for ac_dir in $PATH; do
+    test -z "$ac_dir" && ac_dir=.
+    if test -f $ac_dir/$ac_word; then
+      if test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"; then
+	ac_cv_path_XGETTEXT="$ac_dir/$ac_word"
+	break
+      fi
+    fi
+  done
+  IFS="$ac_save_ifs"
+  test -z "$ac_cv_path_XGETTEXT" && ac_cv_path_XGETTEXT=":"
+  ;;
+esac
+fi
+XGETTEXT="$ac_cv_path_XGETTEXT"
+if test -n "$XGETTEXT"; then
+  echo "$ac_t""$XGETTEXT" 1>&6
 else
   echo "$ac_t""no" 1>&6
 fi
-done
-
-
-
 
+	
+	USE_INCLUDED_LIBINTL=yes
+	CATOBJEXT=.gmo
+	INSTOBJEXT=.mo
+	DATADIRNAME=share
+	INTLDEPS='$(top_builddir)/intl/libintl.a'
+	INTLLIBS=$INTLDEPS
+	LIBS=`echo $LIBS | sed -e 's/-lintl//'`
+	nls_cv_header_intl=intl/libintl.h
+	nls_cv_header_libgt=intl/libgettext.h
+      fi
 
-echo $ac_n "checking for random device""... $ac_c" 1>&6
-echo "configure:3705: checking for random device" >&5
-if eval "test \"`echo '$''{'ac_cv_have_dev_random'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  if test -c /dev/random && test -c /dev/urandom ; then
-  ac_cv_have_dev_random=yes; else ac_cv_have_dev_random=no; fi
-fi
+            if test "$XGETTEXT" != ":"; then
+			if $XGETTEXT --omit-header /dev/null 2> /dev/null; then
+	  : ;
+	else
+	  echo "$ac_t""found xgettext programs is not GNU xgettext; ignore it" 1>&6
+	  XGETTEXT=":"
+	fi
+      fi
 
-echo "$ac_t""$ac_cv_have_dev_random" 1>&6
-if test "$ac_cv_have_dev_random" = yes; then
-    cat >> confdefs.h <<\EOF
-#define HAVE_DEV_RANDOM 1
-EOF
+      # We need to process the po/ directory.
+      POSUB=po
+    else
+      DATADIRNAME=share
+      nls_cv_header_intl=intl/libintl.h
+      nls_cv_header_libgt=intl/libgettext.h
+    fi
 
-fi
+    # If this is used in GNU gettext we have to set USE_NLS to `yes'
+    # because some of the sources are only built for this goal.
+    if test "$PACKAGE" = gettext; then
+      USE_NLS=yes
+      USE_INCLUDED_LIBINTL=yes
+    fi
 
+                for lang in $ALL_LINGUAS; do
+      GMOFILES="$GMOFILES $lang.gmo"
+      POFILES="$POFILES $lang.po"
+    done
 
-echo $ac_n "checking for mpi assembler functions""... $ac_c" 1>&6
-echo "configure:3723: checking for mpi assembler functions" >&5
-if test -f $srcdir/mpi/config.links ; then
-    . $srcdir/mpi/config.links
-     if test "x$wk_link_files_src" = "x"; then
-	wk_link_files_src="$mpi_ln_src"
-	wk_link_files_dst="$mpi_ln_dst"
-    else
-	wk_link_files_src="$wk_link_files_src $mpi_ln_src"
-	wk_link_files_dst="$wk_link_files_dst $mpi_ln_dst"
-    fi
-  
-    ac_cv_mpi_extra_asm_modules="$mpi_extra_modules"
-    ac_cv_mpi_config_done="yes"
-    echo "$ac_t""done" 1>&6
-else
-    echo "$ac_t""failed" 1>&6
-    { echo "configure: error: mpi/config.links missing!" 1>&2; exit 1; }
-fi
-MPI_EXTRA_ASM_OBJS=""
-if test "$ac_cv_mpi_extra_asm_modules" != ""; then
- echo $ac_n "mpi extra asm functions:"" $ac_c" 1>&6
-  
-for i in $ac_cv_mpi_extra_asm_modules; do
-     echo $ac_n "$i"" $ac_c" 1>&6
+        
+    
+    
+    
+    
+    
+    
+    
+    
+    
+    
   
-    MPI_EXTRA_ASM_OBJS="$MPI_EXTRA_ASM_OBJS $i.o"
-done
-echo "$ac_t""" 1>&6
-fi
 
+   if test "x$CATOBJEXT" != "x"; then
+     if test "x$ALL_LINGUAS" = "x"; then
+       LINGUAS=
+     else
+       echo $ac_n "checking for catalogs to be installed""... $ac_c" 1>&6
+echo "configure:3912: checking for catalogs to be installed" >&5
+       NEW_LINGUAS=
+       for lang in ${LINGUAS=$ALL_LINGUAS}; do
+	 case "$ALL_LINGUAS" in
+	  *$lang*) NEW_LINGUAS="$NEW_LINGUAS $lang" ;;
+	 esac
+       done
+       LINGUAS=$NEW_LINGUAS
+       echo "$ac_t""$LINGUAS" 1>&6
+     fi
 
-if test "$g10_force_zlib" = "yes"; then
-    ZLIBS="../zlib/libzlib.a"
-    
+          if test -n "$LINGUAS"; then
+       for lang in $LINGUAS; do CATALOGS="$CATALOGS $lang$CATOBJEXT"; done
+     fi
+   fi
 
-if true; then
-  ENABLE_LOCAL_ZLIB_TRUE=
-  ENABLE_LOCAL_ZLIB_FALSE='#'
-else
-  ENABLE_LOCAL_ZLIB_TRUE='#'
-  ENABLE_LOCAL_ZLIB_FALSE=
-fi
-     if test "x$wk_link_files_src" = "x"; then
-	wk_link_files_src="zlib/zlib.h"
-	wk_link_files_dst="zlib.h "
-    else
-	wk_link_files_src="$wk_link_files_src zlib/zlib.h"
-	wk_link_files_dst="$wk_link_files_dst zlib.h "
-    fi
-  
-     if test "x$wk_link_files_src" = "x"; then
-	wk_link_files_src="zlib/zconf.h"
-	wk_link_files_dst="zconf.h "
-    else
-	wk_link_files_src="$wk_link_files_src zlib/zconf.h"
-	wk_link_files_dst="$wk_link_files_dst zconf.h "
-    fi
-  
-else
-for ac_hdr in zlib.h
-do
-ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
-echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
-echo "configure:3786: checking for $ac_hdr" >&5
+            if test $ac_cv_header_locale_h = yes; then
+     INCLUDE_LOCALE_H="#include <locale.h>"
+   else
+     INCLUDE_LOCALE_H="\
+/* The system does not provide the header <locale.h>.  Take care yourself.  */"
+   fi
+   
+
+            test -d intl || mkdir intl
+   if test "$CATOBJEXT" = ".cat"; then
+     ac_safe=`echo "linux/version.h" | sed 'y%./+-%__p_%'`
+echo $ac_n "checking for linux/version.h""... $ac_c" 1>&6
+echo "configure:3940: checking for linux/version.h" >&5
 if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3791 "configure"
+#line 3945 "configure"
 #include "confdefs.h"
-#include <$ac_hdr>
+#include <linux/version.h>
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:3796: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:3950: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   rm -rf conftest*
@@ -3808,87 +3962,62 @@
 fi
 if eval "test \"`echo '$ac_cv_header_'$ac_safe`\" = yes"; then
   echo "$ac_t""yes" 1>&6
-    ac_tr_hdr=HAVE_`echo $ac_hdr | sed 'y%abcdefghijklmnopqrstuvwxyz./-%ABCDEFGHIJKLMNOPQRSTUVWXYZ___%'`
-  cat >> confdefs.h <<EOF
-#define $ac_tr_hdr 1
-EOF
- 
+  msgformat=linux
 else
   echo "$ac_t""no" 1>&6
+msgformat=xopen
 fi
-done
 
-if test "$ac_cv_header_zlib_h" = yes ; then
-    LIBS="$LIBS -lz"
-    ZLIBS=
-    
 
-if false; then
-  ENABLE_LOCAL_ZLIB_TRUE=
-  ENABLE_LOCAL_ZLIB_FALSE='#'
-else
-  ENABLE_LOCAL_ZLIB_TRUE='#'
-  ENABLE_LOCAL_ZLIB_FALSE=
-fi
-else
-    ZLIBS="../zlib/libzlib.a"
-    
+               sed -e '/^#/d' $srcdir/intl/$msgformat-msg.sed > intl/po2msg.sed
+   fi
+      sed -e '/^#.*[^\\]$/d' -e '/^#$/d' \
+     $srcdir/intl/po2tbl.sed.in > intl/po2tbl.sed
 
-if true; then
-  ENABLE_LOCAL_ZLIB_TRUE=
-  ENABLE_LOCAL_ZLIB_FALSE='#'
-else
-  ENABLE_LOCAL_ZLIB_TRUE='#'
-  ENABLE_LOCAL_ZLIB_FALSE=
-fi
-     if test "x$wk_link_files_src" = "x"; then
-	wk_link_files_src="zlib/zlib.h"
-	wk_link_files_dst="zlib.h "
-    else
-	wk_link_files_src="$wk_link_files_src zlib/zlib.h"
-	wk_link_files_dst="$wk_link_files_dst zlib.h "
-    fi
+            if test "$PACKAGE" = "gettext"; then
+     GT_NO="#NO#"
+     GT_YES=
+   else
+     GT_NO=
+     GT_YES="#YES#"
+   fi
+   
+   
+
+            MKINSTALLDIRS=
+   if test -n "$ac_aux_dir"; then
+     MKINSTALLDIRS="$ac_aux_dir/mkinstalldirs"
+   fi
+   if test -z "$MKINSTALLDIRS"; then
+     MKINSTALLDIRS="\$(top_srcdir)/mkinstalldirs"
+   fi
+   
+
+      l=
+   
+
+         test -d po || mkdir po
+   if test "x$srcdir" != "x."; then
+     if test "x`echo $srcdir | sed 's@/.*@@'`" = "x"; then
+       posrcprefix="$srcdir/"
+     else
+       posrcprefix="../$srcdir/"
+     fi
+   else
+     posrcprefix="../"
+   fi
+   rm -f po/POTFILES
+   sed -e "/^#/d" -e "/^\$/d" -e "s,.*, $posrcprefix& \\\\," -e "\$s/\(.*\) \\\\/\1/" \
+	< $srcdir/po/POTFILES.in > po/POTFILES
   
-     if test "x$wk_link_files_src" = "x"; then
-	wk_link_files_src="zlib/zconf.h"
-	wk_link_files_dst="zconf.h "
+ if test "x$wk_link_files_src" = "x"; then
+	wk_link_files_src="$nls_cv_header_libgt"
+	wk_link_files_dst="$nls_cv_header_intl "
     else
-	wk_link_files_src="$wk_link_files_src zlib/zconf.h"
-	wk_link_files_dst="$wk_link_files_dst zconf.h "
+	wk_link_files_src="$wk_link_files_src $nls_cv_header_libgt"
+	wk_link_files_dst="$wk_link_files_dst $nls_cv_header_intl "
     fi
   
-fi
-fi
-
-
-
-CIPHER_EXTRA_OBJS=""
-CIPHER_EXTRA_DIST=""
-echo $ac_n "checking for extra cipher modules""... $ac_c" 1>&6
-echo "configure:3869: checking for extra cipher modules" >&5
-if eval "test \"`echo '$''{'ac_cv_have_rsa_cipher'+set}'`\" = set"; then
-  echo $ac_n "(cached) $ac_c" 1>&6
-else
-  if test -f $srcdir/cipher/rsa.c && test -f $srcdir/cipher/rsa.h; then
-  ac_cv_have_rsa_cipher=yes; else ac_cv_have_rsa_cipher=no; fi
-fi
-
-echo "$ac_t""$ac_cv_have_rsa_cipher" 1>&6
-if test $ac_cv_have_rsa_cipher = yes; then
-    cat >> confdefs.h <<\EOF
-#define HAVE_RSA_CIPHER 1
-EOF
-
-    CIPHER_EXTRA_OBJS="rsa.o"
-    CIPHER_EXTRA_DIST="rsa.c rsa.h"
-fi
-
-
-
-if test x$ac_cv_func_gettext = xno; then
-    LIBS="$LIBS -lintl -L\$(topbuilddir)/intl"
-fi
-
 
  
   
@@ -4002,6 +4131,7 @@
 mpi/Makefile
 cipher/Makefile
 g10/Makefile
+doc/Makefile
 tools/Makefile
 zlib/Makefile
 checks/Makefile
@@ -4057,16 +4187,25 @@
 s%@AUTOCONF@%$AUTOCONF%g
 s%@AUTOMAKE@%$AUTOMAKE%g
 s%@AUTOHEADER@%$AUTOHEADER%g
+s%@CC@%$CC%g
 s%@RANLIB@%$RANLIB%g
 s%@INSTALL_PROGRAM@%$INSTALL_PROGRAM%g
 s%@INSTALL_DATA@%$INSTALL_DATA%g
-s%@CC@%$CC%g
 s%@CPP@%$CPP%g
+s%@G10_LOCALEDIR@%$G10_LOCALEDIR%g
+s%@MPI_EXTRA_ASM_OBJS@%$MPI_EXTRA_ASM_OBJS%g
+s%@ENABLE_LOCAL_ZLIB_TRUE@%$ENABLE_LOCAL_ZLIB_TRUE%g
+s%@ENABLE_LOCAL_ZLIB_FALSE@%$ENABLE_LOCAL_ZLIB_FALSE%g
+s%@ZLIBS@%$ZLIBS%g
+s%@CIPHER_EXTRA_OBJS@%$CIPHER_EXTRA_OBJS%g
+s%@CIPHER_EXTRA_DIST@%$CIPHER_EXTRA_DIST%g
 s%@ALLOCA@%$ALLOCA%g
+s%@USE_NLS@%$USE_NLS%g
 s%@MSGFMT@%$MSGFMT%g
 s%@GMSGFMT@%$GMSGFMT%g
 s%@XGETTEXT@%$XGETTEXT%g
 s%@GENCAT@%$GENCAT%g
+s%@USE_INCLUDED_LIBINTL@%$USE_INCLUDED_LIBINTL%g
 s%@CATALOGS@%$CATALOGS%g
 s%@CATOBJEXT@%$CATOBJEXT%g
 s%@DATADIRNAME@%$DATADIRNAME%g
@@ -4075,16 +4214,13 @@
 s%@INTLDEPS@%$INTLDEPS%g
 s%@INTLLIBS@%$INTLLIBS%g
 s%@INTLOBJS@%$INTLOBJS%g
-s%@INTLSUB@%$INTLSUB%g
 s%@POFILES@%$POFILES%g
 s%@POSUB@%$POSUB%g
-s%@G10_LOCALEDIR@%$G10_LOCALEDIR%g
-s%@MPI_EXTRA_ASM_OBJS@%$MPI_EXTRA_ASM_OBJS%g
-s%@ENABLE_LOCAL_ZLIB_TRUE@%$ENABLE_LOCAL_ZLIB_TRUE%g
-s%@ENABLE_LOCAL_ZLIB_FALSE@%$ENABLE_LOCAL_ZLIB_FALSE%g
-s%@ZLIBS@%$ZLIBS%g
-s%@CIPHER_EXTRA_OBJS@%$CIPHER_EXTRA_OBJS%g
-s%@CIPHER_EXTRA_DIST@%$CIPHER_EXTRA_DIST%g
+s%@INCLUDE_LOCALE_H@%$INCLUDE_LOCALE_H%g
+s%@GT_NO@%$GT_NO%g
+s%@GT_YES@%$GT_YES%g
+s%@MKINSTALLDIRS@%$MKINSTALLDIRS%g
+s%@l@%$l%g
 
 CEOF
 EOF
@@ -4133,6 +4269,7 @@
 mpi/Makefile
 cipher/Makefile
 g10/Makefile
+doc/Makefile
 tools/Makefile
 zlib/Makefile
 checks/Makefile
diff -urN gnupg-0.2.8/configure.in gnupg-0.2.9/configure.in
--- gnupg-0.2.8/configure.in	Sat Feb 21 14:00:18 1998
+++ gnupg-0.2.9/configure.in	Thu Feb 26 16:40:23 1998
@@ -55,6 +55,7 @@
 AM_MISSING_PROG(AUTOMAKE, automake, $missing_dir)
 AM_MISSING_PROG(AUTOHEADER, autoheader, $missing_dir)
 dnl AM_MISSING_PROG(MAKEINFO, makeinfo, $missing_dir)
+AC_ISC_POSIX
 
 case "${target}" in
     i386--mingw32)
@@ -82,12 +83,10 @@
 AC_HEADER_STDC
 AC_CHECK_HEADERS(unistd.h)
 
-AM_GNU_GETTEXT
 G10_LOCALEDIR="$g10_prefix/$DATADIRNAME/locale"
 AC_SUBST(G10_LOCALEDIR)
 AC_DEFINE_UNQUOTED(G10_LOCALEDIR, "$G10_LOCALEDIR")
 
-WK_LINK_FILES($nls_cv_header_libgt, $nls_cv_header_intl )
 
 dnl Checks for typedefs, structures, and compiler characteristics.
 AC_C_CONST
@@ -191,13 +190,8 @@
 AC_SUBST(CIPHER_EXTRA_OBJS)
 AC_SUBST(CIPHER_EXTRA_DIST)
 
-dnl
-dnl If no gettext is found, default to gnu gettext
-dnl
-if test x$ac_cv_func_gettext = xno; then
-    LIBS="$LIBS -lintl -L\$(topbuilddir)/intl"
-fi
-
+AM_GNU_GETTEXT
+WK_LINK_FILES($nls_cv_header_libgt, $nls_cv_header_intl )
 
 WK_DO_LINK_FILES
 
@@ -209,6 +203,7 @@
 mpi/Makefile
 cipher/Makefile
 g10/Makefile
+doc/Makefile
 tools/Makefile
 zlib/Makefile
 checks/Makefile
diff -urN gnupg-0.2.8/doc/Makefile.am gnupg-0.2.9/doc/Makefile.am
--- gnupg-0.2.8/doc/Makefile.am	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/doc/Makefile.am	Thu Feb 26 09:20:37 1998
@@ -0,0 +1,13 @@
+## Process this file with automake to create Makefile.in
+
+EXTRA_DIST = DETAILS rfcs gpg.1pod gpg.1
+
+man_MANS = gpg.1
+
+%: %pod
+	 pod2man $< --section=`echo $@ | sed 's/^.*(?)$$/$$&/'`\
+		    --release="`date -r $< '+%d %b %Y'`"\
+		    --center="GNU Tools"  --date=' '\
+		     >$@,$$$$ && mv -f $@,$$$$ $@\
+		    || rm -f $@,$$$$
+
diff -urN gnupg-0.2.8/doc/Makefile.in gnupg-0.2.9/doc/Makefile.in
--- gnupg-0.2.8/doc/Makefile.in	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/doc/Makefile.in	Thu Feb 26 17:13:34 1998
@@ -0,0 +1,241 @@
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+
+SHELL = /bin/sh
+
+srcdir = @srcdir@
+top_srcdir = @top_srcdir@
+VPATH = @srcdir@
+prefix = @prefix@
+exec_prefix = @exec_prefix@
+
+bindir = @bindir@
+sbindir = @sbindir@
+libexecdir = @libexecdir@
+datadir = @datadir@
+sysconfdir = @sysconfdir@
+sharedstatedir = @sharedstatedir@
+localstatedir = @localstatedir@
+libdir = @libdir@
+infodir = @infodir@
+mandir = @mandir@
+includedir = @includedir@
+oldincludedir = /usr/include
+
+pkgdatadir = $(datadir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+
+top_builddir = ..
+
+ACLOCAL = @ACLOCAL@
+AUTOCONF = @AUTOCONF@
+AUTOMAKE = @AUTOMAKE@
+AUTOHEADER = @AUTOHEADER@
+
+INSTALL = @INSTALL@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+transform = @program_transform_name@
+
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_alias = @build_alias@
+build_triplet = @build@
+host_alias = @host_alias@
+host_triplet = @host@
+target_alias = @target_alias@
+target_triplet = @target@
+CATALOGS = @CATALOGS@
+CATOBJEXT = @CATOBJEXT@
+CC = @CC@
+CIPHER_EXTRA_DIST = @CIPHER_EXTRA_DIST@
+CIPHER_EXTRA_OBJS = @CIPHER_EXTRA_OBJS@
+CPP = @CPP@
+DATADIRNAME = @DATADIRNAME@
+G10_LOCALEDIR = @G10_LOCALEDIR@
+GENCAT = @GENCAT@
+GMOFILES = @GMOFILES@
+GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
+INSTOBJEXT = @INSTOBJEXT@
+INTLDEPS = @INTLDEPS@
+INTLLIBS = @INTLLIBS@
+INTLOBJS = @INTLOBJS@
+MKINSTALLDIRS = @MKINSTALLDIRS@
+MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
+MSGFMT = @MSGFMT@
+PACKAGE = @PACKAGE@
+POFILES = @POFILES@
+POSUB = @POSUB@
+RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
+VERSION = @VERSION@
+ZLIBS = @ZLIBS@
+l = @l@
+
+EXTRA_DIST = DETAILS rfcs gpg.1pod gpg.1
+
+man_MANS = gpg.1
+mkinstalldirs = $(SHELL) $(top_srcdir)/scripts/mkinstalldirs
+CONFIG_HEADER = ../config.h
+CONFIG_CLEAN_FILES = 
+man1dir = $(mandir)/man1
+MANS = $(man_MANS)
+
+NROFF = nroff
+DIST_COMMON =  Makefile.am Makefile.in
+
+
+DISTFILES = $(DIST_COMMON) $(SOURCES) $(HEADERS) $(TEXINFOS) $(EXTRA_DIST)
+
+TAR = tar
+GZIP = --best
+default: all
+
+.SUFFIXES:
+$(srcdir)/Makefile.in: Makefile.am $(top_srcdir)/configure.in $(ACLOCAL_M4) 
+	cd $(top_srcdir) && $(AUTOMAKE) --gnu --include-deps doc/Makefile
+
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	cd $(top_builddir) \
+	  && CONFIG_FILES=$(subdir)/$@ CONFIG_HEADERS= $(SHELL) ./config.status
+
+
+install-man1:
+	$(mkinstalldirs) $(man1dir)
+	@list='$(man1_MANS)'; \
+	l2='$(man_MANS)'; for i in $$l2; do \
+	  case "$$i" in \
+	    *.1*) list="$$list $$i" ;; \
+	  esac; \
+	done; \
+	for i in $$list; do \
+	  if test -f $(srcdir)/$$i; then file=$(srcdir)/$$i; \
+	  else file=$$i; fi; \
+	  ext=`echo $$i | sed -e 's/^.*\\.//'`; \
+	  inst=`echo $$i | sed -e 's/\\.[0-9a-z]*$$//'`; \
+	  inst=`echo $$inst | sed '$(transform)'`.$$ext; \
+	  echo " $(INSTALL_DATA) $$file $(man1dir)/$$inst"; \
+	  $(INSTALL_DATA) $$file $(man1dir)/$$inst; \
+	done
+
+uninstall-man1:
+	@list='$(man1_MANS)'; \
+	l2='$(man_MANS)'; for i in $$l2; do \
+	  case "$$i" in \
+	    *.1*) list="$$list $$i" ;; \
+	  esac; \
+	done; \
+	for i in $$list; do \
+	  ext=`echo $$i | sed -e 's/^.*\\.//'`; \
+	  inst=`echo $$i | sed -e 's/\\.[0-9a-z]*$$//'`; \
+	  inst=`echo $$inst | sed '$(transform)'`.$$ext; \
+	  echo " rm -f $(man1dir)/$$inst"; \
+	  rm -f $(man1dir)/$$inst; \
+	done
+install-man: $(MANS)
+	@$(NORMAL_INSTALL)
+	$(MAKE) install-man1
+uninstall-man:
+	@$(NORMAL_UNINSTALL)
+	$(MAKE) uninstall-man1
+tags: TAGS
+TAGS:
+
+
+distdir = $(top_builddir)/$(PACKAGE)-$(VERSION)/$(subdir)
+
+subdir = doc
+
+distdir: $(DISTFILES)
+	@for file in $(DISTFILES); do \
+	  d=$(srcdir); \
+	  test -f $(distdir)/$$file \
+	  || ln $$d/$$file $(distdir)/$$file 2> /dev/null \
+	  || cp -p $$d/$$file $(distdir)/$$file; \
+	done
+info:
+dvi:
+check: all
+	$(MAKE)
+installcheck:
+install-exec: 
+	@$(NORMAL_INSTALL)
+
+install-data: install-man
+	@$(NORMAL_INSTALL)
+
+install: install-exec install-data all
+	@:
+
+uninstall: uninstall-man
+
+all: Makefile $(MANS)
+
+install-strip:
+	$(MAKE) INSTALL_PROGRAM='$(INSTALL_PROGRAM) -s' INSTALL_SCRIPT='$(INSTALL_PROGRAM)' install
+installdirs:
+	$(mkinstalldirs)  $(mandir)/man1
+
+
+mostlyclean-generic:
+	-test -z "$(MOSTLYCLEANFILES)" || rm -f $(MOSTLYCLEANFILES)
+
+clean-generic:
+	-test -z "$(CLEANFILES)" || rm -f $(CLEANFILES)
+
+distclean-generic:
+	-rm -f Makefile $(DISTCLEANFILES)
+	-rm -f config.cache config.log stamp-h stamp-h[0-9]*
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+
+maintainer-clean-generic:
+	-test -z "$(MAINTAINERCLEANFILES)" || rm -f $(MAINTAINERCLEANFILES)
+	-test -z "$(BUILT_SOURCES)" || rm -f $(BUILT_SOURCES)
+mostlyclean:  mostlyclean-generic
+
+clean:  clean-generic mostlyclean
+
+distclean:  distclean-generic clean
+	-rm -f config.status
+
+maintainer-clean:  maintainer-clean-generic distclean
+	@echo "This command is intended for maintainers to use;"
+	@echo "it deletes files that may require special tools to rebuild."
+
+.PHONY: default install-man1 uninstall-man1 install-man uninstall-man \
+tags distdir info dvi installcheck install-exec install-data install \
+uninstall all installdirs mostlyclean-generic distclean-generic \
+clean-generic maintainer-clean-generic clean mostlyclean distclean \
+maintainer-clean
+
+
+%: %pod
+	 pod2man $< --section=`echo $@ | sed 's/^.*(?)$$/$$&/'`\
+		    --release="`date -r $< '+%d %b %Y'`"\
+		    --center="GNU Tools"  --date=' '\
+		     >$@,$$$$ && mv -f $@,$$$$ $@\
+		    || rm -f $@,$$$$
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:
diff -urN gnupg-0.2.8/doc/distfiles gnupg-0.2.9/doc/distfiles
--- gnupg-0.2.8/doc/distfiles	Wed Feb 18 09:04:21 1998
+++ gnupg-0.2.9/doc/distfiles	Thu Jan  1 01:00:00 1970
@@ -1,4 +0,0 @@
-
-DETAILS
-rfcs
-
diff -urN gnupg-0.2.8/doc/gpg.1 gnupg-0.2.9/doc/gpg.1
--- gnupg-0.2.8/doc/gpg.1	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/doc/gpg.1	Thu Feb 26 14:34:31 1998
@@ -0,0 +1,454 @@
+.rn '' }`
+''' $RCSfile$$Revision$$Date$
+'''
+''' $Log$
+'''
+.de Sh
+.br
+.if t .Sp
+.ne 5
+.PP
+\fB\\$1\fR
+.PP
+..
+.de Sp
+.if t .sp .5v
+.if n .sp
+..
+.de Ip
+.br
+.ie \\n(.$>=3 .ne \\$3
+.el .ne 3
+.IP "\\$1" \\$2
+..
+.de Vb
+.ft CW
+.nf
+.ne \\$1
+..
+.de Ve
+.ft R
+
+.fi
+..
+'''
+'''
+'''     Set up \*(-- to give an unbreakable dash;
+'''     string Tr holds user defined translation string.
+'''     Bell System Logo is used as a dummy character.
+'''
+.tr \(*W-|\(bv\*(Tr
+.ie n \{\
+.ds -- \(*W-
+.ds PI pi
+.if (\n(.H=4u)&(1m=24u) .ds -- \(*W\h'-12u'\(*W\h'-12u'-\" diablo 10 pitch
+.if (\n(.H=4u)&(1m=20u) .ds -- \(*W\h'-12u'\(*W\h'-8u'-\" diablo 12 pitch
+.ds L" ""
+.ds R" ""
+.ds L' '
+.ds R' '
+'br\}
+.el\{\
+.ds -- \(em\|
+.tr \*(Tr
+.ds L" ``
+.ds R" ''
+.ds L' `
+.ds R' '
+.ds PI \(*p
+'br\}
+.\"	If the F register is turned on, we'll generate
+.\"	index entries out stderr for the following things:
+.\"		TH	Title 
+.\"		SH	Header
+.\"		Sh	Subsection 
+.\"		Ip	Item
+.\"		X<>	Xref  (embedded
+.\"	Of course, you have to process the output yourself
+.\"	in some meaninful fashion.
+.if \nF \{
+.de IX
+.tm Index:\\$1\t\\n%\t"\\$2"
+..
+.nr % 0
+.rr F
+.\}
+.TH gpg gpg.1 "26 Feb 1998" " " "GNU Tools"
+.IX Title "gpg gpg.1"
+.UC
+.IX Name "gpg - GNU Privacy Guard"
+.if n .hy 0
+.if n .na
+.ds C+ C\v'-.1v'\h'-1p'\s-2+\h'-1p'+\s0\v'.1v'\h'-1p'
+.de CQ          \" put $1 in typewriter font
+.ft CW
+'if n "\c
+'if t \\&\\$1\c
+'if n \\&\\$1\c
+'if n \&"
+\\&\\$2 \\$3 \\$4 \\$5 \\$6 \\$7
+'.ft R
+..
+.\" @(#)ms.acc 1.5 88/02/08 SMI; from UCB 4.2
+.	\" AM - accent mark definitions
+.bd B 3
+.	\" fudge factors for nroff and troff
+.if n \{\
+.	ds #H 0
+.	ds #V .8m
+.	ds #F .3m
+.	ds #[ \f1
+.	ds #] \fP
+.\}
+.if t \{\
+.	ds #H ((1u-(\\\\n(.fu%2u))*.13m)
+.	ds #V .6m
+.	ds #F 0
+.	ds #[ \&
+.	ds #] \&
+.\}
+.	\" simple accents for nroff and troff
+.if n \{\
+.	ds ' \&
+.	ds ` \&
+.	ds ^ \&
+.	ds , \&
+.	ds ~ ~
+.	ds ? ?
+.	ds ! !
+.	ds /
+.	ds q
+.\}
+.if t \{\
+.	ds ' \\k:\h'-(\\n(.wu*8/10-\*(#H)'\'\h"|\\n:u"
+.	ds ` \\k:\h'-(\\n(.wu*8/10-\*(#H)'\`\h'|\\n:u'
+.	ds ^ \\k:\h'-(\\n(.wu*10/11-\*(#H)'^\h'|\\n:u'
+.	ds , \\k:\h'-(\\n(.wu*8/10)',\h'|\\n:u'
+.	ds ~ \\k:\h'-(\\n(.wu-\*(#H-.1m)'~\h'|\\n:u'
+.	ds ? \s-2c\h'-\w'c'u*7/10'\u\h'\*(#H'\zi\d\s+2\h'\w'c'u*8/10'
+.	ds ! \s-2\(or\s+2\h'-\w'\(or'u'\v'-.8m'.\v'.8m'
+.	ds / \\k:\h'-(\\n(.wu*8/10-\*(#H)'\z\(sl\h'|\\n:u'
+.	ds q o\h'-\w'o'u*8/10'\s-4\v'.4m'\z\(*i\v'-.4m'\s+4\h'\w'o'u*8/10'
+.\}
+.	\" troff and (daisy-wheel) nroff accents
+.ds : \\k:\h'-(\\n(.wu*8/10-\*(#H+.1m+\*(#F)'\v'-\*(#V'\z.\h'.2m+\*(#F'.\h'|\\n:u'\v'\*(#V'
+.ds 8 \h'\*(#H'\(*b\h'-\*(#H'
+.ds v \\k:\h'-(\\n(.wu*9/10-\*(#H)'\v'-\*(#V'\*(#[\s-4v\s0\v'\*(#V'\h'|\\n:u'\*(#]
+.ds _ \\k:\h'-(\\n(.wu*9/10-\*(#H+(\*(#F*2/3))'\v'-.4m'\z\(hy\v'.4m'\h'|\\n:u'
+.ds . \\k:\h'-(\\n(.wu*8/10)'\v'\*(#V*4/10'\z.\v'-\*(#V*4/10'\h'|\\n:u'
+.ds 3 \*(#[\v'.2m'\s-2\&3\s0\v'-.2m'\*(#]
+.ds o \\k:\h'-(\\n(.wu+\w'\(de'u-\*(#H)/2u'\v'-.3n'\*(#[\z\(de\v'.3n'\h'|\\n:u'\*(#]
+.ds d- \h'\*(#H'\(pd\h'-\w'~'u'\v'-.25m'\f2\(hy\fP\v'.25m'\h'-\*(#H'
+.ds D- D\\k:\h'-\w'D'u'\v'-.11m'\z\(hy\v'.11m'\h'|\\n:u'
+.ds th \*(#[\v'.3m'\s+1I\s-1\v'-.3m'\h'-(\w'I'u*2/3)'\s-1o\s+1\*(#]
+.ds Th \*(#[\s+2I\s-2\h'-\w'I'u*3/5'\v'-.3m'o\v'.3m'\*(#]
+.ds ae a\h'-(\w'a'u*4/10)'e
+.ds Ae A\h'-(\w'A'u*4/10)'E
+.ds oe o\h'-(\w'o'u*4/10)'e
+.ds Oe O\h'-(\w'O'u*4/10)'E
+.	\" corrections for vroff
+.if v .ds ~ \\k:\h'-(\\n(.wu*9/10-\*(#H)'\s-2\u~\d\s+2\h'|\\n:u'
+.if v .ds ^ \\k:\h'-(\\n(.wu*10/11-\*(#H)'\v'-.4m'^\v'.4m'\h'|\\n:u'
+.	\" for low resolution devices (crt and lpr)
+.if \n(.H>23 .if \n(.V>19 \
+\{\
+.	ds : e
+.	ds 8 ss
+.	ds v \h'-1'\o'\(aa\(ga'
+.	ds _ \h'-1'^
+.	ds . \h'-1'.
+.	ds 3 3
+.	ds o a
+.	ds d- d\h'-1'\(ga
+.	ds D- D\h'-1'\(hy
+.	ds th \o'bp'
+.	ds Th \o'LP'
+.	ds ae ae
+.	ds Ae AE
+.	ds oe oe
+.	ds Oe OE
+.\}
+.rm #[ #] #H #V #F C
+.SH "NAME"
+.IX Header "NAME"
+gpg \- GNU Privacy Guard
+.SH "SYNOPSIS"
+.IX Header "SYNOPSIS"
+\fBgpg\fR [--homedir name] [--options file] [options] command [args]
+.SH "DESCRIPTION"
+.IX Header "DESCRIPTION"
+This is the main program from the GNUPG system.
+.SH "COMMANDS"
+.IX Header "COMMANDS"
+\fBgpg\fR recognizes these commands:
+.PP
+\fB\-s\fR, \fB--sign\fR
+    Make a signature. This option maybe combined
+    with \fB--encrypt\fR.
+.PP
+\fB--clearsign\fR
+    Make a clear text signature.
+.PP
+\fB\-b\fR, \fB--detach-sign\fR
+    Make a detached signature.
+.PP
+\fB\-e\fR, \fB--encrypt\fR
+    Encrypt data. This option may be combined with \fB--sign\fR.
+.PP
+\fB\-c\fR, \fB--symmetric\fR
+    Encrypt only with symmetric cipher
+    This command asks for a passphrase.
+.PP
+\fB--store\fR
+    store only (make a RFC1991 packet).
+.PP
+\fB\-d\fR, \fB--decrypt\fR
+    Decrypt data. This is the default operation for data
+    files.
+.PP
+\fB\-k\fR [\fIkeyring\fR]
+    Kludge to be somewhat compatibe to PGP.
+    Without arguments, all public key-rings are listed,
+    with one argument, only \fIkeyring\fR is listed.
+    Special combinations are also allowed, but it may
+    give starnge results when combined with more options.
+    \fB\-kv\fR    Same as \fB\-k\fR
+    \fB\-kvv\fR   List the signatures with every key.
+    \fB\-kvvv\fR  Additional check all signatures.
+    \fB\-kvc\fR   List fingerprints
+    \fB\-kvvc\fR  List fingerprints and signatures
+.PP
+\fB--list-keys\fR
+    List all keys in all public key-rings and check the
+    signatures.
+.PP
+\fB--check-keys\fR
+    Check signatures on a key in the keyring
+.PP
+\fB--fingerprint\fR
+    Show the fingerprints
+.PP
+\fB--list-packets\fR
+    List only the sequence of packets. This is mainly
+    useful for debugging.
+.PP
+\fB--gen-key\fR
+    Generate a new key pair. This command can only be
+    used interactive.
+.PP
+\fB--sign-key\fR \fIname\fR
+    Make a signature on key of user \fIname\fR.
+    This looks for the key, displays the key and checks
+    all existing signatures of this key. If the key is
+    not yet signed by the default user (or the users given
+    with \fB\-u\fR), the program displays the information of
+    the key again, together with it's fingerprint and
+    asked whether it should be signed. This question
+    is repeated for all users specified with \fB\-u\fR.
+    The key is then signed and the keyring which
+    contains the key is updated.
+.PP
+\fB--delete-key\fR
+    Remove key from the public keyring
+.PP
+\fB--edit-sig\fR
+    Edit/remove a key signature.
+.PP
+\fB--change-passphrase\fR
+    Change the passphrase of your secret keyring
+.PP
+\fB--gen-revoke\fR
+    Generate a revocation certificate.
+.PP
+\fB--export\fR [\fInames\fR]
+    Either export all keys from all key-rings (default
+    key-rings and those registered via option \fB--keyring\fR,
+    or if at least one name is given, those of the given
+    name. The new keyring is written to \fIstdout\fR or to
+    the file given with option \*(L"output\*(R".  Use together
+    with \fB\-a\fR to mail those keys.
+.PP
+\fB--import\fR
+    import/merge keys
+.SH "OPTIONS"
+.IX Header "OPTIONS"
+Long options can be put in an options file (default \fI~/.gnupg/options\fR);
+do not write the 2 dashes, but simply the name of the option and any
+arguments if required, lines with a hash as the first non-white-space
+character are ignored. Commands maybe put in this file too, but that
+does not make sense.
+.PP
+\fBgpg\fR recognizes these options:
+.PP
+\fB\-a\fR, \fB--armor\fR
+    Create ASCII armored output.
+.PP
+\fB\-o\fR \fIfile\fR, \fB--output\fR \fIfile\fR
+    Write output to \fIfile\fR.
+.PP
+\fB\-u\fR \fIname\fR, \fB--local-user\fR \fIname\fR
+    Use \fIname\fR as the user-id to sign.
+.PP
+\fB\-r\fR  \fIname\fR, \fB--remote-user\fR  \fIname\fR
+    Use  \fIname\fR as the user-id for encryption.
+.PP
+\fB\-v\fR, \fB--verbose\fR
+    Give more informations during processing. If used
+    2 times, the input data is listed in detail.
+.PP
+\fB\-z\fR \fIn\fR
+    Set compress level to \fIn\fR. A value of 0 for \fIn\fR
+    disables compression. Default is to use the default
+    compression level of zlib (which is 6).
+.PP
+\fB\-t\fR, \fB--textmode\fR
+    Use canonical text mode.  Used to make clear-text
+    signatures.
+.PP
+\fB\-n\fR, \fB--dry-run\fR
+    Don't make any changes (not yet implemented).
+.PP
+\fB--batch\fR
+    Batch mode; never ask, do not allow interactive
+    commands.
+.PP
+\fB--no-batch\fR
+    Disable batch mode; this may be used if \fBbatch\fR
+    is used in the options file.
+.PP
+\fB--yes\fR
+    Assume yes on most questions.
+.PP
+\fB--no\fR
+    Assume no on most questions.
+.PP
+\fB--keyring\fR \fIfile\fR
+    Add \fIfile\fR to the list of key-rings.
+    If \fIfile\fR begins with a tilde and a slash, these
+    are replaced by the HOME directory. If the filename
+    does not contain a slash, it is assumed to be in the
+    home-directory (\fI~/.gnupg\fR if \fB--homedir\fR) is not used.
+.PP
+\fB--secret-keyring\fR \fIfile\fR
+    Same as \fB--keyring\fR but for secret key-rings.
+.PP
+\fB--homedir\fR \fIdir\fR
+    Set the name of the home directory to \fIdir\fR. If this
+    option is not used it defaults to \fI~/.gnupg\fR. It does
+    not make sense to use this in a options file.
+.PP
+\fB--options\fR \fIfile\fR
+    Read options from \fIfile\fR and do not try to read
+    them from the default options file in the homedir
+    (see \fB--homedir\fR). This option is ignored when used
+    in an options file.
+.PP
+\fBno-options\fR
+    Shortcut for \fB--options\fR \fI/dev/null\fR.  This option is
+    detected before an attempt to open an option file.
+.PP
+\fB--debug\fR \fIflags\fR
+    Set debugging flags. All flags are or-ed and \fIflags\fR may
+    be given in C syntax (e.g. 0x0042).
+.PP
+\fB--debug-all\fR
+    Set all useful debugging flags.
+.PP
+\fB--status-fd\fR \fIn\fR
+    Write special status strings to the file descriptor \fIn\fR.
+.PP
+\fB--no-comment\fR
+    Do not write comment packets.
+.PP
+\fB--completes-needed\fR \fIn\fR
+    Number of completey trusted users to introduce a new
+    key signator (defaults to 1).
+.PP
+\fB--marginals-needed\fR \fIn\fR
+    Number of marginally trusted users to introduce a new
+    key signator (defaults to 3)
+.PP
+\fB--cipher-algo\fR \fIname\fR
+    Use \fIname\fR as cipher algorithm. Running the program
+    with the option \fB--verbose\fR yields a list off supported
+    algorithms.
+.PP
+\fB--pubkey-algo\fR \fIname\fR
+    Use \fIname\fR as puplic key algorithm. Running the program
+    with the option \fB--verbose\fR yields a list off supported
+    algorithms.
+.PP
+\fB--digest-algo\fR \fIname\fR
+    Use \fIname\fR as message digest algorithm. Running the
+    program with the option \fB--verbose\fR yields a list off
+    supported algorithms.
+.PP
+\fB--passphrase-fd\fR \fIn\fR
+    Read the passphrase from file descriptor \fIn\fR. If you use
+    0 for \fIn\fR, the passphrase will be read from stdin.  This
+    can only be used if only one passphrase is supplied.
+    \fBDon't use this option if you can avoid it\fR
+.PP
+\fBno-verbose\fR
+    Reset verbose level to 0.
+.PP
+\fBno-greeting\fR
+    Suppress the initial copyright message but do not
+    enter batch mode.
+.PP
+\fBno-armor\fR
+    Assume the input data is not in ASCCI armored format.
+.PP
+\fBno-default-keyring\fR
+    Do not add the default key-rings to the list of
+    key-rings.
+.PP
+\fB--version\fR
+    Print version information along with a list
+    of supported algorithms.
+.PP
+\fB--warranty\fR
+    Print warranty information.
+.PP
+\fB\-h\fR, \fB--help\fR
+    Print usage information.
+.SH "RETURN VALUE"
+.IX Header "RETURN VALUE"
+The Program returns 0 if everything was fine, 1 if at least
+a signature was bad and other errorcode for fatal errors.
+.SH "EXAMPLES"
+.IX Header "EXAMPLES"
+.PP
+.Vb 5
+\&  -se -r Bob [file]          sign and encrypt for user Bob
+\&  -sat [file]                make a clear text signature
+\&  -sb  [file]                make a detached signature
+\&  -k   [userid]              show keys
+\&  -kc  [userid]              show fingerprint
+.Ve
+.SH "ENVIRONMENT"
+.IX Header "ENVIRONMENT"
+\f(CWHOME\fR   Used to locate the default home directory.
+.SH "FILES"
+.IX Header "FILES"
+\fI~/.gnupg/secring.gpg\fR     The secret key-ring
+.PP
+\fI~/.gnupg/pubring.gpg\fR     The public key-ring
+.PP
+\fI~/.gnupg/trustdb.gpg\fR     The trust database
+.PP
+\fI~/.gnupg/gnupg.gpg\fR	    Signature of GNUPG files.
+.PP
+\fI~/.gnupg/options\fR	    May contain options
+.SH "SEE ALSO"
+.IX Header "SEE ALSO"
+\fIgpgm\fR\|(1)  \fIgpgk\fR\|(1)
+.SH "WARNINGS"
+.IX Header "WARNINGS"
+Use a \fBgood\fR password for your user account and a non-simple passphrase
+to protect your secret key.
+.PP
+Keep in mind that, if this program is used over a network (telnet), it
+is \fBvery\fR easy to spy out your passphrase!
+
+.rn }` ''
diff -urN gnupg-0.2.8/doc/gpg.1pod gnupg-0.2.9/doc/gpg.1pod
--- gnupg-0.2.8/doc/gpg.1pod	Thu Jan  1 01:00:00 1970
+++ gnupg-0.2.9/doc/gpg.1pod	Thu Feb 26 14:31:56 1998
@@ -0,0 +1,297 @@
+=head1 NAME
+
+gpg - GNU Privacy Guard
+
+=head1 SYNOPSIS
+
+B<gpg> [--homedir name] [--options file] [options] command [args]
+
+=head1 DESCRIPTION
+
+This is the main program from the GNUPG system.
+
+=head1 COMMANDS
+
+B<gpg> recognizes these commands:
+
+B<-s>, B<--sign>
+    Make a signature. This option maybe combined
+    with B<--encrypt>.
+
+B<--clearsign>
+    Make a clear text signature.
+
+B<-b>, B<--detach-sign>
+    Make a detached signature.
+
+B<-e>, B<--encrypt>
+    Encrypt data. This option may be combined with B<--sign>.
+
+B<-c>, B<--symmetric>
+    Encrypt only with symmetric cipher
+    This command asks for a passphrase.
+
+B<--store>
+    store only (make a RFC1991 packet).
+
+B<-d>, B<--decrypt>
+    Decrypt data. This is the default operation for data
+    files.
+
+B<-k> [I<keyring>]
+    Kludge to be somewhat compatibe to PGP.
+    Without arguments, all public key-rings are listed,
+    with one argument, only I<keyring> is listed.
+    Special combinations are also allowed, but it may
+    give starnge results when combined with more options.
+    B<-kv>    Same as B<-k>
+    B<-kvv>   List the signatures with every key.
+    B<-kvvv>  Additional check all signatures.
+    B<-kvc>   List fingerprints
+    B<-kvvc>  List fingerprints and signatures
+
+B<--list-keys>
+    List all keys in all public key-rings and check the
+    signatures.
+
+B<--check-keys>
+    Check signatures on a key in the keyring
+
+B<--fingerprint>
+    Show the fingerprints
+
+B<--list-packets>
+    List only the sequence of packets. This is mainly
+    useful for debugging.
+
+B<--gen-key>
+    Generate a new key pair. This command can only be
+    used interactive.
+
+B<--sign-key> I<name>
+    Make a signature on key of user I<name>.
+    This looks for the key, displays the key and checks
+    all existing signatures of this key. If the key is
+    not yet signed by the default user (or the users given
+    with B<-u>), the program displays the information of
+    the key again, together with it's fingerprint and
+    asked whether it should be signed. This question
+    is repeated for all users specified with B<-u>.
+    The key is then signed and the keyring which
+    contains the key is updated.
+
+
+B<--delete-key>
+    Remove key from the public keyring
+
+B<--edit-sig>
+    Edit/remove a key signature.
+
+B<--change-passphrase>
+    Change the passphrase of your secret keyring
+
+B<--gen-revoke>
+    Generate a revocation certificate.
+
+B<--export> [I<names>]
+    Either export all keys from all key-rings (default
+    key-rings and those registered via option B<--keyring>,
+    or if at least one name is given, those of the given
+    name. The new keyring is written to F<stdout> or to
+    the file given with option "output".  Use together
+    with B<-a> to mail those keys.
+
+B<--import>
+    import/merge keys
+
+
+=head1 OPTIONS
+
+Long options can be put in an options file (default F<~/.gnupg/options>);
+do not write the 2 dashes, but simply the name of the option and any
+arguments if required, lines with a hash as the first non-white-space
+character are ignored. Commands maybe put in this file too, but that
+does not make sense.
+
+B<gpg> recognizes these options:
+
+
+B<-a>, B<--armor>
+    Create ASCII armored output.
+
+B<-o> I<file>, B<--output> I<file>
+    Write output to I<file>.
+
+B<-u> I<name>, B<--local-user> I<name>
+    Use I<name> as the user-id to sign.
+
+B<-r>  I<name>, B<--remote-user>  I<name>
+    Use  I<name> as the user-id for encryption.
+
+B<-v>, B<--verbose>
+    Give more informations during processing. If used
+    2 times, the input data is listed in detail.
+
+
+B<-z> I<n>
+    Set compress level to I<n>. A value of 0 for I<n>
+    disables compression. Default is to use the default
+    compression level of zlib (which is 6).
+
+B<-t>, B<--textmode>
+    Use canonical text mode.  Used to make clear-text
+    signatures.
+
+B<-n>, B<--dry-run>
+    Don't make any changes (not yet implemented).
+
+B<--batch>
+    Batch mode; never ask, do not allow interactive
+    commands.
+
+B<--no-batch>
+    Disable batch mode; this may be used if B<batch>
+    is used in the options file.
+
+B<--yes>
+    Assume yes on most questions.
+
+B<--no>
+    Assume no on most questions.
+
+B<--keyring> I<file>
+    Add I<file> to the list of key-rings.
+    If I<file> begins with a tilde and a slash, these
+    are replaced by the HOME directory. If the filename
+    does not contain a slash, it is assumed to be in the
+    home-directory (F<~/.gnupg> if B<--homedir>) is not used.
+
+B<--secret-keyring> I<file>
+    Same as B<--keyring> but for secret key-rings.
+
+B<--homedir> I<dir>
+    Set the name of the home directory to I<dir>. If this
+    option is not used it defaults to F<~/.gnupg>. It does
+    not make sense to use this in a options file.
+
+B<--options> I<file>
+    Read options from I<file> and do not try to read
+    them from the default options file in the homedir
+    (see B<--homedir>). This option is ignored when used
+    in an options file.
+
+B<no-options>
+    Shortcut for B<--options> I</dev/null>.  This option is
+    detected before an attempt to open an option file.
+
+B<--debug> I<flags>
+    Set debugging flags. All flags are or-ed and I<flags> may
+    be given in C syntax (e.g. 0x0042).
+
+B<--debug-all>
+    Set all useful debugging flags.
+
+B<--status-fd> I<n>
+    Write special status strings to the file descriptor I<n>.
+
+B<--no-comment>
+    Do not write comment packets.
+
+B<--completes-needed> I<n>
+    Number of completey trusted users to introduce a new
+    key signator (defaults to 1).
+
+B<--marginals-needed> I<n>
+    Number of marginally trusted users to introduce a new
+    key signator (defaults to 3)
+
+B<--cipher-algo> I<name>
+    Use I<name> as cipher algorithm. Running the program
+    with the option B<--verbose> yields a list off supported
+    algorithms.
+
+B<--pubkey-algo> I<name>
+    Use I<name> as puplic key algorithm. Running the program
+    with the option B<--verbose> yields a list off supported
+    algorithms.
+
+B<--digest-algo> I<name>
+    Use I<name> as message digest algorithm. Running the
+    program with the option B<--verbose> yields a list off
+    supported algorithms.
+
+B<--passphrase-fd> I<n>
+    Read the passphrase from file descriptor I<n>. If you use
+    0 for I<n>, the passphrase will be read from stdin.  This
+    can only be used if only one passphrase is supplied.
+    B<Don't use this option if you can avoid it>
+
+B<no-verbose>
+    Reset verbose level to 0.
+
+B<no-greeting>
+    Suppress the initial copyright message but do not
+    enter batch mode.
+
+B<no-armor>
+    Assume the input data is not in ASCCI armored format.
+
+B<no-default-keyring>
+    Do not add the default key-rings to the list of
+    key-rings.
+
+B<--version>
+    Print version information along with a list
+    of supported algorithms.
+
+B<--warranty>
+    Print warranty information.
+
+B<-h>, B<--help>
+    Print usage information.
+
+
+=head1 RETURN VALUE
+
+The Program returns 0 if everything was fine, 1 if at least
+a signature was bad and other errorcode for fatal errors.
+
+=head1 EXAMPLES
+
+  -se -r Bob [file]	     sign and encrypt for user Bob
+  -sat [file]		     make a clear text signature
+  -sb  [file]		     make a detached signature
+  -k   [userid] 	     show keys
+  -kc  [userid] 	     show fingerprint
+
+=head1 ENVIRONMENT
+
+C<HOME>   Used to locate the default home directory.
+
+=head1 FILES
+
+F<~/.gnupg/secring.gpg>     The secret key-ring
+
+F<~/.gnupg/pubring.gpg>     The public key-ring
+
+F<~/.gnupg/trustdb.gpg>     The trust database
+
+F<~/.gnupg/gnupg.gpg>	    Signature of GNUPG files.
+
+F<~/.gnupg/options>	    May contain options
+
+
+=head1 SEE ALSO
+
+gpgm(1)  gpgk(1)
+
+
+=head1 WARNINGS
+
+Use a B<good> password for your user account and a non-simple passphrase
+to protect your secret key.
+
+Keep in mind that, if this program is used over a network (telnet), it
+is B<very> easy to spy out your passphrase!
+
+
diff -urN gnupg-0.2.8/g10/ChangeLog gnupg-0.2.9/g10/ChangeLog
--- gnupg-0.2.8/g10/ChangeLog	Tue Feb 24 15:57:35 1998
+++ gnupg-0.2.9/g10/ChangeLog	Wed Feb 25 11:43:56 1998
@@ -1,3 +1,14 @@
+Wed Feb 25 11:40:04 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* plaintext.c (ask_for_detached_datafile): add opt.verbose to
+	info output.
+
+	* openfile.c (open_sigfile): Try also name ending in ".asc"
+
+Wed Feb 25 08:41:00 1998  Werner Koch  (wk@isil.d.shuttle.de)
+
+	* keygen.c (generate_keypair): Fixed memory overflow.
+
 Tue Feb 24 15:51:55 1998  Werner Koch  (wk@isil.d.shuttle.de)
 
 	* parse-packet.c (parse_certificate): Support for S2K.
diff -urN gnupg-0.2.8/g10/Makefile.in gnupg-0.2.9/g10/Makefile.in
--- gnupg-0.2.8/g10/Makefile.in	Tue Feb 24 18:12:19 1998
+++ gnupg-0.2.9/g10/Makefile.in	Thu Feb 26 17:13:31 1998
@@ -1,6 +1,6 @@
-# Makefile.in generated automatically by automake 1.2d from Makefile.am
+# Makefile.in generated automatically by automake 1.2f from Makefile.am
 
-# Copyright (C) 1994, 1995, 1996, 1997 Free Software Foundation, Inc.
+# Copyright (C) 1994, 1995, 1996, 1997, 1998 Free Software Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -72,19 +72,25 @@
 GENCAT = @GENCAT@
 GMOFILES = @GMOFILES@
 GMSGFMT = @GMSGFMT@
+GT_NO = @GT_NO@
+GT_YES = @GT_YES@
+INCLUDE_LOCALE_H = @INCLUDE_LOCALE_H@
 INSTOBJEXT = @INSTOBJEXT@
 INTLDEPS = @INTLDEPS@
 INTLLIBS = @INTLLIBS@
 INTLOBJS = @INTLOBJS@
-INTLSUB = @INTLSUB@
+MKINSTALLDIRS = @MKINSTALLDIRS@
 MPI_EXTRA_ASM_OBJS = @MPI_EXTRA_ASM_OBJS@
 MSGFMT = @MSGFMT@
 PACKAGE = @PACKAGE@
 POFILES = @POFILES@
 POSUB = @POSUB@
 RANLIB = @RANLIB@
+USE_INCLUDED_LIBINTL = @USE_INCLUDED_LIBINTL@
+USE_NLS = @USE_NLS@
 VERSION = @VERSION@
 ZLIBS = @ZLIBS@
+l = @l@
 
 INCLUDES = -I$(top_srcdir)/include
 EXTRA_DIST = OPTIONS  pubring.asc
@@ -219,7 +225,7 @@
 	done
 
 uninstall-binPROGRAMS:
-	$(NORMAL_UNINSTALL)
+	@$(NORMAL_UNINSTALL)
 	list='$(bin_PROGRAMS)'; for p in $$list; do \
 	  rm -f $(bindir)/`echo $$p|sed '$(transform)'`; \
 	done
@@ -234,7 +240,7 @@
 	$(COMPILE) -c $<
 
 mostlyclean-compile:
-	-rm -f *.o core
+	-rm -f *.o core *.core
 
 clean-compile:
 
@@ -260,8 +266,12 @@
 TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) $(LISP)
 	tags=; \
 	here=`pwd`; \
-	test -z "$(ETAGS_ARGS)$(SOURCES)$(HEADERS)$(LISP)$$tags" \
-	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $(SOURCES) $(HEADERS) $(LISP) -o $$here/TAGS)
+	list='$(SOURCES) $(HEADERS)'; \
+	unique=`for i in $$list; do echo $$i; done | \
+	  awk '    { files[$$0] = 1; } \
+	       END { for (i in files) print i; }'`; \
+	test -z "$(ETAGS_ARGS)$$unique$(LISP)$$tags" \
+	  || (cd $(srcdir) && etags $(ETAGS_ARGS) $$tags  $$unique $(LISP) -o $$here/TAGS)
 
 mostlyclean-tags:
 
@@ -283,69 +293,65 @@
 	  || ln $$d/$$file $(distdir)/$$file 2> /dev/null \
 	  || cp -p $$d/$$file $(distdir)/$$file; \
 	done
-armor.o armor.lo: armor.c ../config.h ../include/errors.h \
-	../include/iobuf.h ../include/types.h ../include/memory.h \
-	../include/util.h ../include/mpi.h filter.h ../include/cipher.h \
+armor.o: armor.c ../config.h ../include/errors.h ../include/iobuf.h \
+	../include/types.h ../include/memory.h ../include/util.h \
+	../include/mpi.h filter.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h packet.h options.h main.h \
 	keydb.h status.h
-build-packet.o build-packet.lo: build-packet.c ../config.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/errors.h \
-	../include/util.h options.h
-cipher.o cipher.lo: cipher.c ../config.h ../include/errors.h \
-	../include/iobuf.h ../include/types.h ../include/memory.h \
-	../include/util.h ../include/mpi.h filter.h ../include/cipher.h \
+build-packet.o: build-packet.c ../config.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
+	../include/cipher.h ../include/../cipher/md.h \
+	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
+	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
+	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
+	filter.h ../include/errors.h ../include/util.h options.h
+cipher.o: cipher.c ../config.h ../include/errors.h ../include/iobuf.h \
+	../include/types.h ../include/memory.h ../include/util.h \
+	../include/mpi.h filter.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h packet.h options.h
-comment.o comment.lo: comment.c ../config.h options.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/errors.h \
-	../include/util.h main.h keydb.h
-compress.o compress.lo: compress.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h packet.h \
+comment.o: comment.c ../config.h options.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
-	filter.h options.h
-dearmor.o dearmor.lo: dearmor.c ../config.h ../include/errors.h \
-	../include/iobuf.h ../include/types.h ../include/memory.h \
-	../include/util.h ../include/mpi.h filter.h ../include/cipher.h \
+	filter.h ../include/errors.h ../include/util.h main.h keydb.h
+compress.o: compress.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h packet.h ../include/cipher.h \
+	../include/../cipher/md.h ../include/../cipher/rmd.h \
+	../include/../cipher/sha1.h ../include/../cipher/md5.h \
+	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
+	../include/../cipher/elgamal.h filter.h options.h
+dearmor.o: dearmor.c ../config.h ../include/errors.h ../include/iobuf.h \
+	../include/types.h ../include/memory.h ../include/util.h \
+	../include/mpi.h filter.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h packet.h options.h main.h \
 	keydb.h
-elg.o elg.lo: elg.c ../config.h options.h packet.h ../include/types.h \
+elg.o: elg.c ../config.h options.h packet.h ../include/types.h \
 	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	filter.h ../include/errors.h keydb.h ../include/util.h main.h
-encode.o encode.lo: encode.c ../config.h options.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/errors.h \
-	keydb.h ../include/util.h main.h
-encr-data.o encr-data.lo: encr-data.c ../config.h ../include/util.h \
+encode.o: encode.c ../config.h options.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
+	../include/cipher.h ../include/../cipher/md.h \
+	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
+	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
+	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
+	filter.h ../include/errors.h keydb.h ../include/util.h main.h
+encr-data.o: encr-data.c ../config.h ../include/util.h \
 	../include/types.h ../include/errors.h ../include/mpi.h \
 	../include/iobuf.h ../include/memory.h packet.h \
 	../include/cipher.h ../include/../cipher/md.h \
@@ -353,113 +359,106 @@
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	filter.h
-export.o export.lo: export.c ../config.h options.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/errors.h \
-	keydb.h ../include/util.h main.h
-free-packet.o free-packet.lo: free-packet.c ../config.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/util.h \
-	../include/errors.h
-g10.o g10.lo: g10.c ../config.h packet.h ../include/types.h \
+export.o: export.c ../config.h options.h packet.h ../include/types.h \
 	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
-	filter.h ../include/util.h ../include/errors.h main.h keydb.h \
-	options.h trustdb.h ../include/ttyio.h ../include/i18n.h \
-	status.h
-g10maint.o g10maint.lo: g10maint.c ../config.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
+	filter.h ../include/errors.h keydb.h ../include/util.h main.h
+free-packet.o: free-packet.c ../config.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
+	../include/cipher.h ../include/../cipher/md.h \
+	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
+	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
+	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
+	filter.h ../include/util.h ../include/errors.h
+g10.o: g10.c ../config.h packet.h ../include/types.h ../include/iobuf.h \
+	../include/mpi.h ../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h filter.h ../include/util.h \
 	../include/errors.h main.h keydb.h options.h trustdb.h \
 	../include/ttyio.h ../include/i18n.h status.h
-getkey.o getkey.lo: getkey.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h packet.h \
+g10maint.o: g10maint.c ../config.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
-	filter.h keydb.h options.h
-import.o import.lo: import.c ../config.h options.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
+	filter.h ../include/util.h ../include/errors.h main.h keydb.h \
+	options.h trustdb.h ../include/ttyio.h ../include/i18n.h \
+	status.h
+getkey.o: getkey.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h packet.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/errors.h \
-	keydb.h ../include/util.h trustdb.h main.h
-kbnode.o kbnode.lo: kbnode.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h packet.h \
-	../include/cipher.h ../include/../cipher/md.h \
-	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
-	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
-	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
-	filter.h keydb.h
-keygen.o keygen.lo: keygen.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h main.h \
+	../include/../cipher/elgamal.h filter.h keydb.h options.h
+import.o: import.c ../config.h options.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
-	keydb.h packet.h filter.h ../include/ttyio.h options.h \
-	../include/i18n.h
-keyid.o keyid.lo: keyid.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h main.h \
+	filter.h ../include/errors.h keydb.h ../include/util.h \
+	trustdb.h main.h
+kbnode.o: kbnode.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h packet.h ../include/cipher.h \
+	../include/../cipher/md.h ../include/../cipher/rmd.h \
+	../include/../cipher/sha1.h ../include/../cipher/md5.h \
+	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
+	../include/../cipher/elgamal.h filter.h keydb.h
+keygen.o: keygen.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h main.h ../include/cipher.h \
+	../include/../cipher/md.h ../include/../cipher/rmd.h \
+	../include/../cipher/sha1.h ../include/../cipher/md5.h \
+	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
+	../include/../cipher/elgamal.h keydb.h packet.h filter.h \
+	../include/ttyio.h options.h ../include/i18n.h
+keyid.o: keyid.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h main.h ../include/cipher.h \
+	../include/../cipher/md.h ../include/../cipher/rmd.h \
+	../include/../cipher/sha1.h ../include/../cipher/md5.h \
+	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
+	../include/../cipher/elgamal.h keydb.h packet.h filter.h \
+	options.h
+mainproc.o: mainproc.c ../config.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
-	keydb.h packet.h filter.h options.h
-mainproc.o mainproc.lo: mainproc.c ../config.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h options.h \
-	../include/util.h ../include/errors.h keydb.h main.h status.h
-mdfilter.o mdfilter.lo: mdfilter.c ../config.h ../include/errors.h \
+	filter.h options.h ../include/util.h ../include/errors.h \
+	keydb.h main.h status.h
+mdfilter.o: mdfilter.c ../config.h ../include/errors.h \
 	../include/iobuf.h ../include/types.h ../include/memory.h \
 	../include/util.h ../include/mpi.h filter.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h
-openfile.o openfile.lo: openfile.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/ttyio.h \
-	options.h main.h ../include/cipher.h ../include/../cipher/md.h \
+openfile.o: openfile.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/ttyio.h options.h main.h \
+	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	keydb.h packet.h filter.h
-parse-packet.o parse-packet.lo: parse-packet.c ../config.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/util.h \
-	../include/errors.h options.h
-passphrase.o passphrase.lo: passphrase.c ../config.h ../include/util.h \
+parse-packet.o: parse-packet.c ../config.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
+	../include/cipher.h ../include/../cipher/md.h \
+	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
+	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
+	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
+	filter.h ../include/util.h ../include/errors.h options.h
+passphrase.o: passphrase.c ../config.h ../include/util.h \
 	../include/types.h ../include/errors.h ../include/mpi.h \
 	../include/iobuf.h ../include/memory.h options.h \
 	../include/ttyio.h ../include/cipher.h \
@@ -467,16 +466,15 @@
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h keydb.h packet.h filter.h
-pkclist.o pkclist.lo: pkclist.c ../config.h options.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/errors.h \
-	keydb.h ../include/util.h trustdb.h ../include/ttyio.h \
-	../include/i18n.h
-plaintext.o plaintext.lo: plaintext.c ../config.h ../include/util.h \
+pkclist.o: pkclist.c ../config.h options.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
+	../include/cipher.h ../include/../cipher/md.h \
+	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
+	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
+	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
+	filter.h ../include/errors.h keydb.h ../include/util.h \
+	trustdb.h ../include/ttyio.h ../include/i18n.h
+plaintext.o: plaintext.c ../config.h ../include/util.h \
 	../include/types.h ../include/errors.h ../include/mpi.h \
 	../include/iobuf.h ../include/memory.h options.h packet.h \
 	../include/cipher.h ../include/../cipher/md.h \
@@ -484,7 +482,7 @@
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	filter.h ../include/ttyio.h main.h keydb.h
-pubkey-enc.o pubkey-enc.lo: pubkey-enc.c ../config.h ../include/util.h \
+pubkey-enc.o: pubkey-enc.c ../config.h ../include/util.h \
 	../include/types.h ../include/errors.h ../include/mpi.h \
 	../include/iobuf.h ../include/memory.h packet.h \
 	../include/cipher.h ../include/../cipher/md.h \
@@ -492,45 +490,44 @@
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	filter.h keydb.h
-revoke.o revoke.lo: revoke.c ../config.h options.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/errors.h \
-	keydb.h ../include/util.h main.h ../include/ttyio.h
-ringedit.o ringedit.lo: ringedit.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h packet.h \
+revoke.o: revoke.c ../config.h options.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
-	filter.h keydb.h
-rsa.o rsa.lo: rsa.c ../config.h options.h packet.h ../include/types.h \
+	filter.h ../include/errors.h keydb.h ../include/util.h main.h \
+	../include/ttyio.h
+ringedit.o: ringedit.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h packet.h ../include/cipher.h \
+	../include/../cipher/md.h ../include/../cipher/rmd.h \
+	../include/../cipher/sha1.h ../include/../cipher/md5.h \
+	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
+	../include/../cipher/elgamal.h filter.h keydb.h
+rsa.o: rsa.c ../config.h options.h packet.h ../include/types.h \
 	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	filter.h ../include/errors.h keydb.h ../include/util.h main.h
-seckey-cert.o seckey-cert.lo: seckey-cert.c ../config.h \
-	../include/util.h ../include/types.h ../include/errors.h \
-	../include/mpi.h ../include/iobuf.h ../include/memory.h \
-	packet.h ../include/cipher.h ../include/../cipher/md.h \
+seckey-cert.o: seckey-cert.c ../config.h ../include/util.h \
+	../include/types.h ../include/errors.h ../include/mpi.h \
+	../include/iobuf.h ../include/memory.h packet.h \
+	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	filter.h keydb.h
-seskey.o seskey.lo: seskey.c ../config.h ../include/util.h \
-	../include/types.h ../include/errors.h ../include/mpi.h \
-	../include/iobuf.h ../include/memory.h ../include/cipher.h \
+seskey.o: seskey.c ../config.h ../include/util.h ../include/types.h \
+	../include/errors.h ../include/mpi.h ../include/iobuf.h \
+	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h main.h keydb.h packet.h filter.h
-sig-check.o sig-check.lo: sig-check.c ../config.h ../include/util.h \
+sig-check.o: sig-check.c ../config.h ../include/util.h \
 	../include/types.h ../include/errors.h ../include/mpi.h \
 	../include/iobuf.h ../include/memory.h packet.h \
 	../include/cipher.h ../include/../cipher/md.h \
@@ -538,7 +535,7 @@
 	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	filter.h keydb.h main.h
-sign.o sign.lo: sign.c ../config.h options.h packet.h ../include/types.h \
+sign.o: sign.c ../config.h options.h packet.h ../include/types.h \
 	../include/iobuf.h ../include/mpi.h ../include/memory.h \
 	../include/cipher.h ../include/../cipher/md.h \
 	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
@@ -546,25 +543,24 @@
 	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
 	filter.h ../include/errors.h keydb.h ../include/util.h main.h \
 	../include/ttyio.h
-skclist.o skclist.lo: skclist.c ../config.h options.h packet.h \
-	../include/types.h ../include/iobuf.h ../include/mpi.h \
-	../include/memory.h ../include/cipher.h \
-	../include/../cipher/md.h ../include/../cipher/rmd.h \
-	../include/../cipher/sha1.h ../include/../cipher/md5.h \
-	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
-	../include/../cipher/elgamal.h filter.h ../include/errors.h \
-	keydb.h ../include/util.h
-status.o status.lo: status.c ../config.h status.h
-textfilter.o textfilter.lo: textfilter.c ../config.h ../include/errors.h \
+skclist.o: skclist.c ../config.h options.h packet.h ../include/types.h \
+	../include/iobuf.h ../include/mpi.h ../include/memory.h \
+	../include/cipher.h ../include/../cipher/md.h \
+	../include/../cipher/rmd.h ../include/../cipher/sha1.h \
+	../include/../cipher/md5.h ../include/../cipher/blowfish.h \
+	../include/../cipher/gost.h ../include/../cipher/elgamal.h \
+	filter.h ../include/errors.h keydb.h ../include/util.h
+status.o: status.c ../config.h status.h
+textfilter.o: textfilter.c ../config.h ../include/errors.h \
 	../include/iobuf.h ../include/types.h ../include/memory.h \
 	../include/util.h ../include/mpi.h filter.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
 	../include/../cipher/elgamal.h
-trustdb.o trustdb.lo: trustdb.c ../config.h ../include/errors.h \
-	../include/iobuf.h ../include/types.h keydb.h packet.h \
-	../include/mpi.h ../include/memory.h ../include/cipher.h \
+trustdb.o: trustdb.c ../config.h ../include/errors.h ../include/iobuf.h \
+	../include/types.h keydb.h packet.h ../include/mpi.h \
+	../include/memory.h ../include/cipher.h \
 	../include/../cipher/md.h ../include/../cipher/rmd.h \
 	../include/../cipher/sha1.h ../include/../cipher/md5.h \
 	../include/../cipher/blowfish.h ../include/../cipher/gost.h \
diff -urN gnupg-0.2.8/g10/OPTIONS gnupg-0.2.9/g10/OPTIONS
--- gnupg-0.2.8/g10/OPTIONS	Tue Feb 17 09:40:32 1998
+++ gnupg-0.2.9/g10/OPTIONS	Thu Feb 26 14:24:51 1998
@@ -1,11 +1,11 @@
 # This is a sample option file
 #
 # Unless you you specify which option file to use with the
-# commandline option "--options filename", g10 uses per
-# default the file ~/.g10/options.
+# commandline option "--options filename", gpg uses per
+# default the file ~/.gnupg/options.
 #
 # An option file can contain all long options which are
-# available in G10. If the first non white space character of
+# available in GNUPG. If the first non white space character of
 # a line is a '#', this line is ignored.  Empty lines are also
 # ignored.
 #
@@ -19,41 +19,6 @@
 #-----------------------------------------------
 # With some expections, those cannot be combined
 
-add-key
-# add key to the public keyring
-
-change-passphrase
-# change the passphrase of your secret keyring
-
-check
-# check a signature
-
-decrypt
-# decrypt data (default)
-
-delete-key
-# remove key from public keyring,
-
-edit-sig
-# edit a key signature. Currently you have only the option to delete
-# some signatures.
-
-encrypt
-# (Can be combined with a "sign")
-# encrypt data
-
-export <names>
-# Either export all keys from all keyrings (default keyrings and
-# those registered via option "keyring"), or if at least one name is
-# given, those of the givename. The new keyring is written to stdout
-# or to the file given with option "output"
-
-fingerprint
-# show the fingerprints,
-
-gen-key
-# generate a new key pair, this is an interactive command.
-
 gen-prime
 # Generate a prime.
 # With one argument:  take it as the bitsize and make a simple prime of
@@ -62,160 +27,10 @@
 # With three arguments: same as above, but a third argument indicates
 #			that a generator should also be calculated.
 
-list-packets
-# List only the sequence of packets"},
-
-
 print-mds
 # print all message digests of all give filenames
 
-sign
-# (Can be combined with a "encrypt")
-# make a signature
-
 sign-key
-# make a signature on a key in the keyring
-# Argument is the userid of the key to sign.
-# This looks for the key, displays the key and checks all
-# existing signatures of this key. If the key is not yet signed
-# by the default user (or the users given with "-l"), the programm
-# displays the information of the key again, together with
-# it's fingerprint and asked wehter it should be signed. This question
-# is repeated for all users specified with "-l".  The key is then signed
-# and the keyring which contains the key is updated.
-
 store
 # simply packs the input data into a rfc1991 packet format
-
-symmetric
-# encrypt the input only with the symmetric (conventional) cipher.
-# This asks for a passphrase.
-
-
-test
-# Used for testing some parts of the program
-
-#----------------------------------------------
-#------  Options without a long form ----------
-#----------------------------------------------
-
--k
-# List keyrings.
-# Without arguments, all default public keyrings are listed
-# With one argument, this keyring is listed.
-#
-# -kv	 is the same as -k
-# -kvv	 list the signatures with every key
-# -kvvv  additional checks all signatures
-# -kvc	 list fingerprints
-# -kvvc  list fingerprints and signatures
-# Note that this is a kludge, to emulate the strange pgp syntax;
-# combining it with other options may give other outputs.
-
-
-
--z n
-# Set compress level to n.
-# n = 0 disables compresson. Default compress level depends on
-# the local zlib (6).
-
-
-#-----------------------------------------------
-#------------------- Options -------------------
-#-----------------------------------------------
-
-
-armor
-# create ascii armored output
-
-
-batch
-# batch mode: never ask
-
-no-batch
-# disables batch
-
-cache-all
-# hold everything in memory
-
-
-check-key
-# check signatures on a key in the keyring
-
-debug  value|hexvalue
-#  set debugging flags,
-
-debug-all
-# enable full debugging
-
-
-detach-sign
-# make a detached signature,
-
-dry-run
-# don't make any changes
-
-homedir dirname
-# Set the name of the home directory which defaults to "~/.g10".
-
-keyring  filename
-# add this filename to the list of keyrings.
-# If the filename begins with a tilde and a slash, these are replaced
-# by the HOME directory. If the filename does not contain a slash, it
-# is assumed to be in "~/.g10"
-
-local-user user-string
-#  use this user-string to sign or decrypt
-
-no
-# assume no on most questions
-
-no-armor
-# Assume the input data is not in ascii armored format.
-
-no-default-keyring
-# Do not add the default keyrings to the list of keyrings
-
-no-greeting
-# suppress the initial copyright etc. messages but do not enter batch mode.
-
-no-verbose
-# set verbose level to 0
-
-options filename
-#  Ignored in option files.
-
-no-options
-# same as --options /dev/null.	This option is detected
-# before an attempt to open an option file
-
-output filename
-# use filename for output
-
-passphrase-fd n
-# Read the passphrase from file with the descriptor n.	If you use
-# 0 for n, the passphrase will be read from stdin.  This can only be used
-# if only one passphrase is supplied.
-
-
-remote-user
-# use this user-id for encryption"
-
-secret-keyring filename
-# add filename to the list of secret keyrings
-# see "keyring" for further informations
-
-status-fd n
-# Write status informations to this file descriptor. If this option
-# is not used, no status information is writte.  This option is for the
-# sake of a calling programm (e.g. a MUA) to ease up parsing of output
-# and providing a defined set of status messages.
-# FIXME: use a format ala "100 Blabla"?
-
-verbose
-# Give more informations suring processing. If used 2 times, the input data
-# is listed in detail.
-
-yes
-# assume yes on most questions
 
diff -urN gnupg-0.2.8/g10/g10.c gnupg-0.2.9/g10/g10.c
--- gnupg-0.2.8/g10/g10.c	Tue Feb 24 16:09:00 1998
+++ gnupg-0.2.9/g10/g10.c	Thu Feb 26 16:49:31 1998
@@ -137,7 +137,7 @@
   static char *digests, *pubkeys, *ciphers;
     const char *p;
     switch( level ) {
-      case 11: p = "GNUPG"; break;
+      case 11: p = "gpg (GNUPG)"; break;
       case 13: p = VERSION; break;
       case 17: p = PRINTABLE_OS_NAME; break;
       case 19: p = _(
diff -urN gnupg-0.2.8/g10/keygen.c gnupg-0.2.9/g10/keygen.c
--- gnupg-0.2.8/g10/keygen.c	Tue Feb 24 15:24:41 1998
+++ gnupg-0.2.9/g10/keygen.c	Wed Feb 25 08:38:19 1998
@@ -502,7 +502,7 @@
 
     tty_printf(_("You need a Passphrase to protect your secret key.\n\n") );
 
-    dek = m_alloc_secure( sizeof *dek );
+    dek = m_alloc_secure( sizeof *dek + 8 );
     salt = (byte*)dek + sizeof *dek;
     for(;;) {
 	dek->algo = CIPHER_ALGO_BLOWFISH;
diff -urN gnupg-0.2.8/g10/openfile.c gnupg-0.2.9/g10/openfile.c
--- gnupg-0.2.8/g10/openfile.c	Tue Feb 24 15:58:57 1998
+++ gnupg-0.2.9/g10/openfile.c	Wed Feb 25 11:43:07 1998
@@ -124,7 +124,7 @@
 
 
 /****************
- * Try to open a file without the extension ".sig"
+ * Try to open a file without the extension ".sig" or ".asc"
  * Return NULL if such a file is not available.
  */
 IOBUF
@@ -135,7 +135,8 @@
 
     if( iname ) {
 	len = strlen(iname);
-	if( len > 4 && !strcmp(iname + len - 4, ".sig") ) {
+	if( len > 4 && ( !strcmp(iname + len - 4, ".sig")
+			|| !strcmp(iname + len - 4, ".asc")) ) {
 	    char *buf;
 	    buf = m_strdup(iname);
 	    buf[len-4] = 0 ;
diff -urN gnupg-0.2.8/g10/plaintext.c gnupg-0.2.9/g10/plaintext.c
--- gnupg-0.2.8/g10/plaintext.c	Mon Feb 23 13:10:49 1998
+++ gnupg-0.2.9/g10/plaintext.c	Wed Feb 25 11:41:34 1998
@@ -160,7 +160,8 @@
     }
 
     if( !fp ) {
-	log_info("reading stdin ...\n");
+	if( opt.verbose )
+	    log_info("reading stdin ...\n");
 	while( (c = getchar()) != EOF ) {
 	    if( mfx->md )
 		md_putc(mfx->md, c );
diff -urN gnupg-0.2.8/intl/ChangeLog gnupg-0.2.9/intl/ChangeLog
--- gnupg-0.2.8/intl/ChangeLog	Mon Jan 26 20:10:55 1998
+++ gnupg-0.2.9/intl/ChangeLog	Thu Feb 26 16:27:25 1998
@@ -1,3 +1,334 @@
+1997-09-06 02:10  Ulrich Drepper  <drepper@cygnus.com>
+
+	* intlh.inst.in: Reformat copyright.
+
+1997-08-19 15:22  Ulrich Drepper  <drepper@cygnus.com>
+
+	* dcgettext.c (DCGETTEXT): Remove wrong comment.
+
+1997-08-16 00:13  Ulrich Drepper  <drepper@cygnus.com>
+
+	* Makefile.in (install-data): Don't change directory to install.
+
+1997-08-01 14:30  Ulrich Drepper  <drepper@cygnus.com>
+
+	* cat-compat.c: Fix copyright.
+
+	* localealias.c: Don't define strchr unless !HAVE_STRCHR.
+
+	* loadmsgcat.c: Update copyright.  Fix typos.
+
+	* l10nflist.c: Don't define strchr unless !HAVE_STRCHR.
+	(_nl_make_l10nflist): Handle sponsor and revision correctly.
+
+	* gettext.c: Update copyright.
+	* gettext.h: Likewise.
+	* hash-string.h: Likewise.
+
+	* finddomain.c: Remoave dead code.  Define strchr only if
+	!HAVE_STRCHR.
+
+	* explodename.c: Include <sys/types.h>.
+
+	* explodename.c: Reformat copyright text.
+	(_nl_explode_name): Fix typo.
+
+	* dcgettext.c: Define and use __set_errno.
+	(guess_category_value): Don't use setlocale if HAVE_LC_MESSAGES is
+	not defined.
+
+	* bindtextdom.c: Pretty printing.
+
+1997-05-01 02:25  Ulrich Drepper  <drepper@cygnus.com>
+
+	* dcgettext.c (guess_category_value): Don't depend on
+	HAVE_LC_MESSAGES.  We don't need the macro here.
+	Patch by Bruno Haible <haible@ilog.fr>.
+
+	* cat-compat.c (textdomain): DoN't refer to HAVE_SETLOCALE_NULL
+	macro.  Instead use HAVE_LOCALE_NULL and define it when using
+	glibc, as in dcgettext.c.
+	Patch by Bruno Haible <haible@ilog.fr>.
+
+	* Makefile.in (CPPFLAGS): New variable.  Reported by Franc,ois
+	Pinard.
+
+Mon Mar 10 06:51:17 1997  Ulrich Drepper  <drepper@cygnus.com>
+
+	* Makefile.in: Implement handling of libtool.
+
+	* gettextP.h: Change data structures for use of generic lowlevel
+	i18n file handling.
+
+Wed Dec  4 20:21:18 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* textdomain.c: Put parentheses around arguments of memcpy macro
+	definition.
+	* localealias.c: Likewise.
+	* l10nflist.c: Likewise.
+	* finddomain.c: Likewise.
+	* bindtextdom.c: Likewise.
+	Reported by Thomas Esken.
+
+Mon Nov 25 22:57:51 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* textdomain.c: Move definition of `memcpy` macro to right
+	position.
+
+Fri Nov 22 04:01:58 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* finddomain.c [!HAVE_STRING_H && !_LIBC]: Define memcpy using
+ 	bcopy if not already defined.  Reported by Thomas Esken.
+	* bindtextdom.c: Likewise.
+	* l10nflist.c: Likewise.
+	* localealias.c: Likewise.
+	* textdomain.c: Likewise.
+
+Tue Oct 29 11:10:27 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* Makefile.in (libdir): Change to use exec_prefix instead of
+ 	prefix.  Reported by Knut-HvardAksnes <etokna@eto.ericsson.se>.
+
+Sat Aug 31 03:07:09 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* l10nflist.c (_nl_normalize_codeset): We convert to lower case,
+	so don't prepend uppercase `ISO' for only numeric arg.
+
+Fri Jul 19 00:15:46 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* l10nflist.c: Move inclusion of argz.h, ctype.h, stdlib.h after
+	definition of _GNU_SOURCE.  Patch by Roland McGrath.
+
+	* Makefile.in (uninstall): Fix another bug with `for' loop and
+	empty arguments.  Patch by Jim Meyering.  Correct name os
+	uninstalled files: no intl- prefix anymore.
+
+	* Makefile.in (install-data): Again work around shells which
+	cannot handle mpty for list.  Reported by Jim Meyering.
+
+Sat Jul 13 18:11:35 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* Makefile.in (install): Split goal.  Now depend on install-exec
+        and install-data.
+	(install-exec, install-data): New goals.  Created from former
+	install goal.
+	Reported by Karl Berry.
+
+Sat Jun 22 04:58:14 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* Makefile.in (MKINSTALLDIRS): New variable.  Path to
+        mkinstalldirs script.
+	(install): use MKINSTALLDIRS variable or if the script is not present
+	try to find it in the $top_scrdir).
+
+Wed Jun 19 02:56:56 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* l10nflist.c: Linux libc *partly* includes the argz_* functions.
+	Grr.  Work around by renaming the static version and use macros
+	for renaming.
+
+Tue Jun 18 20:11:17 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* l10nflist.c: Correct presence test macros of __argz_* functions.
+
+	* l10nflist.c: Include <argz.h> based on test of it instead when
+	__argz_* functions are available.
+	Reported by Andreas Schwab.
+
+Thu Jun 13 15:17:44 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* explodename.c, l10nflist.c: Define NULL for dumb systems.
+
+Tue Jun 11 17:05:13 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* intlh.inst.in, libgettext.h (dcgettext): Rename local variable
+	result to __result to prevent name clash.
+
+	* l10nflist.c, localealias.c, dcgettext.c: Define _GNU_SOURCE to
+        get prototype for stpcpy and strcasecmp.
+
+	* intlh.inst.in, libgettext.h: Move declaration of
+	`_nl_msg_cat_cntr' outside __extension__ block to prevent warning
+	from gcc's -Wnested-extern option.
+
+Fri Jun  7 01:58:00 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* Makefile.in (install): Remove comment.
+
+Thu Jun  6 17:28:17 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* Makefile.in (install): Work around for another Buglix stupidity.
+	Always use an `else' close for `if's.  Reported by Nelson Beebe.
+
+	* Makefile.in (intlh.inst): Correct typo in phony rule.
+	Reported by Nelson Beebe.
+
+Thu Jun  6 01:49:52 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* dcgettext.c (read_alias_file): Rename variable alloca_list to
+	block_list as the macro calls assume.
+	Patch by Eric Backus.
+
+	* localealias.c [!HAVE_ALLOCA]: Define alloca as macro using
+        malloc.
+	(read_alias_file): Rename varriabe alloca_list to block_list as the
+	macro calls assume.
+	Patch by Eric Backus.
+
+	* l10nflist.c: Correct conditional for <argz.h> inclusion.
+	Reported by Roland McGrath.
+
+	* Makefile.in (all): Depend on all-@USE_INCLUDED_LIBINTL@, not
+        all-@USE_NLS@.
+
+	* Makefile.in (install): intlh.inst comes from local dir, not
+        $(srcdir).
+
+	* Makefile.in (intlh.inst): Special handling of this goal.  If
+	used in gettext, this is really a rul to construct this file.  If
+	used in any other package it is defined as a .PHONY rule with
+	empty body.
+
+	* finddomain.c: Extract locale file information handling into
+	l10nfile.c.  Rename local stpcpy__ function to stpcpy.
+
+	* dcgettext.c (stpcpy): Add local definition.
+
+	* l10nflist.c: Solve some portability problems.  Patches partly by
+	Thomas Esken.  Add local definition of stpcpy.
+
+Tue Jun  4 02:47:49 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* intlh.inst.in: Don't depend including <locale.h> on
+	HAVE_LOCALE_H.  Instead configure must rewrite this fiile
+	depending on the result of the configure run.
+
+	* Makefile.in (install): libintl.inst is now called intlh.inst.
+	Add rules for updating intlh.inst from intlh.inst.in.
+
+	* libintl.inst: Renamed to intlh.inst.in.
+
+	* localealias.c, dcgettext.c [__GNUC__]: Define HAVE_ALLOCA to 1
+        because gcc has __buitlin_alloca.
+	Reported by Roland McGrath.
+
+Mon Jun  3 00:32:16 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* Makefile.in (installcheck): New goal to fulfill needs of
+        automake's distcheck.
+
+	* Makefile.in (install): Reorder commands so that VERSION is
+        found.
+
+	* Makefile.in (gettextsrcdir): Now use subdirectory intl/ in
+        @datadir@/gettext.
+	(COMSRCS): Add l10nfile.c.
+	(OBJECTS): Add l10nfile.o.
+	(DISTFILES): Rename to DISTFILE.normal.  Remove $(DISTFILES.common).
+	(DISTFILE.gettext): Remove $(DISTFILES.common).
+	(all-gettext): Remove goal.
+	(install): If $(PACKAGE) = gettext install, otherwose do nothing.  No
+	package but gettext itself should install libintl.h + headers.
+	(dist): Extend goal to work for gettext, too.
+	(dist-gettext): Remove goal.
+
+	* dcgettext.c [!HAVE_ALLOCA]: Define macro alloca by using malloc.
+
+Sun Jun  2 17:33:06 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* loadmsgcat.c (_nl_load_domain): Parameter is now comes from
+        find_l10nfile.
+
+Sat Jun  1 02:23:03 1996  Ulrich Drepper  <drepper@cygnus.com>
+
+	* l10nflist.c (__argz_next): Add definition.
+
+	* dcgettext.c [!HAVE_ALLOCA]: Add code for handling missing alloca
+	code.  Use new l10nfile handling.
+
+	* localealias.c [!HAVE_ALLOCA]: Add code for handling missing
+        alloca code.
+
+	* l10nflist.c: Initial revision.
+
+Tue Apr  2 18:51:18 1996  Ulrich Drepper  <drepper@myware>
+
+	* Makefile.in (all-gettext): New goal.  Same as all-yes.
+
+Thu Mar 28 23:01:22 1996  Karl Eichwalder  <ke@ke.central.de>
+
+	* Makefile.in (gettextsrcdir): Define using @datadir@.
+
+Tue Mar 26 12:39:14 1996  Ulrich Drepper  <drepper@myware>
+
+	* finddomain.c: Include <ctype.h>.  Reported by Roland McGrath.
+
+Sat Mar 23 02:00:35 1996  Ulrich Drepper  <drepper@myware>
+
+	* finddomain.c (stpcpy): Rename to stpcpy__ to prevent clashing
+        with external declaration.
+
+Sat Mar  2 00:47:09 1996  Ulrich Drepper  <drepper@myware>
+
+	* Makefile.in (all-no): Rename from all_no.
+
+Sat Feb 17 00:25:59 1996  Ulrich Drepper  <drepper@myware>
+
+	* gettextP.h [loaded_domain]: Array `successor' must now contain up
+        to 63 elements (because of codeset name normalization).
+
+	* finddomain.c: Implement codeset name normalization.
+
+Thu Feb 15 04:39:09 1996  Ulrich Drepper  <drepper@myware>
+
+	* Makefile.in (all): Define to `all-@USE_NLS@'.
+	(all-yes, all_no): New goals.  `all-no' is noop, `all-yes'
+	is former all.
+
+Mon Jan 15 21:46:01 1996  Howard Gayle  <howard@hal.com>
+
+	* localealias.c (alias_compare): Increment string pointers in loop
+        of strcasecmp replacement.
+
+Fri Dec 29 21:16:34 1995  Ulrich Drepper  <drepper@myware>
+
+	* Makefile.in (install-src): Who commented this goal out ? :-)
+
+Fri Dec 29 15:08:16 1995  Ulrich Drepper  <drepper@myware>
+
+	* dcgettext.c (DCGETTEXT): Save `errno'.  Failing system calls
+	should not effect it because a missing catalog is no error.
+	Reported by Harald K<o:>nig <koenig@tat.physik.uni-tuebingen.de>.
+
+Tue Dec 19 22:09:13 1995  Ulrich Drepper  <drepper@myware>
+
+	* Makefile.in (Makefile): Explicitly use $(SHELL) for running
+        shell scripts.
+
+Fri Dec 15 17:34:59 1995  Andreas Schwab  <schwab@issan.informatik.uni-dortmund.de>
+
+	* Makefile.in (install-src): Only install library and header when
+	we use the own implementation.  Don't do it when using the
+	system's gettext or catgets functions.
+
+	* dcgettext.c (find_msg): Must not swap domain->hash_size here.
+
+Sat Dec  9 16:24:37 1995  Ulrich Drepper  <drepper@myware>
+
+	* localealias.c, libintl.inst, libgettext.h, hash-string.h,
+	gettextP.h, finddomain.c, dcgettext.c, cat-compat.c:
+	Use PARAMS instead of __P.  Suggested by Roland McGrath.
+
+Tue Dec  5 11:39:14 1995  Larry Schwimmer  <rosebud@cyclone.stanford.edu>
+
+	* libgettext.h: Use `#if !defined (_LIBINTL_H)' instead of `#if
+	!_LIBINTL_H' because Solaris defines _LIBINTL_H as empty.
+
+Mon Dec  4 15:42:07 1995  Ulrich Drepper  <drepper@myware>
+
+	* Makefile.in (install-src):
+	Install libintl.inst instead of libintl.h.install.
+
 Sat Dec  2 22:51:38 1995  Marcus Daniels  <marcus@sysc.pdx.edu>
 
 	* cat-compat.c (textdomain):
@@ -689,5 +1020,3 @@
 	which allow to use the X/Open catgets function with an interface
 	like the Uniforum gettext function.  For system which does not
 	have neither of those a complete implementation is provided.
-
-
diff -urN gnupg-0.2.8/intl/Makefile.in gnupg-0.2.9/intl/Makefile.in
--- gnupg-0.2.8/intl/Makefile.in	Wed Jan 28 16:33:52 1998
+++ gnupg-0.2.9/intl/Makefile.in	Thu Feb 26 16:27:25 1998
@@ -1,5 +1,5 @@
 # Makefile for directory with message catalog handling in GNU NLS Utilities.
-# Copyright (C) 1995 Free Software Foundation, Inc.
+# Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -8,7 +8,7 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
@@ -22,98 +22,137 @@
 
 srcdir = @srcdir@
 top_srcdir = @top_srcdir@
+top_builddir = ..
 VPATH = @srcdir@
 
 prefix = @prefix@
 exec_prefix = @exec_prefix@
 transform = @program_transform_name@
-libdir = $(prefix)/lib
+libdir = $(exec_prefix)/lib
 includedir = $(prefix)/include
 datadir = $(prefix)/@DATADIRNAME@
 localedir = $(datadir)/locale
 gnulocaledir = $(prefix)/share/locale
-gettextsrcdir = $(prefix)/share/gettext
+gettextsrcdir = @datadir@/gettext/intl
 aliaspath = $(localedir):.
 subdir = intl
 
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
+MKINSTALLDIRS = @MKINSTALLDIRS@
+
+l = @l@
 
 AR = ar
 CC = @CC@
+LIBTOOL = @LIBTOOL@
 RANLIB = @RANLIB@
 
 DEFS = -DLOCALEDIR=\"$(localedir)\" -DGNULOCALEDIR=\"$(gnulocaledir)\" \
 -DLOCALE_ALIAS_PATH=\"$(aliaspath)\" @DEFS@
+CPPFLAGS = @CPPFLAGS@
 CFLAGS = @CFLAGS@
+LDFLAGS = @LDFLAGS@
 
 COMPILE = $(CC) -c $(DEFS) $(INCLUDES) $(CPPFLAGS) $(CFLAGS) $(XCFLAGS)
 
-HEADERS = $(COMHDRS) libgettext.h
+HEADERS = $(COMHDRS) libgettext.h loadinfo.h
 COMHDRS = gettext.h gettextP.h hash-string.h
 SOURCES = $(COMSRCS) intl-compat.c cat-compat.c
 COMSRCS = bindtextdom.c dcgettext.c dgettext.c gettext.c \
-finddomain.c loadmsgcat.c localealias.c textdomain.c
-OBJECTS = @INTLOBJS@ bindtextdom.o dcgettext.o dgettext.o gettext.o \
-finddomain.o loadmsgcat.o localealias.o textdomain.o
-CATOBJS = cat-compat.o ../po/cat-id-tbl.o
-GETTOBJS = intl-compat.o
+finddomain.c loadmsgcat.c localealias.c textdomain.c l10nflist.c \
+explodename.c
+OBJECTS = @INTLOBJS@ bindtextdom.$lo dcgettext.$lo dgettext.$lo gettext.$lo \
+finddomain.$lo loadmsgcat.$lo localealias.$lo textdomain.$lo l10nflist.$lo \
+explodename.$lo
+CATOBJS = cat-compat.$lo ../po/cat-id-tbl.$lo
+GETTOBJS = intl-compat.$lo
 DISTFILES.common = ChangeLog Makefile.in linux-msg.sed po2tbl.sed.in \
 xopen-msg.sed $(HEADERS) $(SOURCES)
-DISTFILES = $(DISTFILES.common) VERSION
-DISTFILES.gettext = $(DISTFILES.common) libintl.glibc libintl.inst
+DISTFILES.normal = VERSION
+DISTFILES.gettext = libintl.glibc intlh.inst.in
 
 .SUFFIXES:
-.SUFFIXES: .c .o
+.SUFFIXES: .c .o .lo
 .c.o:
 	$(COMPILE) $<
+.c.lo:
+	$(LIBTOOL) --mode=compile $(COMPILE) $<
 
 INCLUDES = -I.. -I. -I$(top_srcdir)/intl -I$(top_srcdir)/lib
 
-all: libintl.a
+all: all-@USE_INCLUDED_LIBINTL@
 
+all-yes: libintl.$la intlh.inst
+all-no:
 
 libintl.a: $(OBJECTS)
 	rm -f $@
 	$(AR) cru $@ $(OBJECTS)
 	$(RANLIB) $@
 
-../po/cat-id-tbl.o: ../po/cat-id-tbl.c $(top_srcdir)/po/$(PACKAGE).pot
-	cd ../po && $(MAKE) cat-id-tbl.o
+libintl.la: $(OBJECTS)
+	$(LIBTOOL) --mode=link $(CC) $(LDFLAGS) -o $@ $(OBJECTS) \
+		   -version-info 1:0 -rpath $(libdir)
+
+../po/cat-id-tbl.$lo: ../po/cat-id-tbl.c $(top_srcdir)/po/$(PACKAGE).pot
+	cd ../po && $(MAKE) cat-id-tbl.$lo
 
-check install: all
+check: all
 
 # This installation goal is only used in GNU gettext.  Packages which
 # only use the library should use install instead.
-#
-# We must not install the libintl.h/libintl.a files if we are on a system
-# which has the gettext() function in its C library or in a separate
-# library.  A special case is where configure found a previously installed
-# GNU gettext library.	If you want to use the one which comes with this
-# version of the package, you have to use `configure --with-gnu-gettext'.
-install-src: install
-	$(top_srcdir)/mkinstalldirs $(libdir) $(includedir) $(gettextsrcdir)
-	if test -f libintl.h; then \
-	  $(INSTALL_DATA) $(srcdir)/libintl.inst \
-	    $(includedir)/libintl.h; \
+
+# We must not install the libintl.h/libintl.a files if we are on a
+# system which has the gettext() function in its C library or in a
+# separate library or use the catgets interface.  A special case is
+# where configure found a previously installed GNU gettext library.
+# If you want to use the one which comes with this version of the
+# package, you have to use `configure --with-included-gettext'.
+install: install-exec install-data
+install-exec: all
+	if test "$(PACKAGE)" = "gettext" \
+	   && test '@INTLOBJS@' = '$(GETTOBJS)'; then \
+	  if test -r $(MKINSTALLDIRS); then \
+	    $(MKINSTALLDIRS) $(libdir) $(includedir); \
+	  else \
+	    $(top_srcdir)/mkinstalldirs $(libdir) $(includedir); \
+	  fi; \
+	  $(INSTALL_DATA) intlh.inst $(includedir)/libintl.h; \
 	  $(INSTALL_DATA) libintl.a $(libdir)/libintl.a; \
+	else \
+	  : ; \
+	fi
+install-data: all
+	if test "$(PACKAGE)" = "gettext"; then \
+	  if test -r $(MKINSTALLDIRS); then \
+	    $(MKINSTALLDIRS) $(gettextsrcdir); \
+	  else \
+	    $(top_srcdir)/mkinstalldirs $(gettextsrcdir); \
+	  fi; \
+	  $(INSTALL_DATA) VERSION $(gettextsrcdir)/VERSION; \
+	  dists="$(DISTFILES.common)"; \
+	  for file in $$dists; do \
+	    $(INSTALL_DATA) $(srcdir)/$$file $(gettextsrcdir)/$$file; \
+	  done; \
+	else \
+	  : ; \
 	fi
-	cd $(srcdir) && \
-	for file in $(DISTFILES.common); do \
-	  $(INSTALL_DATA) $$file $(gettextsrcdir)/intl-$$file; \
-	done
-	$(INSTALL_DATA) VERSION $(gettextsrcdir)/intl-VERSION
+
+# Define this as empty until I found a useful application.
+installcheck:
 
 uninstall:
-	for file in $(DISTFILES); do \
-	  rm -f $(gettextsrcdir)/intl-$$file; \
+	dists="$(DISTFILES.common)"; \
+	for file in $$dists; do \
+	  rm -f $(gettextsrcdir)/$$file; \
 	done
 
 info dvi:
 
-$(OBJECTS): ../config.h libgettext.h
-bindtextdom.o finddomain.o loadmsgcat.o: gettextP.h gettext.h
-dcgettext.o: gettextP.h gettext.h hash-string.h
+$(OBJECTS): $(top_builddir)/config.h libgettext.h
+bindtextdom.$lo finddomain.$lo loadmsgcat.$lo: gettextP.h gettext.h loadinfo.h
+dcgettext.$lo: gettextP.h gettext.h hash-string.h loadinfo.h
 
 tags: TAGS
 
@@ -127,7 +166,7 @@
 
 
 mostlyclean:
-	rm -f *.a *.o core core.*
+	rm -f *.a *.o *.lo core core.*
 
 clean: mostlyclean
 
@@ -138,19 +177,17 @@
 	@echo "This command is intended for maintainers to use;"
 	@echo "it deletes files that may require special tools to rebuild."
 
-distdir = $(top_builddir)/$(PACKAGE)-$(VERSION)/$(subdir)
-distdir: Makefile.in $(DEP_DISTFILES)
-	@for file in `cd $(srcdir) && echo $(DISTFILES)`; do \
-	  test -f $(distdir)/$$file \
-	  || ln $(srcdir)/$$file $(distdir)/$$file 2> /dev/null \
-	  || cp -p $(srcdir)/$$file $(distdir)/$$file; \
-	done
 
-# This dist goal is only used in GNU gettext.  GNU gettext needs not contain
-# the file `VERSION' but contains some other files which should not be
-# distributed in other packages.
-dist-gettext: Makefile $(DISTFILES.gettext)
-	for file in $(DISTFILES.gettext); do \
+# GNU gettext needs not contain the file `VERSION' but contains some
+# other files which should not be distributed in other packages.
+distdir = ../$(PACKAGE)-$(VERSION)/$(subdir)
+dist distdir: Makefile $(DISTFILES)
+	if test "$(PACKAGE)" = gettext; then \
+	  additional="$(DISTFILES.gettext)"; \
+	else \
+	  additional="$(DISTFILES.normal)"; \
+	fi; \
+	for file in $(DISTFILES.common) $$additional; do \
 	  ln $(srcdir)/$$file $(distdir) 2> /dev/null \
 	    || cp -p $(srcdir)/$$file $(distdir); \
 	done
@@ -158,8 +195,19 @@
 dist-libc:
 	tar zcvf intl-glibc.tar.gz $(COMSRCS) $(COMHDRS) libintl.h.glibc
 
-Makefile: Makefile.in ../config.status
-	cd .. && CONFIG_FILES=$(subdir)/$@ CONFIG_HEADERS= ./config.status
+Makefile: Makefile.in $(top_builddir)/config.status
+	cd $(top_builddir) \
+	  && CONFIG_FILES=$(subdir)/$@ CONFIG_HEADERS= $(SHELL) ./config.status
+
+# The dependency for intlh.inst is different in gettext and all other
+# packages.  Because we cannot you GNU make features we have to solve
+# the problem while rewriting Makefile.in.
+@GT_YES@intlh.inst: intlh.inst.in $(top_builddir)/config.status
+@GT_YES@	cd $(top_builddir) \
+@GT_YES@	&& CONFIG_FILES=$(subdir)/$@ CONFIG_HEADERS= \
+@GT_YES@	  $(SHELL) ./config.status
+@GT_NO@.PHONY: intlh.inst
+@GT_NO@intlh.inst:
 
 # Tell versions [3.59,3.63) of GNU make not to export all variables.
 # Otherwise a system limit (for SysV at least) may be exceeded.
